/*
 *  Copyright (C) 1996-2017 Edward F. Valeev and Justin T. Fermann
 *
 *  This file is part of Libint.
 *
 *  Libint is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU Lesser General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  Libint is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public License
 *  along with Libint.  If not, see <http://www.gnu.org/licenses/>.
 *
 */

#include <stdio.h>
#include <string.h>
#include <libint/libint.h>
#include "libderiv.h"
#include <libint/hrr_header.h>

#include "d1hrr_header.h"

extern void d12vrr_order_fphp(Libderiv_t *, prim_data *);

  /* Computes derivatives of (fp|hp) integrals */

void d12hrr_order_fphp(Libderiv_t *Libderiv, int num_prim_comb)
{
 prim_data *Data = Libderiv->PrimQuartet;
 double *int_stack = Libderiv->int_stack;
 double *zero_stack = Libderiv->zero_stack;
 int i,j;
 double tmp, *target;

 Libderiv->deriv_classes[4][6][11] = int_stack + 0;
 Libderiv->deriv_classes[4][6][10] = int_stack + 420;
 Libderiv->deriv_classes[4][6][9] = int_stack + 840;
 Libderiv->deriv_classes[4][6][8] = int_stack + 1260;
 Libderiv->deriv_classes[4][6][7] = int_stack + 1680;
 Libderiv->dvrr_classes[4][5] = int_stack + 2100;
 Libderiv->deriv_classes[4][6][6] = int_stack + 2415;
 Libderiv->deriv_classes[4][6][2] = int_stack + 2835;
 Libderiv->deriv_classes[4][6][1] = int_stack + 3255;
 Libderiv->dvrr_classes[3][6] = int_stack + 3675;
 Libderiv->deriv_classes[4][6][0] = int_stack + 3955;
 Libderiv->deriv2_classes[3][5][143] = int_stack + 4375;
 Libderiv->deriv2_classes[3][6][143] = int_stack + 4585;
 Libderiv->deriv2_classes[4][5][143] = int_stack + 4865;
 Libderiv->deriv2_classes[4][6][143] = int_stack + 5180;
 Libderiv->deriv2_classes[3][5][131] = int_stack + 5600;
 Libderiv->deriv2_classes[3][6][131] = int_stack + 5810;
 Libderiv->deriv2_classes[4][5][131] = int_stack + 6090;
 Libderiv->deriv2_classes[4][6][131] = int_stack + 6405;
 Libderiv->deriv2_classes[3][5][130] = int_stack + 6825;
 Libderiv->deriv2_classes[3][6][130] = int_stack + 7035;
 Libderiv->deriv2_classes[4][5][130] = int_stack + 7315;
 Libderiv->deriv2_classes[4][6][130] = int_stack + 7630;
 Libderiv->deriv2_classes[3][5][119] = int_stack + 8050;
 Libderiv->deriv2_classes[3][6][119] = int_stack + 8260;
 Libderiv->deriv2_classes[4][5][119] = int_stack + 8540;
 Libderiv->deriv2_classes[4][6][119] = int_stack + 8855;
 Libderiv->deriv2_classes[3][5][118] = int_stack + 9275;
 Libderiv->deriv2_classes[3][6][118] = int_stack + 9485;
 Libderiv->deriv2_classes[4][5][118] = int_stack + 9765;
 Libderiv->deriv2_classes[4][6][118] = int_stack + 10080;
 Libderiv->deriv2_classes[3][5][117] = int_stack + 10500;
 Libderiv->deriv2_classes[3][6][117] = int_stack + 10710;
 Libderiv->deriv2_classes[4][5][117] = int_stack + 10990;
 Libderiv->deriv2_classes[4][6][117] = int_stack + 11305;
 Libderiv->deriv2_classes[3][5][107] = int_stack + 11725;
 Libderiv->deriv2_classes[3][6][107] = int_stack + 11935;
 Libderiv->deriv2_classes[4][5][107] = int_stack + 12215;
 Libderiv->deriv2_classes[4][6][107] = int_stack + 12530;
 Libderiv->deriv2_classes[3][5][106] = int_stack + 12950;
 Libderiv->deriv2_classes[3][6][106] = int_stack + 13160;
 Libderiv->deriv2_classes[4][5][106] = int_stack + 13440;
 Libderiv->deriv2_classes[4][6][106] = int_stack + 13755;
 Libderiv->deriv2_classes[3][5][105] = int_stack + 14175;
 Libderiv->deriv2_classes[3][6][105] = int_stack + 14385;
 Libderiv->deriv2_classes[4][5][105] = int_stack + 14665;
 Libderiv->deriv2_classes[4][6][105] = int_stack + 14980;
 Libderiv->deriv2_classes[3][5][104] = int_stack + 15400;
 Libderiv->deriv2_classes[3][6][104] = int_stack + 15610;
 Libderiv->deriv2_classes[4][5][104] = int_stack + 15890;
 Libderiv->deriv2_classes[4][6][104] = int_stack + 16205;
 Libderiv->deriv2_classes[3][5][95] = int_stack + 16625;
 Libderiv->deriv2_classes[3][6][95] = int_stack + 16835;
 Libderiv->deriv2_classes[4][5][95] = int_stack + 17115;
 Libderiv->deriv2_classes[4][6][95] = int_stack + 17430;
 Libderiv->deriv2_classes[3][5][94] = int_stack + 17850;
 Libderiv->deriv2_classes[3][6][94] = int_stack + 18060;
 Libderiv->deriv2_classes[4][5][94] = int_stack + 18340;
 Libderiv->deriv2_classes[4][6][94] = int_stack + 18655;
 Libderiv->deriv2_classes[3][5][93] = int_stack + 19075;
 Libderiv->deriv2_classes[3][6][93] = int_stack + 19285;
 Libderiv->deriv2_classes[4][5][93] = int_stack + 19565;
 Libderiv->deriv2_classes[4][6][93] = int_stack + 19880;
 Libderiv->deriv2_classes[3][5][92] = int_stack + 20300;
 Libderiv->deriv2_classes[3][6][92] = int_stack + 20510;
 Libderiv->deriv2_classes[4][5][92] = int_stack + 20790;
 Libderiv->deriv2_classes[4][6][92] = int_stack + 21105;
 Libderiv->deriv2_classes[3][5][91] = int_stack + 21525;
 Libderiv->deriv2_classes[3][6][91] = int_stack + 21735;
 Libderiv->deriv2_classes[4][5][91] = int_stack + 22015;
 Libderiv->deriv2_classes[4][6][91] = int_stack + 22330;
 Libderiv->deriv2_classes[3][5][83] = int_stack + 22750;
 Libderiv->deriv2_classes[3][6][83] = int_stack + 22960;
 Libderiv->deriv_classes[4][5][11] = int_stack + 23240;
 Libderiv->deriv2_classes[4][5][83] = int_stack + 23555;
 Libderiv->deriv2_classes[4][6][83] = int_stack + 23870;
 Libderiv->deriv2_classes[3][5][82] = int_stack + 24290;
 Libderiv->deriv2_classes[3][6][82] = int_stack + 24500;
 Libderiv->deriv_classes[4][5][10] = int_stack + 24780;
 Libderiv->deriv2_classes[4][5][82] = int_stack + 25095;
 Libderiv->deriv2_classes[4][6][82] = int_stack + 25410;
 Libderiv->deriv2_classes[3][5][81] = int_stack + 25830;
 Libderiv->deriv2_classes[3][6][81] = int_stack + 26040;
 Libderiv->deriv_classes[4][5][9] = int_stack + 26320;
 Libderiv->deriv2_classes[4][5][81] = int_stack + 26635;
 Libderiv->deriv2_classes[4][6][81] = int_stack + 26950;
 Libderiv->deriv2_classes[3][5][80] = int_stack + 27370;
 Libderiv->deriv2_classes[3][6][80] = int_stack + 27580;
 Libderiv->deriv_classes[4][5][8] = int_stack + 27860;
 Libderiv->deriv2_classes[4][5][80] = int_stack + 28175;
 Libderiv->deriv2_classes[4][6][80] = int_stack + 28490;
 Libderiv->deriv2_classes[3][5][79] = int_stack + 28910;
 Libderiv->deriv2_classes[3][6][79] = int_stack + 29120;
 Libderiv->deriv_classes[4][5][7] = int_stack + 29400;
 Libderiv->deriv2_classes[4][5][79] = int_stack + 29715;
 Libderiv->deriv2_classes[4][6][79] = int_stack + 30030;
 Libderiv->deriv2_classes[3][5][78] = int_stack + 30450;
 Libderiv->deriv2_classes[3][6][78] = int_stack + 30660;
 Libderiv->deriv_classes[4][5][6] = int_stack + 30940;
 Libderiv->deriv2_classes[4][5][78] = int_stack + 31255;
 Libderiv->deriv2_classes[4][6][78] = int_stack + 31570;
 Libderiv->deriv2_classes[3][5][35] = int_stack + 31990;
 Libderiv->deriv2_classes[3][6][35] = int_stack + 32200;
 Libderiv->deriv2_classes[4][5][35] = int_stack + 32480;
 Libderiv->deriv2_classes[4][6][35] = int_stack + 32795;
 Libderiv->deriv2_classes[3][5][34] = int_stack + 33215;
 Libderiv->deriv2_classes[3][6][34] = int_stack + 33425;
 Libderiv->deriv2_classes[4][5][34] = int_stack + 33705;
 Libderiv->deriv2_classes[4][6][34] = int_stack + 34020;
 Libderiv->deriv2_classes[3][5][33] = int_stack + 34440;
 Libderiv->deriv2_classes[3][6][33] = int_stack + 34650;
 Libderiv->deriv2_classes[4][5][33] = int_stack + 34930;
 Libderiv->deriv2_classes[4][6][33] = int_stack + 35245;
 Libderiv->deriv2_classes[3][5][32] = int_stack + 35665;
 Libderiv->deriv2_classes[3][6][32] = int_stack + 35875;
 Libderiv->deriv2_classes[4][5][32] = int_stack + 36155;
 Libderiv->deriv2_classes[4][6][32] = int_stack + 36470;
 Libderiv->deriv2_classes[3][5][31] = int_stack + 36890;
 Libderiv->deriv2_classes[3][6][31] = int_stack + 37100;
 Libderiv->deriv2_classes[4][5][31] = int_stack + 37380;
 Libderiv->deriv2_classes[4][6][31] = int_stack + 37695;
 Libderiv->deriv2_classes[3][5][30] = int_stack + 38115;
 Libderiv->deriv2_classes[3][6][30] = int_stack + 38325;
 Libderiv->deriv_classes[4][5][2] = int_stack + 38605;
 Libderiv->deriv2_classes[4][5][30] = int_stack + 38920;
 Libderiv->deriv2_classes[4][6][30] = int_stack + 39235;
 Libderiv->deriv2_classes[3][5][26] = int_stack + 39655;
 Libderiv->deriv2_classes[3][6][26] = int_stack + 39865;
 Libderiv->deriv2_classes[4][5][26] = int_stack + 40145;
 Libderiv->deriv2_classes[4][6][26] = int_stack + 40460;
 Libderiv->deriv2_classes[3][5][23] = int_stack + 40880;
 Libderiv->deriv2_classes[3][6][23] = int_stack + 41090;
 Libderiv->deriv2_classes[4][5][23] = int_stack + 41370;
 Libderiv->deriv2_classes[4][6][23] = int_stack + 41685;
 Libderiv->deriv2_classes[3][5][22] = int_stack + 42105;
 Libderiv->deriv2_classes[3][6][22] = int_stack + 42315;
 Libderiv->deriv2_classes[4][5][22] = int_stack + 42595;
 Libderiv->deriv2_classes[4][6][22] = int_stack + 42910;
 Libderiv->deriv2_classes[3][5][21] = int_stack + 43330;
 Libderiv->deriv2_classes[3][6][21] = int_stack + 43540;
 Libderiv->deriv2_classes[4][5][21] = int_stack + 43820;
 Libderiv->deriv2_classes[4][6][21] = int_stack + 44135;
 Libderiv->deriv2_classes[3][5][20] = int_stack + 44555;
 Libderiv->deriv2_classes[3][6][20] = int_stack + 44765;
 Libderiv->deriv2_classes[4][5][20] = int_stack + 45045;
 Libderiv->deriv2_classes[4][6][20] = int_stack + 45360;
 Libderiv->deriv2_classes[3][5][19] = int_stack + 45780;
 Libderiv->deriv2_classes[3][6][19] = int_stack + 45990;
 Libderiv->deriv2_classes[4][5][19] = int_stack + 46270;
 Libderiv->deriv2_classes[4][6][19] = int_stack + 46585;
 Libderiv->deriv2_classes[3][5][18] = int_stack + 47005;
 Libderiv->deriv2_classes[3][6][18] = int_stack + 47215;
 Libderiv->deriv_classes[4][5][1] = int_stack + 47495;
 Libderiv->deriv2_classes[4][5][18] = int_stack + 47810;
 Libderiv->deriv2_classes[4][6][18] = int_stack + 48125;
 Libderiv->deriv2_classes[3][5][14] = int_stack + 48545;
 Libderiv->deriv2_classes[3][6][14] = int_stack + 48755;
 Libderiv->deriv2_classes[4][5][14] = int_stack + 49035;
 Libderiv->deriv2_classes[4][6][14] = int_stack + 49350;
 Libderiv->deriv2_classes[3][5][13] = int_stack + 49770;
 Libderiv->deriv2_classes[3][6][13] = int_stack + 49980;
 Libderiv->deriv2_classes[4][5][13] = int_stack + 50260;
 Libderiv->deriv2_classes[4][6][13] = int_stack + 50575;
 Libderiv->deriv_classes[3][5][11] = int_stack + 50995;
 Libderiv->deriv_classes[3][6][11] = int_stack + 51205;
 Libderiv->deriv2_classes[3][5][11] = int_stack + 51485;
 Libderiv->deriv2_classes[3][6][11] = int_stack + 51695;
 Libderiv->deriv2_classes[4][5][11] = int_stack + 51975;
 Libderiv->deriv2_classes[4][6][11] = int_stack + 52290;
 Libderiv->deriv_classes[3][5][10] = int_stack + 52710;
 Libderiv->deriv_classes[3][6][10] = int_stack + 52920;
 Libderiv->deriv2_classes[3][5][10] = int_stack + 53200;
 Libderiv->deriv2_classes[3][6][10] = int_stack + 53410;
 Libderiv->deriv2_classes[4][5][10] = int_stack + 53690;
 Libderiv->deriv2_classes[4][6][10] = int_stack + 54005;
 Libderiv->deriv_classes[3][5][9] = int_stack + 54425;
 Libderiv->deriv_classes[3][6][9] = int_stack + 54635;
 Libderiv->deriv2_classes[3][5][9] = int_stack + 54915;
 Libderiv->deriv2_classes[3][6][9] = int_stack + 55125;
 Libderiv->deriv2_classes[4][5][9] = int_stack + 55405;
 Libderiv->deriv2_classes[4][6][9] = int_stack + 55720;
 Libderiv->deriv_classes[3][5][8] = int_stack + 56140;
 Libderiv->deriv_classes[3][6][8] = int_stack + 56350;
 Libderiv->deriv2_classes[3][5][8] = int_stack + 56630;
 Libderiv->deriv2_classes[3][6][8] = int_stack + 56840;
 Libderiv->deriv2_classes[4][5][8] = int_stack + 57120;
 Libderiv->deriv2_classes[4][6][8] = int_stack + 57435;
 Libderiv->deriv_classes[3][5][7] = int_stack + 57855;
 Libderiv->deriv_classes[3][6][7] = int_stack + 58065;
 Libderiv->deriv2_classes[3][5][7] = int_stack + 58345;
 Libderiv->deriv2_classes[3][6][7] = int_stack + 58555;
 Libderiv->deriv2_classes[4][5][7] = int_stack + 58835;
 Libderiv->deriv2_classes[4][6][7] = int_stack + 59150;
 Libderiv->dvrr_classes[3][5] = int_stack + 59570;
 Libderiv->deriv_classes[3][5][6] = int_stack + 59780;
 Libderiv->deriv_classes[3][6][6] = int_stack + 59990;
 Libderiv->deriv2_classes[3][5][6] = int_stack + 60270;
 Libderiv->deriv2_classes[3][6][6] = int_stack + 60480;
 Libderiv->deriv_classes[4][5][0] = int_stack + 60760;
 Libderiv->deriv2_classes[4][5][6] = int_stack + 61075;
 Libderiv->deriv2_classes[4][6][6] = int_stack + 61390;
 Libderiv->deriv_classes[3][5][2] = int_stack + 61810;
 Libderiv->deriv_classes[3][6][2] = int_stack + 62020;
 Libderiv->deriv2_classes[3][5][2] = int_stack + 62300;
 Libderiv->deriv2_classes[3][6][2] = int_stack + 62510;
 Libderiv->deriv2_classes[4][5][2] = int_stack + 62790;
 Libderiv->deriv2_classes[4][6][2] = int_stack + 63105;
 Libderiv->deriv_classes[3][5][1] = int_stack + 63525;
 Libderiv->deriv_classes[3][6][1] = int_stack + 63735;
 Libderiv->deriv2_classes[3][5][1] = int_stack + 64015;
 Libderiv->deriv2_classes[3][6][1] = int_stack + 64225;
 Libderiv->deriv2_classes[4][5][1] = int_stack + 64505;
 Libderiv->deriv2_classes[4][6][1] = int_stack + 64820;
 Libderiv->deriv_classes[3][5][0] = int_stack + 65240;
 Libderiv->deriv_classes[3][6][0] = int_stack + 65450;
 Libderiv->deriv2_classes[3][5][0] = int_stack + 65730;
 Libderiv->deriv2_classes[3][6][0] = int_stack + 65940;
 Libderiv->deriv2_classes[4][5][0] = int_stack + 66220;
 Libderiv->deriv2_classes[4][6][0] = int_stack + 66535;
 memset(int_stack,0,535640);

 Libderiv->dvrr_stack = int_stack + 112630;
 for(i=0;i<num_prim_comb;i++) {
   d12vrr_order_fphp(Libderiv, Data);
   Data++;
 }

 /*--- compute (f0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+66955,int_stack+51205,int_stack+50995, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+59570,10);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+67585,int_stack+0,int_stack+23240, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2100,15);
 /*--- compute (f0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+68530,int_stack+52920,int_stack+52710, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+59570, 0.0, zero_stack,10);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+69160,int_stack+420,int_stack+24780, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2100, 0.0, zero_stack,15);
 /*--- compute (f0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+0,int_stack+54635,int_stack+54425, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+59570, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+70105,int_stack+840,int_stack+26320, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2100, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (f0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+630,int_stack+56350,int_stack+56140, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+59570, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+71050,int_stack+1260,int_stack+27860, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2100, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (f0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+71995,int_stack+58065,int_stack+57855, 0.0, zero_stack, 1.0, int_stack+59570, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+72625,int_stack+1680,int_stack+29400, 0.0, zero_stack, 1.0, int_stack+2100, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (f0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+1260,int_stack+59990,int_stack+59780, 1.0, int_stack+59570, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+73570,int_stack+2415,int_stack+30940, 1.0, int_stack+2100, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (f0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+1890,int_stack+3675,int_stack+59570,10);
 /*--- compute (f0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+74515,int_stack+62020,int_stack+61810,10);
 /*--- compute (g0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+75145,int_stack+2835,int_stack+38605,15);
 /*--- compute (f0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+2520,int_stack+63735,int_stack+63525,10);
 /*--- compute (g0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+76090,int_stack+3255,int_stack+47495,15);
 /*--- compute (f0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+3150,int_stack+65450,int_stack+65240,10);
 /*--- compute (g0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+77035,int_stack+3955,int_stack+60760,15);
 /*--- compute (f0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+77980,int_stack+4585,int_stack+4375, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+50995,10);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+3780,int_stack+5180,int_stack+4865, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+23240,15);
 /*--- compute (f0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+4725,int_stack+5810,int_stack+5600, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+50995, 1.0, int_stack+52710,10);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+78610,int_stack+6405,int_stack+6090, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+23240, 1.0, int_stack+24780,15);
 /*--- compute (f0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+5355,int_stack+7035,int_stack+6825, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+52710, 0.0, zero_stack,10);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+5985,int_stack+7630,int_stack+7315, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+24780, 0.0, zero_stack,15);
 /*--- compute (f0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+6930,int_stack+8260,int_stack+8050, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+50995, 0.0, zero_stack, 1.0, int_stack+54425,10);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+7560,int_stack+8855,int_stack+8540, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+23240, 0.0, zero_stack, 1.0, int_stack+26320,15);
 /*--- compute (f0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+8505,int_stack+9485,int_stack+9275, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+52710, 1.0, int_stack+54425, 0.0, zero_stack,10);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+79555,int_stack+10080,int_stack+9765, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+24780, 1.0, int_stack+26320, 0.0, zero_stack,15);
 /*--- compute (f0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+9135,int_stack+10710,int_stack+10500, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+54425, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+9765,int_stack+11305,int_stack+10990, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+26320, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (f0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+10710,int_stack+11935,int_stack+11725, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+50995, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+56140,10);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+80500,int_stack+12530,int_stack+12215, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+23240, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+27860,15);
 /*--- compute (f0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+11340,int_stack+13160,int_stack+12950, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+52710, 0.0, zero_stack, 1.0, int_stack+56140, 0.0, zero_stack,10);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+11970,int_stack+13755,int_stack+13440, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+24780, 0.0, zero_stack, 1.0, int_stack+27860, 0.0, zero_stack,15);
 /*--- compute (f0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+12915,int_stack+14385,int_stack+14175, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+54425, 1.0, int_stack+56140, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+13545,int_stack+14980,int_stack+14665, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+26320, 1.0, int_stack+27860, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (f0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+14490,int_stack+15610,int_stack+15400, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+56140, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+81445,int_stack+16205,int_stack+15890, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+27860, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (f0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+15120,int_stack+16835,int_stack+16625, 0.0, zero_stack, 1.0, int_stack+50995, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+57855,10);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+15750,int_stack+17430,int_stack+17115, 0.0, zero_stack, 1.0, int_stack+23240, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+29400,15);
 /*--- compute (f0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+16695,int_stack+18060,int_stack+17850, 0.0, zero_stack, 1.0, int_stack+52710, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+57855, 0.0, zero_stack,10);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+17325,int_stack+18655,int_stack+18340, 0.0, zero_stack, 1.0, int_stack+24780, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+29400, 0.0, zero_stack,15);
 /*--- compute (f0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+18270,int_stack+19285,int_stack+19075, 0.0, zero_stack, 1.0, int_stack+54425, 0.0, zero_stack, 1.0, int_stack+57855, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+82390,int_stack+19880,int_stack+19565, 0.0, zero_stack, 1.0, int_stack+26320, 0.0, zero_stack, 1.0, int_stack+29400, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (f0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+18900,int_stack+20510,int_stack+20300, 0.0, zero_stack, 1.0, int_stack+56140, 1.0, int_stack+57855, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+19530,int_stack+21105,int_stack+20790, 0.0, zero_stack, 1.0, int_stack+27860, 1.0, int_stack+29400, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (f0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+20475,int_stack+21735,int_stack+21525, 0.0, zero_stack, 2.0, int_stack+57855, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+83335,int_stack+22330,int_stack+22015, 0.0, zero_stack, 2.0, int_stack+29400, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (f0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+21105,int_stack+22960,int_stack+22750, 1.0, int_stack+50995, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+59780,10);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+21735,int_stack+23870,int_stack+23555, 1.0, int_stack+23240, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+30940,15);
 /*--- compute (f0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+22680,int_stack+24500,int_stack+24290, 1.0, int_stack+52710, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+59780, 0.0, zero_stack,10);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+23310,int_stack+25410,int_stack+25095, 1.0, int_stack+24780, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+30940, 0.0, zero_stack,15);
 /*--- compute (f0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+24255,int_stack+26040,int_stack+25830, 1.0, int_stack+54425, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+59780, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+24885,int_stack+26950,int_stack+26635, 1.0, int_stack+26320, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+30940, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (f0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+25830,int_stack+27580,int_stack+27370, 1.0, int_stack+56140, 0.0, zero_stack, 1.0, int_stack+59780, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+26460,int_stack+28490,int_stack+28175, 1.0, int_stack+27860, 0.0, zero_stack, 1.0, int_stack+30940, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (f0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+27405,int_stack+29120,int_stack+28910, 1.0, int_stack+57855, 1.0, int_stack+59780, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+28035,int_stack+30030,int_stack+29715, 1.0, int_stack+29400, 1.0, int_stack+30940, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (f0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+28980,int_stack+30660,int_stack+30450, 2.0, int_stack+59780, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+29610,int_stack+31570,int_stack+31255, 2.0, int_stack+30940, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (f0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+59570,int_stack+32200,int_stack+31990, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+61810,10);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+30555,int_stack+32795,int_stack+32480, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+38605,15);
 /*--- compute (f0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+31500,int_stack+33425,int_stack+33215, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+61810, 0.0, zero_stack,10);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+32130,int_stack+34020,int_stack+33705, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+38605, 0.0, zero_stack,15);
 /*--- compute (f0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+33075,int_stack+34650,int_stack+34440, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+61810, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+33705,int_stack+35245,int_stack+34930, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+38605, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (f0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+34650,int_stack+35875,int_stack+35665, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+61810, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+84280,int_stack+36470,int_stack+36155, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+38605, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (f0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+35280,int_stack+37100,int_stack+36890, 0.0, zero_stack, 1.0, int_stack+61810, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+35910,int_stack+37695,int_stack+37380, 0.0, zero_stack, 1.0, int_stack+38605, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (f0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+36855,int_stack+38325,int_stack+38115, 1.0, int_stack+61810, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+37485,int_stack+39235,int_stack+38920, 1.0, int_stack+38605, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (f0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+38430,int_stack+39865,int_stack+39655,10);
 /*--- compute (g0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+39060,int_stack+40460,int_stack+40145,15);
 /*--- compute (f0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+40005,int_stack+41090,int_stack+40880, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+63525,10);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+85225,int_stack+41685,int_stack+41370, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+47495,15);
 /*--- compute (f0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+40635,int_stack+42315,int_stack+42105, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+63525, 0.0, zero_stack,10);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+41265,int_stack+42910,int_stack+42595, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+47495, 0.0, zero_stack,15);
 /*--- compute (f0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+42210,int_stack+43540,int_stack+43330, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+63525, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+42840,int_stack+44135,int_stack+43820, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+47495, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (f0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+43785,int_stack+44765,int_stack+44555, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+63525, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+86170,int_stack+45360,int_stack+45045, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+47495, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (f0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+44415,int_stack+45990,int_stack+45780, 0.0, zero_stack, 1.0, int_stack+63525, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+45045,int_stack+46585,int_stack+46270, 0.0, zero_stack, 1.0, int_stack+47495, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (f0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+45990,int_stack+47215,int_stack+47005, 1.0, int_stack+63525, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+87115,int_stack+48125,int_stack+47810, 1.0, int_stack+47495, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (f0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+46620,int_stack+48755,int_stack+48545,10);
 /*--- compute (g0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+47250,int_stack+49350,int_stack+49035,15);
 /*--- compute (f0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+48195,int_stack+49980,int_stack+49770,10);
 /*--- compute (g0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+48825,int_stack+50575,int_stack+50260,15);
 /*--- compute (f0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+49770,int_stack+51695,int_stack+51485, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+65240,10);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+50400,int_stack+52290,int_stack+51975, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+60760,15);
 /*--- compute (f0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+51345,int_stack+53410,int_stack+53200, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+65240, 0.0, zero_stack,10);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+51975,int_stack+54005,int_stack+53690, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+60760, 0.0, zero_stack,15);
 /*--- compute (f0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+52920,int_stack+55125,int_stack+54915, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+65240, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+53550,int_stack+55720,int_stack+55405, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+60760, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (f0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+54495,int_stack+56840,int_stack+56630, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+65240, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+55125,int_stack+57435,int_stack+57120, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+60760, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (f0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+56070,int_stack+58555,int_stack+58345, 0.0, zero_stack, 1.0, int_stack+65240, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+56700,int_stack+59150,int_stack+58835, 0.0, zero_stack, 1.0, int_stack+60760, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (f0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+57645,int_stack+60480,int_stack+60270, 1.0, int_stack+65240, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+58275,int_stack+61390,int_stack+61075, 1.0, int_stack+60760, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (f0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+60200,int_stack+62510,int_stack+62300,10);
 /*--- compute (g0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+60830,int_stack+63105,int_stack+62790,15);
 /*--- compute (f0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+61775,int_stack+64225,int_stack+64015,10);
 /*--- compute (g0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+62405,int_stack+64820,int_stack+64505,15);
 /*--- compute (f0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+63350,int_stack+65940,int_stack+65730,10);
 /*--- compute (g0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+63980,int_stack+66535,int_stack+66220,15);
 /*--- compute (fp|hp) ---*/
   hrr1_build_fp(Libderiv->AB,int_stack+64925,int_stack+67585,int_stack+66955,63);
     Libderiv->ABCD[11] = int_stack + 64925;
 /*--- compute (fp|hp) ---*/
   hrr1_build_fp(Libderiv->AB,int_stack+88060,int_stack+69160,int_stack+68530,63);
     Libderiv->ABCD[10] = int_stack + 88060;
 /*--- compute (fp|hp) ---*/
   hrr1_build_fp(Libderiv->AB,int_stack+89950,int_stack+70105,int_stack+0,63);
     Libderiv->ABCD[9] = int_stack + 89950;
 /*--- compute (fp|hp) ---*/
   hrr1_build_fp(Libderiv->AB,int_stack+69160,int_stack+71050,int_stack+630,63);
     Libderiv->ABCD[8] = int_stack + 69160;
 /*--- compute (fp|hp) ---*/
   hrr1_build_fp(Libderiv->AB,int_stack+91840,int_stack+72625,int_stack+71995,63);
     Libderiv->ABCD[7] = int_stack + 91840;
 /*--- compute (fp|hp) ---*/
   hrr1_build_fp(Libderiv->AB,int_stack+93730,int_stack+73570,int_stack+1260,63);
     Libderiv->ABCD[6] = int_stack + 93730;
 /*--- compute (fp|hp) ---*/
   d1hrr1_build_fp(Libderiv->AB,int_stack+72625,int_stack+75145,int_stack+74515, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1890, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,63);
     Libderiv->ABCD[2] = int_stack + 72625;
 /*--- compute (fp|hp) ---*/
   d1hrr1_build_fp(Libderiv->AB,int_stack+95620,int_stack+76090,int_stack+2520, 0.0, zero_stack, 1.0, int_stack+1890, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,63);
     Libderiv->ABCD[1] = int_stack + 95620;
 /*--- compute (fp|hp) ---*/
   d1hrr1_build_fp(Libderiv->AB,int_stack+75145,int_stack+77035,int_stack+3150, 1.0, int_stack+1890, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,63);
     Libderiv->ABCD[0] = int_stack + 75145;
 /*--- compute (fp|hp) ---*/
   hrr1_build_fp(Libderiv->AB,int_stack+97510,int_stack+3780,int_stack+77980,63);
     Libderiv->ABCD[155] = int_stack + 97510;
 /*--- compute (fp|hp) ---*/
   hrr1_build_fp(Libderiv->AB,int_stack+99400,int_stack+78610,int_stack+4725,63);
     Libderiv->ABCD[143] = int_stack + 99400;
 /*--- compute (fp|hp) ---*/
   hrr1_build_fp(Libderiv->AB,int_stack+77035,int_stack+5985,int_stack+5355,63);
     Libderiv->ABCD[142] = int_stack + 77035;
 /*--- compute (fp|hp) ---*/
   hrr1_build_fp(Libderiv->AB,int_stack+3780,int_stack+7560,int_stack+6930,63);
     Libderiv->ABCD[131] = int_stack + 3780;
 /*--- compute (fp|hp) ---*/
   hrr1_build_fp(Libderiv->AB,int_stack+5670,int_stack+79555,int_stack+8505,63);
     Libderiv->ABCD[130] = int_stack + 5670;
 /*--- compute (fp|hp) ---*/
   hrr1_build_fp(Libderiv->AB,int_stack+101290,int_stack+9765,int_stack+9135,63);
     Libderiv->ABCD[129] = int_stack + 101290;
 /*--- compute (fp|hp) ---*/
   hrr1_build_fp(Libderiv->AB,int_stack+7560,int_stack+80500,int_stack+10710,63);
     Libderiv->ABCD[119] = int_stack + 7560;
 /*--- compute (fp|hp) ---*/
   hrr1_build_fp(Libderiv->AB,int_stack+9450,int_stack+11970,int_stack+11340,63);
     Libderiv->ABCD[118] = int_stack + 9450;
 /*--- compute (fp|hp) ---*/
   hrr1_build_fp(Libderiv->AB,int_stack+78925,int_stack+13545,int_stack+12915,63);
     Libderiv->ABCD[117] = int_stack + 78925;
 /*--- compute (fp|hp) ---*/
   hrr1_build_fp(Libderiv->AB,int_stack+11340,int_stack+81445,int_stack+14490,63);
     Libderiv->ABCD[116] = int_stack + 11340;
 /*--- compute (fp|hp) ---*/
   hrr1_build_fp(Libderiv->AB,int_stack+13230,int_stack+15750,int_stack+15120,63);
     Libderiv->ABCD[107] = int_stack + 13230;
 /*--- compute (fp|hp) ---*/
   hrr1_build_fp(Libderiv->AB,int_stack+103180,int_stack+17325,int_stack+16695,63);
     Libderiv->ABCD[106] = int_stack + 103180;
 /*--- compute (fp|hp) ---*/
   hrr1_build_fp(Libderiv->AB,int_stack+15120,int_stack+82390,int_stack+18270,63);
     Libderiv->ABCD[105] = int_stack + 15120;
 /*--- compute (fp|hp) ---*/
   hrr1_build_fp(Libderiv->AB,int_stack+17010,int_stack+19530,int_stack+18900,63);
     Libderiv->ABCD[104] = int_stack + 17010;
 /*--- compute (fp|hp) ---*/
   hrr1_build_fp(Libderiv->AB,int_stack+80815,int_stack+83335,int_stack+20475,63);
     Libderiv->ABCD[103] = int_stack + 80815;
 /*--- compute (fp|hp) ---*/
   hrr1_build_fp(Libderiv->AB,int_stack+18900,int_stack+21735,int_stack+21105,63);
     Libderiv->ABCD[95] = int_stack + 18900;
 /*--- compute (fp|hp) ---*/
   hrr1_build_fp(Libderiv->AB,int_stack+20790,int_stack+23310,int_stack+22680,63);
     Libderiv->ABCD[94] = int_stack + 20790;
 /*--- compute (fp|hp) ---*/
   hrr1_build_fp(Libderiv->AB,int_stack+105070,int_stack+24885,int_stack+24255,63);
     Libderiv->ABCD[93] = int_stack + 105070;
 /*--- compute (fp|hp) ---*/
   hrr1_build_fp(Libderiv->AB,int_stack+22680,int_stack+26460,int_stack+25830,63);
     Libderiv->ABCD[92] = int_stack + 22680;
 /*--- compute (fp|hp) ---*/
   hrr1_build_fp(Libderiv->AB,int_stack+24570,int_stack+28035,int_stack+27405,63);
     Libderiv->ABCD[91] = int_stack + 24570;
 /*--- compute (fp|hp) ---*/
   hrr1_build_fp(Libderiv->AB,int_stack+26460,int_stack+29610,int_stack+28980,63);
     Libderiv->ABCD[90] = int_stack + 26460;
 /*--- compute (fp|hp) ---*/
   d1hrr1_build_fp(Libderiv->AB,int_stack+28350,int_stack+30555,int_stack+59570, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+66955, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,63);
     Libderiv->ABCD[47] = int_stack + 28350;
 /*--- compute (fp|hp) ---*/
   d1hrr1_build_fp(Libderiv->AB,int_stack+106960,int_stack+32130,int_stack+31500, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+68530, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,63);
     Libderiv->ABCD[46] = int_stack + 106960;
 /*--- compute (fp|hp) ---*/
   d1hrr1_build_fp(Libderiv->AB,int_stack+30240,int_stack+33705,int_stack+33075, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+0, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,63);
     Libderiv->ABCD[45] = int_stack + 30240;
 /*--- compute (fp|hp) ---*/
   d1hrr1_build_fp(Libderiv->AB,int_stack+32130,int_stack+84280,int_stack+34650, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+630, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,63);
     Libderiv->ABCD[44] = int_stack + 32130;
 /*--- compute (fp|hp) ---*/
   d1hrr1_build_fp(Libderiv->AB,int_stack+82705,int_stack+35910,int_stack+35280, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+71995, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,63);
     Libderiv->ABCD[43] = int_stack + 82705;
 /*--- compute (fp|hp) ---*/
   d1hrr1_build_fp(Libderiv->AB,int_stack+34020,int_stack+37485,int_stack+36855, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1260, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,63);
     Libderiv->ABCD[42] = int_stack + 34020;
 /*--- compute (fp|hp) ---*/
   d1hrr1_build_fp(Libderiv->AB,int_stack+35910,int_stack+39060,int_stack+38430, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+74515, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,63);
     Libderiv->ABCD[38] = int_stack + 35910;
 /*--- compute (fp|hp) ---*/
   d1hrr1_build_fp(Libderiv->AB,int_stack+37800,int_stack+85225,int_stack+40005, 0.0, zero_stack, 1.0, int_stack+66955, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,63);
     Libderiv->ABCD[35] = int_stack + 37800;
 /*--- compute (fp|hp) ---*/
   d1hrr1_build_fp(Libderiv->AB,int_stack+108850,int_stack+41265,int_stack+40635, 0.0, zero_stack, 1.0, int_stack+68530, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,63);
     Libderiv->ABCD[34] = int_stack + 108850;
 /*--- compute (fp|hp) ---*/
   d1hrr1_build_fp(Libderiv->AB,int_stack+39690,int_stack+42840,int_stack+42210, 0.0, zero_stack, 1.0, int_stack+0, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,63);
     Libderiv->ABCD[33] = int_stack + 39690;
 /*--- compute (fp|hp) ---*/
   d1hrr1_build_fp(Libderiv->AB,int_stack+41580,int_stack+86170,int_stack+43785, 0.0, zero_stack, 1.0, int_stack+630, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,63);
     Libderiv->ABCD[32] = int_stack + 41580;
 /*--- compute (fp|hp) ---*/
   d1hrr1_build_fp(Libderiv->AB,int_stack+84595,int_stack+45045,int_stack+44415, 0.0, zero_stack, 1.0, int_stack+71995, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,63);
     Libderiv->ABCD[31] = int_stack + 84595;
 /*--- compute (fp|hp) ---*/
   d1hrr1_build_fp(Libderiv->AB,int_stack+43470,int_stack+87115,int_stack+45990, 0.0, zero_stack, 1.0, int_stack+1260, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,63);
     Libderiv->ABCD[30] = int_stack + 43470;
 /*--- compute (fp|hp) ---*/
   d1hrr1_build_fp(Libderiv->AB,int_stack+110740,int_stack+47250,int_stack+46620, 0.0, zero_stack, 1.0, int_stack+74515, 1.0, int_stack+2520, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,63);
     Libderiv->ABCD[26] = int_stack + 110740;
 /*--- compute (fp|hp) ---*/
   d1hrr1_build_fp(Libderiv->AB,int_stack+45360,int_stack+48825,int_stack+48195, 0.0, zero_stack, 2.0, int_stack+2520, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,63);
     Libderiv->ABCD[25] = int_stack + 45360;
 /*--- compute (fp|hp) ---*/
   d1hrr1_build_fp(Libderiv->AB,int_stack+47250,int_stack+50400,int_stack+49770, 1.0, int_stack+66955, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,63);
     Libderiv->ABCD[23] = int_stack + 47250;
 /*--- compute (fp|hp) ---*/
   d1hrr1_build_fp(Libderiv->AB,int_stack+49140,int_stack+51975,int_stack+51345, 1.0, int_stack+68530, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,63);
     Libderiv->ABCD[22] = int_stack + 49140;
 /*--- compute (fp|hp) ---*/
   d1hrr1_build_fp(Libderiv->AB,int_stack+51030,int_stack+53550,int_stack+52920, 1.0, int_stack+0, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,63);
     Libderiv->ABCD[21] = int_stack + 51030;
 /*--- compute (fp|hp) ---*/
   d1hrr1_build_fp(Libderiv->AB,int_stack+66815,int_stack+55125,int_stack+54495, 1.0, int_stack+630, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,63);
     Libderiv->ABCD[20] = int_stack + 66815;
 /*--- compute (fp|hp) ---*/
   d1hrr1_build_fp(Libderiv->AB,int_stack+52920,int_stack+56700,int_stack+56070, 1.0, int_stack+71995, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,63);
     Libderiv->ABCD[19] = int_stack + 52920;
 /*--- compute (fp|hp) ---*/
   d1hrr1_build_fp(Libderiv->AB,int_stack+54810,int_stack+58275,int_stack+57645, 1.0, int_stack+1260, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,63);
     Libderiv->ABCD[18] = int_stack + 54810;
 /*--- compute (fp|hp) ---*/
   d1hrr1_build_fp(Libderiv->AB,int_stack+0,int_stack+60830,int_stack+60200, 1.0, int_stack+74515, 0.0, zero_stack, 1.0, int_stack+3150, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,63);
     Libderiv->ABCD[14] = int_stack + 0;
 /*--- compute (fp|hp) ---*/
   d1hrr1_build_fp(Libderiv->AB,int_stack+56700,int_stack+62405,int_stack+61775, 1.0, int_stack+2520, 1.0, int_stack+3150, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,63);
     Libderiv->ABCD[13] = int_stack + 56700;
 /*--- compute (fp|hp) ---*/
   d1hrr1_build_fp(Libderiv->AB,int_stack+58590,int_stack+63980,int_stack+63350, 2.0, int_stack+3150, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,63);
     Libderiv->ABCD[12] = int_stack + 58590;

}
