/*
 *  Copyright (C) 1996-2017 Edward F. Valeev and Justin T. Fermann
 *
 *  This file is part of Libint.
 *
 *  Libint is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU Lesser General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  Libint is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public License
 *  along with Libint.  If not, see <http://www.gnu.org/licenses/>.
 *
 */

#include <stdio.h>
#include <string.h>
#include <libint/libint.h>
#include "libderiv.h"
#include <libint/hrr_header.h>

#include "d1hrr_header.h"

extern void d12vrr_order_g0hp(Libderiv_t *, prim_data *);

  /* Computes derivatives of (g0|hp) integrals */

void d12hrr_order_g0hp(Libderiv_t *Libderiv, int num_prim_comb)
{
 prim_data *Data = Libderiv->PrimQuartet;
 double *int_stack = Libderiv->int_stack;
 double *zero_stack = Libderiv->zero_stack;
 int i,j;
 double tmp, *target;

 Libderiv->deriv_classes[4][6][11] = int_stack + 0;
 Libderiv->deriv_classes[4][6][10] = int_stack + 420;
 Libderiv->deriv_classes[4][6][9] = int_stack + 840;
 Libderiv->deriv_classes[4][6][8] = int_stack + 1260;
 Libderiv->deriv_classes[4][6][7] = int_stack + 1680;
 Libderiv->dvrr_classes[4][5] = int_stack + 2100;
 Libderiv->deriv_classes[4][6][6] = int_stack + 2415;
 Libderiv->deriv_classes[4][6][2] = int_stack + 2835;
 Libderiv->deriv_classes[4][6][1] = int_stack + 3255;
 Libderiv->deriv_classes[4][6][0] = int_stack + 3675;
 Libderiv->deriv2_classes[4][5][143] = int_stack + 4095;
 Libderiv->deriv2_classes[4][6][143] = int_stack + 4410;
 Libderiv->deriv2_classes[4][5][131] = int_stack + 4830;
 Libderiv->deriv2_classes[4][6][131] = int_stack + 5145;
 Libderiv->deriv2_classes[4][5][130] = int_stack + 5565;
 Libderiv->deriv2_classes[4][6][130] = int_stack + 5880;
 Libderiv->deriv2_classes[4][5][119] = int_stack + 6300;
 Libderiv->deriv2_classes[4][6][119] = int_stack + 6615;
 Libderiv->deriv2_classes[4][5][118] = int_stack + 7035;
 Libderiv->deriv2_classes[4][6][118] = int_stack + 7350;
 Libderiv->deriv2_classes[4][5][117] = int_stack + 7770;
 Libderiv->deriv2_classes[4][6][117] = int_stack + 8085;
 Libderiv->deriv2_classes[4][5][107] = int_stack + 8505;
 Libderiv->deriv2_classes[4][6][107] = int_stack + 8820;
 Libderiv->deriv2_classes[4][5][106] = int_stack + 9240;
 Libderiv->deriv2_classes[4][6][106] = int_stack + 9555;
 Libderiv->deriv2_classes[4][5][105] = int_stack + 9975;
 Libderiv->deriv2_classes[4][6][105] = int_stack + 10290;
 Libderiv->deriv2_classes[4][5][104] = int_stack + 10710;
 Libderiv->deriv2_classes[4][6][104] = int_stack + 11025;
 Libderiv->deriv2_classes[4][5][95] = int_stack + 11445;
 Libderiv->deriv2_classes[4][6][95] = int_stack + 11760;
 Libderiv->deriv2_classes[4][5][94] = int_stack + 12180;
 Libderiv->deriv2_classes[4][6][94] = int_stack + 12495;
 Libderiv->deriv2_classes[4][5][93] = int_stack + 12915;
 Libderiv->deriv2_classes[4][6][93] = int_stack + 13230;
 Libderiv->deriv2_classes[4][5][92] = int_stack + 13650;
 Libderiv->deriv2_classes[4][6][92] = int_stack + 13965;
 Libderiv->deriv2_classes[4][5][91] = int_stack + 14385;
 Libderiv->deriv2_classes[4][6][91] = int_stack + 14700;
 Libderiv->deriv_classes[4][5][11] = int_stack + 15120;
 Libderiv->deriv2_classes[4][5][83] = int_stack + 15435;
 Libderiv->deriv2_classes[4][6][83] = int_stack + 15750;
 Libderiv->deriv_classes[4][5][10] = int_stack + 16170;
 Libderiv->deriv2_classes[4][5][82] = int_stack + 16485;
 Libderiv->deriv2_classes[4][6][82] = int_stack + 16800;
 Libderiv->deriv_classes[4][5][9] = int_stack + 17220;
 Libderiv->deriv2_classes[4][5][81] = int_stack + 17535;
 Libderiv->deriv2_classes[4][6][81] = int_stack + 17850;
 Libderiv->deriv_classes[4][5][8] = int_stack + 18270;
 Libderiv->deriv2_classes[4][5][80] = int_stack + 18585;
 Libderiv->deriv2_classes[4][6][80] = int_stack + 18900;
 Libderiv->deriv_classes[4][5][7] = int_stack + 19320;
 Libderiv->deriv2_classes[4][5][79] = int_stack + 19635;
 Libderiv->deriv2_classes[4][6][79] = int_stack + 19950;
 Libderiv->deriv_classes[4][5][6] = int_stack + 20370;
 Libderiv->deriv2_classes[4][5][78] = int_stack + 20685;
 Libderiv->deriv2_classes[4][6][78] = int_stack + 21000;
 Libderiv->deriv2_classes[4][5][35] = int_stack + 21420;
 Libderiv->deriv2_classes[4][6][35] = int_stack + 21735;
 Libderiv->deriv2_classes[4][5][34] = int_stack + 22155;
 Libderiv->deriv2_classes[4][6][34] = int_stack + 22470;
 Libderiv->deriv2_classes[4][5][33] = int_stack + 22890;
 Libderiv->deriv2_classes[4][6][33] = int_stack + 23205;
 Libderiv->deriv2_classes[4][5][32] = int_stack + 23625;
 Libderiv->deriv2_classes[4][6][32] = int_stack + 23940;
 Libderiv->deriv2_classes[4][5][31] = int_stack + 24360;
 Libderiv->deriv2_classes[4][6][31] = int_stack + 24675;
 Libderiv->deriv_classes[4][5][2] = int_stack + 25095;
 Libderiv->deriv2_classes[4][5][30] = int_stack + 25410;
 Libderiv->deriv2_classes[4][6][30] = int_stack + 25725;
 Libderiv->deriv2_classes[4][5][26] = int_stack + 26145;
 Libderiv->deriv2_classes[4][6][26] = int_stack + 26460;
 Libderiv->deriv2_classes[4][5][23] = int_stack + 26880;
 Libderiv->deriv2_classes[4][6][23] = int_stack + 27195;
 Libderiv->deriv2_classes[4][5][22] = int_stack + 27615;
 Libderiv->deriv2_classes[4][6][22] = int_stack + 27930;
 Libderiv->deriv2_classes[4][5][21] = int_stack + 28350;
 Libderiv->deriv2_classes[4][6][21] = int_stack + 28665;
 Libderiv->deriv2_classes[4][5][20] = int_stack + 29085;
 Libderiv->deriv2_classes[4][6][20] = int_stack + 29400;
 Libderiv->deriv2_classes[4][5][19] = int_stack + 29820;
 Libderiv->deriv2_classes[4][6][19] = int_stack + 30135;
 Libderiv->deriv_classes[4][5][1] = int_stack + 30555;
 Libderiv->deriv2_classes[4][5][18] = int_stack + 30870;
 Libderiv->deriv2_classes[4][6][18] = int_stack + 31185;
 Libderiv->deriv2_classes[4][5][14] = int_stack + 31605;
 Libderiv->deriv2_classes[4][6][14] = int_stack + 31920;
 Libderiv->deriv2_classes[4][5][13] = int_stack + 32340;
 Libderiv->deriv2_classes[4][6][13] = int_stack + 32655;
 Libderiv->deriv2_classes[4][5][11] = int_stack + 33075;
 Libderiv->deriv2_classes[4][6][11] = int_stack + 33390;
 Libderiv->deriv2_classes[4][5][10] = int_stack + 33810;
 Libderiv->deriv2_classes[4][6][10] = int_stack + 34125;
 Libderiv->deriv2_classes[4][5][9] = int_stack + 34545;
 Libderiv->deriv2_classes[4][6][9] = int_stack + 34860;
 Libderiv->deriv2_classes[4][5][8] = int_stack + 35280;
 Libderiv->deriv2_classes[4][6][8] = int_stack + 35595;
 Libderiv->deriv2_classes[4][5][7] = int_stack + 36015;
 Libderiv->deriv2_classes[4][6][7] = int_stack + 36330;
 Libderiv->deriv_classes[4][5][0] = int_stack + 36750;
 Libderiv->deriv2_classes[4][5][6] = int_stack + 37065;
 Libderiv->deriv2_classes[4][6][6] = int_stack + 37380;
 Libderiv->deriv2_classes[4][5][2] = int_stack + 37800;
 Libderiv->deriv2_classes[4][6][2] = int_stack + 38115;
 Libderiv->deriv2_classes[4][5][1] = int_stack + 38535;
 Libderiv->deriv2_classes[4][6][1] = int_stack + 38850;
 Libderiv->deriv2_classes[4][5][0] = int_stack + 39270;
 Libderiv->deriv2_classes[4][6][0] = int_stack + 39585;
 memset(int_stack,0,320040);

 Libderiv->dvrr_stack = int_stack + 52290;
 for(i=0;i<num_prim_comb;i++) {
   d12vrr_order_g0hp(Libderiv, Data);
   Data++;
 }

 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+40005,int_stack+0,int_stack+15120, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2100,15);
     Libderiv->ABCD[11] = int_stack + 40005;
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+40950,int_stack+420,int_stack+16170, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2100, 0.0, zero_stack,15);
     Libderiv->ABCD[10] = int_stack + 40950;
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+41895,int_stack+840,int_stack+17220, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2100, 0.0, zero_stack, 0.0, zero_stack,15);
     Libderiv->ABCD[9] = int_stack + 41895;
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+0,int_stack+1260,int_stack+18270, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2100, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
     Libderiv->ABCD[8] = int_stack + 0;
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+42840,int_stack+1680,int_stack+19320, 0.0, zero_stack, 1.0, int_stack+2100, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
     Libderiv->ABCD[7] = int_stack + 42840;
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+945,int_stack+2415,int_stack+20370, 1.0, int_stack+2100, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
     Libderiv->ABCD[6] = int_stack + 945;
 /*--- compute (g0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+1890,int_stack+2835,int_stack+25095,15);
     Libderiv->ABCD[2] = int_stack + 1890;
 /*--- compute (g0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+43785,int_stack+3255,int_stack+30555,15);
     Libderiv->ABCD[1] = int_stack + 43785;
 /*--- compute (g0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+44730,int_stack+3675,int_stack+36750,15);
     Libderiv->ABCD[0] = int_stack + 44730;
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+2835,int_stack+4410,int_stack+4095, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+15120,15);
     Libderiv->ABCD[155] = int_stack + 2835;
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+3780,int_stack+5145,int_stack+4830, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+15120, 1.0, int_stack+16170,15);
     Libderiv->ABCD[143] = int_stack + 3780;
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+45675,int_stack+5880,int_stack+5565, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+16170, 0.0, zero_stack,15);
     Libderiv->ABCD[142] = int_stack + 45675;
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+4725,int_stack+6615,int_stack+6300, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+15120, 0.0, zero_stack, 1.0, int_stack+17220,15);
     Libderiv->ABCD[131] = int_stack + 4725;
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+5670,int_stack+7350,int_stack+7035, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+16170, 1.0, int_stack+17220, 0.0, zero_stack,15);
     Libderiv->ABCD[130] = int_stack + 5670;
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+6615,int_stack+8085,int_stack+7770, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+17220, 0.0, zero_stack, 0.0, zero_stack,15);
     Libderiv->ABCD[129] = int_stack + 6615;
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+7560,int_stack+8820,int_stack+8505, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+15120, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+18270,15);
     Libderiv->ABCD[119] = int_stack + 7560;
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+46620,int_stack+9555,int_stack+9240, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+16170, 0.0, zero_stack, 1.0, int_stack+18270, 0.0, zero_stack,15);
     Libderiv->ABCD[118] = int_stack + 46620;
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+8505,int_stack+10290,int_stack+9975, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+17220, 1.0, int_stack+18270, 0.0, zero_stack, 0.0, zero_stack,15);
     Libderiv->ABCD[117] = int_stack + 8505;
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+9450,int_stack+11025,int_stack+10710, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+18270, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
     Libderiv->ABCD[116] = int_stack + 9450;
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+10395,int_stack+11760,int_stack+11445, 0.0, zero_stack, 1.0, int_stack+15120, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+19320,15);
     Libderiv->ABCD[107] = int_stack + 10395;
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+47565,int_stack+12495,int_stack+12180, 0.0, zero_stack, 1.0, int_stack+16170, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+19320, 0.0, zero_stack,15);
     Libderiv->ABCD[106] = int_stack + 47565;
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+11340,int_stack+13230,int_stack+12915, 0.0, zero_stack, 1.0, int_stack+17220, 0.0, zero_stack, 1.0, int_stack+19320, 0.0, zero_stack, 0.0, zero_stack,15);
     Libderiv->ABCD[105] = int_stack + 11340;
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+12285,int_stack+13965,int_stack+13650, 0.0, zero_stack, 1.0, int_stack+18270, 1.0, int_stack+19320, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
     Libderiv->ABCD[104] = int_stack + 12285;
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+13230,int_stack+14700,int_stack+14385, 0.0, zero_stack, 2.0, int_stack+19320, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
     Libderiv->ABCD[103] = int_stack + 13230;
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+14175,int_stack+15750,int_stack+15435, 1.0, int_stack+15120, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+20370,15);
     Libderiv->ABCD[95] = int_stack + 14175;
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+15120,int_stack+16800,int_stack+16485, 1.0, int_stack+16170, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+20370, 0.0, zero_stack,15);
     Libderiv->ABCD[94] = int_stack + 15120;
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+16065,int_stack+17850,int_stack+17535, 1.0, int_stack+17220, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+20370, 0.0, zero_stack, 0.0, zero_stack,15);
     Libderiv->ABCD[93] = int_stack + 16065;
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+17010,int_stack+18900,int_stack+18585, 1.0, int_stack+18270, 0.0, zero_stack, 1.0, int_stack+20370, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
     Libderiv->ABCD[92] = int_stack + 17010;
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+17955,int_stack+19950,int_stack+19635, 1.0, int_stack+19320, 1.0, int_stack+20370, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
     Libderiv->ABCD[91] = int_stack + 17955;
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+18900,int_stack+21000,int_stack+20685, 2.0, int_stack+20370, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
     Libderiv->ABCD[90] = int_stack + 18900;
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+19845,int_stack+21735,int_stack+21420, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+25095,15);
     Libderiv->ABCD[47] = int_stack + 19845;
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+20790,int_stack+22470,int_stack+22155, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+25095, 0.0, zero_stack,15);
     Libderiv->ABCD[46] = int_stack + 20790;
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+21735,int_stack+23205,int_stack+22890, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+25095, 0.0, zero_stack, 0.0, zero_stack,15);
     Libderiv->ABCD[45] = int_stack + 21735;
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+22680,int_stack+23940,int_stack+23625, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+25095, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
     Libderiv->ABCD[44] = int_stack + 22680;
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+48510,int_stack+24675,int_stack+24360, 0.0, zero_stack, 1.0, int_stack+25095, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
     Libderiv->ABCD[43] = int_stack + 48510;
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+23625,int_stack+25725,int_stack+25410, 1.0, int_stack+25095, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
     Libderiv->ABCD[42] = int_stack + 23625;
 /*--- compute (g0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+24570,int_stack+26460,int_stack+26145,15);
     Libderiv->ABCD[38] = int_stack + 24570;
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+25515,int_stack+27195,int_stack+26880, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+30555,15);
     Libderiv->ABCD[35] = int_stack + 25515;
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+26460,int_stack+27930,int_stack+27615, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+30555, 0.0, zero_stack,15);
     Libderiv->ABCD[34] = int_stack + 26460;
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+27405,int_stack+28665,int_stack+28350, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+30555, 0.0, zero_stack, 0.0, zero_stack,15);
     Libderiv->ABCD[33] = int_stack + 27405;
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+49455,int_stack+29400,int_stack+29085, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+30555, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
     Libderiv->ABCD[32] = int_stack + 49455;
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+28350,int_stack+30135,int_stack+29820, 0.0, zero_stack, 1.0, int_stack+30555, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
     Libderiv->ABCD[31] = int_stack + 28350;
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+29295,int_stack+31185,int_stack+30870, 1.0, int_stack+30555, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
     Libderiv->ABCD[30] = int_stack + 29295;
 /*--- compute (g0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+30240,int_stack+31920,int_stack+31605,15);
     Libderiv->ABCD[26] = int_stack + 30240;
 /*--- compute (g0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+31185,int_stack+32655,int_stack+32340,15);
     Libderiv->ABCD[25] = int_stack + 31185;
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+32130,int_stack+33390,int_stack+33075, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+36750,15);
     Libderiv->ABCD[23] = int_stack + 32130;
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+50400,int_stack+34125,int_stack+33810, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+36750, 0.0, zero_stack,15);
     Libderiv->ABCD[22] = int_stack + 50400;
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+33075,int_stack+34860,int_stack+34545, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+36750, 0.0, zero_stack, 0.0, zero_stack,15);
     Libderiv->ABCD[21] = int_stack + 33075;
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+34020,int_stack+35595,int_stack+35280, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+36750, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
     Libderiv->ABCD[20] = int_stack + 34020;
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+34965,int_stack+36330,int_stack+36015, 0.0, zero_stack, 1.0, int_stack+36750, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
     Libderiv->ABCD[19] = int_stack + 34965;
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+51345,int_stack+37380,int_stack+37065, 1.0, int_stack+36750, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
     Libderiv->ABCD[18] = int_stack + 51345;
 /*--- compute (g0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+35910,int_stack+38115,int_stack+37800,15);
     Libderiv->ABCD[14] = int_stack + 35910;
 /*--- compute (g0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+36855,int_stack+38850,int_stack+38535,15);
     Libderiv->ABCD[13] = int_stack + 36855;
 /*--- compute (g0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+37800,int_stack+39585,int_stack+39270,15);
     Libderiv->ABCD[12] = int_stack + 37800;

}
