/*
 *  Copyright (C) 1996-2017 Edward F. Valeev and Justin T. Fermann
 *
 *  This file is part of Libint.
 *
 *  Libint is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU Lesser General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  Libint is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public License
 *  along with Libint.  If not, see <http://www.gnu.org/licenses/>.
 *
 */

#include <stdio.h>
#include <string.h>
#include <libint/libint.h>
#include "libderiv.h"
#include <libint/hrr_header.h>

#include "d1hrr_header.h"

extern void d1vrr_order_dphd(Libderiv_t *, prim_data *);

  /* Computes derivatives of (dp|hd) integrals */

void d1hrr_order_dphd(Libderiv_t *Libderiv, int num_prim_comb)
{
 prim_data *Data = Libderiv->PrimQuartet;
 double *int_stack = Libderiv->int_stack;
 double *zero_stack = Libderiv->zero_stack;
 int i,j;
 double tmp, *target;

 Libderiv->deriv_classes[2][5][11] = int_stack + 0;
 Libderiv->deriv_classes[2][6][11] = int_stack + 126;
 Libderiv->deriv_classes[2][7][11] = int_stack + 294;
 Libderiv->deriv_classes[3][5][11] = int_stack + 510;
 Libderiv->deriv_classes[3][6][11] = int_stack + 720;
 Libderiv->deriv_classes[3][7][11] = int_stack + 1000;
 Libderiv->deriv_classes[2][5][10] = int_stack + 1360;
 Libderiv->deriv_classes[2][6][10] = int_stack + 1486;
 Libderiv->deriv_classes[2][7][10] = int_stack + 1654;
 Libderiv->deriv_classes[3][5][10] = int_stack + 1870;
 Libderiv->deriv_classes[3][6][10] = int_stack + 2080;
 Libderiv->deriv_classes[3][7][10] = int_stack + 2360;
 Libderiv->deriv_classes[2][5][9] = int_stack + 2720;
 Libderiv->deriv_classes[2][6][9] = int_stack + 2846;
 Libderiv->deriv_classes[2][7][9] = int_stack + 3014;
 Libderiv->deriv_classes[3][5][9] = int_stack + 3230;
 Libderiv->deriv_classes[3][6][9] = int_stack + 3440;
 Libderiv->deriv_classes[3][7][9] = int_stack + 3720;
 Libderiv->deriv_classes[2][5][8] = int_stack + 4080;
 Libderiv->deriv_classes[2][6][8] = int_stack + 4206;
 Libderiv->deriv_classes[2][7][8] = int_stack + 4374;
 Libderiv->deriv_classes[3][5][8] = int_stack + 4590;
 Libderiv->deriv_classes[3][6][8] = int_stack + 4800;
 Libderiv->deriv_classes[3][7][8] = int_stack + 5080;
 Libderiv->deriv_classes[2][5][7] = int_stack + 5440;
 Libderiv->deriv_classes[2][6][7] = int_stack + 5566;
 Libderiv->deriv_classes[2][7][7] = int_stack + 5734;
 Libderiv->deriv_classes[3][5][7] = int_stack + 5950;
 Libderiv->deriv_classes[3][6][7] = int_stack + 6160;
 Libderiv->deriv_classes[3][7][7] = int_stack + 6440;
 Libderiv->deriv_classes[2][5][6] = int_stack + 6800;
 Libderiv->deriv_classes[2][6][6] = int_stack + 6926;
 Libderiv->deriv_classes[2][7][6] = int_stack + 7094;
 Libderiv->dvrr_classes[3][5] = int_stack + 7310;
 Libderiv->deriv_classes[3][5][6] = int_stack + 7520;
 Libderiv->dvrr_classes[3][6] = int_stack + 7730;
 Libderiv->deriv_classes[3][6][6] = int_stack + 8010;
 Libderiv->deriv_classes[3][7][6] = int_stack + 8290;
 Libderiv->deriv_classes[2][5][2] = int_stack + 8650;
 Libderiv->deriv_classes[2][6][2] = int_stack + 8776;
 Libderiv->deriv_classes[2][7][2] = int_stack + 8944;
 Libderiv->deriv_classes[3][5][2] = int_stack + 9160;
 Libderiv->deriv_classes[3][6][2] = int_stack + 9370;
 Libderiv->deriv_classes[3][7][2] = int_stack + 9650;
 Libderiv->deriv_classes[2][5][1] = int_stack + 10010;
 Libderiv->deriv_classes[2][6][1] = int_stack + 10136;
 Libderiv->deriv_classes[2][7][1] = int_stack + 10304;
 Libderiv->deriv_classes[3][5][1] = int_stack + 10520;
 Libderiv->deriv_classes[3][6][1] = int_stack + 10730;
 Libderiv->deriv_classes[3][7][1] = int_stack + 11010;
 Libderiv->dvrr_classes[2][5] = int_stack + 11370;
 Libderiv->dvrr_classes[2][6] = int_stack + 11496;
 Libderiv->dvrr_classes[2][7] = int_stack + 11664;
 Libderiv->deriv_classes[2][5][0] = int_stack + 11880;
 Libderiv->deriv_classes[2][6][0] = int_stack + 12006;
 Libderiv->deriv_classes[2][7][0] = int_stack + 12174;
 Libderiv->deriv_classes[3][5][0] = int_stack + 12390;
 Libderiv->deriv_classes[3][6][0] = int_stack + 12600;
 Libderiv->deriv_classes[3][7][0] = int_stack + 12880;
 memset(int_stack,0,105920);

 Libderiv->dvrr_stack = int_stack + 26722;
 for(i=0;i<num_prim_comb;i++) {
   d1vrr_order_dphd(Libderiv, Data);
   Data++;
 }

 /*--- compute (d0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+13240,int_stack+11496,int_stack+11370,6);
 /*--- compute (d0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+13618,int_stack+126,int_stack+0, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+11370,6);
 /*--- compute (d0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+13996,int_stack+294,int_stack+126, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+11496,6);
 /*--- compute (d0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+14500,int_stack+13996,int_stack+13618, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+13240,6);
 /*--- compute (f0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+13618,int_stack+7730,int_stack+7310,10);
 /*--- compute (f0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+15256,int_stack+720,int_stack+510, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+7310,10);
 /*--- compute (f0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+15886,int_stack+1000,int_stack+720, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+7730,10);
 /*--- compute (f0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+0,int_stack+15886,int_stack+15256, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+13618,10);
 /*--- compute (d0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+15256,int_stack+1486,int_stack+1360, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+11370, 0.0, zero_stack,6);
 /*--- compute (d0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+15634,int_stack+1654,int_stack+1486, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+11496, 0.0, zero_stack,6);
 /*--- compute (d0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+16138,int_stack+15634,int_stack+15256, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+13240, 0.0, zero_stack,6);
 /*--- compute (f0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+15256,int_stack+2080,int_stack+1870, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+7310, 0.0, zero_stack,10);
 /*--- compute (f0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+16894,int_stack+2360,int_stack+2080, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+7730, 0.0, zero_stack,10);
 /*--- compute (f0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+1260,int_stack+16894,int_stack+15256, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+13618, 0.0, zero_stack,10);
 /*--- compute (d0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+15256,int_stack+2846,int_stack+2720, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+11370, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+15634,int_stack+3014,int_stack+2846, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+11496, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+16894,int_stack+15634,int_stack+15256, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+13240, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (f0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+15256,int_stack+3440,int_stack+3230, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+7310, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+2520,int_stack+3720,int_stack+3440, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+7730, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+17650,int_stack+2520,int_stack+15256, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+13618, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (d0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+15256,int_stack+4206,int_stack+4080, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+11370, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+15634,int_stack+4374,int_stack+4206, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+11496, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+2520,int_stack+15634,int_stack+15256, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+13240, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (f0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+15256,int_stack+4800,int_stack+4590, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+7310, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+3276,int_stack+5080,int_stack+4800, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+7730, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+4116,int_stack+3276,int_stack+15256, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+13618, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (d0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+15256,int_stack+5566,int_stack+5440, 0.0, zero_stack, 1.0, int_stack+11370, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+15634,int_stack+5734,int_stack+5566, 0.0, zero_stack, 1.0, int_stack+11496, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+3276,int_stack+15634,int_stack+15256, 0.0, zero_stack, 1.0, int_stack+13240, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (f0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+15256,int_stack+6160,int_stack+5950, 0.0, zero_stack, 1.0, int_stack+7310, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+18910,int_stack+6440,int_stack+6160, 0.0, zero_stack, 1.0, int_stack+7730, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+5376,int_stack+18910,int_stack+15256, 0.0, zero_stack, 1.0, int_stack+13618, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (d0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+15256,int_stack+6926,int_stack+6800, 1.0, int_stack+11370, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+15634,int_stack+7094,int_stack+6926, 1.0, int_stack+11496, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+18910,int_stack+15634,int_stack+15256, 1.0, int_stack+13240, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (f0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+15256,int_stack+8010,int_stack+7520, 1.0, int_stack+7310, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+6636,int_stack+8290,int_stack+8010, 1.0, int_stack+7730, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+19666,int_stack+6636,int_stack+15256, 1.0, int_stack+13618, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (d0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+13618,int_stack+11664,int_stack+11496,6);
 /*--- compute (d0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+15256,int_stack+13618,int_stack+13240,6);
 /*--- compute (d0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+13240,int_stack+8776,int_stack+8650,6);
 /*--- compute (d0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+13618,int_stack+8944,int_stack+8776,6);
 /*--- compute (d0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+6636,int_stack+13618,int_stack+13240,6);
 /*--- compute (f0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+13240,int_stack+9370,int_stack+9160,10);
 /*--- compute (f0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+7392,int_stack+9650,int_stack+9370,10);
 /*--- compute (f0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+8232,int_stack+7392,int_stack+13240,10);
 /*--- compute (d0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+13240,int_stack+10136,int_stack+10010,6);
 /*--- compute (d0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+13618,int_stack+10304,int_stack+10136,6);
 /*--- compute (d0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+7392,int_stack+13618,int_stack+13240,6);
 /*--- compute (f0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+13240,int_stack+10730,int_stack+10520,10);
 /*--- compute (f0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+9492,int_stack+11010,int_stack+10730,10);
 /*--- compute (f0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+10332,int_stack+9492,int_stack+13240,10);
 /*--- compute (d0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+13240,int_stack+12006,int_stack+11880,6);
 /*--- compute (d0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+13618,int_stack+12174,int_stack+12006,6);
 /*--- compute (d0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+9492,int_stack+13618,int_stack+13240,6);
 /*--- compute (f0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+13240,int_stack+12600,int_stack+12390,10);
 /*--- compute (f0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+11592,int_stack+12880,int_stack+12600,10);
 /*--- compute (f0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+20926,int_stack+11592,int_stack+13240,10);
 /*--- compute (dp|hd) ---*/
   hrr1_build_dp(Libderiv->AB,int_stack+11592,int_stack+0,int_stack+14500,126);
     Libderiv->ABCD[11] = int_stack + 11592;
 /*--- compute (dp|hd) ---*/
   hrr1_build_dp(Libderiv->AB,int_stack+22186,int_stack+1260,int_stack+16138,126);
     Libderiv->ABCD[10] = int_stack + 22186;
 /*--- compute (dp|hd) ---*/
   hrr1_build_dp(Libderiv->AB,int_stack+0,int_stack+17650,int_stack+16894,126);
     Libderiv->ABCD[9] = int_stack + 0;
 /*--- compute (dp|hd) ---*/
   hrr1_build_dp(Libderiv->AB,int_stack+16012,int_stack+4116,int_stack+2520,126);
     Libderiv->ABCD[8] = int_stack + 16012;
 /*--- compute (dp|hd) ---*/
   hrr1_build_dp(Libderiv->AB,int_stack+24454,int_stack+5376,int_stack+3276,126);
     Libderiv->ABCD[7] = int_stack + 24454;
 /*--- compute (dp|hd) ---*/
   hrr1_build_dp(Libderiv->AB,int_stack+2268,int_stack+19666,int_stack+18910,126);
     Libderiv->ABCD[6] = int_stack + 2268;
 /*--- compute (dp|hd) ---*/
   d1hrr1_build_dp(Libderiv->AB,int_stack+18280,int_stack+8232,int_stack+6636, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+15256, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,126);
     Libderiv->ABCD[2] = int_stack + 18280;
 /*--- compute (dp|hd) ---*/
   d1hrr1_build_dp(Libderiv->AB,int_stack+4536,int_stack+10332,int_stack+7392, 0.0, zero_stack, 1.0, int_stack+15256, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,126);
     Libderiv->ABCD[1] = int_stack + 4536;
 /*--- compute (dp|hd) ---*/
   d1hrr1_build_dp(Libderiv->AB,int_stack+6804,int_stack+20926,int_stack+9492, 1.0, int_stack+15256, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,126);
     Libderiv->ABCD[0] = int_stack + 6804;

}
