/*
 *  Copyright (C) 1996-2017 Edward F. Valeev and Justin T. Fermann
 *
 *  This file is part of Libint.
 *
 *  Libint is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU Lesser General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  Libint is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public License
 *  along with Libint.  If not, see <http://www.gnu.org/licenses/>.
 *
 */

#include <stdio.h>
#include <string.h>
#include <libint/libint.h>
#include "libderiv.h"
#include <libint/hrr_header.h>

#include "d1hrr_header.h"

extern void d1vrr_order_hphg(Libderiv_t *, prim_data *);

  /* Computes derivatives of (hp|hg) integrals */

void d1hrr_order_hphg(Libderiv_t *Libderiv, int num_prim_comb)
{
 prim_data *Data = Libderiv->PrimQuartet;
 double *int_stack = Libderiv->int_stack;
 double *zero_stack = Libderiv->zero_stack;
 int i,j;
 double tmp, *target;

 Libderiv->deriv_classes[5][5][11] = int_stack + 0;
 Libderiv->deriv_classes[5][6][11] = int_stack + 441;
 Libderiv->deriv_classes[5][7][11] = int_stack + 1029;
 Libderiv->deriv_classes[5][8][11] = int_stack + 1785;
 Libderiv->deriv_classes[5][9][11] = int_stack + 2730;
 Libderiv->deriv_classes[6][5][11] = int_stack + 3885;
 Libderiv->deriv_classes[6][6][11] = int_stack + 4473;
 Libderiv->deriv_classes[6][7][11] = int_stack + 5257;
 Libderiv->deriv_classes[6][8][11] = int_stack + 6265;
 Libderiv->deriv_classes[6][9][11] = int_stack + 7525;
 Libderiv->deriv_classes[5][5][10] = int_stack + 9065;
 Libderiv->deriv_classes[5][6][10] = int_stack + 9506;
 Libderiv->deriv_classes[5][7][10] = int_stack + 10094;
 Libderiv->deriv_classes[5][8][10] = int_stack + 10850;
 Libderiv->deriv_classes[5][9][10] = int_stack + 11795;
 Libderiv->deriv_classes[6][5][10] = int_stack + 12950;
 Libderiv->deriv_classes[6][6][10] = int_stack + 13538;
 Libderiv->deriv_classes[6][7][10] = int_stack + 14322;
 Libderiv->deriv_classes[6][8][10] = int_stack + 15330;
 Libderiv->deriv_classes[6][9][10] = int_stack + 16590;
 Libderiv->deriv_classes[5][5][9] = int_stack + 18130;
 Libderiv->deriv_classes[5][6][9] = int_stack + 18571;
 Libderiv->deriv_classes[5][7][9] = int_stack + 19159;
 Libderiv->deriv_classes[5][8][9] = int_stack + 19915;
 Libderiv->deriv_classes[5][9][9] = int_stack + 20860;
 Libderiv->deriv_classes[6][5][9] = int_stack + 22015;
 Libderiv->deriv_classes[6][6][9] = int_stack + 22603;
 Libderiv->deriv_classes[6][7][9] = int_stack + 23387;
 Libderiv->deriv_classes[6][8][9] = int_stack + 24395;
 Libderiv->deriv_classes[6][9][9] = int_stack + 25655;
 Libderiv->deriv_classes[5][5][8] = int_stack + 27195;
 Libderiv->deriv_classes[5][6][8] = int_stack + 27636;
 Libderiv->deriv_classes[5][7][8] = int_stack + 28224;
 Libderiv->deriv_classes[5][8][8] = int_stack + 28980;
 Libderiv->deriv_classes[5][9][8] = int_stack + 29925;
 Libderiv->deriv_classes[6][5][8] = int_stack + 31080;
 Libderiv->deriv_classes[6][6][8] = int_stack + 31668;
 Libderiv->deriv_classes[6][7][8] = int_stack + 32452;
 Libderiv->deriv_classes[6][8][8] = int_stack + 33460;
 Libderiv->deriv_classes[6][9][8] = int_stack + 34720;
 Libderiv->deriv_classes[5][5][7] = int_stack + 36260;
 Libderiv->deriv_classes[5][6][7] = int_stack + 36701;
 Libderiv->deriv_classes[5][7][7] = int_stack + 37289;
 Libderiv->deriv_classes[5][8][7] = int_stack + 38045;
 Libderiv->deriv_classes[5][9][7] = int_stack + 38990;
 Libderiv->deriv_classes[6][5][7] = int_stack + 40145;
 Libderiv->deriv_classes[6][6][7] = int_stack + 40733;
 Libderiv->deriv_classes[6][7][7] = int_stack + 41517;
 Libderiv->deriv_classes[6][8][7] = int_stack + 42525;
 Libderiv->deriv_classes[6][9][7] = int_stack + 43785;
 Libderiv->deriv_classes[5][5][6] = int_stack + 45325;
 Libderiv->deriv_classes[5][6][6] = int_stack + 45766;
 Libderiv->deriv_classes[5][7][6] = int_stack + 46354;
 Libderiv->deriv_classes[5][8][6] = int_stack + 47110;
 Libderiv->deriv_classes[5][9][6] = int_stack + 48055;
 Libderiv->dvrr_classes[6][5] = int_stack + 49210;
 Libderiv->deriv_classes[6][5][6] = int_stack + 49798;
 Libderiv->dvrr_classes[6][6] = int_stack + 50386;
 Libderiv->deriv_classes[6][6][6] = int_stack + 51170;
 Libderiv->dvrr_classes[6][7] = int_stack + 51954;
 Libderiv->deriv_classes[6][7][6] = int_stack + 52962;
 Libderiv->dvrr_classes[6][8] = int_stack + 53970;
 Libderiv->deriv_classes[6][8][6] = int_stack + 55230;
 Libderiv->deriv_classes[6][9][6] = int_stack + 56490;
 Libderiv->deriv_classes[5][5][2] = int_stack + 58030;
 Libderiv->deriv_classes[5][6][2] = int_stack + 58471;
 Libderiv->deriv_classes[5][7][2] = int_stack + 59059;
 Libderiv->deriv_classes[5][8][2] = int_stack + 59815;
 Libderiv->deriv_classes[5][9][2] = int_stack + 60760;
 Libderiv->deriv_classes[6][5][2] = int_stack + 61915;
 Libderiv->deriv_classes[6][6][2] = int_stack + 62503;
 Libderiv->deriv_classes[6][7][2] = int_stack + 63287;
 Libderiv->deriv_classes[6][8][2] = int_stack + 64295;
 Libderiv->deriv_classes[6][9][2] = int_stack + 65555;
 Libderiv->deriv_classes[5][5][1] = int_stack + 67095;
 Libderiv->deriv_classes[5][6][1] = int_stack + 67536;
 Libderiv->deriv_classes[5][7][1] = int_stack + 68124;
 Libderiv->deriv_classes[5][8][1] = int_stack + 68880;
 Libderiv->deriv_classes[5][9][1] = int_stack + 69825;
 Libderiv->deriv_classes[6][5][1] = int_stack + 70980;
 Libderiv->deriv_classes[6][6][1] = int_stack + 71568;
 Libderiv->deriv_classes[6][7][1] = int_stack + 72352;
 Libderiv->deriv_classes[6][8][1] = int_stack + 73360;
 Libderiv->deriv_classes[6][9][1] = int_stack + 74620;
 Libderiv->dvrr_classes[5][5] = int_stack + 76160;
 Libderiv->dvrr_classes[5][6] = int_stack + 76601;
 Libderiv->dvrr_classes[5][7] = int_stack + 77189;
 Libderiv->dvrr_classes[5][8] = int_stack + 77945;
 Libderiv->dvrr_classes[5][9] = int_stack + 78890;
 Libderiv->deriv_classes[5][5][0] = int_stack + 80045;
 Libderiv->deriv_classes[5][6][0] = int_stack + 80486;
 Libderiv->deriv_classes[5][7][0] = int_stack + 81074;
 Libderiv->deriv_classes[5][8][0] = int_stack + 81830;
 Libderiv->deriv_classes[5][9][0] = int_stack + 82775;
 Libderiv->deriv_classes[6][5][0] = int_stack + 83930;
 Libderiv->deriv_classes[6][6][0] = int_stack + 84518;
 Libderiv->deriv_classes[6][7][0] = int_stack + 85302;
 Libderiv->deriv_classes[6][8][0] = int_stack + 86310;
 Libderiv->deriv_classes[6][9][0] = int_stack + 87570;
 memset(int_stack,0,712880);

 Libderiv->dvrr_stack = int_stack + 248794;
 for(i=0;i<num_prim_comb;i++) {
   d1vrr_order_hphg(Libderiv, Data);
   Data++;
 }

 /*--- compute (h0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+89110,int_stack+76601,int_stack+76160,21);
 /*--- compute (h0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+90433,int_stack+77189,int_stack+76601,21);
 /*--- compute (h0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+92197,int_stack+90433,int_stack+89110,21);
 /*--- compute (h0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+94843,int_stack+77945,int_stack+77189,21);
 /*--- compute (h0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+97111,int_stack+94843,int_stack+90433,21);
 /*--- compute (h0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+100639,int_stack+97111,int_stack+92197,21);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+105049,int_stack+441,int_stack+0, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+76160,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+106372,int_stack+1029,int_stack+441, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+76601,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+108136,int_stack+106372,int_stack+105049, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+89110,21);
 /*--- compute (h0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+110782,int_stack+1785,int_stack+1029, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+77189,21);
 /*--- compute (h0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+113050,int_stack+110782,int_stack+106372, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+90433,21);
 /*--- compute (h0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+116578,int_stack+113050,int_stack+108136, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+92197,21);
 /*--- compute (h0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+105049,int_stack+2730,int_stack+1785, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+77945,21);
 /*--- compute (h0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+120988,int_stack+105049,int_stack+110782, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+94843,21);
 /*--- compute (h0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+105049,int_stack+120988,int_stack+113050, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+97111,21);
 /*--- compute (h0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+120988,int_stack+105049,int_stack+116578, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+100639,21);
 /*--- compute (i0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+105049,int_stack+50386,int_stack+49210,28);
 /*--- compute (i0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+106813,int_stack+51954,int_stack+50386,28);
 /*--- compute (i0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+109165,int_stack+106813,int_stack+105049,28);
 /*--- compute (i0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+112693,int_stack+53970,int_stack+51954,28);
 /*--- compute (i0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+115717,int_stack+112693,int_stack+106813,28);
 /*--- compute (i0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+127603,int_stack+115717,int_stack+109165,28);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+0,int_stack+4473,int_stack+3885, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+49210,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+1764,int_stack+5257,int_stack+4473, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+50386,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+133483,int_stack+1764,int_stack+0, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+105049,28);
 /*--- compute (i0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+137011,int_stack+6265,int_stack+5257, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+51954,28);
 /*--- compute (i0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+140035,int_stack+137011,int_stack+1764, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+106813,28);
 /*--- compute (i0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+0,int_stack+140035,int_stack+133483, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+109165,28);
 /*--- compute (i0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+144739,int_stack+7525,int_stack+6265, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+53970,28);
 /*--- compute (i0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+148519,int_stack+144739,int_stack+137011, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+112693,28);
 /*--- compute (i0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+154567,int_stack+148519,int_stack+140035, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+115717,28);
 /*--- compute (i0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+133483,int_stack+154567,int_stack+0, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+127603,28);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+0,int_stack+9506,int_stack+9065, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+76160, 0.0, zero_stack,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+1323,int_stack+10094,int_stack+9506, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+76601, 0.0, zero_stack,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+3087,int_stack+1323,int_stack+0, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+89110, 0.0, zero_stack,21);
 /*--- compute (h0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+5733,int_stack+10850,int_stack+10094, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+77189, 0.0, zero_stack,21);
 /*--- compute (h0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+142303,int_stack+5733,int_stack+1323, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+90433, 0.0, zero_stack,21);
 /*--- compute (h0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+145831,int_stack+142303,int_stack+3087, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+92197, 0.0, zero_stack,21);
 /*--- compute (h0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+0,int_stack+11795,int_stack+10850, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+77945, 0.0, zero_stack,21);
 /*--- compute (h0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+8001,int_stack+0,int_stack+5733, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+94843, 0.0, zero_stack,21);
 /*--- compute (h0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+0,int_stack+8001,int_stack+142303, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+97111, 0.0, zero_stack,21);
 /*--- compute (h0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+5880,int_stack+0,int_stack+145831, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+100639, 0.0, zero_stack,21);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+0,int_stack+13538,int_stack+12950, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+49210, 0.0, zero_stack,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+1764,int_stack+14322,int_stack+13538, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+50386, 0.0, zero_stack,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+142303,int_stack+1764,int_stack+0, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+105049, 0.0, zero_stack,28);
 /*--- compute (i0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+145831,int_stack+15330,int_stack+14322, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+51954, 0.0, zero_stack,28);
 /*--- compute (i0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+148855,int_stack+145831,int_stack+1764, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+106813, 0.0, zero_stack,28);
 /*--- compute (i0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+0,int_stack+148855,int_stack+142303, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+109165, 0.0, zero_stack,28);
 /*--- compute (i0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+153559,int_stack+16590,int_stack+15330, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+53970, 0.0, zero_stack,28);
 /*--- compute (i0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+157339,int_stack+153559,int_stack+145831, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+112693, 0.0, zero_stack,28);
 /*--- compute (i0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+163387,int_stack+157339,int_stack+148855, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+115717, 0.0, zero_stack,28);
 /*--- compute (i0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+142303,int_stack+163387,int_stack+0, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+127603, 0.0, zero_stack,28);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+0,int_stack+18571,int_stack+18130, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+76160, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+1323,int_stack+19159,int_stack+18571, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+76601, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+3087,int_stack+1323,int_stack+0, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+89110, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+151123,int_stack+19915,int_stack+19159, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+77189, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+153391,int_stack+151123,int_stack+1323, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+90433, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+156919,int_stack+153391,int_stack+3087, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+92197, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+0,int_stack+20860,int_stack+19915, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+77945, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+161329,int_stack+0,int_stack+151123, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+94843, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+0,int_stack+161329,int_stack+153391, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+97111, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+161329,int_stack+0,int_stack+156919, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+100639, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+0,int_stack+22603,int_stack+22015, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+49210, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+1764,int_stack+23387,int_stack+22603, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+50386, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+167944,int_stack+1764,int_stack+0, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+105049, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+151123,int_stack+24395,int_stack+23387, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+51954, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+154147,int_stack+151123,int_stack+1764, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+106813, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+0,int_stack+154147,int_stack+167944, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+109165, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+167944,int_stack+25655,int_stack+24395, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+53970, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+12495,int_stack+167944,int_stack+151123, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+112693, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+18543,int_stack+12495,int_stack+154147, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+115717, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+151123,int_stack+18543,int_stack+0, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+127603, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+0,int_stack+27636,int_stack+27195, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+76160, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+1323,int_stack+28224,int_stack+27636, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+76601, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+3087,int_stack+1323,int_stack+0, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+89110, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+12495,int_stack+28980,int_stack+28224, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+77189, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+14763,int_stack+12495,int_stack+1323, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+90433, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+18291,int_stack+14763,int_stack+3087, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+92197, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+0,int_stack+29925,int_stack+28980, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+77945, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+22701,int_stack+0,int_stack+12495, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+94843, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+0,int_stack+22701,int_stack+14763, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+97111, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+22701,int_stack+0,int_stack+18291, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+100639, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+29316,int_stack+31668,int_stack+31080, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+49210, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+0,int_stack+32452,int_stack+31668, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+50386, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+2352,int_stack+0,int_stack+29316, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+105049, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+29316,int_stack+33460,int_stack+32452, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+51954, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+12495,int_stack+29316,int_stack+0, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+106813, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+167944,int_stack+12495,int_stack+2352, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+109165, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+0,int_stack+34720,int_stack+33460, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+53970, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+173824,int_stack+0,int_stack+29316, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+112693, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+179872,int_stack+173824,int_stack+12495, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+115717, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+12495,int_stack+179872,int_stack+167944, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+127603, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+167944,int_stack+36701,int_stack+36260, 0.0, zero_stack, 1.0, int_stack+76160, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+169267,int_stack+37289,int_stack+36701, 0.0, zero_stack, 1.0, int_stack+76601, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+171031,int_stack+169267,int_stack+167944, 0.0, zero_stack, 1.0, int_stack+89110, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+173677,int_stack+38045,int_stack+37289, 0.0, zero_stack, 1.0, int_stack+77189, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+175945,int_stack+173677,int_stack+169267, 0.0, zero_stack, 1.0, int_stack+90433, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+179473,int_stack+175945,int_stack+171031, 0.0, zero_stack, 1.0, int_stack+92197, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+167944,int_stack+38990,int_stack+38045, 0.0, zero_stack, 1.0, int_stack+77945, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+29316,int_stack+167944,int_stack+173677, 0.0, zero_stack, 1.0, int_stack+94843, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+0,int_stack+29316,int_stack+175945, 0.0, zero_stack, 1.0, int_stack+97111, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+29316,int_stack+0,int_stack+179473, 0.0, zero_stack, 1.0, int_stack+100639, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+0,int_stack+40733,int_stack+40145, 0.0, zero_stack, 1.0, int_stack+49210, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+1764,int_stack+41517,int_stack+40733, 0.0, zero_stack, 1.0, int_stack+50386, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+35931,int_stack+1764,int_stack+0, 0.0, zero_stack, 1.0, int_stack+105049, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+167944,int_stack+42525,int_stack+41517, 0.0, zero_stack, 1.0, int_stack+51954, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+170968,int_stack+167944,int_stack+1764, 0.0, zero_stack, 1.0, int_stack+106813, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+0,int_stack+170968,int_stack+35931, 0.0, zero_stack, 1.0, int_stack+109165, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+35931,int_stack+43785,int_stack+42525, 0.0, zero_stack, 1.0, int_stack+53970, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+175672,int_stack+35931,int_stack+167944, 0.0, zero_stack, 1.0, int_stack+112693, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+35931,int_stack+175672,int_stack+170968, 0.0, zero_stack, 1.0, int_stack+115717, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+167944,int_stack+35931,int_stack+0, 0.0, zero_stack, 1.0, int_stack+127603, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+0,int_stack+45766,int_stack+45325, 1.0, int_stack+76160, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+1323,int_stack+46354,int_stack+45766, 1.0, int_stack+76601, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+3087,int_stack+1323,int_stack+0, 1.0, int_stack+89110, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+35931,int_stack+47110,int_stack+46354, 1.0, int_stack+77189, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+38199,int_stack+35931,int_stack+1323, 1.0, int_stack+90433, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+41727,int_stack+38199,int_stack+3087, 1.0, int_stack+92197, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+89110,int_stack+48055,int_stack+47110, 1.0, int_stack+77945, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+0,int_stack+89110,int_stack+35931, 1.0, int_stack+94843, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+176764,int_stack+0,int_stack+38199, 1.0, int_stack+97111, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+182644,int_stack+176764,int_stack+41727, 1.0, int_stack+100639, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+176764,int_stack+51170,int_stack+49798, 1.0, int_stack+49210, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+178528,int_stack+52962,int_stack+51170, 1.0, int_stack+50386, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+0,int_stack+178528,int_stack+176764, 1.0, int_stack+105049, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+35931,int_stack+55230,int_stack+52962, 1.0, int_stack+51954, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+38955,int_stack+35931,int_stack+178528, 1.0, int_stack+106813, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+176764,int_stack+38955,int_stack+0, 1.0, int_stack+109165, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+0,int_stack+56490,int_stack+55230, 1.0, int_stack+53970, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+105049,int_stack+0,int_stack+35931, 1.0, int_stack+112693, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+43659,int_stack+105049,int_stack+38955, 1.0, int_stack+115717, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+105049,int_stack+43659,int_stack+176764, 1.0, int_stack+127603, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (h0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+127603,int_stack+78890,int_stack+77945,21);
 /*--- compute (h0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+176764,int_stack+127603,int_stack+94843,21);
 /*--- compute (h0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+127603,int_stack+176764,int_stack+97111,21);
 /*--- compute (h0|hg) ---*/
   hrr3_build_hg(Libderiv->CD,int_stack+113869,int_stack+127603,int_stack+100639,21);
 /*--- compute (h0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+127603,int_stack+58471,int_stack+58030,21);
 /*--- compute (h0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+128926,int_stack+59059,int_stack+58471,21);
 /*--- compute (h0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+130690,int_stack+128926,int_stack+127603,21);
 /*--- compute (h0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+176764,int_stack+59815,int_stack+59059,21);
 /*--- compute (h0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+179032,int_stack+176764,int_stack+128926,21);
 /*--- compute (h0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+35931,int_stack+179032,int_stack+130690,21);
 /*--- compute (h0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+127603,int_stack+60760,int_stack+59815,21);
 /*--- compute (h0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+40341,int_stack+127603,int_stack+176764,21);
 /*--- compute (h0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+127603,int_stack+40341,int_stack+179032,21);
 /*--- compute (h0|hg) ---*/
   hrr3_build_hg(Libderiv->CD,int_stack+40341,int_stack+127603,int_stack+35931,21);
 /*--- compute (i0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+35931,int_stack+62503,int_stack+61915,28);
 /*--- compute (i0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+37695,int_stack+63287,int_stack+62503,28);
 /*--- compute (i0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+127603,int_stack+37695,int_stack+35931,28);
 /*--- compute (i0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+46956,int_stack+64295,int_stack+63287,28);
 /*--- compute (i0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+49980,int_stack+46956,int_stack+37695,28);
 /*--- compute (i0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+176764,int_stack+49980,int_stack+127603,28);
 /*--- compute (i0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+127603,int_stack+65555,int_stack+64295,28);
 /*--- compute (i0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+54684,int_stack+127603,int_stack+46956,28);
 /*--- compute (i0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+89110,int_stack+54684,int_stack+49980,28);
 /*--- compute (i0|hg) ---*/
   hrr3_build_hg(Libderiv->CD,int_stack+46956,int_stack+89110,int_stack+176764,28);
 /*--- compute (h0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+176764,int_stack+67536,int_stack+67095,21);
 /*--- compute (h0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+178087,int_stack+68124,int_stack+67536,21);
 /*--- compute (h0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+179851,int_stack+178087,int_stack+176764,21);
 /*--- compute (h0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+89110,int_stack+68880,int_stack+68124,21);
 /*--- compute (h0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+91378,int_stack+89110,int_stack+178087,21);
 /*--- compute (h0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+35931,int_stack+91378,int_stack+179851,21);
 /*--- compute (h0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+176764,int_stack+69825,int_stack+68880,21);
 /*--- compute (h0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+94906,int_stack+176764,int_stack+89110,21);
 /*--- compute (h0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+176764,int_stack+94906,int_stack+91378,21);
 /*--- compute (h0|hg) ---*/
   hrr3_build_hg(Libderiv->CD,int_stack+89110,int_stack+176764,int_stack+35931,21);
 /*--- compute (i0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+35931,int_stack+71568,int_stack+70980,28);
 /*--- compute (i0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+37695,int_stack+72352,int_stack+71568,28);
 /*--- compute (i0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+176764,int_stack+37695,int_stack+35931,28);
 /*--- compute (i0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+95725,int_stack+73360,int_stack+72352,28);
 /*--- compute (i0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+98749,int_stack+95725,int_stack+37695,28);
 /*--- compute (i0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+127603,int_stack+98749,int_stack+176764,28);
 /*--- compute (i0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+176764,int_stack+74620,int_stack+73360,28);
 /*--- compute (i0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+55776,int_stack+176764,int_stack+95725,28);
 /*--- compute (i0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+61824,int_stack+55776,int_stack+98749,28);
 /*--- compute (i0|hg) ---*/
   hrr3_build_hg(Libderiv->CD,int_stack+95725,int_stack+61824,int_stack+127603,28);
 /*--- compute (h0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+127603,int_stack+80486,int_stack+80045,21);
 /*--- compute (h0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+128926,int_stack+81074,int_stack+80486,21);
 /*--- compute (h0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+130690,int_stack+128926,int_stack+127603,21);
 /*--- compute (h0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+55776,int_stack+81830,int_stack+81074,21);
 /*--- compute (h0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+58044,int_stack+55776,int_stack+128926,21);
 /*--- compute (h0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+35931,int_stack+58044,int_stack+130690,21);
 /*--- compute (h0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+127603,int_stack+82775,int_stack+81830,21);
 /*--- compute (h0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+61572,int_stack+127603,int_stack+55776,21);
 /*--- compute (h0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+127603,int_stack+61572,int_stack+58044,21);
 /*--- compute (h0|hg) ---*/
   hrr3_build_hg(Libderiv->CD,int_stack+55776,int_stack+127603,int_stack+35931,21);
 /*--- compute (i0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+35931,int_stack+84518,int_stack+83930,28);
 /*--- compute (i0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+37695,int_stack+85302,int_stack+84518,28);
 /*--- compute (i0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+127603,int_stack+37695,int_stack+35931,28);
 /*--- compute (i0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+62391,int_stack+86310,int_stack+85302,28);
 /*--- compute (i0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+65415,int_stack+62391,int_stack+37695,28);
 /*--- compute (i0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+176764,int_stack+65415,int_stack+127603,28);
 /*--- compute (i0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+127603,int_stack+87570,int_stack+86310,28);
 /*--- compute (i0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+70119,int_stack+127603,int_stack+62391,28);
 /*--- compute (i0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+76167,int_stack+70119,int_stack+65415,28);
 /*--- compute (i0|hg) ---*/
   hrr3_build_hg(Libderiv->CD,int_stack+62391,int_stack+76167,int_stack+176764,28);
 /*--- compute (hp|hg) ---*/
   hrr1_build_hp(Libderiv->AB,int_stack+189259,int_stack+133483,int_stack+120988,315);
     Libderiv->ABCD[11] = int_stack + 189259;
 /*--- compute (hp|hg) ---*/
   hrr1_build_hp(Libderiv->AB,int_stack+120484,int_stack+142303,int_stack+5880,315);
     Libderiv->ABCD[10] = int_stack + 120484;
 /*--- compute (hp|hg) ---*/
   hrr1_build_hp(Libderiv->AB,int_stack+209104,int_stack+151123,int_stack+161329,315);
     Libderiv->ABCD[9] = int_stack + 209104;
 /*--- compute (hp|hg) ---*/
   hrr1_build_hp(Libderiv->AB,int_stack+140329,int_stack+12495,int_stack+22701,315);
     Libderiv->ABCD[8] = int_stack + 140329;
 /*--- compute (hp|hg) ---*/
   hrr1_build_hp(Libderiv->AB,int_stack+0,int_stack+167944,int_stack+29316,315);
     Libderiv->ABCD[7] = int_stack + 0;
 /*--- compute (hp|hg) ---*/
   hrr1_build_hp(Libderiv->AB,int_stack+160174,int_stack+105049,int_stack+182644,315);
     Libderiv->ABCD[6] = int_stack + 160174;
 /*--- compute (hp|hg) ---*/
   d1hrr1_build_hp(Libderiv->AB,int_stack+19845,int_stack+46956,int_stack+40341, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+113869, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,315);
     Libderiv->ABCD[2] = int_stack + 19845;
 /*--- compute (hp|hg) ---*/
   d1hrr1_build_hp(Libderiv->AB,int_stack+228949,int_stack+95725,int_stack+89110, 0.0, zero_stack, 1.0, int_stack+113869, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,315);
     Libderiv->ABCD[1] = int_stack + 228949;
 /*--- compute (hp|hg) ---*/
   d1hrr1_build_hp(Libderiv->AB,int_stack+71211,int_stack+62391,int_stack+55776, 1.0, int_stack+113869, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,315);
     Libderiv->ABCD[0] = int_stack + 71211;

}
