/*
 *  Copyright (C) 1996-2017 Edward F. Valeev and Justin T. Fermann
 *
 *  This file is part of Libint.
 *
 *  Libint is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU Lesser General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  Libint is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public License
 *  along with Libint.  If not, see <http://www.gnu.org/licenses/>.
 *
 */

#include <stdio.h>
#include <string.h>
#include <libint/libint.h>
#include "libderiv.h"
#include <libint/hrr_header.h>

#include "d1hrr_header.h"

extern void d1vrr_order_ipid(Libderiv_t *, prim_data *);

  /* Computes derivatives of (ip|id) integrals */

void d1hrr_order_ipid(Libderiv_t *Libderiv, int num_prim_comb)
{
 prim_data *Data = Libderiv->PrimQuartet;
 double *int_stack = Libderiv->int_stack;
 double *zero_stack = Libderiv->zero_stack;
 int i,j;
 double tmp, *target;

 Libderiv->deriv_classes[6][6][11] = int_stack + 0;
 Libderiv->deriv_classes[6][7][11] = int_stack + 784;
 Libderiv->deriv_classes[6][8][11] = int_stack + 1792;
 Libderiv->deriv_classes[7][6][11] = int_stack + 3052;
 Libderiv->deriv_classes[7][7][11] = int_stack + 4060;
 Libderiv->deriv_classes[7][8][11] = int_stack + 5356;
 Libderiv->deriv_classes[6][6][10] = int_stack + 6976;
 Libderiv->deriv_classes[6][7][10] = int_stack + 7760;
 Libderiv->deriv_classes[6][8][10] = int_stack + 8768;
 Libderiv->deriv_classes[7][6][10] = int_stack + 10028;
 Libderiv->deriv_classes[7][7][10] = int_stack + 11036;
 Libderiv->deriv_classes[7][8][10] = int_stack + 12332;
 Libderiv->deriv_classes[6][6][9] = int_stack + 13952;
 Libderiv->deriv_classes[6][7][9] = int_stack + 14736;
 Libderiv->deriv_classes[6][8][9] = int_stack + 15744;
 Libderiv->deriv_classes[7][6][9] = int_stack + 17004;
 Libderiv->deriv_classes[7][7][9] = int_stack + 18012;
 Libderiv->deriv_classes[7][8][9] = int_stack + 19308;
 Libderiv->deriv_classes[6][6][8] = int_stack + 20928;
 Libderiv->deriv_classes[6][7][8] = int_stack + 21712;
 Libderiv->deriv_classes[6][8][8] = int_stack + 22720;
 Libderiv->deriv_classes[7][6][8] = int_stack + 23980;
 Libderiv->deriv_classes[7][7][8] = int_stack + 24988;
 Libderiv->deriv_classes[7][8][8] = int_stack + 26284;
 Libderiv->deriv_classes[6][6][7] = int_stack + 27904;
 Libderiv->deriv_classes[6][7][7] = int_stack + 28688;
 Libderiv->deriv_classes[6][8][7] = int_stack + 29696;
 Libderiv->deriv_classes[7][6][7] = int_stack + 30956;
 Libderiv->deriv_classes[7][7][7] = int_stack + 31964;
 Libderiv->deriv_classes[7][8][7] = int_stack + 33260;
 Libderiv->deriv_classes[6][6][6] = int_stack + 34880;
 Libderiv->deriv_classes[6][7][6] = int_stack + 35664;
 Libderiv->deriv_classes[6][8][6] = int_stack + 36672;
 Libderiv->dvrr_classes[7][6] = int_stack + 37932;
 Libderiv->deriv_classes[7][6][6] = int_stack + 38940;
 Libderiv->dvrr_classes[7][7] = int_stack + 39948;
 Libderiv->deriv_classes[7][7][6] = int_stack + 41244;
 Libderiv->deriv_classes[7][8][6] = int_stack + 42540;
 Libderiv->deriv_classes[6][6][2] = int_stack + 44160;
 Libderiv->deriv_classes[6][7][2] = int_stack + 44944;
 Libderiv->deriv_classes[6][8][2] = int_stack + 45952;
 Libderiv->deriv_classes[7][6][2] = int_stack + 47212;
 Libderiv->deriv_classes[7][7][2] = int_stack + 48220;
 Libderiv->deriv_classes[7][8][2] = int_stack + 49516;
 Libderiv->deriv_classes[6][6][1] = int_stack + 51136;
 Libderiv->deriv_classes[6][7][1] = int_stack + 51920;
 Libderiv->deriv_classes[6][8][1] = int_stack + 52928;
 Libderiv->deriv_classes[7][6][1] = int_stack + 54188;
 Libderiv->deriv_classes[7][7][1] = int_stack + 55196;
 Libderiv->deriv_classes[7][8][1] = int_stack + 56492;
 Libderiv->dvrr_classes[6][6] = int_stack + 58112;
 Libderiv->dvrr_classes[6][7] = int_stack + 58896;
 Libderiv->dvrr_classes[6][8] = int_stack + 59904;
 Libderiv->deriv_classes[6][6][0] = int_stack + 61164;
 Libderiv->deriv_classes[6][7][0] = int_stack + 61948;
 Libderiv->deriv_classes[6][8][0] = int_stack + 62956;
 Libderiv->deriv_classes[7][6][0] = int_stack + 64216;
 Libderiv->deriv_classes[7][7][0] = int_stack + 65224;
 Libderiv->deriv_classes[7][8][0] = int_stack + 66520;
 memset(int_stack,0,545120);

 Libderiv->dvrr_stack = int_stack + 154348;
 for(i=0;i<num_prim_comb;i++) {
   d1vrr_order_ipid(Libderiv, Data);
   Data++;
 }

 /*--- compute (i0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+68140,int_stack+58896,int_stack+58112,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+70492,int_stack+784,int_stack+0, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+58112,28);
 /*--- compute (i0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+72844,int_stack+1792,int_stack+784, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+58896,28);
 /*--- compute (i0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+75868,int_stack+72844,int_stack+70492, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+68140,28);
 /*--- compute (k0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+70492,int_stack+39948,int_stack+37932,36);
 /*--- compute (k0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+0,int_stack+4060,int_stack+3052, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+37932,36);
 /*--- compute (k0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+80572,int_stack+5356,int_stack+4060, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+39948,36);
 /*--- compute (k0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+84460,int_stack+80572,int_stack+0, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+70492,36);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+73516,int_stack+7760,int_stack+6976, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+58112, 0.0, zero_stack,28);
 /*--- compute (i0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+0,int_stack+8768,int_stack+7760, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+58896, 0.0, zero_stack,28);
 /*--- compute (i0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+3024,int_stack+0,int_stack+73516, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+68140, 0.0, zero_stack,28);
 /*--- compute (k0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+0,int_stack+11036,int_stack+10028, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+37932, 0.0, zero_stack,36);
 /*--- compute (k0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+80572,int_stack+12332,int_stack+11036, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+39948, 0.0, zero_stack,36);
 /*--- compute (k0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+7728,int_stack+80572,int_stack+0, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+70492, 0.0, zero_stack,36);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+73516,int_stack+14736,int_stack+13952, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+58112, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+0,int_stack+15744,int_stack+14736, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+58896, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+90508,int_stack+0,int_stack+73516, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+68140, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (k0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+0,int_stack+18012,int_stack+17004, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+37932, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+80572,int_stack+19308,int_stack+18012, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+39948, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+13776,int_stack+80572,int_stack+0, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+70492, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+73516,int_stack+21712,int_stack+20928, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+58112, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+0,int_stack+22720,int_stack+21712, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+58896, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+95212,int_stack+0,int_stack+73516, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+68140, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (k0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+0,int_stack+24988,int_stack+23980, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+37932, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+80572,int_stack+26284,int_stack+24988, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+39948, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+19824,int_stack+80572,int_stack+0, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+70492, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+73516,int_stack+28688,int_stack+27904, 0.0, zero_stack, 1.0, int_stack+58112, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+0,int_stack+29696,int_stack+28688, 0.0, zero_stack, 1.0, int_stack+58896, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+25872,int_stack+0,int_stack+73516, 0.0, zero_stack, 1.0, int_stack+68140, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (k0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+0,int_stack+31964,int_stack+30956, 0.0, zero_stack, 1.0, int_stack+37932, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+80572,int_stack+33260,int_stack+31964, 0.0, zero_stack, 1.0, int_stack+39948, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+99916,int_stack+80572,int_stack+0, 0.0, zero_stack, 1.0, int_stack+70492, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+73516,int_stack+35664,int_stack+34880, 1.0, int_stack+58112, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+0,int_stack+36672,int_stack+35664, 1.0, int_stack+58896, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+30576,int_stack+0,int_stack+73516, 1.0, int_stack+68140, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (k0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+0,int_stack+41244,int_stack+38940, 1.0, int_stack+37932, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+80572,int_stack+42540,int_stack+41244, 1.0, int_stack+39948, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+35280,int_stack+80572,int_stack+0, 1.0, int_stack+70492, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (i0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+0,int_stack+59904,int_stack+58896,28);
 /*--- compute (i0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+70492,int_stack+0,int_stack+68140,28);
 /*--- compute (i0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+68140,int_stack+44944,int_stack+44160,28);
 /*--- compute (i0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+0,int_stack+45952,int_stack+44944,28);
 /*--- compute (i0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+41328,int_stack+0,int_stack+68140,28);
 /*--- compute (k0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+0,int_stack+48220,int_stack+47212,36);
 /*--- compute (k0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+80572,int_stack+49516,int_stack+48220,36);
 /*--- compute (k0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+105964,int_stack+80572,int_stack+0,36);
 /*--- compute (i0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+68140,int_stack+51920,int_stack+51136,28);
 /*--- compute (i0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+0,int_stack+52928,int_stack+51920,28);
 /*--- compute (i0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+46032,int_stack+0,int_stack+68140,28);
 /*--- compute (k0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+0,int_stack+55196,int_stack+54188,36);
 /*--- compute (k0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+80572,int_stack+56492,int_stack+55196,36);
 /*--- compute (k0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+50736,int_stack+80572,int_stack+0,36);
 /*--- compute (i0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+68140,int_stack+61948,int_stack+61164,28);
 /*--- compute (i0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+0,int_stack+62956,int_stack+61948,28);
 /*--- compute (i0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+56784,int_stack+0,int_stack+68140,28);
 /*--- compute (k0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+0,int_stack+65224,int_stack+64216,36);
 /*--- compute (k0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+80572,int_stack+66520,int_stack+65224,36);
 /*--- compute (k0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+61488,int_stack+80572,int_stack+0,36);
 /*--- compute (ip|id) ---*/
   hrr1_build_ip(Libderiv->AB,int_stack+112012,int_stack+84460,int_stack+75868,168);
     Libderiv->ABCD[11] = int_stack + 112012;
 /*--- compute (ip|id) ---*/
   hrr1_build_ip(Libderiv->AB,int_stack+75196,int_stack+7728,int_stack+3024,168);
     Libderiv->ABCD[10] = int_stack + 75196;
 /*--- compute (ip|id) ---*/
   hrr1_build_ip(Libderiv->AB,int_stack+126124,int_stack+13776,int_stack+90508,168);
     Libderiv->ABCD[9] = int_stack + 126124;
 /*--- compute (ip|id) ---*/
   hrr1_build_ip(Libderiv->AB,int_stack+0,int_stack+19824,int_stack+95212,168);
     Libderiv->ABCD[8] = int_stack + 0;
 /*--- compute (ip|id) ---*/
   hrr1_build_ip(Libderiv->AB,int_stack+140236,int_stack+99916,int_stack+25872,168);
     Libderiv->ABCD[7] = int_stack + 140236;
 /*--- compute (ip|id) ---*/
   hrr1_build_ip(Libderiv->AB,int_stack+14112,int_stack+35280,int_stack+30576,168);
     Libderiv->ABCD[6] = int_stack + 14112;
 /*--- compute (ip|id) ---*/
   d1hrr1_build_ip(Libderiv->AB,int_stack+89308,int_stack+105964,int_stack+41328, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+70492, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,168);
     Libderiv->ABCD[2] = int_stack + 89308;
 /*--- compute (ip|id) ---*/
   d1hrr1_build_ip(Libderiv->AB,int_stack+28224,int_stack+50736,int_stack+46032, 0.0, zero_stack, 1.0, int_stack+70492, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,168);
     Libderiv->ABCD[1] = int_stack + 28224;
 /*--- compute (ip|id) ---*/
   d1hrr1_build_ip(Libderiv->AB,int_stack+42336,int_stack+61488,int_stack+56784, 1.0, int_stack+70492, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,168);
     Libderiv->ABCD[0] = int_stack + 42336;

}
