/*
 *  Copyright (C) 1996-2017 Edward F. Valeev and Justin T. Fermann
 *
 *  This file is part of Libint.
 *
 *  Libint is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU Lesser General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  Libint is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public License
 *  along with Libint.  If not, see <http://www.gnu.org/licenses/>.
 *
 */

#include <stdio.h>
#include <string.h>
#include <libint/libint.h>
#include "libr12.h"
#include <libint/hrr_header.h>

#include "r12_hrr_header.h"

extern void vrr_grt_order_fdhp(Libr12_t *, prim_data *);

  /* Computes (fd|hp) integrals for linear R12-methods */

void hrr_grt_order_fdhp(Libr12_t *Libr12, int num_prim_comb)
{
 prim_data *Data = Libr12->PrimQuartet;
 REALTYPE *int_stack = Libr12->int_stack;
 int i,j;
 REALTYPE tmp, *target;

 Libr12->t2vrr_classes[3][5] = int_stack + 0;
 Libr12->t2vrr_classes[3][6] = int_stack + 210;
 Libr12->t2vrr_classes[4][5] = int_stack + 490;
 Libr12->t2vrr_classes[4][6] = int_stack + 805;
 Libr12->gvrr_classes[6][5] = int_stack + 1225;
 Libr12->t2vrr_classes[5][5] = int_stack + 1813;
 Libr12->t2vrr_classes[5][6] = int_stack + 2254;
 Libr12->gvrr_classes[3][7] = int_stack + 2842;
 Libr12->t1vrr_classes[3][5] = int_stack + 3202;
 Libr12->t1vrr_classes[3][6] = int_stack + 3412;
 Libr12->gvrr_classes[4][7] = int_stack + 3692;
 Libr12->t1vrr_classes[4][5] = int_stack + 4232;
 Libr12->t1vrr_classes[4][6] = int_stack + 4547;
 Libr12->t1vrr_classes[5][5] = int_stack + 4967;
 Libr12->t1vrr_classes[5][6] = int_stack + 5408;
 Libr12->rvrr_classes[3][5] = int_stack + 5996;
 Libr12->rvrr_classes[3][6] = int_stack + 6206;
 Libr12->rvrr_classes[4][5] = int_stack + 6486;
 Libr12->rvrr_classes[4][6] = int_stack + 6801;
 Libr12->rvrr_classes[5][5] = int_stack + 7221;
 Libr12->rvrr_classes[5][6] = int_stack + 7662;
 Libr12->gvrr_classes[3][5] = int_stack + 8250;
 Libr12->gvrr_classes[3][6] = int_stack + 8460;
 Libr12->gvrr_classes[4][5] = int_stack + 8740;
 Libr12->gvrr_classes[4][6] = int_stack + 9055;
 Libr12->gvrr_classes[5][5] = int_stack + 9475;
 Libr12->gvrr_classes[5][6] = int_stack + 9916;
 memset(int_stack,0,10504*sizeof(REALTYPE));

 Libr12->r12vrr_stack = int_stack + 10504;
 for(i=0;i<num_prim_comb;i++) {
   vrr_grt_order_fdhp(Libr12, Data);
   Data++;
 }

 /*--- compute (f0|[r12,T2]|hp) ---*/
   t2hrr3_build_hp(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+10504, int_stack+210, int_stack+0, int_stack+8460, int_stack+8740, int_stack+8250, 3, 0);
 /*--- compute (g0|[r12,T2]|hp) ---*/
   t2hrr3_build_hp(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+11134, int_stack+805, int_stack+490, int_stack+9055, int_stack+9475, int_stack+8740, 4, 0);
 /*--- compute (fp|[r12,T2]|hp) ---*/
   hrr1_build_fp(Libr12->ShellQuartet.AB,int_stack+12079, int_stack+11134, int_stack+10504, 63);
 /*--- compute (h0|[r12,T2]|hp) ---*/
   t2hrr3_build_hp(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+13969, int_stack+2254, int_stack+1813, int_stack+9916, int_stack+1225, int_stack+9475, 5, 0);
 /*--- compute (gp|[r12,T2]|hp) ---*/
   hrr1_build_gp(Libr12->ShellQuartet.AB,int_stack+0, int_stack+13969, int_stack+11134, 63);
 /*--- compute (f0|hp) ---*/
   hrr3_build_hp(Libr12->ShellQuartet.CD,int_stack+13969, int_stack+8460, int_stack+8250, 10);
 /*--- compute (g0|hp) ---*/
   hrr3_build_hp(Libr12->ShellQuartet.CD,int_stack+14599, int_stack+9055, int_stack+8740, 15);
 /*--- compute (fp|hp) ---*/
   hrr1_build_fp(Libr12->ShellQuartet.AB,int_stack+15544, int_stack+14599, int_stack+13969, 63);
 /*--- compute (f0|ip) ---*/
   hrr3_build_ip(Libr12->ShellQuartet.CD,int_stack+10504, int_stack+2842, int_stack+8460, 10);
 /*--- compute (g0|ip) ---*/
   hrr3_build_ip(Libr12->ShellQuartet.CD,int_stack+17434, int_stack+3692, int_stack+9055, 15);
 /*--- compute (fp|ip) ---*/
   hrr1_build_fp(Libr12->ShellQuartet.AB,int_stack+18694, int_stack+17434, int_stack+10504, 84);
 /*--- compute (h0|hp) ---*/
   hrr3_build_hp(Libr12->ShellQuartet.CD,int_stack+21214, int_stack+9916, int_stack+9475, 21);
 /*--- compute (gp|hp) ---*/
   hrr1_build_gp(Libr12->ShellQuartet.AB,int_stack+22537, int_stack+21214, int_stack+14599, 63);
 /*--- compute (f0|[r12,T1]|hp) ---*/
   hrr3_build_hp(Libr12->ShellQuartet.CD,int_stack+8250, int_stack+3412, int_stack+3202, 10);
 /*--- compute (g0|[r12,T1]|hp) ---*/
   hrr3_build_hp(Libr12->ShellQuartet.CD,int_stack+8880, int_stack+4547, int_stack+4232, 15);
 /*--- compute (fp|[r12,T1]|hp) ---*/
   t1hrr1_build_fp(Libr12->ShellQuartet.AB,Libr12->ShellQuartet.AC,int_stack+2835, int_stack+8880, int_stack+8250, int_stack+14599, int_stack+10504, int_stack+13969, 5, 1);
 /*--- compute (h0|[r12,T1]|hp) ---*/
   hrr3_build_hp(Libr12->ShellQuartet.CD,int_stack+9825, int_stack+5408, int_stack+4967, 21);
 /*--- compute (gp|[r12,T1]|hp) ---*/
   t1hrr1_build_gp(Libr12->ShellQuartet.AB,Libr12->ShellQuartet.AC,int_stack+25372, int_stack+9825, int_stack+8880, int_stack+21214, int_stack+17434, int_stack+14599, 5, 1);
 /*--- compute (f0||hp) ---*/
   hrr3_build_hp(Libr12->ShellQuartet.CD,int_stack+17434, int_stack+6206, int_stack+5996, 10);
 /*--- compute (g0||hp) ---*/
   hrr3_build_hp(Libr12->ShellQuartet.CD,int_stack+21214, int_stack+6801, int_stack+6486, 15);
 /*--- compute (fp||hp) ---*/
   hrr1_build_fp(Libr12->ShellQuartet.AB,int_stack+8250, int_stack+21214, int_stack+17434, 63);
 /*--- compute (h0||hp) ---*/
   hrr3_build_hp(Libr12->ShellQuartet.CD,int_stack+13969, int_stack+7662, int_stack+7221, 21);
 /*--- compute (gp||hp) ---*/
   hrr1_build_gp(Libr12->ShellQuartet.AB,int_stack+4725, int_stack+13969, int_stack+21214, 63);
 /*--- compute (fd|[r12,T2]|hp) ---*/
   hrr1_build_fd(Libr12->ShellQuartet.AB,int_stack+28207, int_stack+0, int_stack+12079, 63);
     Libr12->te_ptr[3] = int_stack + 28207;
 /*--- compute (fd|[r12,T1]|hp) ---*/
   t1hrr1_build_fd(Libr12->ShellQuartet.AB,Libr12->ShellQuartet.AC,int_stack+10140, int_stack+25372, int_stack+2835, int_stack+22537, int_stack+18694, int_stack+15544, 5, 1);
     Libr12->te_ptr[2] = int_stack + 10140;
 /*--- compute (fd||hp) ---*/
   hrr1_build_fd(Libr12->ShellQuartet.AB,int_stack+0, int_stack+4725, int_stack+8250, 63);
     Libr12->te_ptr[1] = int_stack + 0;
 /*--- compute (fd|hp) ---*/
   hrr1_build_fd(Libr12->ShellQuartet.AB,int_stack+3780, int_stack+22537, int_stack+15544, 63);
     Libr12->te_ptr[0] = int_stack + 3780;

}
