/*
 *  Copyright (C) 1996-2017 Edward F. Valeev and Justin T. Fermann
 *
 *  This file is part of Libint.
 *
 *  Libint is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU Lesser General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  Libint is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public License
 *  along with Libint.  If not, see <http://www.gnu.org/licenses/>.
 *
 */

#include <stdio.h>
#include <string.h>
#include <libint/libint.h>
#include "libr12.h"
#include <libint/hrr_header.h>

#include "r12_hrr_header.h"

extern void vrr_grt_order_fpff(Libr12_t *, prim_data *);

  /* Computes (fp|ff) integrals for linear R12-methods */

void hrr_grt_order_fpff(Libr12_t *Libr12, int num_prim_comb)
{
 prim_data *Data = Libr12->PrimQuartet;
 REALTYPE *int_stack = Libr12->int_stack;
 int i,j;
 REALTYPE tmp, *target;

 Libr12->t2vrr_classes[3][3] = int_stack + 0;
 Libr12->t2vrr_classes[3][4] = int_stack + 100;
 Libr12->t2vrr_classes[3][5] = int_stack + 250;
 Libr12->t2vrr_classes[3][6] = int_stack + 460;
 Libr12->gvrr_classes[5][3] = int_stack + 740;
 Libr12->t2vrr_classes[4][3] = int_stack + 950;
 Libr12->gvrr_classes[5][4] = int_stack + 1100;
 Libr12->t2vrr_classes[4][4] = int_stack + 1415;
 Libr12->gvrr_classes[5][5] = int_stack + 1640;
 Libr12->t2vrr_classes[4][5] = int_stack + 2081;
 Libr12->t2vrr_classes[4][6] = int_stack + 2396;
 Libr12->gvrr_classes[3][7] = int_stack + 2816;
 Libr12->t1vrr_classes[3][3] = int_stack + 3176;
 Libr12->t1vrr_classes[3][4] = int_stack + 3276;
 Libr12->t1vrr_classes[3][5] = int_stack + 3426;
 Libr12->t1vrr_classes[3][6] = int_stack + 3636;
 Libr12->t1vrr_classes[4][3] = int_stack + 3916;
 Libr12->t1vrr_classes[4][4] = int_stack + 4066;
 Libr12->t1vrr_classes[4][5] = int_stack + 4291;
 Libr12->t1vrr_classes[4][6] = int_stack + 4606;
 Libr12->rvrr_classes[3][3] = int_stack + 5026;
 Libr12->rvrr_classes[3][4] = int_stack + 5126;
 Libr12->rvrr_classes[3][5] = int_stack + 5276;
 Libr12->rvrr_classes[3][6] = int_stack + 5486;
 Libr12->rvrr_classes[4][3] = int_stack + 5766;
 Libr12->rvrr_classes[4][4] = int_stack + 5916;
 Libr12->rvrr_classes[4][5] = int_stack + 6141;
 Libr12->rvrr_classes[4][6] = int_stack + 6456;
 Libr12->gvrr_classes[3][3] = int_stack + 6876;
 Libr12->gvrr_classes[3][4] = int_stack + 6976;
 Libr12->gvrr_classes[3][5] = int_stack + 7126;
 Libr12->gvrr_classes[3][6] = int_stack + 7336;
 Libr12->gvrr_classes[4][3] = int_stack + 7616;
 Libr12->gvrr_classes[4][4] = int_stack + 7766;
 Libr12->gvrr_classes[4][5] = int_stack + 7991;
 Libr12->gvrr_classes[4][6] = int_stack + 8306;
 memset(int_stack,0,8726*sizeof(REALTYPE));

 Libr12->r12vrr_stack = int_stack + 8726;
 for(i=0;i<num_prim_comb;i++) {
   vrr_grt_order_fpff(Libr12, Data);
   Data++;
 }

 /*--- compute (f0|fp) ---*/
   hrr3_build_fp(Libr12->ShellQuartet.CD,int_stack+8726, int_stack+6976, int_stack+6876, 10);
 /*--- compute (f0|gp) ---*/
   hrr3_build_gp(Libr12->ShellQuartet.CD,int_stack+9026, int_stack+7126, int_stack+6976, 10);
 /*--- compute (f0|fd) ---*/
   hrr3_build_fd(Libr12->ShellQuartet.CD,int_stack+9476, int_stack+9026, int_stack+8726, 10);
 /*--- compute (g0|fp) ---*/
   hrr3_build_fp(Libr12->ShellQuartet.CD,int_stack+10076, int_stack+7766, int_stack+7616, 15);
 /*--- compute (g0|gp) ---*/
   hrr3_build_gp(Libr12->ShellQuartet.CD,int_stack+10526, int_stack+7991, int_stack+7766, 15);
 /*--- compute (g0|fd) ---*/
   hrr3_build_fd(Libr12->ShellQuartet.CD,int_stack+11201, int_stack+10526, int_stack+10076, 15);
 /*--- compute (f0|hp) ---*/
   hrr3_build_hp(Libr12->ShellQuartet.CD,int_stack+12101, int_stack+7336, int_stack+7126, 10);
 /*--- compute (f0|gd) ---*/
   hrr3_build_gd(Libr12->ShellQuartet.CD,int_stack+12731, int_stack+12101, int_stack+9026, 10);
 /*--- compute (f0|[r12,T2]|fp) ---*/
   t2hrr3_build_fp(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+13631, int_stack+100, int_stack+0, int_stack+6976, int_stack+7616, int_stack+6876, 3, 0);
 /*--- compute (f0|[r12,T2]|gp) ---*/
   t2hrr3_build_gp(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+13931, int_stack+250, int_stack+100, int_stack+7126, int_stack+7766, int_stack+6976, 3, 0);
 /*--- compute (f0|[r12,T2]|fd) ---*/
   t2hrr3_build_fd(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+14381, int_stack+13931, int_stack+13631, int_stack+9026, int_stack+10076, int_stack+8726, 3, 0);
 /*--- compute (f0|[r12,T2]|hp) ---*/
   t2hrr3_build_hp(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+14981, int_stack+460, int_stack+250, int_stack+7336, int_stack+7991, int_stack+7126, 3, 0);
 /*--- compute (f0|[r12,T2]|gd) ---*/
   t2hrr3_build_gd(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+15611, int_stack+14981, int_stack+13931, int_stack+12101, int_stack+10526, int_stack+9026, 3, 0);
 /*--- compute (f0|[r12,T2]|ff) ---*/
   t2hrr3_build_ff(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+16511, int_stack+15611, int_stack+14381, int_stack+12731, int_stack+11201, int_stack+9476, 3, 0);
 /*--- compute (h0|fp) ---*/
   hrr3_build_fp(Libr12->ShellQuartet.CD,int_stack+8726, int_stack+1100, int_stack+740, 21);
 /*--- compute (h0|gp) ---*/
   hrr3_build_gp(Libr12->ShellQuartet.CD,int_stack+13631, int_stack+1640, int_stack+1100, 21);
 /*--- compute (h0|fd) ---*/
   hrr3_build_fd(Libr12->ShellQuartet.CD,int_stack+14576, int_stack+13631, int_stack+8726, 21);
 /*--- compute (g0|hp) ---*/
   hrr3_build_hp(Libr12->ShellQuartet.CD,int_stack+17511, int_stack+8306, int_stack+7991, 15);
 /*--- compute (g0|gd) ---*/
   hrr3_build_gd(Libr12->ShellQuartet.CD,int_stack+18456, int_stack+17511, int_stack+10526, 15);
 /*--- compute (g0|[r12,T2]|fp) ---*/
   t2hrr3_build_fp(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+15836, int_stack+1415, int_stack+950, int_stack+7766, int_stack+740, int_stack+7616, 4, 0);
 /*--- compute (g0|[r12,T2]|gp) ---*/
   t2hrr3_build_gp(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+0, int_stack+2081, int_stack+1415, int_stack+7991, int_stack+1100, int_stack+7766, 4, 0);
 /*--- compute (g0|[r12,T2]|fd) ---*/
   t2hrr3_build_fd(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+675, int_stack+0, int_stack+15836, int_stack+10526, int_stack+8726, int_stack+10076, 4, 0);
 /*--- compute (g0|[r12,T2]|hp) ---*/
   t2hrr3_build_hp(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+19806, int_stack+2396, int_stack+2081, int_stack+8306, int_stack+1640, int_stack+7991, 4, 0);
 /*--- compute (g0|[r12,T2]|gd) ---*/
   t2hrr3_build_gd(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+7616, int_stack+19806, int_stack+0, int_stack+17511, int_stack+13631, int_stack+10526, 4, 0);
 /*--- compute (g0|[r12,T2]|ff) ---*/
   t2hrr3_build_ff(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+19806, int_stack+7616, int_stack+675, int_stack+18456, int_stack+14576, int_stack+11201, 4, 0);
 /*--- compute (f0|ff) ---*/
   hrr3_build_ff(Libr12->ShellQuartet.CD,int_stack+7616, int_stack+12731, int_stack+9476, 10);
 /*--- compute (f0|ip) ---*/
   hrr3_build_ip(Libr12->ShellQuartet.CD,int_stack+8616, int_stack+2816, int_stack+7336, 10);
 /*--- compute (f0|hd) ---*/
   hrr3_build_hd(Libr12->ShellQuartet.CD,int_stack+9456, int_stack+8616, int_stack+12101, 10);
 /*--- compute (f0|gf) ---*/
   hrr3_build_gf(Libr12->ShellQuartet.CD,int_stack+13631, int_stack+9456, int_stack+12731, 10);
 /*--- compute (g0|ff) ---*/
   hrr3_build_ff(Libr12->ShellQuartet.CD,int_stack+12101, int_stack+18456, int_stack+11201, 15);
 /*--- compute (f0|[r12,T1]|fp) ---*/
   hrr3_build_fp(Libr12->ShellQuartet.CD,int_stack+8616, int_stack+3276, int_stack+3176, 10);
 /*--- compute (f0|[r12,T1]|gp) ---*/
   hrr3_build_gp(Libr12->ShellQuartet.CD,int_stack+8916, int_stack+3426, int_stack+3276, 10);
 /*--- compute (f0|[r12,T1]|fd) ---*/
   hrr3_build_fd(Libr12->ShellQuartet.CD,int_stack+9366, int_stack+8916, int_stack+8616, 10);
 /*--- compute (f0|[r12,T1]|hp) ---*/
   hrr3_build_hp(Libr12->ShellQuartet.CD,int_stack+9966, int_stack+3636, int_stack+3426, 10);
 /*--- compute (f0|[r12,T1]|gd) ---*/
   hrr3_build_gd(Libr12->ShellQuartet.CD,int_stack+10596, int_stack+9966, int_stack+8916, 10);
 /*--- compute (f0|[r12,T1]|ff) ---*/
   hrr3_build_ff(Libr12->ShellQuartet.CD,int_stack+15131, int_stack+10596, int_stack+9366, 10);
 /*--- compute (g0|[r12,T1]|fp) ---*/
   hrr3_build_fp(Libr12->ShellQuartet.CD,int_stack+8616, int_stack+4066, int_stack+3916, 15);
 /*--- compute (g0|[r12,T1]|gp) ---*/
   hrr3_build_gp(Libr12->ShellQuartet.CD,int_stack+9066, int_stack+4291, int_stack+4066, 15);
 /*--- compute (g0|[r12,T1]|fd) ---*/
   hrr3_build_fd(Libr12->ShellQuartet.CD,int_stack+9741, int_stack+9066, int_stack+8616, 15);
 /*--- compute (g0|[r12,T1]|hp) ---*/
   hrr3_build_hp(Libr12->ShellQuartet.CD,int_stack+10641, int_stack+4606, int_stack+4291, 15);
 /*--- compute (g0|[r12,T1]|gd) ---*/
   hrr3_build_gd(Libr12->ShellQuartet.CD,int_stack+17511, int_stack+10641, int_stack+9066, 15);
 /*--- compute (g0|[r12,T1]|ff) ---*/
   hrr3_build_ff(Libr12->ShellQuartet.CD,int_stack+0, int_stack+17511, int_stack+9741, 15);
 /*--- compute (f0||fp) ---*/
   hrr3_build_fp(Libr12->ShellQuartet.CD,int_stack+17511, int_stack+5126, int_stack+5026, 10);
 /*--- compute (f0||gp) ---*/
   hrr3_build_gp(Libr12->ShellQuartet.CD,int_stack+17811, int_stack+5276, int_stack+5126, 10);
 /*--- compute (f0||fd) ---*/
   hrr3_build_fd(Libr12->ShellQuartet.CD,int_stack+18261, int_stack+17811, int_stack+17511, 10);
 /*--- compute (f0||hp) ---*/
   hrr3_build_hp(Libr12->ShellQuartet.CD,int_stack+18861, int_stack+5486, int_stack+5276, 10);
 /*--- compute (f0||gd) ---*/
   hrr3_build_gd(Libr12->ShellQuartet.CD,int_stack+8616, int_stack+18861, int_stack+17811, 10);
 /*--- compute (f0||ff) ---*/
   hrr3_build_ff(Libr12->ShellQuartet.CD,int_stack+9516, int_stack+8616, int_stack+18261, 10);
 /*--- compute (g0||fp) ---*/
   hrr3_build_fp(Libr12->ShellQuartet.CD,int_stack+8616, int_stack+5916, int_stack+5766, 15);
 /*--- compute (g0||gp) ---*/
   hrr3_build_gp(Libr12->ShellQuartet.CD,int_stack+17511, int_stack+6141, int_stack+5916, 15);
 /*--- compute (g0||fd) ---*/
   hrr3_build_fd(Libr12->ShellQuartet.CD,int_stack+18186, int_stack+17511, int_stack+8616, 15);
 /*--- compute (g0||hp) ---*/
   hrr3_build_hp(Libr12->ShellQuartet.CD,int_stack+10516, int_stack+6456, int_stack+6141, 15);
 /*--- compute (g0||gd) ---*/
   hrr3_build_gd(Libr12->ShellQuartet.CD,int_stack+1500, int_stack+10516, int_stack+17511, 15);
 /*--- compute (g0||ff) ---*/
   hrr3_build_ff(Libr12->ShellQuartet.CD,int_stack+10516, int_stack+1500, int_stack+18186, 15);
 /*--- compute (fp|[r12,T2]|ff) ---*/
   hrr1_build_fp(Libr12->ShellQuartet.AB,int_stack+1500, int_stack+19806, int_stack+16511, 100);
     Libr12->te_ptr[3] = int_stack + 1500;
 /*--- compute (fp|[r12,T1]|ff) ---*/
   t1hrr1_build_fp(Libr12->ShellQuartet.AB,Libr12->ShellQuartet.AC,int_stack+4500, int_stack+0, int_stack+15131, int_stack+12101, int_stack+13631, int_stack+7616, 3, 3);
     Libr12->te_ptr[2] = int_stack + 4500;
 /*--- compute (fp||ff) ---*/
   hrr1_build_fp(Libr12->ShellQuartet.AB,int_stack+13601, int_stack+10516, int_stack+9516, 100);
     Libr12->te_ptr[1] = int_stack + 13601;
 /*--- compute (fp|ff) ---*/
   hrr1_build_fp(Libr12->ShellQuartet.AB,int_stack+8616, int_stack+12101, int_stack+7616, 100);
     Libr12->te_ptr[0] = int_stack + 8616;

}
