/*
 *  Copyright (C) 1996-2017 Edward F. Valeev and Justin T. Fermann
 *
 *  This file is part of Libint.
 *
 *  Libint is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU Lesser General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  Libint is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public License
 *  along with Libint.  If not, see <http://www.gnu.org/licenses/>.
 *
 */

#include <stdio.h>
#include <string.h>
#include <libint/libint.h>
#include "libr12.h"
#include <libint/hrr_header.h>

#include "r12_hrr_header.h"

extern void vrr_grt_order_fphf(Libr12_t *, prim_data *);

  /* Computes (fp|hf) integrals for linear R12-methods */

void hrr_grt_order_fphf(Libr12_t *Libr12, int num_prim_comb)
{
 prim_data *Data = Libr12->PrimQuartet;
 REALTYPE *int_stack = Libr12->int_stack;
 int i,j;
 REALTYPE tmp, *target;

 Libr12->t2vrr_classes[3][5] = int_stack + 0;
 Libr12->t2vrr_classes[3][6] = int_stack + 210;
 Libr12->t2vrr_classes[3][7] = int_stack + 490;
 Libr12->t2vrr_classes[3][8] = int_stack + 850;
 Libr12->gvrr_classes[5][5] = int_stack + 1300;
 Libr12->t2vrr_classes[4][5] = int_stack + 1741;
 Libr12->gvrr_classes[5][6] = int_stack + 2056;
 Libr12->t2vrr_classes[4][6] = int_stack + 2644;
 Libr12->gvrr_classes[5][7] = int_stack + 3064;
 Libr12->t2vrr_classes[4][7] = int_stack + 3820;
 Libr12->t2vrr_classes[4][8] = int_stack + 4360;
 Libr12->gvrr_classes[3][9] = int_stack + 5035;
 Libr12->t1vrr_classes[3][5] = int_stack + 5585;
 Libr12->t1vrr_classes[3][6] = int_stack + 5795;
 Libr12->t1vrr_classes[3][7] = int_stack + 6075;
 Libr12->t1vrr_classes[3][8] = int_stack + 6435;
 Libr12->t1vrr_classes[4][5] = int_stack + 6885;
 Libr12->t1vrr_classes[4][6] = int_stack + 7200;
 Libr12->t1vrr_classes[4][7] = int_stack + 7620;
 Libr12->t1vrr_classes[4][8] = int_stack + 8160;
 Libr12->rvrr_classes[3][5] = int_stack + 8835;
 Libr12->rvrr_classes[3][6] = int_stack + 9045;
 Libr12->rvrr_classes[3][7] = int_stack + 9325;
 Libr12->rvrr_classes[3][8] = int_stack + 9685;
 Libr12->rvrr_classes[4][5] = int_stack + 10135;
 Libr12->rvrr_classes[4][6] = int_stack + 10450;
 Libr12->rvrr_classes[4][7] = int_stack + 10870;
 Libr12->rvrr_classes[4][8] = int_stack + 11410;
 Libr12->gvrr_classes[3][5] = int_stack + 12085;
 Libr12->gvrr_classes[3][6] = int_stack + 12295;
 Libr12->gvrr_classes[3][7] = int_stack + 12575;
 Libr12->gvrr_classes[3][8] = int_stack + 12935;
 Libr12->gvrr_classes[4][5] = int_stack + 13385;
 Libr12->gvrr_classes[4][6] = int_stack + 13700;
 Libr12->gvrr_classes[4][7] = int_stack + 14120;
 Libr12->gvrr_classes[4][8] = int_stack + 14660;
 memset(int_stack,0,15335*sizeof(REALTYPE));

 Libr12->r12vrr_stack = int_stack + 15335;
 for(i=0;i<num_prim_comb;i++) {
   vrr_grt_order_fphf(Libr12, Data);
   Data++;
 }

 /*--- compute (f0|hp) ---*/
   hrr3_build_hp(Libr12->ShellQuartet.CD,int_stack+15335, int_stack+12295, int_stack+12085, 10);
 /*--- compute (f0|ip) ---*/
   hrr3_build_ip(Libr12->ShellQuartet.CD,int_stack+15965, int_stack+12575, int_stack+12295, 10);
 /*--- compute (f0|hd) ---*/
   hrr3_build_hd(Libr12->ShellQuartet.CD,int_stack+16805, int_stack+15965, int_stack+15335, 10);
 /*--- compute (g0|hp) ---*/
   hrr3_build_hp(Libr12->ShellQuartet.CD,int_stack+18065, int_stack+13700, int_stack+13385, 15);
 /*--- compute (g0|ip) ---*/
   hrr3_build_ip(Libr12->ShellQuartet.CD,int_stack+19010, int_stack+14120, int_stack+13700, 15);
 /*--- compute (g0|hd) ---*/
   hrr3_build_hd(Libr12->ShellQuartet.CD,int_stack+20270, int_stack+19010, int_stack+18065, 15);
 /*--- compute (f0|kp) ---*/
   hrr3_build_kp(Libr12->ShellQuartet.CD,int_stack+22160, int_stack+12935, int_stack+12575, 10);
 /*--- compute (f0|id) ---*/
   hrr3_build_id(Libr12->ShellQuartet.CD,int_stack+23240, int_stack+22160, int_stack+15965, 10);
 /*--- compute (f0|[r12,T2]|hp) ---*/
   t2hrr3_build_hp(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+24920, int_stack+210, int_stack+0, int_stack+12295, int_stack+13385, int_stack+12085, 3, 0);
 /*--- compute (f0|[r12,T2]|ip) ---*/
   t2hrr3_build_ip(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+25550, int_stack+490, int_stack+210, int_stack+12575, int_stack+13700, int_stack+12295, 3, 0);
 /*--- compute (f0|[r12,T2]|hd) ---*/
   t2hrr3_build_hd(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+26390, int_stack+25550, int_stack+24920, int_stack+15965, int_stack+18065, int_stack+15335, 3, 0);
 /*--- compute (f0|[r12,T2]|kp) ---*/
   t2hrr3_build_kp(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+27650, int_stack+850, int_stack+490, int_stack+12935, int_stack+14120, int_stack+12575, 3, 0);
 /*--- compute (f0|[r12,T2]|id) ---*/
   t2hrr3_build_id(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+28730, int_stack+27650, int_stack+25550, int_stack+22160, int_stack+19010, int_stack+15965, 3, 0);
 /*--- compute (f0|[r12,T2]|hf) ---*/
   t2hrr3_build_hf(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+30410, int_stack+28730, int_stack+26390, int_stack+23240, int_stack+20270, int_stack+16805, 3, 0);
 /*--- compute (h0|hp) ---*/
   hrr3_build_hp(Libr12->ShellQuartet.CD,int_stack+15335, int_stack+2056, int_stack+1300, 21);
 /*--- compute (h0|ip) ---*/
   hrr3_build_ip(Libr12->ShellQuartet.CD,int_stack+24920, int_stack+3064, int_stack+2056, 21);
 /*--- compute (h0|hd) ---*/
   hrr3_build_hd(Libr12->ShellQuartet.CD,int_stack+26684, int_stack+24920, int_stack+15335, 21);
 /*--- compute (g0|kp) ---*/
   hrr3_build_kp(Libr12->ShellQuartet.CD,int_stack+32510, int_stack+14660, int_stack+14120, 15);
 /*--- compute (g0|id) ---*/
   hrr3_build_id(Libr12->ShellQuartet.CD,int_stack+34130, int_stack+32510, int_stack+19010, 15);
 /*--- compute (g0|[r12,T2]|hp) ---*/
   t2hrr3_build_hp(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+29330, int_stack+2644, int_stack+1741, int_stack+13700, int_stack+1300, int_stack+13385, 4, 0);
 /*--- compute (g0|[r12,T2]|ip) ---*/
   t2hrr3_build_ip(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+0, int_stack+3820, int_stack+2644, int_stack+14120, int_stack+2056, int_stack+13700, 4, 0);
 /*--- compute (g0|[r12,T2]|hd) ---*/
   t2hrr3_build_hd(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+36650, int_stack+0, int_stack+29330, int_stack+19010, int_stack+15335, int_stack+18065, 4, 0);
 /*--- compute (g0|[r12,T2]|kp) ---*/
   t2hrr3_build_kp(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+1260, int_stack+4360, int_stack+3820, int_stack+14660, int_stack+3064, int_stack+14120, 4, 0);
 /*--- compute (g0|[r12,T2]|id) ---*/
   t2hrr3_build_id(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+13385, int_stack+1260, int_stack+0, int_stack+32510, int_stack+24920, int_stack+19010, 4, 0);
 /*--- compute (g0|[r12,T2]|hf) ---*/
   t2hrr3_build_hf(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+0, int_stack+13385, int_stack+36650, int_stack+34130, int_stack+26684, int_stack+20270, 4, 0);
 /*--- compute (f0|hf) ---*/
   hrr3_build_hf(Libr12->ShellQuartet.CD,int_stack+36650, int_stack+23240, int_stack+16805, 10);
 /*--- compute (f0|lp) ---*/
   hrr3_build_lp(Libr12->ShellQuartet.CD,int_stack+13385, int_stack+5035, int_stack+12935, 10);
 /*--- compute (f0|kd) ---*/
   hrr3_build_kd(Libr12->ShellQuartet.CD,int_stack+14735, int_stack+13385, int_stack+22160, 10);
 /*--- compute (f0|if) ---*/
   hrr3_build_if(Libr12->ShellQuartet.CD,int_stack+16895, int_stack+14735, int_stack+23240, 10);
 /*--- compute (g0|hf) ---*/
   hrr3_build_hf(Libr12->ShellQuartet.CD,int_stack+22160, int_stack+34130, int_stack+20270, 15);
 /*--- compute (f0|[r12,T1]|hp) ---*/
   hrr3_build_hp(Libr12->ShellQuartet.CD,int_stack+25310, int_stack+5795, int_stack+5585, 10);
 /*--- compute (f0|[r12,T1]|ip) ---*/
   hrr3_build_ip(Libr12->ShellQuartet.CD,int_stack+25940, int_stack+6075, int_stack+5795, 10);
 /*--- compute (f0|[r12,T1]|hd) ---*/
   hrr3_build_hd(Libr12->ShellQuartet.CD,int_stack+26780, int_stack+25940, int_stack+25310, 10);
 /*--- compute (f0|[r12,T1]|kp) ---*/
   hrr3_build_kp(Libr12->ShellQuartet.CD,int_stack+28040, int_stack+6435, int_stack+6075, 10);
 /*--- compute (f0|[r12,T1]|id) ---*/
   hrr3_build_id(Libr12->ShellQuartet.CD,int_stack+19695, int_stack+28040, int_stack+25940, 10);
 /*--- compute (f0|[r12,T1]|hf) ---*/
   hrr3_build_hf(Libr12->ShellQuartet.CD,int_stack+28040, int_stack+19695, int_stack+26780, 10);
 /*--- compute (g0|[r12,T1]|hp) ---*/
   hrr3_build_hp(Libr12->ShellQuartet.CD,int_stack+19695, int_stack+7200, int_stack+6885, 15);
 /*--- compute (g0|[r12,T1]|ip) ---*/
   hrr3_build_ip(Libr12->ShellQuartet.CD,int_stack+20640, int_stack+7620, int_stack+7200, 15);
 /*--- compute (g0|[r12,T1]|hd) ---*/
   hrr3_build_hd(Libr12->ShellQuartet.CD,int_stack+25310, int_stack+20640, int_stack+19695, 15);
 /*--- compute (g0|[r12,T1]|kp) ---*/
   hrr3_build_kp(Libr12->ShellQuartet.CD,int_stack+32510, int_stack+8160, int_stack+7620, 15);
 /*--- compute (g0|[r12,T1]|id) ---*/
   hrr3_build_id(Libr12->ShellQuartet.CD,int_stack+34130, int_stack+32510, int_stack+20640, 15);
 /*--- compute (g0|[r12,T1]|hf) ---*/
   hrr3_build_hf(Libr12->ShellQuartet.CD,int_stack+3150, int_stack+34130, int_stack+25310, 15);
 /*--- compute (f0||hp) ---*/
   hrr3_build_hp(Libr12->ShellQuartet.CD,int_stack+25310, int_stack+9045, int_stack+8835, 10);
 /*--- compute (f0||ip) ---*/
   hrr3_build_ip(Libr12->ShellQuartet.CD,int_stack+25940, int_stack+9325, int_stack+9045, 10);
 /*--- compute (f0||hd) ---*/
   hrr3_build_hd(Libr12->ShellQuartet.CD,int_stack+26780, int_stack+25940, int_stack+25310, 10);
 /*--- compute (f0||kp) ---*/
   hrr3_build_kp(Libr12->ShellQuartet.CD,int_stack+32510, int_stack+9685, int_stack+9325, 10);
 /*--- compute (f0||id) ---*/
   hrr3_build_id(Libr12->ShellQuartet.CD,int_stack+33590, int_stack+32510, int_stack+25940, 10);
 /*--- compute (f0||hf) ---*/
   hrr3_build_hf(Libr12->ShellQuartet.CD,int_stack+19695, int_stack+33590, int_stack+26780, 10);
 /*--- compute (g0||hp) ---*/
   hrr3_build_hp(Libr12->ShellQuartet.CD,int_stack+32510, int_stack+10450, int_stack+10135, 15);
 /*--- compute (g0||ip) ---*/
   hrr3_build_ip(Libr12->ShellQuartet.CD,int_stack+33455, int_stack+10870, int_stack+10450, 15);
 /*--- compute (g0||hd) ---*/
   hrr3_build_hd(Libr12->ShellQuartet.CD,int_stack+34715, int_stack+33455, int_stack+32510, 15);
 /*--- compute (g0||kp) ---*/
   hrr3_build_kp(Libr12->ShellQuartet.CD,int_stack+25310, int_stack+11410, int_stack+10870, 15);
 /*--- compute (g0||id) ---*/
   hrr3_build_id(Libr12->ShellQuartet.CD,int_stack+6300, int_stack+25310, int_stack+33455, 15);
 /*--- compute (g0||hf) ---*/
   hrr3_build_hf(Libr12->ShellQuartet.CD,int_stack+8820, int_stack+6300, int_stack+34715, 15);
 /*--- compute (fp|[r12,T2]|hf) ---*/
   hrr1_build_fp(Libr12->ShellQuartet.AB,int_stack+38750, int_stack+0, int_stack+30410, 210);
     Libr12->te_ptr[3] = int_stack + 38750;
 /*--- compute (fp|[r12,T1]|hf) ---*/
   t1hrr1_build_fp(Libr12->ShellQuartet.AB,Libr12->ShellQuartet.AC,int_stack+30140, int_stack+3150, int_stack+28040, int_stack+22160, int_stack+16895, int_stack+36650, 5, 3);
     Libr12->te_ptr[2] = int_stack + 30140;
 /*--- compute (fp||hf) ---*/
   hrr1_build_fp(Libr12->ShellQuartet.AB,int_stack+0, int_stack+8820, int_stack+19695, 210);
     Libr12->te_ptr[1] = int_stack + 0;
 /*--- compute (fp|hf) ---*/
   hrr1_build_fp(Libr12->ShellQuartet.AB,int_stack+6300, int_stack+22160, int_stack+36650, 210);
     Libr12->te_ptr[0] = int_stack + 6300;

}
