/*
 *  Copyright (C) 1996-2017 Edward F. Valeev and Justin T. Fermann
 *
 *  This file is part of Libint.
 *
 *  Libint is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU Lesser General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  Libint is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public License
 *  along with Libint.  If not, see <http://www.gnu.org/licenses/>.
 *
 */

#include <stdio.h>
#include <string.h>
#include <libint/libint.h>
#include "libr12.h"
#include <libint/hrr_header.h>

#include "r12_hrr_header.h"

extern void vrr_grt_order_g0hg(Libr12_t *, prim_data *);

  /* Computes (g0|hg) integrals for linear R12-methods */

void hrr_grt_order_g0hg(Libr12_t *Libr12, int num_prim_comb)
{
 prim_data *Data = Libr12->PrimQuartet;
 REALTYPE *int_stack = Libr12->int_stack;
 int i,j;
 REALTYPE tmp, *target;

 Libr12->gvrr_classes[5][5] = int_stack + 0;
 Libr12->t2vrr_classes[4][5] = int_stack + 441;
 Libr12->gvrr_classes[5][6] = int_stack + 756;
 Libr12->t2vrr_classes[4][6] = int_stack + 1344;
 Libr12->gvrr_classes[5][7] = int_stack + 1764;
 Libr12->t2vrr_classes[4][7] = int_stack + 2520;
 Libr12->gvrr_classes[5][8] = int_stack + 3060;
 Libr12->t2vrr_classes[4][8] = int_stack + 4005;
 Libr12->t2vrr_classes[4][9] = int_stack + 4680;
 Libr12->t1vrr_classes[4][5] = int_stack + 5505;
 Libr12->t1vrr_classes[4][6] = int_stack + 5820;
 Libr12->t1vrr_classes[4][7] = int_stack + 6240;
 Libr12->t1vrr_classes[4][8] = int_stack + 6780;
 Libr12->t1vrr_classes[4][9] = int_stack + 7455;
 Libr12->rvrr_classes[4][5] = int_stack + 8280;
 Libr12->rvrr_classes[4][6] = int_stack + 8595;
 Libr12->rvrr_classes[4][7] = int_stack + 9015;
 Libr12->rvrr_classes[4][8] = int_stack + 9555;
 Libr12->rvrr_classes[4][9] = int_stack + 10230;
 Libr12->gvrr_classes[4][5] = int_stack + 11055;
 Libr12->gvrr_classes[4][6] = int_stack + 11370;
 Libr12->gvrr_classes[4][7] = int_stack + 11790;
 Libr12->gvrr_classes[4][8] = int_stack + 12330;
 Libr12->gvrr_classes[4][9] = int_stack + 13005;
 memset(int_stack,0,13830*sizeof(REALTYPE));

 Libr12->r12vrr_stack = int_stack + 13830;
 for(i=0;i<num_prim_comb;i++) {
   vrr_grt_order_g0hg(Libr12, Data);
   Data++;
 }

 /*--- compute (g0|hp) ---*/
   hrr3_build_hp(Libr12->ShellQuartet.CD,int_stack+13830, int_stack+11370, int_stack+11055, 15);
 /*--- compute (g0|ip) ---*/
   hrr3_build_ip(Libr12->ShellQuartet.CD,int_stack+14775, int_stack+11790, int_stack+11370, 15);
 /*--- compute (g0|hd) ---*/
   hrr3_build_hd(Libr12->ShellQuartet.CD,int_stack+16035, int_stack+14775, int_stack+13830, 15);
 /*--- compute (g0|kp) ---*/
   hrr3_build_kp(Libr12->ShellQuartet.CD,int_stack+17925, int_stack+12330, int_stack+11790, 15);
 /*--- compute (g0|id) ---*/
   hrr3_build_id(Libr12->ShellQuartet.CD,int_stack+19545, int_stack+17925, int_stack+14775, 15);
 /*--- compute (g0|hf) ---*/
   hrr3_build_hf(Libr12->ShellQuartet.CD,int_stack+22065, int_stack+19545, int_stack+16035, 15);
 /*--- compute (h0|hp) ---*/
   hrr3_build_hp(Libr12->ShellQuartet.CD,int_stack+25215, int_stack+756, int_stack+0, 21);
 /*--- compute (h0|ip) ---*/
   hrr3_build_ip(Libr12->ShellQuartet.CD,int_stack+26538, int_stack+1764, int_stack+756, 21);
 /*--- compute (h0|hd) ---*/
   hrr3_build_hd(Libr12->ShellQuartet.CD,int_stack+28302, int_stack+26538, int_stack+25215, 21);
 /*--- compute (h0|kp) ---*/
   hrr3_build_kp(Libr12->ShellQuartet.CD,int_stack+30948, int_stack+3060, int_stack+1764, 21);
 /*--- compute (h0|id) ---*/
   hrr3_build_id(Libr12->ShellQuartet.CD,int_stack+33216, int_stack+30948, int_stack+26538, 21);
 /*--- compute (h0|hf) ---*/
   hrr3_build_hf(Libr12->ShellQuartet.CD,int_stack+36744, int_stack+33216, int_stack+28302, 21);
 /*--- compute (g0|lp) ---*/
   hrr3_build_lp(Libr12->ShellQuartet.CD,int_stack+41154, int_stack+13005, int_stack+12330, 15);
 /*--- compute (g0|kd) ---*/
   hrr3_build_kd(Libr12->ShellQuartet.CD,int_stack+43179, int_stack+41154, int_stack+17925, 15);
 /*--- compute (g0|if) ---*/
   hrr3_build_if(Libr12->ShellQuartet.CD,int_stack+46419, int_stack+43179, int_stack+19545, 15);
 /*--- compute (g0|[r12,T2]|hp) ---*/
   t2hrr3_build_hp(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+50619, int_stack+1344, int_stack+441, int_stack+11370, int_stack+0, int_stack+11055, 4, 0);
 /*--- compute (g0|[r12,T2]|ip) ---*/
   t2hrr3_build_ip(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+51564, int_stack+2520, int_stack+1344, int_stack+11790, int_stack+756, int_stack+11370, 4, 0);
 /*--- compute (g0|[r12,T2]|hd) ---*/
   t2hrr3_build_hd(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+52824, int_stack+51564, int_stack+50619, int_stack+14775, int_stack+25215, int_stack+13830, 4, 0);
 /*--- compute (g0|[r12,T2]|kp) ---*/
   t2hrr3_build_kp(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+0, int_stack+4005, int_stack+2520, int_stack+12330, int_stack+1764, int_stack+11790, 4, 0);
 /*--- compute (g0|[r12,T2]|id) ---*/
   t2hrr3_build_id(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+54714, int_stack+0, int_stack+51564, int_stack+17925, int_stack+26538, int_stack+14775, 4, 0);
 /*--- compute (g0|[r12,T2]|hf) ---*/
   t2hrr3_build_hf(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+57234, int_stack+54714, int_stack+52824, int_stack+19545, int_stack+28302, int_stack+16035, 4, 0);
 /*--- compute (g0|[r12,T2]|lp) ---*/
   t2hrr3_build_lp(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+13830, int_stack+4680, int_stack+4005, int_stack+13005, int_stack+3060, int_stack+12330, 4, 0);
 /*--- compute (g0|[r12,T2]|kd) ---*/
   t2hrr3_build_kd(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+25215, int_stack+13830, int_stack+0, int_stack+41154, int_stack+30948, int_stack+17925, 4, 0);
 /*--- compute (g0|[r12,T2]|if) ---*/
   t2hrr3_build_if(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+0, int_stack+25215, int_stack+54714, int_stack+43179, int_stack+33216, int_stack+19545, 4, 0);
 /*--- compute (g0|[r12,T1]|hp) ---*/
   hrr3_build_hp(Libr12->ShellQuartet.CD,int_stack+25215, int_stack+5820, int_stack+5505, 15);
 /*--- compute (g0|[r12,T1]|ip) ---*/
   hrr3_build_ip(Libr12->ShellQuartet.CD,int_stack+26160, int_stack+6240, int_stack+5820, 15);
 /*--- compute (g0|[r12,T1]|hd) ---*/
   hrr3_build_hd(Libr12->ShellQuartet.CD,int_stack+27420, int_stack+26160, int_stack+25215, 15);
 /*--- compute (g0|[r12,T1]|kp) ---*/
   hrr3_build_kp(Libr12->ShellQuartet.CD,int_stack+29310, int_stack+6780, int_stack+6240, 15);
 /*--- compute (g0|[r12,T1]|id) ---*/
   hrr3_build_id(Libr12->ShellQuartet.CD,int_stack+30930, int_stack+29310, int_stack+26160, 15);
 /*--- compute (g0|[r12,T1]|hf) ---*/
   hrr3_build_hf(Libr12->ShellQuartet.CD,int_stack+33450, int_stack+30930, int_stack+27420, 15);
 /*--- compute (g0|[r12,T1]|lp) ---*/
   hrr3_build_lp(Libr12->ShellQuartet.CD,int_stack+25215, int_stack+7455, int_stack+6780, 15);
 /*--- compute (g0|[r12,T1]|kd) ---*/
   hrr3_build_kd(Libr12->ShellQuartet.CD,int_stack+41154, int_stack+25215, int_stack+29310, 15);
 /*--- compute (g0|[r12,T1]|if) ---*/
   hrr3_build_if(Libr12->ShellQuartet.CD,int_stack+25215, int_stack+41154, int_stack+30930, 15);
 /*--- compute (g0||hp) ---*/
   hrr3_build_hp(Libr12->ShellQuartet.CD,int_stack+41154, int_stack+8595, int_stack+8280, 15);
 /*--- compute (g0||ip) ---*/
   hrr3_build_ip(Libr12->ShellQuartet.CD,int_stack+42099, int_stack+9015, int_stack+8595, 15);
 /*--- compute (g0||hd) ---*/
   hrr3_build_hd(Libr12->ShellQuartet.CD,int_stack+43359, int_stack+42099, int_stack+41154, 15);
 /*--- compute (g0||kp) ---*/
   hrr3_build_kp(Libr12->ShellQuartet.CD,int_stack+29415, int_stack+9555, int_stack+9015, 15);
 /*--- compute (g0||id) ---*/
   hrr3_build_id(Libr12->ShellQuartet.CD,int_stack+4200, int_stack+29415, int_stack+42099, 15);
 /*--- compute (g0||hf) ---*/
   hrr3_build_hf(Libr12->ShellQuartet.CD,int_stack+50619, int_stack+4200, int_stack+43359, 15);
 /*--- compute (g0||lp) ---*/
   hrr3_build_lp(Libr12->ShellQuartet.CD,int_stack+41154, int_stack+10230, int_stack+9555, 15);
 /*--- compute (g0||kd) ---*/
   hrr3_build_kd(Libr12->ShellQuartet.CD,int_stack+43179, int_stack+41154, int_stack+29415, 15);
 /*--- compute (g0||if) ---*/
   hrr3_build_if(Libr12->ShellQuartet.CD,int_stack+6720, int_stack+43179, int_stack+4200, 15);
 /*--- compute (g0|[r12,T2]|hg) ---*/
   t2hrr3_build_hg(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+41154, int_stack+0, int_stack+57234, int_stack+46419, int_stack+36744, int_stack+22065, 4, 0);
     Libr12->te_ptr[3] = int_stack + 41154;
 /*--- compute (g0|[r12,T1]|hg) ---*/
   hrr3_build_hg(Libr12->ShellQuartet.CD,int_stack+0, int_stack+25215, int_stack+33450, 15);
     Libr12->te_ptr[2] = int_stack + 0;
 /*--- compute (g0||hg) ---*/
   hrr3_build_hg(Libr12->ShellQuartet.CD,int_stack+25215, int_stack+6720, int_stack+50619, 15);
     Libr12->te_ptr[1] = int_stack + 25215;
 /*--- compute (g0|hg) ---*/
   hrr3_build_hg(Libr12->ShellQuartet.CD,int_stack+50619, int_stack+46419, int_stack+22065, 15);
     Libr12->te_ptr[0] = int_stack + 50619;

}
