/*
 *  Copyright (C) 1996-2017 Edward F. Valeev and Justin T. Fermann
 *
 *  This file is part of Libint.
 *
 *  Libint is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU Lesser General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  Libint is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public License
 *  along with Libint.  If not, see <http://www.gnu.org/licenses/>.
 *
 */

#include <stdio.h>
#include <string.h>
#include <libint/libint.h>
#include "libr12.h"
#include <libint/hrr_header.h>

#include "r12_hrr_header.h"

extern void vrr_grt_order_gdff(Libr12_t *, prim_data *);

  /* Computes (gd|ff) integrals for linear R12-methods */

void hrr_grt_order_gdff(Libr12_t *Libr12, int num_prim_comb)
{
 prim_data *Data = Libr12->PrimQuartet;
 REALTYPE *int_stack = Libr12->int_stack;
 int i,j;
 REALTYPE tmp, *target;

 Libr12->t2vrr_classes[4][3] = int_stack + 0;
 Libr12->t2vrr_classes[4][4] = int_stack + 150;
 Libr12->t2vrr_classes[4][5] = int_stack + 375;
 Libr12->t2vrr_classes[4][6] = int_stack + 690;
 Libr12->t2vrr_classes[5][3] = int_stack + 1110;
 Libr12->t2vrr_classes[5][4] = int_stack + 1320;
 Libr12->t2vrr_classes[5][5] = int_stack + 1635;
 Libr12->t2vrr_classes[5][6] = int_stack + 2076;
 Libr12->gvrr_classes[7][3] = int_stack + 2664;
 Libr12->t2vrr_classes[6][3] = int_stack + 3024;
 Libr12->gvrr_classes[7][4] = int_stack + 3304;
 Libr12->t2vrr_classes[6][4] = int_stack + 3844;
 Libr12->gvrr_classes[7][5] = int_stack + 4264;
 Libr12->t2vrr_classes[6][5] = int_stack + 5020;
 Libr12->t2vrr_classes[6][6] = int_stack + 5608;
 Libr12->gvrr_classes[4][7] = int_stack + 6392;
 Libr12->t1vrr_classes[4][3] = int_stack + 6932;
 Libr12->t1vrr_classes[4][4] = int_stack + 7082;
 Libr12->t1vrr_classes[4][5] = int_stack + 7307;
 Libr12->t1vrr_classes[4][6] = int_stack + 7622;
 Libr12->gvrr_classes[5][7] = int_stack + 8042;
 Libr12->t1vrr_classes[5][3] = int_stack + 8798;
 Libr12->t1vrr_classes[5][4] = int_stack + 9008;
 Libr12->t1vrr_classes[5][5] = int_stack + 9323;
 Libr12->t1vrr_classes[5][6] = int_stack + 9764;
 Libr12->t1vrr_classes[6][3] = int_stack + 10352;
 Libr12->t1vrr_classes[6][4] = int_stack + 10632;
 Libr12->t1vrr_classes[6][5] = int_stack + 11052;
 Libr12->t1vrr_classes[6][6] = int_stack + 11640;
 Libr12->rvrr_classes[4][3] = int_stack + 12424;
 Libr12->rvrr_classes[4][4] = int_stack + 12574;
 Libr12->rvrr_classes[4][5] = int_stack + 12799;
 Libr12->rvrr_classes[4][6] = int_stack + 13114;
 Libr12->rvrr_classes[5][3] = int_stack + 13534;
 Libr12->rvrr_classes[5][4] = int_stack + 13744;
 Libr12->rvrr_classes[5][5] = int_stack + 14059;
 Libr12->rvrr_classes[5][6] = int_stack + 14500;
 Libr12->rvrr_classes[6][3] = int_stack + 15088;
 Libr12->rvrr_classes[6][4] = int_stack + 15368;
 Libr12->rvrr_classes[6][5] = int_stack + 15788;
 Libr12->rvrr_classes[6][6] = int_stack + 16376;
 Libr12->gvrr_classes[4][3] = int_stack + 17160;
 Libr12->gvrr_classes[4][4] = int_stack + 17310;
 Libr12->gvrr_classes[4][5] = int_stack + 17535;
 Libr12->gvrr_classes[4][6] = int_stack + 17850;
 Libr12->gvrr_classes[5][3] = int_stack + 18270;
 Libr12->gvrr_classes[5][4] = int_stack + 18480;
 Libr12->gvrr_classes[5][5] = int_stack + 18795;
 Libr12->gvrr_classes[5][6] = int_stack + 19236;
 Libr12->gvrr_classes[6][3] = int_stack + 19824;
 Libr12->gvrr_classes[6][4] = int_stack + 20104;
 Libr12->gvrr_classes[6][5] = int_stack + 20524;
 Libr12->gvrr_classes[6][6] = int_stack + 21112;
 memset(int_stack,0,21896*sizeof(REALTYPE));

 Libr12->r12vrr_stack = int_stack + 21896;
 for(i=0;i<num_prim_comb;i++) {
   vrr_grt_order_gdff(Libr12, Data);
   Data++;
 }

 /*--- compute (g0|fp) ---*/
   hrr3_build_fp(Libr12->ShellQuartet.CD,int_stack+21896, int_stack+17310, int_stack+17160, 15);
 /*--- compute (g0|gp) ---*/
   hrr3_build_gp(Libr12->ShellQuartet.CD,int_stack+22346, int_stack+17535, int_stack+17310, 15);
 /*--- compute (g0|fd) ---*/
   hrr3_build_fd(Libr12->ShellQuartet.CD,int_stack+23021, int_stack+22346, int_stack+21896, 15);
 /*--- compute (h0|fp) ---*/
   hrr3_build_fp(Libr12->ShellQuartet.CD,int_stack+23921, int_stack+18480, int_stack+18270, 21);
 /*--- compute (h0|gp) ---*/
   hrr3_build_gp(Libr12->ShellQuartet.CD,int_stack+24551, int_stack+18795, int_stack+18480, 21);
 /*--- compute (h0|fd) ---*/
   hrr3_build_fd(Libr12->ShellQuartet.CD,int_stack+25496, int_stack+24551, int_stack+23921, 21);
 /*--- compute (g0|hp) ---*/
   hrr3_build_hp(Libr12->ShellQuartet.CD,int_stack+26756, int_stack+17850, int_stack+17535, 15);
 /*--- compute (g0|gd) ---*/
   hrr3_build_gd(Libr12->ShellQuartet.CD,int_stack+27701, int_stack+26756, int_stack+22346, 15);
 /*--- compute (g0|[r12,T2]|fp) ---*/
   t2hrr3_build_fp(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+29051, int_stack+150, int_stack+0, int_stack+17310, int_stack+18270, int_stack+17160, 4, 0);
 /*--- compute (g0|[r12,T2]|gp) ---*/
   t2hrr3_build_gp(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+29501, int_stack+375, int_stack+150, int_stack+17535, int_stack+18480, int_stack+17310, 4, 0);
 /*--- compute (g0|[r12,T2]|fd) ---*/
   t2hrr3_build_fd(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+30176, int_stack+29501, int_stack+29051, int_stack+22346, int_stack+23921, int_stack+21896, 4, 0);
 /*--- compute (g0|[r12,T2]|hp) ---*/
   t2hrr3_build_hp(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+31076, int_stack+690, int_stack+375, int_stack+17850, int_stack+18795, int_stack+17535, 4, 0);
 /*--- compute (g0|[r12,T2]|gd) ---*/
   t2hrr3_build_gd(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+32021, int_stack+31076, int_stack+29501, int_stack+26756, int_stack+24551, int_stack+22346, 4, 0);
 /*--- compute (g0|[r12,T2]|ff) ---*/
   t2hrr3_build_ff(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+33371, int_stack+32021, int_stack+30176, int_stack+27701, int_stack+25496, int_stack+23021, 4, 0);
 /*--- compute (i0|fp) ---*/
   hrr3_build_fp(Libr12->ShellQuartet.CD,int_stack+21896, int_stack+20104, int_stack+19824, 28);
 /*--- compute (i0|gp) ---*/
   hrr3_build_gp(Libr12->ShellQuartet.CD,int_stack+29051, int_stack+20524, int_stack+20104, 28);
 /*--- compute (i0|fd) ---*/
   hrr3_build_fd(Libr12->ShellQuartet.CD,int_stack+30311, int_stack+29051, int_stack+21896, 28);
 /*--- compute (h0|hp) ---*/
   hrr3_build_hp(Libr12->ShellQuartet.CD,int_stack+31991, int_stack+19236, int_stack+18795, 21);
 /*--- compute (h0|gd) ---*/
   hrr3_build_gd(Libr12->ShellQuartet.CD,int_stack+34871, int_stack+31991, int_stack+24551, 21);
 /*--- compute (h0|[r12,T2]|fp) ---*/
   t2hrr3_build_fp(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+17160, int_stack+1320, int_stack+1110, int_stack+18480, int_stack+19824, int_stack+18270, 5, 0);
 /*--- compute (h0|[r12,T2]|gp) ---*/
   t2hrr3_build_gp(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+0, int_stack+1635, int_stack+1320, int_stack+18795, int_stack+20104, int_stack+18480, 5, 0);
 /*--- compute (h0|[r12,T2]|fd) ---*/
   t2hrr3_build_fd(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+36761, int_stack+0, int_stack+17160, int_stack+24551, int_stack+21896, int_stack+23921, 5, 0);
 /*--- compute (h0|[r12,T2]|hp) ---*/
   t2hrr3_build_hp(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+38021, int_stack+2076, int_stack+1635, int_stack+19236, int_stack+20524, int_stack+18795, 5, 0);
 /*--- compute (h0|[r12,T2]|gd) ---*/
   t2hrr3_build_gd(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+39344, int_stack+38021, int_stack+0, int_stack+31991, int_stack+29051, int_stack+24551, 5, 0);
 /*--- compute (h0|[r12,T2]|ff) ---*/
   t2hrr3_build_ff(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+0, int_stack+39344, int_stack+36761, int_stack+34871, int_stack+30311, int_stack+25496, 5, 0);
 /*--- compute (gp|[r12,T2]|ff) ---*/
   hrr1_build_gp(Libr12->ShellQuartet.AB,int_stack+36761, int_stack+0, int_stack+33371, 100);
 /*--- compute (k0|fp) ---*/
   hrr3_build_fp(Libr12->ShellQuartet.CD,int_stack+23921, int_stack+3304, int_stack+2664, 36);
 /*--- compute (k0|gp) ---*/
   hrr3_build_gp(Libr12->ShellQuartet.CD,int_stack+41261, int_stack+4264, int_stack+3304, 36);
 /*--- compute (k0|fd) ---*/
   hrr3_build_fd(Libr12->ShellQuartet.CD,int_stack+42881, int_stack+41261, int_stack+23921, 36);
 /*--- compute (i0|hp) ---*/
   hrr3_build_hp(Libr12->ShellQuartet.CD,int_stack+45041, int_stack+21112, int_stack+20524, 28);
 /*--- compute (i0|gd) ---*/
   hrr3_build_gd(Libr12->ShellQuartet.CD,int_stack+46805, int_stack+45041, int_stack+29051, 28);
 /*--- compute (i0|[r12,T2]|fp) ---*/
   t2hrr3_build_fp(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+18270, int_stack+3844, int_stack+3024, int_stack+20104, int_stack+2664, int_stack+19824, 6, 0);
 /*--- compute (i0|[r12,T2]|gp) ---*/
   t2hrr3_build_gp(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+33314, int_stack+5020, int_stack+3844, int_stack+20524, int_stack+3304, int_stack+20104, 6, 0);
 /*--- compute (i0|[r12,T2]|fd) ---*/
   t2hrr3_build_fd(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+2100, int_stack+33314, int_stack+18270, int_stack+29051, int_stack+23921, int_stack+21896, 6, 0);
 /*--- compute (i0|[r12,T2]|hp) ---*/
   t2hrr3_build_hp(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+49325, int_stack+5608, int_stack+5020, int_stack+21112, int_stack+4264, int_stack+20524, 6, 0);
 /*--- compute (i0|[r12,T2]|gd) ---*/
   t2hrr3_build_gd(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+19824, int_stack+49325, int_stack+33314, int_stack+45041, int_stack+41261, int_stack+29051, 6, 0);
 /*--- compute (i0|[r12,T2]|ff) ---*/
   t2hrr3_build_ff(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+49325, int_stack+19824, int_stack+2100, int_stack+46805, int_stack+42881, int_stack+30311, 6, 0);
 /*--- compute (hp|[r12,T2]|ff) ---*/
   hrr1_build_hp(Libr12->ShellQuartet.AB,int_stack+52125, int_stack+49325, int_stack+0, 100);
 /*--- compute (g0|ff) ---*/
   hrr3_build_ff(Libr12->ShellQuartet.CD,int_stack+0, int_stack+27701, int_stack+23021, 15);
 /*--- compute (h0|ff) ---*/
   hrr3_build_ff(Libr12->ShellQuartet.CD,int_stack+1500, int_stack+34871, int_stack+25496, 21);
 /*--- compute (gp|ff) ---*/
   hrr1_build_gp(Libr12->ShellQuartet.AB,int_stack+19824, int_stack+1500, int_stack+0, 100);
 /*--- compute (g0|ip) ---*/
   hrr3_build_ip(Libr12->ShellQuartet.CD,int_stack+29051, int_stack+6392, int_stack+17850, 15);
 /*--- compute (g0|hd) ---*/
   hrr3_build_hd(Libr12->ShellQuartet.CD,int_stack+3600, int_stack+29051, int_stack+26756, 15);
 /*--- compute (g0|gf) ---*/
   hrr3_build_gf(Libr12->ShellQuartet.CD,int_stack+49325, int_stack+3600, int_stack+27701, 15);
 /*--- compute (h0|ip) ---*/
   hrr3_build_ip(Libr12->ShellQuartet.CD,int_stack+3600, int_stack+8042, int_stack+19236, 21);
 /*--- compute (h0|hd) ---*/
   hrr3_build_hd(Libr12->ShellQuartet.CD,int_stack+24324, int_stack+3600, int_stack+31991, 21);
 /*--- compute (h0|gf) ---*/
   hrr3_build_gf(Libr12->ShellQuartet.CD,int_stack+3600, int_stack+24324, int_stack+34871, 21);
 /*--- compute (gp|gf) ---*/
   hrr1_build_gp(Libr12->ShellQuartet.AB,int_stack+58425, int_stack+3600, int_stack+49325, 150);
 /*--- compute (i0|ff) ---*/
   hrr3_build_ff(Libr12->ShellQuartet.CD,int_stack+24324, int_stack+46805, int_stack+30311, 28);
 /*--- compute (hp|ff) ---*/
   hrr1_build_hp(Libr12->ShellQuartet.AB,int_stack+27124, int_stack+24324, int_stack+1500, 100);
 /*--- compute (g0|[r12,T1]|fp) ---*/
   hrr3_build_fp(Libr12->ShellQuartet.CD,int_stack+33424, int_stack+7082, int_stack+6932, 15);
 /*--- compute (g0|[r12,T1]|gp) ---*/
   hrr3_build_gp(Libr12->ShellQuartet.CD,int_stack+33874, int_stack+7307, int_stack+7082, 15);
 /*--- compute (g0|[r12,T1]|fd) ---*/
   hrr3_build_fd(Libr12->ShellQuartet.CD,int_stack+34549, int_stack+33874, int_stack+33424, 15);
 /*--- compute (g0|[r12,T1]|hp) ---*/
   hrr3_build_hp(Libr12->ShellQuartet.CD,int_stack+35449, int_stack+7622, int_stack+7307, 15);
 /*--- compute (g0|[r12,T1]|gd) ---*/
   hrr3_build_gd(Libr12->ShellQuartet.CD,int_stack+6750, int_stack+35449, int_stack+33874, 15);
 /*--- compute (g0|[r12,T1]|ff) ---*/
   hrr3_build_ff(Libr12->ShellQuartet.CD,int_stack+41261, int_stack+6750, int_stack+34549, 15);
 /*--- compute (h0|[r12,T1]|fp) ---*/
   hrr3_build_fp(Libr12->ShellQuartet.CD,int_stack+6750, int_stack+9008, int_stack+8798, 21);
 /*--- compute (h0|[r12,T1]|gp) ---*/
   hrr3_build_gp(Libr12->ShellQuartet.CD,int_stack+7380, int_stack+9323, int_stack+9008, 21);
 /*--- compute (h0|[r12,T1]|fd) ---*/
   hrr3_build_fd(Libr12->ShellQuartet.CD,int_stack+33424, int_stack+7380, int_stack+6750, 21);
 /*--- compute (h0|[r12,T1]|hp) ---*/
   hrr3_build_hp(Libr12->ShellQuartet.CD,int_stack+34684, int_stack+9764, int_stack+9323, 21);
 /*--- compute (h0|[r12,T1]|gd) ---*/
   hrr3_build_gd(Libr12->ShellQuartet.CD,int_stack+8325, int_stack+34684, int_stack+7380, 21);
 /*--- compute (h0|[r12,T1]|ff) ---*/
   hrr3_build_ff(Libr12->ShellQuartet.CD,int_stack+42761, int_stack+8325, int_stack+33424, 21);
 /*--- compute (gp|[r12,T1]|ff) ---*/
   t1hrr1_build_gp(Libr12->ShellQuartet.AB,Libr12->ShellQuartet.AC,int_stack+65175, int_stack+42761, int_stack+41261, int_stack+1500, int_stack+49325, int_stack+0, 3, 3);
 /*--- compute (i0|[r12,T1]|fp) ---*/
   hrr3_build_fp(Libr12->ShellQuartet.CD,int_stack+0, int_stack+10632, int_stack+10352, 28);
 /*--- compute (i0|[r12,T1]|gp) ---*/
   hrr3_build_gp(Libr12->ShellQuartet.CD,int_stack+41261, int_stack+11052, int_stack+10632, 28);
 /*--- compute (i0|[r12,T1]|fd) ---*/
   hrr3_build_fd(Libr12->ShellQuartet.CD,int_stack+33424, int_stack+41261, int_stack+0, 28);
 /*--- compute (i0|[r12,T1]|hp) ---*/
   hrr3_build_hp(Libr12->ShellQuartet.CD,int_stack+6750, int_stack+11640, int_stack+11052, 28);
 /*--- compute (i0|[r12,T1]|gd) ---*/
   hrr3_build_gd(Libr12->ShellQuartet.CD,int_stack+8514, int_stack+6750, int_stack+41261, 28);
 /*--- compute (i0|[r12,T1]|ff) ---*/
   hrr3_build_ff(Libr12->ShellQuartet.CD,int_stack+44861, int_stack+8514, int_stack+33424, 28);
 /*--- compute (hp|[r12,T1]|ff) ---*/
   t1hrr1_build_hp(Libr12->ShellQuartet.AB,Libr12->ShellQuartet.AC,int_stack+69675, int_stack+44861, int_stack+42761, int_stack+24324, int_stack+3600, int_stack+1500, 3, 3);
 /*--- compute (g0||fp) ---*/
   hrr3_build_fp(Libr12->ShellQuartet.CD,int_stack+24324, int_stack+12574, int_stack+12424, 15);
 /*--- compute (g0||gp) ---*/
   hrr3_build_gp(Libr12->ShellQuartet.CD,int_stack+24774, int_stack+12799, int_stack+12574, 15);
 /*--- compute (g0||fd) ---*/
   hrr3_build_fd(Libr12->ShellQuartet.CD,int_stack+25449, int_stack+24774, int_stack+24324, 15);
 /*--- compute (g0||hp) ---*/
   hrr3_build_hp(Libr12->ShellQuartet.CD,int_stack+33424, int_stack+13114, int_stack+12799, 15);
 /*--- compute (g0||gd) ---*/
   hrr3_build_gd(Libr12->ShellQuartet.CD,int_stack+34369, int_stack+33424, int_stack+24774, 15);
 /*--- compute (g0||ff) ---*/
   hrr3_build_ff(Libr12->ShellQuartet.CD,int_stack+41261, int_stack+34369, int_stack+25449, 15);
 /*--- compute (h0||fp) ---*/
   hrr3_build_fp(Libr12->ShellQuartet.CD,int_stack+33424, int_stack+13744, int_stack+13534, 21);
 /*--- compute (h0||gp) ---*/
   hrr3_build_gp(Libr12->ShellQuartet.CD,int_stack+34054, int_stack+14059, int_stack+13744, 21);
 /*--- compute (h0||fd) ---*/
   hrr3_build_fd(Libr12->ShellQuartet.CD,int_stack+34999, int_stack+34054, int_stack+33424, 21);
 /*--- compute (h0||hp) ---*/
   hrr3_build_hp(Libr12->ShellQuartet.CD,int_stack+24324, int_stack+14500, int_stack+14059, 21);
 /*--- compute (h0||gd) ---*/
   hrr3_build_gd(Libr12->ShellQuartet.CD,int_stack+42761, int_stack+24324, int_stack+34054, 21);
 /*--- compute (h0||ff) ---*/
   hrr3_build_ff(Libr12->ShellQuartet.CD,int_stack+24324, int_stack+42761, int_stack+34999, 21);
 /*--- compute (gp||ff) ---*/
   hrr1_build_gp(Libr12->ShellQuartet.AB,int_stack+42761, int_stack+24324, int_stack+41261, 100);
 /*--- compute (i0||fp) ---*/
   hrr3_build_fp(Libr12->ShellQuartet.CD,int_stack+41261, int_stack+15368, int_stack+15088, 28);
 /*--- compute (i0||gp) ---*/
   hrr3_build_gp(Libr12->ShellQuartet.CD,int_stack+47261, int_stack+15788, int_stack+15368, 28);
 /*--- compute (i0||fd) ---*/
   hrr3_build_fd(Libr12->ShellQuartet.CD,int_stack+48521, int_stack+47261, int_stack+41261, 28);
 /*--- compute (i0||hp) ---*/
   hrr3_build_hp(Libr12->ShellQuartet.CD,int_stack+50201, int_stack+16376, int_stack+15788, 28);
 /*--- compute (i0||gd) ---*/
   hrr3_build_gd(Libr12->ShellQuartet.CD,int_stack+33424, int_stack+50201, int_stack+47261, 28);
 /*--- compute (i0||ff) ---*/
   hrr3_build_ff(Libr12->ShellQuartet.CD,int_stack+0, int_stack+33424, int_stack+48521, 28);
 /*--- compute (hp||ff) ---*/
   hrr1_build_hp(Libr12->ShellQuartet.AB,int_stack+2800, int_stack+0, int_stack+24324, 100);
 /*--- compute (gd|[r12,T2]|ff) ---*/
   hrr1_build_gd(Libr12->ShellQuartet.AB,int_stack+9100, int_stack+52125, int_stack+36761, 100);
     Libr12->te_ptr[3] = int_stack + 9100;
 /*--- compute (gd|[r12,T1]|ff) ---*/
   t1hrr1_build_gd(Libr12->ShellQuartet.AB,Libr12->ShellQuartet.AC,int_stack+33424, int_stack+69675, int_stack+65175, int_stack+27124, int_stack+58425, int_stack+19824, 3, 3);
     Libr12->te_ptr[2] = int_stack + 33424;
 /*--- compute (gd||ff) ---*/
   hrr1_build_gd(Libr12->ShellQuartet.AB,int_stack+47261, int_stack+2800, int_stack+42761, 100);
     Libr12->te_ptr[1] = int_stack + 47261;
 /*--- compute (gd|ff) ---*/
   hrr1_build_gd(Libr12->ShellQuartet.AB,int_stack+0, int_stack+27124, int_stack+19824, 100);
     Libr12->te_ptr[0] = int_stack + 0;

}
