/*
 *  Copyright (C) 1996-2017 Edward F. Valeev and Justin T. Fermann
 *
 *  This file is part of Libint.
 *
 *  Libint is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU Lesser General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  Libint is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public License
 *  along with Libint.  If not, see <http://www.gnu.org/licenses/>.
 *
 */

#include <stdio.h>
#include <string.h>
#include <libint/libint.h>
#include "libr12.h"
#include <libint/hrr_header.h>

#include "r12_hrr_header.h"

extern void vrr_grt_order_h0ff(Libr12_t *, prim_data *);

  /* Computes (h0|ff) integrals for linear R12-methods */

void hrr_grt_order_h0ff(Libr12_t *Libr12, int num_prim_comb)
{
 prim_data *Data = Libr12->PrimQuartet;
 REALTYPE *int_stack = Libr12->int_stack;
 int i,j;
 REALTYPE tmp, *target;

 Libr12->gvrr_classes[6][3] = int_stack + 0;
 Libr12->t2vrr_classes[5][3] = int_stack + 280;
 Libr12->gvrr_classes[6][4] = int_stack + 490;
 Libr12->t2vrr_classes[5][4] = int_stack + 910;
 Libr12->gvrr_classes[6][5] = int_stack + 1225;
 Libr12->t2vrr_classes[5][5] = int_stack + 1813;
 Libr12->t2vrr_classes[5][6] = int_stack + 2254;
 Libr12->t1vrr_classes[5][3] = int_stack + 2842;
 Libr12->t1vrr_classes[5][4] = int_stack + 3052;
 Libr12->t1vrr_classes[5][5] = int_stack + 3367;
 Libr12->t1vrr_classes[5][6] = int_stack + 3808;
 Libr12->rvrr_classes[5][3] = int_stack + 4396;
 Libr12->rvrr_classes[5][4] = int_stack + 4606;
 Libr12->rvrr_classes[5][5] = int_stack + 4921;
 Libr12->rvrr_classes[5][6] = int_stack + 5362;
 Libr12->gvrr_classes[5][3] = int_stack + 5950;
 Libr12->gvrr_classes[5][4] = int_stack + 6160;
 Libr12->gvrr_classes[5][5] = int_stack + 6475;
 Libr12->gvrr_classes[5][6] = int_stack + 6916;
 memset(int_stack,0,7504*sizeof(REALTYPE));

 Libr12->r12vrr_stack = int_stack + 7504;
 for(i=0;i<num_prim_comb;i++) {
   vrr_grt_order_h0ff(Libr12, Data);
   Data++;
 }

 /*--- compute (h0|fp) ---*/
   hrr3_build_fp(Libr12->ShellQuartet.CD,int_stack+7504, int_stack+6160, int_stack+5950, 21);
 /*--- compute (h0|gp) ---*/
   hrr3_build_gp(Libr12->ShellQuartet.CD,int_stack+8134, int_stack+6475, int_stack+6160, 21);
 /*--- compute (h0|fd) ---*/
   hrr3_build_fd(Libr12->ShellQuartet.CD,int_stack+9079, int_stack+8134, int_stack+7504, 21);
 /*--- compute (i0|fp) ---*/
   hrr3_build_fp(Libr12->ShellQuartet.CD,int_stack+10339, int_stack+490, int_stack+0, 28);
 /*--- compute (i0|gp) ---*/
   hrr3_build_gp(Libr12->ShellQuartet.CD,int_stack+11179, int_stack+1225, int_stack+490, 28);
 /*--- compute (i0|fd) ---*/
   hrr3_build_fd(Libr12->ShellQuartet.CD,int_stack+12439, int_stack+11179, int_stack+10339, 28);
 /*--- compute (h0|hp) ---*/
   hrr3_build_hp(Libr12->ShellQuartet.CD,int_stack+14119, int_stack+6916, int_stack+6475, 21);
 /*--- compute (h0|gd) ---*/
   hrr3_build_gd(Libr12->ShellQuartet.CD,int_stack+15442, int_stack+14119, int_stack+8134, 21);
 /*--- compute (h0|[r12,T2]|fp) ---*/
   t2hrr3_build_fp(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+17332, int_stack+910, int_stack+280, int_stack+6160, int_stack+0, int_stack+5950, 5, 0);
 /*--- compute (h0|[r12,T2]|gp) ---*/
   t2hrr3_build_gp(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+17962, int_stack+1813, int_stack+910, int_stack+6475, int_stack+490, int_stack+6160, 5, 0);
 /*--- compute (h0|[r12,T2]|fd) ---*/
   t2hrr3_build_fd(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+18907, int_stack+17962, int_stack+17332, int_stack+8134, int_stack+10339, int_stack+7504, 5, 0);
 /*--- compute (h0|[r12,T2]|hp) ---*/
   t2hrr3_build_hp(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+20167, int_stack+2254, int_stack+1813, int_stack+6916, int_stack+1225, int_stack+6475, 5, 0);
 /*--- compute (h0|[r12,T2]|gd) ---*/
   t2hrr3_build_gd(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+5950, int_stack+20167, int_stack+17962, int_stack+14119, int_stack+11179, int_stack+8134, 5, 0);
 /*--- compute (h0|[r12,T1]|fp) ---*/
   hrr3_build_fp(Libr12->ShellQuartet.CD,int_stack+14119, int_stack+3052, int_stack+2842, 21);
 /*--- compute (h0|[r12,T1]|gp) ---*/
   hrr3_build_gp(Libr12->ShellQuartet.CD,int_stack+20167, int_stack+3367, int_stack+3052, 21);
 /*--- compute (h0|[r12,T1]|fd) ---*/
   hrr3_build_fd(Libr12->ShellQuartet.CD,int_stack+10339, int_stack+20167, int_stack+14119, 21);
 /*--- compute (h0|[r12,T1]|hp) ---*/
   hrr3_build_hp(Libr12->ShellQuartet.CD,int_stack+14119, int_stack+3808, int_stack+3367, 21);
 /*--- compute (h0|[r12,T1]|gd) ---*/
   hrr3_build_gd(Libr12->ShellQuartet.CD,int_stack+0, int_stack+14119, int_stack+20167, 21);
 /*--- compute (h0||fp) ---*/
   hrr3_build_fp(Libr12->ShellQuartet.CD,int_stack+20167, int_stack+4606, int_stack+4396, 21);
 /*--- compute (h0||gp) ---*/
   hrr3_build_gp(Libr12->ShellQuartet.CD,int_stack+20797, int_stack+4921, int_stack+4606, 21);
 /*--- compute (h0||fd) ---*/
   hrr3_build_fd(Libr12->ShellQuartet.CD,int_stack+14119, int_stack+20797, int_stack+20167, 21);
 /*--- compute (h0||hp) ---*/
   hrr3_build_hp(Libr12->ShellQuartet.CD,int_stack+17332, int_stack+5362, int_stack+4921, 21);
 /*--- compute (h0||gd) ---*/
   hrr3_build_gd(Libr12->ShellQuartet.CD,int_stack+1890, int_stack+17332, int_stack+20797, 21);
 /*--- compute (h0|[r12,T2]|ff) ---*/
   t2hrr3_build_ff(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+3780, int_stack+5950, int_stack+18907, int_stack+15442, int_stack+12439, int_stack+9079, 5, 0);
     Libr12->te_ptr[3] = int_stack + 3780;
 /*--- compute (h0|[r12,T1]|ff) ---*/
   hrr3_build_ff(Libr12->ShellQuartet.CD,int_stack+17332, int_stack+0, int_stack+10339, 21);
     Libr12->te_ptr[2] = int_stack + 17332;
 /*--- compute (h0||ff) ---*/
   hrr3_build_ff(Libr12->ShellQuartet.CD,int_stack+10339, int_stack+1890, int_stack+14119, 21);
     Libr12->te_ptr[1] = int_stack + 10339;
 /*--- compute (h0|ff) ---*/
   hrr3_build_ff(Libr12->ShellQuartet.CD,int_stack+12439, int_stack+15442, int_stack+9079, 21);
     Libr12->te_ptr[0] = int_stack + 12439;

}
