/*
 *  Copyright (C) 1996-2017 Edward F. Valeev and Justin T. Fermann
 *
 *  This file is part of Libint.
 *
 *  Libint is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU Lesser General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  Libint is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public License
 *  along with Libint.  If not, see <http://www.gnu.org/licenses/>.
 *
 */

#include <stdio.h>
#include <string.h>
#include <libint/libint.h>
#include "libr12.h"
#include <libint/hrr_header.h>

#include "r12_hrr_header.h"

extern void vrr_grt_order_hdgf(Libr12_t *, prim_data *);

  /* Computes (hd|gf) integrals for linear R12-methods */

void hrr_grt_order_hdgf(Libr12_t *Libr12, int num_prim_comb)
{
 prim_data *Data = Libr12->PrimQuartet;
 REALTYPE *int_stack = Libr12->int_stack;
 int i,j;
 REALTYPE tmp, *target;

 Libr12->t2vrr_classes[5][4] = int_stack + 0;
 Libr12->t2vrr_classes[5][5] = int_stack + 315;
 Libr12->t2vrr_classes[5][6] = int_stack + 756;
 Libr12->t2vrr_classes[5][7] = int_stack + 1344;
 Libr12->t2vrr_classes[6][4] = int_stack + 2100;
 Libr12->t2vrr_classes[6][5] = int_stack + 2520;
 Libr12->t2vrr_classes[6][6] = int_stack + 3108;
 Libr12->t2vrr_classes[6][7] = int_stack + 3892;
 Libr12->gvrr_classes[8][4] = int_stack + 4900;
 Libr12->t2vrr_classes[7][4] = int_stack + 5575;
 Libr12->gvrr_classes[8][5] = int_stack + 6115;
 Libr12->t2vrr_classes[7][5] = int_stack + 7060;
 Libr12->gvrr_classes[8][6] = int_stack + 7816;
 Libr12->t2vrr_classes[7][6] = int_stack + 9076;
 Libr12->t2vrr_classes[7][7] = int_stack + 10084;
 Libr12->gvrr_classes[5][8] = int_stack + 11380;
 Libr12->t1vrr_classes[5][4] = int_stack + 12325;
 Libr12->t1vrr_classes[5][5] = int_stack + 12640;
 Libr12->t1vrr_classes[5][6] = int_stack + 13081;
 Libr12->t1vrr_classes[5][7] = int_stack + 13669;
 Libr12->gvrr_classes[6][8] = int_stack + 14425;
 Libr12->t1vrr_classes[6][4] = int_stack + 15685;
 Libr12->t1vrr_classes[6][5] = int_stack + 16105;
 Libr12->t1vrr_classes[6][6] = int_stack + 16693;
 Libr12->t1vrr_classes[6][7] = int_stack + 17477;
 Libr12->t1vrr_classes[7][4] = int_stack + 18485;
 Libr12->t1vrr_classes[7][5] = int_stack + 19025;
 Libr12->t1vrr_classes[7][6] = int_stack + 19781;
 Libr12->t1vrr_classes[7][7] = int_stack + 20789;
 Libr12->rvrr_classes[5][4] = int_stack + 22085;
 Libr12->rvrr_classes[5][5] = int_stack + 22400;
 Libr12->rvrr_classes[5][6] = int_stack + 22841;
 Libr12->rvrr_classes[5][7] = int_stack + 23429;
 Libr12->rvrr_classes[6][4] = int_stack + 24185;
 Libr12->rvrr_classes[6][5] = int_stack + 24605;
 Libr12->rvrr_classes[6][6] = int_stack + 25193;
 Libr12->rvrr_classes[6][7] = int_stack + 25977;
 Libr12->rvrr_classes[7][4] = int_stack + 26985;
 Libr12->rvrr_classes[7][5] = int_stack + 27525;
 Libr12->rvrr_classes[7][6] = int_stack + 28281;
 Libr12->rvrr_classes[7][7] = int_stack + 29289;
 Libr12->gvrr_classes[5][4] = int_stack + 30585;
 Libr12->gvrr_classes[5][5] = int_stack + 30900;
 Libr12->gvrr_classes[5][6] = int_stack + 31341;
 Libr12->gvrr_classes[5][7] = int_stack + 31929;
 Libr12->gvrr_classes[6][4] = int_stack + 32685;
 Libr12->gvrr_classes[6][5] = int_stack + 33105;
 Libr12->gvrr_classes[6][6] = int_stack + 33693;
 Libr12->gvrr_classes[6][7] = int_stack + 34477;
 Libr12->gvrr_classes[7][4] = int_stack + 35485;
 Libr12->gvrr_classes[7][5] = int_stack + 36025;
 Libr12->gvrr_classes[7][6] = int_stack + 36781;
 Libr12->gvrr_classes[7][7] = int_stack + 37789;
 memset(int_stack,0,39085*sizeof(REALTYPE));

 Libr12->r12vrr_stack = int_stack + 39085;
 for(i=0;i<num_prim_comb;i++) {
   vrr_grt_order_hdgf(Libr12, Data);
   Data++;
 }

 /*--- compute (h0|gp) ---*/
   hrr3_build_gp(Libr12->ShellQuartet.CD,int_stack+39085, int_stack+30900, int_stack+30585, 21);
 /*--- compute (h0|hp) ---*/
   hrr3_build_hp(Libr12->ShellQuartet.CD,int_stack+40030, int_stack+31341, int_stack+30900, 21);
 /*--- compute (h0|gd) ---*/
   hrr3_build_gd(Libr12->ShellQuartet.CD,int_stack+41353, int_stack+40030, int_stack+39085, 21);
 /*--- compute (i0|gp) ---*/
   hrr3_build_gp(Libr12->ShellQuartet.CD,int_stack+43243, int_stack+33105, int_stack+32685, 28);
 /*--- compute (i0|hp) ---*/
   hrr3_build_hp(Libr12->ShellQuartet.CD,int_stack+44503, int_stack+33693, int_stack+33105, 28);
 /*--- compute (i0|gd) ---*/
   hrr3_build_gd(Libr12->ShellQuartet.CD,int_stack+46267, int_stack+44503, int_stack+43243, 28);
 /*--- compute (h0|ip) ---*/
   hrr3_build_ip(Libr12->ShellQuartet.CD,int_stack+48787, int_stack+31929, int_stack+31341, 21);
 /*--- compute (h0|hd) ---*/
   hrr3_build_hd(Libr12->ShellQuartet.CD,int_stack+50551, int_stack+48787, int_stack+40030, 21);
 /*--- compute (h0|[r12,T2]|gp) ---*/
   t2hrr3_build_gp(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+53197, int_stack+315, int_stack+0, int_stack+30900, int_stack+32685, int_stack+30585, 5, 0);
 /*--- compute (h0|[r12,T2]|hp) ---*/
   t2hrr3_build_hp(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+54142, int_stack+756, int_stack+315, int_stack+31341, int_stack+33105, int_stack+30900, 5, 0);
 /*--- compute (h0|[r12,T2]|gd) ---*/
   t2hrr3_build_gd(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+55465, int_stack+54142, int_stack+53197, int_stack+40030, int_stack+43243, int_stack+39085, 5, 0);
 /*--- compute (h0|[r12,T2]|ip) ---*/
   t2hrr3_build_ip(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+57355, int_stack+1344, int_stack+756, int_stack+31929, int_stack+33693, int_stack+31341, 5, 0);
 /*--- compute (h0|[r12,T2]|hd) ---*/
   t2hrr3_build_hd(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+59119, int_stack+57355, int_stack+54142, int_stack+48787, int_stack+44503, int_stack+40030, 5, 0);
 /*--- compute (h0|[r12,T2]|gf) ---*/
   t2hrr3_build_gf(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+61765, int_stack+59119, int_stack+55465, int_stack+50551, int_stack+46267, int_stack+41353, 5, 0);
 /*--- compute (k0|gp) ---*/
   hrr3_build_gp(Libr12->ShellQuartet.CD,int_stack+39085, int_stack+36025, int_stack+35485, 36);
 /*--- compute (k0|hp) ---*/
   hrr3_build_hp(Libr12->ShellQuartet.CD,int_stack+53197, int_stack+36781, int_stack+36025, 36);
 /*--- compute (k0|gd) ---*/
   hrr3_build_gd(Libr12->ShellQuartet.CD,int_stack+55465, int_stack+53197, int_stack+39085, 36);
 /*--- compute (i0|ip) ---*/
   hrr3_build_ip(Libr12->ShellQuartet.CD,int_stack+58705, int_stack+34477, int_stack+33693, 28);
 /*--- compute (i0|hd) ---*/
   hrr3_build_hd(Libr12->ShellQuartet.CD,int_stack+64915, int_stack+58705, int_stack+44503, 28);
 /*--- compute (i0|[r12,T2]|gp) ---*/
   t2hrr3_build_gp(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+30585, int_stack+2520, int_stack+2100, int_stack+33105, int_stack+35485, int_stack+32685, 6, 0);
 /*--- compute (i0|[r12,T2]|hp) ---*/
   t2hrr3_build_hp(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+0, int_stack+3108, int_stack+2520, int_stack+33693, int_stack+36025, int_stack+33105, 6, 0);
 /*--- compute (i0|[r12,T2]|gd) ---*/
   t2hrr3_build_gd(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+68443, int_stack+0, int_stack+30585, int_stack+44503, int_stack+39085, int_stack+43243, 6, 0);
 /*--- compute (i0|[r12,T2]|ip) ---*/
   t2hrr3_build_ip(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+70963, int_stack+3892, int_stack+3108, int_stack+34477, int_stack+36781, int_stack+33693, 6, 0);
 /*--- compute (i0|[r12,T2]|hd) ---*/
   t2hrr3_build_hd(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+73315, int_stack+70963, int_stack+0, int_stack+58705, int_stack+53197, int_stack+44503, 6, 0);
 /*--- compute (i0|[r12,T2]|gf) ---*/
   t2hrr3_build_gf(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+0, int_stack+73315, int_stack+68443, int_stack+64915, int_stack+55465, int_stack+46267, 6, 0);
 /*--- compute (hp|[r12,T2]|gf) ---*/
   hrr1_build_hp(Libr12->ShellQuartet.AB,int_stack+68443, int_stack+0, int_stack+61765, 150);
 /*--- compute (l0|gp) ---*/
   hrr3_build_gp(Libr12->ShellQuartet.CD,int_stack+43243, int_stack+6115, int_stack+4900, 45);
 /*--- compute (l0|hp) ---*/
   hrr3_build_hp(Libr12->ShellQuartet.CD,int_stack+61057, int_stack+7816, int_stack+6115, 45);
 /*--- compute (l0|gd) ---*/
   hrr3_build_gd(Libr12->ShellQuartet.CD,int_stack+77893, int_stack+61057, int_stack+43243, 45);
 /*--- compute (k0|ip) ---*/
   hrr3_build_ip(Libr12->ShellQuartet.CD,int_stack+81943, int_stack+37789, int_stack+36781, 36);
 /*--- compute (k0|hd) ---*/
   hrr3_build_hd(Libr12->ShellQuartet.CD,int_stack+84967, int_stack+81943, int_stack+53197, 36);
 /*--- compute (k0|[r12,T2]|gp) ---*/
   t2hrr3_build_gp(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+32685, int_stack+7060, int_stack+5575, int_stack+36025, int_stack+4900, int_stack+35485, 7, 0);
 /*--- compute (k0|[r12,T2]|hp) ---*/
   t2hrr3_build_hp(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+89503, int_stack+9076, int_stack+7060, int_stack+36781, int_stack+6115, int_stack+36025, 7, 0);
 /*--- compute (k0|[r12,T2]|gd) ---*/
   t2hrr3_build_gd(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+4200, int_stack+89503, int_stack+32685, int_stack+53197, int_stack+43243, int_stack+39085, 7, 0);
 /*--- compute (k0|[r12,T2]|ip) ---*/
   t2hrr3_build_ip(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+43243, int_stack+10084, int_stack+9076, int_stack+37789, int_stack+7816, int_stack+36781, 7, 0);
 /*--- compute (k0|[r12,T2]|hd) ---*/
   t2hrr3_build_hd(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+35485, int_stack+43243, int_stack+89503, int_stack+81943, int_stack+61057, int_stack+53197, 7, 0);
 /*--- compute (k0|[r12,T2]|gf) ---*/
   t2hrr3_build_gf(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+89503, int_stack+35485, int_stack+4200, int_stack+84967, int_stack+77893, int_stack+55465, 7, 0);
 /*--- compute (ip|[r12,T2]|gf) ---*/
   hrr1_build_ip(Libr12->ShellQuartet.AB,int_stack+94903, int_stack+89503, int_stack+0, 150);
 /*--- compute (h0|gf) ---*/
   hrr3_build_gf(Libr12->ShellQuartet.CD,int_stack+0, int_stack+50551, int_stack+41353, 21);
 /*--- compute (i0|gf) ---*/
   hrr3_build_gf(Libr12->ShellQuartet.CD,int_stack+3150, int_stack+64915, int_stack+46267, 28);
 /*--- compute (hp|gf) ---*/
   hrr1_build_hp(Libr12->ShellQuartet.AB,int_stack+35485, int_stack+3150, int_stack+0, 150);
 /*--- compute (h0|kp) ---*/
   hrr3_build_kp(Libr12->ShellQuartet.CD,int_stack+53197, int_stack+11380, int_stack+31929, 21);
 /*--- compute (h0|id) ---*/
   hrr3_build_id(Libr12->ShellQuartet.CD,int_stack+7350, int_stack+53197, int_stack+48787, 21);
 /*--- compute (h0|hf) ---*/
   hrr3_build_hf(Libr12->ShellQuartet.CD,int_stack+89503, int_stack+7350, int_stack+50551, 21);
 /*--- compute (i0|kp) ---*/
   hrr3_build_kp(Libr12->ShellQuartet.CD,int_stack+7350, int_stack+14425, int_stack+34477, 28);
 /*--- compute (i0|id) ---*/
   hrr3_build_id(Libr12->ShellQuartet.CD,int_stack+77893, int_stack+7350, int_stack+58705, 28);
 /*--- compute (i0|hf) ---*/
   hrr3_build_hf(Libr12->ShellQuartet.CD,int_stack+58705, int_stack+77893, int_stack+64915, 28);
 /*--- compute (hp|hf) ---*/
   hrr1_build_hp(Libr12->ShellQuartet.AB,int_stack+107503, int_stack+58705, int_stack+89503, 210);
 /*--- compute (k0|gf) ---*/
   hrr3_build_gf(Libr12->ShellQuartet.CD,int_stack+77893, int_stack+84967, int_stack+55465, 36);
 /*--- compute (ip|gf) ---*/
   hrr1_build_ip(Libr12->ShellQuartet.AB,int_stack+44935, int_stack+77893, int_stack+3150, 150);
 /*--- compute (h0|[r12,T1]|gp) ---*/
   hrr3_build_gp(Libr12->ShellQuartet.CD,int_stack+83293, int_stack+12640, int_stack+12325, 21);
 /*--- compute (h0|[r12,T1]|hp) ---*/
   hrr3_build_hp(Libr12->ShellQuartet.CD,int_stack+84238, int_stack+13081, int_stack+12640, 21);
 /*--- compute (h0|[r12,T1]|gd) ---*/
   hrr3_build_gd(Libr12->ShellQuartet.CD,int_stack+85561, int_stack+84238, int_stack+83293, 21);
 /*--- compute (h0|[r12,T1]|ip) ---*/
   hrr3_build_ip(Libr12->ShellQuartet.CD,int_stack+87451, int_stack+13669, int_stack+13081, 21);
 /*--- compute (h0|[r12,T1]|hd) ---*/
   hrr3_build_hd(Libr12->ShellQuartet.CD,int_stack+64585, int_stack+87451, int_stack+84238, 21);
 /*--- compute (h0|[r12,T1]|gf) ---*/
   hrr3_build_gf(Libr12->ShellQuartet.CD,int_stack+7350, int_stack+64585, int_stack+85561, 21);
 /*--- compute (i0|[r12,T1]|gp) ---*/
   hrr3_build_gp(Libr12->ShellQuartet.CD,int_stack+64585, int_stack+16105, int_stack+15685, 28);
 /*--- compute (i0|[r12,T1]|hp) ---*/
   hrr3_build_hp(Libr12->ShellQuartet.CD,int_stack+65845, int_stack+16693, int_stack+16105, 28);
 /*--- compute (i0|[r12,T1]|gd) ---*/
   hrr3_build_gd(Libr12->ShellQuartet.CD,int_stack+83293, int_stack+65845, int_stack+64585, 28);
 /*--- compute (i0|[r12,T1]|ip) ---*/
   hrr3_build_ip(Libr12->ShellQuartet.CD,int_stack+85813, int_stack+17477, int_stack+16693, 28);
 /*--- compute (i0|[r12,T1]|hd) ---*/
   hrr3_build_hd(Libr12->ShellQuartet.CD,int_stack+10500, int_stack+85813, int_stack+65845, 28);
 /*--- compute (i0|[r12,T1]|gf) ---*/
   hrr3_build_gf(Libr12->ShellQuartet.CD,int_stack+14028, int_stack+10500, int_stack+83293, 28);
 /*--- compute (hp|[r12,T1]|gf) ---*/
   t1hrr1_build_hp(Libr12->ShellQuartet.AB,Libr12->ShellQuartet.AC,int_stack+120733, int_stack+14028, int_stack+7350, int_stack+3150, int_stack+89503, int_stack+0, 4, 3);
 /*--- compute (k0|[r12,T1]|gp) ---*/
   hrr3_build_gp(Libr12->ShellQuartet.CD,int_stack+0, int_stack+19025, int_stack+18485, 36);
 /*--- compute (k0|[r12,T1]|hp) ---*/
   hrr3_build_hp(Libr12->ShellQuartet.CD,int_stack+7350, int_stack+19781, int_stack+19025, 36);
 /*--- compute (k0|[r12,T1]|gd) ---*/
   hrr3_build_gd(Libr12->ShellQuartet.CD,int_stack+9618, int_stack+7350, int_stack+0, 36);
 /*--- compute (k0|[r12,T1]|ip) ---*/
   hrr3_build_ip(Libr12->ShellQuartet.CD,int_stack+0, int_stack+20789, int_stack+19781, 36);
 /*--- compute (k0|[r12,T1]|hd) ---*/
   hrr3_build_hd(Libr12->ShellQuartet.CD,int_stack+83293, int_stack+0, int_stack+7350, 36);
 /*--- compute (k0|[r12,T1]|gf) ---*/
   hrr3_build_gf(Libr12->ShellQuartet.CD,int_stack+87829, int_stack+83293, int_stack+9618, 36);
 /*--- compute (ip|[r12,T1]|gf) ---*/
   t1hrr1_build_ip(Libr12->ShellQuartet.AB,Libr12->ShellQuartet.AC,int_stack+130183, int_stack+87829, int_stack+14028, int_stack+77893, int_stack+58705, int_stack+3150, 4, 3);
 /*--- compute (h0||gp) ---*/
   hrr3_build_gp(Libr12->ShellQuartet.CD,int_stack+77893, int_stack+22400, int_stack+22085, 21);
 /*--- compute (h0||hp) ---*/
   hrr3_build_hp(Libr12->ShellQuartet.CD,int_stack+78838, int_stack+22841, int_stack+22400, 21);
 /*--- compute (h0||gd) ---*/
   hrr3_build_gd(Libr12->ShellQuartet.CD,int_stack+80161, int_stack+78838, int_stack+77893, 21);
 /*--- compute (h0||ip) ---*/
   hrr3_build_ip(Libr12->ShellQuartet.CD,int_stack+82051, int_stack+23429, int_stack+22841, 21);
 /*--- compute (h0||hd) ---*/
   hrr3_build_hd(Libr12->ShellQuartet.CD,int_stack+83815, int_stack+82051, int_stack+78838, 21);
 /*--- compute (h0||gf) ---*/
   hrr3_build_gf(Libr12->ShellQuartet.CD,int_stack+86461, int_stack+83815, int_stack+80161, 21);
 /*--- compute (i0||gp) ---*/
   hrr3_build_gp(Libr12->ShellQuartet.CD,int_stack+77893, int_stack+24605, int_stack+24185, 28);
 /*--- compute (i0||hp) ---*/
   hrr3_build_hp(Libr12->ShellQuartet.CD,int_stack+79153, int_stack+25193, int_stack+24605, 28);
 /*--- compute (i0||gd) ---*/
   hrr3_build_gd(Libr12->ShellQuartet.CD,int_stack+80917, int_stack+79153, int_stack+77893, 28);
 /*--- compute (i0||ip) ---*/
   hrr3_build_ip(Libr12->ShellQuartet.CD,int_stack+83437, int_stack+25977, int_stack+25193, 28);
 /*--- compute (i0||hd) ---*/
   hrr3_build_hd(Libr12->ShellQuartet.CD,int_stack+89611, int_stack+83437, int_stack+79153, 28);
 /*--- compute (i0||gf) ---*/
   hrr3_build_gf(Libr12->ShellQuartet.CD,int_stack+0, int_stack+89611, int_stack+80917, 28);
 /*--- compute (hp||gf) ---*/
   hrr1_build_hp(Libr12->ShellQuartet.AB,int_stack+4200, int_stack+0, int_stack+86461, 150);
 /*--- compute (k0||gp) ---*/
   hrr3_build_gp(Libr12->ShellQuartet.CD,int_stack+77893, int_stack+27525, int_stack+26985, 36);
 /*--- compute (k0||hp) ---*/
   hrr3_build_hp(Libr12->ShellQuartet.CD,int_stack+79513, int_stack+28281, int_stack+27525, 36);
 /*--- compute (k0||gd) ---*/
   hrr3_build_gd(Libr12->ShellQuartet.CD,int_stack+81781, int_stack+79513, int_stack+77893, 36);
 /*--- compute (k0||ip) ---*/
   hrr3_build_ip(Libr12->ShellQuartet.CD,int_stack+85021, int_stack+29289, int_stack+28281, 36);
 /*--- compute (k0||hd) ---*/
   hrr3_build_hd(Libr12->ShellQuartet.CD,int_stack+88045, int_stack+85021, int_stack+79513, 36);
 /*--- compute (k0||gf) ---*/
   hrr3_build_gf(Libr12->ShellQuartet.CD,int_stack+13650, int_stack+88045, int_stack+81781, 36);
 /*--- compute (ip||gf) ---*/
   hrr1_build_ip(Libr12->ShellQuartet.AB,int_stack+77893, int_stack+13650, int_stack+0, 150);
 /*--- compute (hd|[r12,T2]|gf) ---*/
   hrr1_build_hd(Libr12->ShellQuartet.AB,int_stack+13650, int_stack+94903, int_stack+68443, 150);
     Libr12->te_ptr[3] = int_stack + 13650;
 /*--- compute (hd|[r12,T1]|gf) ---*/
   t1hrr1_build_hd(Libr12->ShellQuartet.AB,Libr12->ShellQuartet.AC,int_stack+57535, int_stack+130183, int_stack+120733, int_stack+44935, int_stack+107503, int_stack+35485, 4, 3);
     Libr12->te_ptr[2] = int_stack + 57535;
 /*--- compute (hd||gf) ---*/
   hrr1_build_hd(Libr12->ShellQuartet.AB,int_stack+90493, int_stack+77893, int_stack+4200, 150);
     Libr12->te_ptr[1] = int_stack + 90493;
 /*--- compute (hd|gf) ---*/
   hrr1_build_hd(Libr12->ShellQuartet.AB,int_stack+109393, int_stack+44935, int_stack+35485, 150);
     Libr12->te_ptr[0] = int_stack + 109393;

}
