/*
 *  Copyright (C) 1996-2017 Edward F. Valeev and Justin T. Fermann
 *
 *  This file is part of Libint.
 *
 *  Libint is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU Lesser General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  Libint is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public License
 *  along with Libint.  If not, see <http://www.gnu.org/licenses/>.
 *
 */

#include <stdio.h>
#include <string.h>
#include <libint/libint.h>
#include "libr12.h"
#include <libint/hrr_header.h>

#include "r12_hrr_header.h"

extern void vrr_grt_order_p0ff(Libr12_t *, prim_data *);

  /* Computes (p0|ff) integrals for linear R12-methods */

void hrr_grt_order_p0ff(Libr12_t *Libr12, int num_prim_comb)
{
 prim_data *Data = Libr12->PrimQuartet;
 REALTYPE *int_stack = Libr12->int_stack;
 int i,j;
 REALTYPE tmp, *target;

 Libr12->gvrr_classes[2][3] = int_stack + 0;
 Libr12->t2vrr_classes[1][3] = int_stack + 60;
 Libr12->gvrr_classes[2][4] = int_stack + 90;
 Libr12->t2vrr_classes[1][4] = int_stack + 180;
 Libr12->gvrr_classes[2][5] = int_stack + 225;
 Libr12->t2vrr_classes[1][5] = int_stack + 351;
 Libr12->t2vrr_classes[1][6] = int_stack + 414;
 Libr12->t1vrr_classes[1][3] = int_stack + 498;
 Libr12->t1vrr_classes[1][4] = int_stack + 528;
 Libr12->t1vrr_classes[1][5] = int_stack + 573;
 Libr12->t1vrr_classes[1][6] = int_stack + 636;
 Libr12->rvrr_classes[1][3] = int_stack + 720;
 Libr12->rvrr_classes[1][4] = int_stack + 750;
 Libr12->rvrr_classes[1][5] = int_stack + 795;
 Libr12->rvrr_classes[1][6] = int_stack + 858;
 Libr12->gvrr_classes[1][3] = int_stack + 942;
 Libr12->gvrr_classes[1][4] = int_stack + 972;
 Libr12->gvrr_classes[1][5] = int_stack + 1017;
 Libr12->gvrr_classes[1][6] = int_stack + 1080;
 memset(int_stack,0,1164*sizeof(REALTYPE));

 Libr12->r12vrr_stack = int_stack + 1164;
 for(i=0;i<num_prim_comb;i++) {
   vrr_grt_order_p0ff(Libr12, Data);
   Data++;
 }

 /*--- compute (p0|fp) ---*/
   hrr3_build_fp(Libr12->ShellQuartet.CD,int_stack+1164, int_stack+972, int_stack+942, 3);
 /*--- compute (p0|gp) ---*/
   hrr3_build_gp(Libr12->ShellQuartet.CD,int_stack+1254, int_stack+1017, int_stack+972, 3);
 /*--- compute (p0|fd) ---*/
   hrr3_build_fd(Libr12->ShellQuartet.CD,int_stack+1389, int_stack+1254, int_stack+1164, 3);
 /*--- compute (d0|fp) ---*/
   hrr3_build_fp(Libr12->ShellQuartet.CD,int_stack+1569, int_stack+90, int_stack+0, 6);
 /*--- compute (d0|gp) ---*/
   hrr3_build_gp(Libr12->ShellQuartet.CD,int_stack+1749, int_stack+225, int_stack+90, 6);
 /*--- compute (d0|fd) ---*/
   hrr3_build_fd(Libr12->ShellQuartet.CD,int_stack+2019, int_stack+1749, int_stack+1569, 6);
 /*--- compute (p0|hp) ---*/
   hrr3_build_hp(Libr12->ShellQuartet.CD,int_stack+2379, int_stack+1080, int_stack+1017, 3);
 /*--- compute (p0|gd) ---*/
   hrr3_build_gd(Libr12->ShellQuartet.CD,int_stack+2568, int_stack+2379, int_stack+1254, 3);
 /*--- compute (p0|[r12,T2]|fp) ---*/
   t2hrr3_build_fp(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+2838, int_stack+180, int_stack+60, int_stack+972, int_stack+0, int_stack+942, 1, 0);
 /*--- compute (p0|[r12,T2]|gp) ---*/
   t2hrr3_build_gp(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+2928, int_stack+351, int_stack+180, int_stack+1017, int_stack+90, int_stack+972, 1, 0);
 /*--- compute (p0|[r12,T2]|fd) ---*/
   t2hrr3_build_fd(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+0, int_stack+2928, int_stack+2838, int_stack+1254, int_stack+1569, int_stack+1164, 1, 0);
 /*--- compute (p0|[r12,T2]|hp) ---*/
   t2hrr3_build_hp(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+3063, int_stack+414, int_stack+351, int_stack+1080, int_stack+225, int_stack+1017, 1, 0);
 /*--- compute (p0|[r12,T2]|gd) ---*/
   t2hrr3_build_gd(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+942, int_stack+3063, int_stack+2928, int_stack+2379, int_stack+1749, int_stack+1254, 1, 0);
 /*--- compute (p0|[r12,T1]|fp) ---*/
   hrr3_build_fp(Libr12->ShellQuartet.CD,int_stack+2379, int_stack+528, int_stack+498, 3);
 /*--- compute (p0|[r12,T1]|gp) ---*/
   hrr3_build_gp(Libr12->ShellQuartet.CD,int_stack+1569, int_stack+573, int_stack+528, 3);
 /*--- compute (p0|[r12,T1]|fd) ---*/
   hrr3_build_fd(Libr12->ShellQuartet.CD,int_stack+1704, int_stack+1569, int_stack+2379, 3);
 /*--- compute (p0|[r12,T1]|hp) ---*/
   hrr3_build_hp(Libr12->ShellQuartet.CD,int_stack+2379, int_stack+636, int_stack+573, 3);
 /*--- compute (p0|[r12,T1]|gd) ---*/
   hrr3_build_gd(Libr12->ShellQuartet.CD,int_stack+2838, int_stack+2379, int_stack+1569, 3);
 /*--- compute (p0||fp) ---*/
   hrr3_build_fp(Libr12->ShellQuartet.CD,int_stack+1569, int_stack+750, int_stack+720, 3);
 /*--- compute (p0||gp) ---*/
   hrr3_build_gp(Libr12->ShellQuartet.CD,int_stack+1884, int_stack+795, int_stack+750, 3);
 /*--- compute (p0||fd) ---*/
   hrr3_build_fd(Libr12->ShellQuartet.CD,int_stack+2379, int_stack+1884, int_stack+1569, 3);
 /*--- compute (p0||hp) ---*/
   hrr3_build_hp(Libr12->ShellQuartet.CD,int_stack+3108, int_stack+858, int_stack+795, 3);
 /*--- compute (p0||gd) ---*/
   hrr3_build_gd(Libr12->ShellQuartet.CD,int_stack+3297, int_stack+3108, int_stack+1884, 3);
 /*--- compute (p0|[r12,T2]|ff) ---*/
   t2hrr3_build_ff(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+3567, int_stack+942, int_stack+0, int_stack+2568, int_stack+2019, int_stack+1389, 1, 0);
     Libr12->te_ptr[3] = int_stack + 3567;
 /*--- compute (p0|[r12,T1]|ff) ---*/
   hrr3_build_ff(Libr12->ShellQuartet.CD,int_stack+0, int_stack+2838, int_stack+1704, 3);
     Libr12->te_ptr[2] = int_stack + 0;
 /*--- compute (p0||ff) ---*/
   hrr3_build_ff(Libr12->ShellQuartet.CD,int_stack+2838, int_stack+3297, int_stack+2379, 3);
     Libr12->te_ptr[1] = int_stack + 2838;
 /*--- compute (p0|ff) ---*/
   hrr3_build_ff(Libr12->ShellQuartet.CD,int_stack+3138, int_stack+2568, int_stack+1389, 3);
     Libr12->te_ptr[0] = int_stack + 3138;

}
