/*
 *  Copyright (C) 1996-2017 Edward F. Valeev and Justin T. Fermann
 *
 *  This file is part of Libint.
 *
 *  Libint is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU Lesser General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  Libint is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public License
 *  along with Libint.  If not, see <http://www.gnu.org/licenses/>.
 *
 */

#include <stdio.h>
#include <string.h>
#include <libint/libint.h>
#include "libr12.h"
#include <libint/hrr_header.h>

#include "r12_hrr_header.h"

extern void vrr_grt_order_ppdd(Libr12_t *, prim_data *);

  /* Computes (pp|dd) integrals for linear R12-methods */

void hrr_grt_order_ppdd(Libr12_t *Libr12, int num_prim_comb)
{
 prim_data *Data = Libr12->PrimQuartet;
 REALTYPE *int_stack = Libr12->int_stack;
 int i,j;
 REALTYPE tmp, *target;

 Libr12->t2vrr_classes[1][2] = int_stack + 0;
 Libr12->t2vrr_classes[1][3] = int_stack + 18;
 Libr12->t2vrr_classes[1][4] = int_stack + 48;
 Libr12->gvrr_classes[3][2] = int_stack + 93;
 Libr12->t2vrr_classes[2][2] = int_stack + 153;
 Libr12->gvrr_classes[3][3] = int_stack + 189;
 Libr12->t2vrr_classes[2][3] = int_stack + 289;
 Libr12->t2vrr_classes[2][4] = int_stack + 349;
 Libr12->gvrr_classes[1][5] = int_stack + 439;
 Libr12->t1vrr_classes[1][2] = int_stack + 502;
 Libr12->t1vrr_classes[1][3] = int_stack + 520;
 Libr12->t1vrr_classes[1][4] = int_stack + 550;
 Libr12->t1vrr_classes[2][2] = int_stack + 595;
 Libr12->t1vrr_classes[2][3] = int_stack + 631;
 Libr12->t1vrr_classes[2][4] = int_stack + 691;
 Libr12->rvrr_classes[1][2] = int_stack + 781;
 Libr12->rvrr_classes[1][3] = int_stack + 799;
 Libr12->rvrr_classes[1][4] = int_stack + 829;
 Libr12->rvrr_classes[2][2] = int_stack + 874;
 Libr12->rvrr_classes[2][3] = int_stack + 910;
 Libr12->rvrr_classes[2][4] = int_stack + 970;
 Libr12->gvrr_classes[1][2] = int_stack + 1060;
 Libr12->gvrr_classes[1][3] = int_stack + 1078;
 Libr12->gvrr_classes[1][4] = int_stack + 1108;
 Libr12->gvrr_classes[2][2] = int_stack + 1153;
 Libr12->gvrr_classes[2][3] = int_stack + 1189;
 Libr12->gvrr_classes[2][4] = int_stack + 1249;
 memset(int_stack,0,1339*sizeof(REALTYPE));

 Libr12->r12vrr_stack = int_stack + 1339;
 for(i=0;i<num_prim_comb;i++) {
   vrr_grt_order_ppdd(Libr12, Data);
   Data++;
 }

 /*--- compute (p0|dp) ---*/
   hrr3_build_dp(Libr12->ShellQuartet.CD,int_stack+1339, int_stack+1078, int_stack+1060, 3);
 /*--- compute (d0|dp) ---*/
   hrr3_build_dp(Libr12->ShellQuartet.CD,int_stack+1393, int_stack+1189, int_stack+1153, 6);
 /*--- compute (p0|fp) ---*/
   hrr3_build_fp(Libr12->ShellQuartet.CD,int_stack+1501, int_stack+1108, int_stack+1078, 3);
 /*--- compute (p0|[r12,T2]|dp) ---*/
   t2hrr3_build_dp(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+1591, int_stack+18, int_stack+0, int_stack+1078, int_stack+1153, int_stack+1060, 1, 0);
 /*--- compute (p0|[r12,T2]|fp) ---*/
   t2hrr3_build_fp(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+1645, int_stack+48, int_stack+18, int_stack+1108, int_stack+1189, int_stack+1078, 1, 0);
 /*--- compute (p0|[r12,T2]|dd) ---*/
   t2hrr3_build_dd(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+1735, int_stack+1645, int_stack+1591, int_stack+1501, int_stack+1393, int_stack+1339, 1, 0);
 /*--- compute (f0|dp) ---*/
   hrr3_build_dp(Libr12->ShellQuartet.CD,int_stack+1843, int_stack+189, int_stack+93, 10);
 /*--- compute (d0|fp) ---*/
   hrr3_build_fp(Libr12->ShellQuartet.CD,int_stack+2023, int_stack+1249, int_stack+1189, 6);
 /*--- compute (d0|[r12,T2]|dp) ---*/
   t2hrr3_build_dp(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+1591, int_stack+289, int_stack+153, int_stack+1189, int_stack+93, int_stack+1153, 2, 0);
 /*--- compute (d0|[r12,T2]|fp) ---*/
   t2hrr3_build_fp(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+0, int_stack+349, int_stack+289, int_stack+1249, int_stack+189, int_stack+1189, 2, 0);
 /*--- compute (d0|[r12,T2]|dd) ---*/
   t2hrr3_build_dd(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+180, int_stack+0, int_stack+1591, int_stack+2023, int_stack+1843, int_stack+1393, 2, 0);
 /*--- compute (p0|dd) ---*/
   hrr3_build_dd(Libr12->ShellQuartet.CD,int_stack+1843, int_stack+1501, int_stack+1339, 3);
 /*--- compute (p0|gp) ---*/
   hrr3_build_gp(Libr12->ShellQuartet.CD,int_stack+1591, int_stack+439, int_stack+1108, 3);
 /*--- compute (p0|fd) ---*/
   hrr3_build_fd(Libr12->ShellQuartet.CD,int_stack+0, int_stack+1591, int_stack+1501, 3);
 /*--- compute (d0|dd) ---*/
   hrr3_build_dd(Libr12->ShellQuartet.CD,int_stack+1501, int_stack+2023, int_stack+1393, 6);
 /*--- compute (p0|[r12,T1]|dp) ---*/
   hrr3_build_dp(Libr12->ShellQuartet.CD,int_stack+1951, int_stack+520, int_stack+502, 3);
 /*--- compute (p0|[r12,T1]|fp) ---*/
   hrr3_build_fp(Libr12->ShellQuartet.CD,int_stack+2005, int_stack+550, int_stack+520, 3);
 /*--- compute (p0|[r12,T1]|dd) ---*/
   hrr3_build_dd(Libr12->ShellQuartet.CD,int_stack+2095, int_stack+2005, int_stack+1951, 3);
 /*--- compute (d0|[r12,T1]|dp) ---*/
   hrr3_build_dp(Libr12->ShellQuartet.CD,int_stack+1951, int_stack+631, int_stack+595, 6);
 /*--- compute (d0|[r12,T1]|fp) ---*/
   hrr3_build_fp(Libr12->ShellQuartet.CD,int_stack+2203, int_stack+691, int_stack+631, 6);
 /*--- compute (d0|[r12,T1]|dd) ---*/
   hrr3_build_dd(Libr12->ShellQuartet.CD,int_stack+2383, int_stack+2203, int_stack+1951, 6);
 /*--- compute (p0||dp) ---*/
   hrr3_build_dp(Libr12->ShellQuartet.CD,int_stack+1951, int_stack+799, int_stack+781, 3);
 /*--- compute (p0||fp) ---*/
   hrr3_build_fp(Libr12->ShellQuartet.CD,int_stack+2005, int_stack+829, int_stack+799, 3);
 /*--- compute (p0||dd) ---*/
   hrr3_build_dd(Libr12->ShellQuartet.CD,int_stack+2203, int_stack+2005, int_stack+1951, 3);
 /*--- compute (d0||dp) ---*/
   hrr3_build_dp(Libr12->ShellQuartet.CD,int_stack+1951, int_stack+910, int_stack+874, 6);
 /*--- compute (d0||fp) ---*/
   hrr3_build_fp(Libr12->ShellQuartet.CD,int_stack+2599, int_stack+970, int_stack+910, 6);
 /*--- compute (d0||dd) ---*/
   hrr3_build_dd(Libr12->ShellQuartet.CD,int_stack+2779, int_stack+2599, int_stack+1951, 6);
 /*--- compute (pp|[r12,T2]|dd) ---*/
   hrr1_build_pp(Libr12->ShellQuartet.AB,int_stack+396, int_stack+180, int_stack+1735, 36);
     Libr12->te_ptr[3] = int_stack + 396;
 /*--- compute (pp|[r12,T1]|dd) ---*/
   t1hrr1_build_pp(Libr12->ShellQuartet.AB,Libr12->ShellQuartet.AC,int_stack+720, int_stack+2383, int_stack+2095, int_stack+1501, int_stack+0, int_stack+1843, 2, 2);
     Libr12->te_ptr[2] = int_stack + 720;
 /*--- compute (pp||dd) ---*/
   hrr1_build_pp(Libr12->ShellQuartet.AB,int_stack+0, int_stack+2779, int_stack+2203, 36);
     Libr12->te_ptr[1] = int_stack + 0;
 /*--- compute (pp|dd) ---*/
   hrr1_build_pp(Libr12->ShellQuartet.AB,int_stack+1951, int_stack+1501, int_stack+1843, 36);
     Libr12->te_ptr[0] = int_stack + 1951;

}
