/*
 *  Copyright (C) 1996-2017 Edward F. Valeev and Justin T. Fermann
 *
 *  This file is part of Libint.
 *
 *  Libint is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU Lesser General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  Libint is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public License
 *  along with Libint.  If not, see <http://www.gnu.org/licenses/>.
 *
 */

#include <stdio.h>
#include <libint/libint.h>
#include "libr12.h"
#include <libint/vrr_header.h>
#include "r12_vrr_header.h"

void vrr_grt_order_dpg0(Libr12_t *Libr12, prim_data *Data)
{
 REALTYPE *r12vrr_stack = Libr12->r12vrr_stack;
 REALTYPE *tmp, *target_ptr;
 int i, am[2];

 /*--- compute (00|p0)^2 ---*/
 _BUILD_00p0(Data,r12vrr_stack+0, Data->F+2, Data->F+3, NULL, NULL, NULL);

 /*--- compute (00|p0)^3 ---*/
 _BUILD_00p0(Data,r12vrr_stack+3, Data->F+3, Data->F+4, NULL, NULL, NULL);

 /*--- compute (00|d0)^2 ---*/
 _BUILD_00d0(Data,r12vrr_stack+6, r12vrr_stack+0, r12vrr_stack+3, Data->F+2, Data->F+3, NULL);

 /*--- compute (00|p0)^1 ---*/
 _BUILD_00p0(Data,r12vrr_stack+12, Data->F+1, Data->F+2, NULL, NULL, NULL);

 /*--- compute (00|d0)^1 ---*/
 _BUILD_00d0(Data,r12vrr_stack+15, r12vrr_stack+12, r12vrr_stack+0, Data->F+1, Data->F+2, NULL);

 /*--- compute (p0|d0)^1 ---*/
 _BUILD_p0d0(Data,r12vrr_stack+21, r12vrr_stack+15, r12vrr_stack+6, NULL, NULL, r12vrr_stack+0);

 /*--- compute (00|f0)^1 ---*/
 _BUILD_00f0(Data,r12vrr_stack+39, r12vrr_stack+15, r12vrr_stack+6, r12vrr_stack+12, r12vrr_stack+0, NULL);

 /*--- compute (00|p0)^0 ---*/
 _BUILD_00p0(Data,r12vrr_stack+49, Data->F+0, Data->F+1, NULL, NULL, NULL);

 /*--- compute (00|d0)^0 ---*/
 _BUILD_00d0(Data,r12vrr_stack+52, r12vrr_stack+49, r12vrr_stack+12, Data->F+0, Data->F+1, NULL);

 /*--- compute (00|f0)^0 ---*/
 _BUILD_00f0(Data,r12vrr_stack+58, r12vrr_stack+52, r12vrr_stack+15, r12vrr_stack+49, r12vrr_stack+12, NULL);

 /*--- compute (00|p0)^4 ---*/
 _BUILD_00p0(Data,r12vrr_stack+12, Data->F+4, Data->F+5, NULL, NULL, NULL);

 /*--- compute (00|d0)^3 ---*/
 _BUILD_00d0(Data,r12vrr_stack+68, r12vrr_stack+3, r12vrr_stack+12, Data->F+3, Data->F+4, NULL);

 /*--- compute (00|f0)^2 ---*/
 _BUILD_00f0(Data,r12vrr_stack+74, r12vrr_stack+6, r12vrr_stack+68, r12vrr_stack+0, r12vrr_stack+3, NULL);

 /*--- compute (p0|f0)^1 ---*/
 _BUILD_p0f0(Data,r12vrr_stack+84, r12vrr_stack+39, r12vrr_stack+74, NULL, NULL, r12vrr_stack+6);

 /*--- compute (p0|f0)^0 ---*/
 _BUILD_p0f0(Data,r12vrr_stack+114, r12vrr_stack+58, r12vrr_stack+39, NULL, NULL, r12vrr_stack+15);

 /*--- compute (d0|f0)^0 ---*/
 _BUILD_d0f0(Data,r12vrr_stack+144, r12vrr_stack+114, r12vrr_stack+84, r12vrr_stack+58, r12vrr_stack+39, r12vrr_stack+21);

 /*--- compute (p0|p0)^2 ---*/
 _BUILD_p0p0(Data,r12vrr_stack+204, r12vrr_stack+0, r12vrr_stack+3, NULL, NULL, Data->F+3);

 /*--- compute (p0|d0)^2 ---*/
 _BUILD_p0d0(Data,r12vrr_stack+213, r12vrr_stack+6, r12vrr_stack+68, NULL, NULL, r12vrr_stack+3);

 /*--- compute (d0|d0)^1 ---*/
 _BUILD_d0d0(Data,r12vrr_stack+231, r12vrr_stack+21, r12vrr_stack+213, r12vrr_stack+15, r12vrr_stack+6, r12vrr_stack+204);

 /*--- compute (00|p0)^5 ---*/
 _BUILD_00p0(Data,r12vrr_stack+267, Data->F+5, Data->F+6, NULL, NULL, NULL);

 /*--- compute (00|d0)^4 ---*/
 _BUILD_00d0(Data,r12vrr_stack+270, r12vrr_stack+12, r12vrr_stack+267, Data->F+4, Data->F+5, NULL);

 /*--- compute (00|f0)^3 ---*/
 _BUILD_00f0(Data,r12vrr_stack+276, r12vrr_stack+68, r12vrr_stack+270, r12vrr_stack+3, r12vrr_stack+12, NULL);

 /*--- compute (p0|f0)^2 ---*/
 _BUILD_p0f0(Data,r12vrr_stack+286, r12vrr_stack+74, r12vrr_stack+276, NULL, NULL, r12vrr_stack+68);

 /*--- compute (d0|f0)^1 ---*/
 _BUILD_d0f0(Data,r12vrr_stack+316, r12vrr_stack+84, r12vrr_stack+286, r12vrr_stack+39, r12vrr_stack+74, r12vrr_stack+213);

 /*--- compute (f0|f0)^0 ---*/
 _BUILD_f0f0(Data,r12vrr_stack+376, r12vrr_stack+144, r12vrr_stack+316, r12vrr_stack+114, r12vrr_stack+84, r12vrr_stack+231);

 /*--- compute (00|g0)^2 ---*/
 _BUILD_00g0(Data,r12vrr_stack+476, r12vrr_stack+74, r12vrr_stack+276, r12vrr_stack+6, r12vrr_stack+68, NULL);

 /*--- compute (00|g0)^1 ---*/
 _BUILD_00g0(Data,r12vrr_stack+491, r12vrr_stack+39, r12vrr_stack+74, r12vrr_stack+15, r12vrr_stack+6, NULL);

 /*--- compute (p0|g0)^1 ---*/
 _BUILD_p0g0(Data,r12vrr_stack+506, r12vrr_stack+491, r12vrr_stack+476, NULL, NULL, r12vrr_stack+74);

 /*--- compute (00|g0)^0 ---*/
 _BUILD_00g0(Data,r12vrr_stack+551, r12vrr_stack+58, r12vrr_stack+39, r12vrr_stack+52, r12vrr_stack+15, NULL);

 /*--- compute (p0|g0)^0 ---*/
 _BUILD_p0g0(Data,r12vrr_stack+566, r12vrr_stack+551, r12vrr_stack+491, NULL, NULL, r12vrr_stack+39);

 /*--- compute (00|p0)^6 ---*/
 _BUILD_00p0(Data,r12vrr_stack+15, Data->F+6, Data->F+7, NULL, NULL, NULL);

 /*--- compute (00|d0)^5 ---*/
 _BUILD_00d0(Data,r12vrr_stack+611, r12vrr_stack+267, r12vrr_stack+15, Data->F+5, Data->F+6, NULL);

 /*--- compute (00|f0)^4 ---*/
 _BUILD_00f0(Data,r12vrr_stack+617, r12vrr_stack+270, r12vrr_stack+611, r12vrr_stack+12, r12vrr_stack+267, NULL);

 /*--- compute (00|g0)^3 ---*/
 _BUILD_00g0(Data,r12vrr_stack+627, r12vrr_stack+276, r12vrr_stack+617, r12vrr_stack+68, r12vrr_stack+270, NULL);

 /*--- compute (p0|g0)^2 ---*/
 _BUILD_p0g0(Data,r12vrr_stack+642, r12vrr_stack+476, r12vrr_stack+627, NULL, NULL, r12vrr_stack+276);

 /*--- compute (d0|g0)^1 ---*/
 _BUILD_d0g0(Data,r12vrr_stack+687, r12vrr_stack+506, r12vrr_stack+642, r12vrr_stack+491, r12vrr_stack+476, r12vrr_stack+286);

 /*--- compute (d0|g0)^0 ---*/
 _BUILD_d0g0(Data,r12vrr_stack+777, r12vrr_stack+566, r12vrr_stack+506, r12vrr_stack+551, r12vrr_stack+491, r12vrr_stack+84);
 tmp = r12vrr_stack + 777;
 target_ptr = Libr12->gvrr_classes[2][4];
 for(i=0;i<90;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (f0|g0)^0 ---*/
 _BUILD_f0g0(Data,r12vrr_stack+867, r12vrr_stack+777, r12vrr_stack+687, r12vrr_stack+566, r12vrr_stack+506, r12vrr_stack+316);
 tmp = r12vrr_stack + 867;
 target_ptr = Libr12->gvrr_classes[3][4];
 for(i=0;i<150;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (00|h0)^1 ---*/
 _BUILD_00h0(Data,r12vrr_stack+1017, r12vrr_stack+491, r12vrr_stack+476, r12vrr_stack+39, r12vrr_stack+74, NULL);

 /*--- compute (00|h0)^0 ---*/
 _BUILD_00h0(Data,r12vrr_stack+1038, r12vrr_stack+551, r12vrr_stack+491, r12vrr_stack+58, r12vrr_stack+39, NULL);

 /*--- compute (00|h0)^2 ---*/
 _BUILD_00h0(Data,r12vrr_stack+1059, r12vrr_stack+476, r12vrr_stack+627, r12vrr_stack+74, r12vrr_stack+276, NULL);

 /*--- compute (p0|h0)^1 ---*/
 _BUILD_p0h0(Data,r12vrr_stack+1080, r12vrr_stack+1017, r12vrr_stack+1059, NULL, NULL, r12vrr_stack+476);

 /*--- compute (p0|h0)^0 ---*/
 _BUILD_p0h0(Data,r12vrr_stack+1143, r12vrr_stack+1038, r12vrr_stack+1017, NULL, NULL, r12vrr_stack+491);

 /*--- compute (d0|h0)^0 ---*/
 _BUILD_d0h0(Data,r12vrr_stack+1206, r12vrr_stack+1143, r12vrr_stack+1080, r12vrr_stack+1038, r12vrr_stack+1017, r12vrr_stack+506);
 tmp = r12vrr_stack + 1206;
 target_ptr = Libr12->gvrr_classes[2][5];
 for(i=0;i<126;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (p0|00)^3 ---*/
 _BUILD_p000(Data,r12vrr_stack+18, Data->F+3, Data->F+4, NULL, NULL, NULL);

 /*--- compute (p0|p0)^3 ---*/
 _BUILD_p0p0(Data,r12vrr_stack+1038, r12vrr_stack+3, r12vrr_stack+12, NULL, NULL, Data->F+4);

 /*--- compute (d0|p0)^2 ---*/
 _BUILD_d0p0(Data,r12vrr_stack+1332, r12vrr_stack+204, r12vrr_stack+1038, r12vrr_stack+0, r12vrr_stack+3, r12vrr_stack+18);

 /*--- compute (p0|d0)^3 ---*/
 _BUILD_p0d0(Data,r12vrr_stack+1350, r12vrr_stack+68, r12vrr_stack+270, NULL, NULL, r12vrr_stack+12);

 /*--- compute (d0|d0)^2 ---*/
 _BUILD_d0d0(Data,r12vrr_stack+1368, r12vrr_stack+213, r12vrr_stack+1350, r12vrr_stack+6, r12vrr_stack+68, r12vrr_stack+1038);

 /*--- compute (f0|d0)^1 ---*/
 _BUILD_f0d0(Data,r12vrr_stack+1404, r12vrr_stack+231, r12vrr_stack+1368, r12vrr_stack+21, r12vrr_stack+213, r12vrr_stack+1332);

 /*--- compute (p0|f0)^3 ---*/
 _BUILD_p0f0(Data,r12vrr_stack+18, r12vrr_stack+276, r12vrr_stack+617, NULL, NULL, r12vrr_stack+270);

 /*--- compute (d0|f0)^2 ---*/
 _BUILD_d0f0(Data,r12vrr_stack+204, r12vrr_stack+286, r12vrr_stack+18, r12vrr_stack+74, r12vrr_stack+276, r12vrr_stack+1350);

 /*--- compute (f0|f0)^1 ---*/
 _BUILD_f0f0(Data,r12vrr_stack+1464, r12vrr_stack+316, r12vrr_stack+204, r12vrr_stack+84, r12vrr_stack+286, r12vrr_stack+1368);

 /*--- compute (g0|f0)^0 ---*/
 _BUILD_g0f0(Data,r12vrr_stack+1564, r12vrr_stack+376, r12vrr_stack+1464, r12vrr_stack+144, r12vrr_stack+316, r12vrr_stack+1404);

 /*--- compute (00|p0)^7 ---*/
 _BUILD_00p0(Data,r12vrr_stack+264, Data->F+7, Data->F+8, NULL, NULL, NULL);

 /*--- compute (00|d0)^6 ---*/
 _BUILD_00d0(Data,r12vrr_stack+286, r12vrr_stack+15, r12vrr_stack+264, Data->F+6, Data->F+7, NULL);

 /*--- compute (00|f0)^5 ---*/
 _BUILD_00f0(Data,r12vrr_stack+292, r12vrr_stack+611, r12vrr_stack+286, r12vrr_stack+267, r12vrr_stack+15, NULL);

 /*--- compute (00|g0)^4 ---*/
 _BUILD_00g0(Data,r12vrr_stack+491, r12vrr_stack+617, r12vrr_stack+292, r12vrr_stack+270, r12vrr_stack+611, NULL);

 /*--- compute (p0|g0)^3 ---*/
 _BUILD_p0g0(Data,r12vrr_stack+286, r12vrr_stack+627, r12vrr_stack+491, NULL, NULL, r12vrr_stack+617);

 /*--- compute (d0|g0)^2 ---*/
 _BUILD_d0g0(Data,r12vrr_stack+1332, r12vrr_stack+642, r12vrr_stack+286, r12vrr_stack+476, r12vrr_stack+627, r12vrr_stack+18);

 /*--- compute (f0|g0)^1 ---*/
 _BUILD_f0g0(Data,r12vrr_stack+1714, r12vrr_stack+687, r12vrr_stack+1332, r12vrr_stack+506, r12vrr_stack+642, r12vrr_stack+204);

 /*--- compute (g0|g0)^0 ---*/
 _BUILD_g0g0(Data,r12vrr_stack+1864, r12vrr_stack+867, r12vrr_stack+1714, r12vrr_stack+777, r12vrr_stack+687, r12vrr_stack+1464);

 /*--- compute (00|h0)^3 ---*/
 _BUILD_00h0(Data,r12vrr_stack+1038, r12vrr_stack+627, r12vrr_stack+491, r12vrr_stack+276, r12vrr_stack+617, NULL);

 /*--- compute (p0|h0)^2 ---*/
 _BUILD_p0h0(Data,r12vrr_stack+1714, r12vrr_stack+1059, r12vrr_stack+1038, NULL, NULL, r12vrr_stack+627);

 /*--- compute (d0|h0)^1 ---*/
 _BUILD_d0h0(Data,r12vrr_stack+204, r12vrr_stack+1080, r12vrr_stack+1714, r12vrr_stack+1017, r12vrr_stack+1059, r12vrr_stack+642);

 /*--- compute (f0|h0)^0 ---*/
 _BUILD_f0h0(Data,r12vrr_stack+1332, r12vrr_stack+1206, r12vrr_stack+204, r12vrr_stack+1143, r12vrr_stack+1080, r12vrr_stack+687);

 /*--- compute (00||p0)^0 ---*/
 _R_BUILD_00p0(Data,r12vrr_stack+204, &(Data->ss_r12_ss), NULL, r12vrr_stack+49, Data->F+0, NULL, NULL);

 /*--- compute (00||d0)^0 ---*/
 _R_BUILD_00d0(Data,r12vrr_stack+207, r12vrr_stack+204, &(Data->ss_r12_ss), r12vrr_stack+52, r12vrr_stack+49, Data->F+0, NULL);

 /*--- compute (00||f0)^0 ---*/
 _R_BUILD_00f0(Data,r12vrr_stack+213, r12vrr_stack+207, r12vrr_stack+204, r12vrr_stack+58, r12vrr_stack+52, r12vrr_stack+49, NULL);

 /*--- compute (00||g0)^0 ---*/
 _R_BUILD_00g0(Data,r12vrr_stack+223, r12vrr_stack+213, r12vrr_stack+207, r12vrr_stack+551, r12vrr_stack+58, r12vrr_stack+52, NULL);

 /*--- compute (p0||g0)^0 ---*/
 _R_BUILD_p0g0(Data,r12vrr_stack+238, r12vrr_stack+223, NULL, r12vrr_stack+566, r12vrr_stack+551, NULL, r12vrr_stack+58);

 /*--- compute (d0||g0)^0 ---*/
 _R_BUILD_d0g0(Data,r12vrr_stack+283, r12vrr_stack+238, r12vrr_stack+223, r12vrr_stack+777, r12vrr_stack+566, r12vrr_stack+551, r12vrr_stack+114);
 tmp = r12vrr_stack + 283;
 target_ptr = Libr12->rvrr_classes[2][4];
 for(i=0;i<90;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (d0|[r12,T2]|g0)^0 ---*/
 _T2_BUILD_d0g0(Data,&(Libr12->ShellQuartet),r12vrr_stack+476, r12vrr_stack+777, r12vrr_stack+1206, r12vrr_stack+867, r12vrr_stack+376, r12vrr_stack+144);
 tmp = r12vrr_stack + 476;
 target_ptr = Libr12->t2vrr_classes[2][4];
 for(i=0;i<90;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (f0|[r12,T2]|g0)^0 ---*/
 _T2_BUILD_f0g0(Data,&(Libr12->ShellQuartet),r12vrr_stack+1714, r12vrr_stack+867, r12vrr_stack+1332, r12vrr_stack+1864, r12vrr_stack+1564, r12vrr_stack+376);
 tmp = r12vrr_stack + 1714;
 target_ptr = Libr12->t2vrr_classes[3][4];
 for(i=0;i<150;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (d0|[r12,T1]|g0)^0 ---*/
 _T1_BUILD_d0g0(Data,&(Libr12->ShellQuartet),r12vrr_stack+373, r12vrr_stack+777, r12vrr_stack+867, r12vrr_stack+1206, r12vrr_stack+1143, r12vrr_stack+566);
 tmp = r12vrr_stack + 373;
 target_ptr = Libr12->t1vrr_classes[2][4];
 for(i=0;i<90;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (f0|[r12,T1]|g0)^0 ---*/
 _T1_BUILD_f0g0(Data,&(Libr12->ShellQuartet),r12vrr_stack+1017, r12vrr_stack+867, r12vrr_stack+1864, r12vrr_stack+1332, r12vrr_stack+1206, r12vrr_stack+777);
 tmp = r12vrr_stack + 1017;
 target_ptr = Libr12->t1vrr_classes[3][4];
 for(i=0;i<150;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (f0||g0)^0 ---*/
 _R_BUILD_f0g0(Data,r12vrr_stack+1864, r12vrr_stack+283, r12vrr_stack+238, r12vrr_stack+867, r12vrr_stack+777, r12vrr_stack+566, r12vrr_stack+144);
 tmp = r12vrr_stack + 1864;
 target_ptr = Libr12->rvrr_classes[3][4];
 for(i=0;i<150;i++)
   target_ptr[i] += tmp[i];


}

