/*
 *  Copyright (C) 1996-2017 Edward F. Valeev and Justin T. Fermann
 *
 *  This file is part of Libint.
 *
 *  Libint is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU Lesser General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  Libint is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public License
 *  along with Libint.  If not, see <http://www.gnu.org/licenses/>.
 *
 */

#include <stdio.h>
#include <libint/libint.h>
#include "libr12.h"
#include <libint/vrr_header.h>
#include "r12_vrr_header.h"

void vrr_grt_order_gfhf(Libr12_t *Libr12, prim_data *Data)
{
 REALTYPE *r12vrr_stack = Libr12->r12vrr_stack;
 REALTYPE *tmp, *target_ptr;
 int i, am[2];

 /*--- compute (00|p0)^4 ---*/
 _BUILD_00p0(Data,r12vrr_stack+0, Data->F+4, Data->F+5, NULL, NULL, NULL);

 /*--- compute (00|p0)^3 ---*/
 _BUILD_00p0(Data,r12vrr_stack+3, Data->F+3, Data->F+4, NULL, NULL, NULL);

 /*--- compute (p0|p0)^3 ---*/
 _BUILD_p0p0(Data,r12vrr_stack+6, r12vrr_stack+3, r12vrr_stack+0, NULL, NULL, Data->F+4);

 /*--- compute (00|d0)^3 ---*/
 _BUILD_00d0(Data,r12vrr_stack+15, r12vrr_stack+3, r12vrr_stack+0, Data->F+3, Data->F+4, NULL);

 /*--- compute (00|p0)^2 ---*/
 _BUILD_00p0(Data,r12vrr_stack+21, Data->F+2, Data->F+3, NULL, NULL, NULL);

 /*--- compute (00|d0)^2 ---*/
 _BUILD_00d0(Data,r12vrr_stack+24, r12vrr_stack+21, r12vrr_stack+3, Data->F+2, Data->F+3, NULL);

 /*--- compute (00|p0)^5 ---*/
 _BUILD_00p0(Data,r12vrr_stack+30, Data->F+5, Data->F+6, NULL, NULL, NULL);

 /*--- compute (00|d0)^4 ---*/
 _BUILD_00d0(Data,r12vrr_stack+33, r12vrr_stack+0, r12vrr_stack+30, Data->F+4, Data->F+5, NULL);

 /*--- compute (p0|d0)^3 ---*/
 _BUILD_p0d0(Data,r12vrr_stack+39, r12vrr_stack+15, r12vrr_stack+33, NULL, NULL, r12vrr_stack+0);

 /*--- compute (p0|d0)^2 ---*/
 _BUILD_p0d0(Data,r12vrr_stack+57, r12vrr_stack+24, r12vrr_stack+15, NULL, NULL, r12vrr_stack+3);

 /*--- compute (d0|d0)^2 ---*/
 _BUILD_d0d0(Data,r12vrr_stack+75, r12vrr_stack+57, r12vrr_stack+39, r12vrr_stack+24, r12vrr_stack+15, r12vrr_stack+6);

 /*--- compute (00|f0)^3 ---*/
 _BUILD_00f0(Data,r12vrr_stack+111, r12vrr_stack+15, r12vrr_stack+33, r12vrr_stack+3, r12vrr_stack+0, NULL);

 /*--- compute (00|f0)^2 ---*/
 _BUILD_00f0(Data,r12vrr_stack+121, r12vrr_stack+24, r12vrr_stack+15, r12vrr_stack+21, r12vrr_stack+3, NULL);

 /*--- compute (p0|f0)^2 ---*/
 _BUILD_p0f0(Data,r12vrr_stack+131, r12vrr_stack+121, r12vrr_stack+111, NULL, NULL, r12vrr_stack+15);

 /*--- compute (00|p0)^1 ---*/
 _BUILD_00p0(Data,r12vrr_stack+161, Data->F+1, Data->F+2, NULL, NULL, NULL);

 /*--- compute (00|d0)^1 ---*/
 _BUILD_00d0(Data,r12vrr_stack+164, r12vrr_stack+161, r12vrr_stack+21, Data->F+1, Data->F+2, NULL);

 /*--- compute (00|f0)^1 ---*/
 _BUILD_00f0(Data,r12vrr_stack+170, r12vrr_stack+164, r12vrr_stack+24, r12vrr_stack+161, r12vrr_stack+21, NULL);

 /*--- compute (p0|f0)^1 ---*/
 _BUILD_p0f0(Data,r12vrr_stack+180, r12vrr_stack+170, r12vrr_stack+121, NULL, NULL, r12vrr_stack+24);

 /*--- compute (00|p0)^6 ---*/
 _BUILD_00p0(Data,r12vrr_stack+21, Data->F+6, Data->F+7, NULL, NULL, NULL);

 /*--- compute (00|d0)^5 ---*/
 _BUILD_00d0(Data,r12vrr_stack+210, r12vrr_stack+30, r12vrr_stack+21, Data->F+5, Data->F+6, NULL);

 /*--- compute (00|f0)^4 ---*/
 _BUILD_00f0(Data,r12vrr_stack+216, r12vrr_stack+33, r12vrr_stack+210, r12vrr_stack+0, r12vrr_stack+30, NULL);

 /*--- compute (p0|f0)^3 ---*/
 _BUILD_p0f0(Data,r12vrr_stack+226, r12vrr_stack+111, r12vrr_stack+216, NULL, NULL, r12vrr_stack+33);

 /*--- compute (d0|f0)^2 ---*/
 _BUILD_d0f0(Data,r12vrr_stack+256, r12vrr_stack+131, r12vrr_stack+226, r12vrr_stack+121, r12vrr_stack+111, r12vrr_stack+39);

 /*--- compute (d0|f0)^1 ---*/
 _BUILD_d0f0(Data,r12vrr_stack+316, r12vrr_stack+180, r12vrr_stack+131, r12vrr_stack+170, r12vrr_stack+121, r12vrr_stack+57);

 /*--- compute (f0|f0)^1 ---*/
 _BUILD_f0f0(Data,r12vrr_stack+376, r12vrr_stack+316, r12vrr_stack+256, r12vrr_stack+180, r12vrr_stack+131, r12vrr_stack+75);

 /*--- compute (00|g0)^2 ---*/
 _BUILD_00g0(Data,r12vrr_stack+476, r12vrr_stack+121, r12vrr_stack+111, r12vrr_stack+24, r12vrr_stack+15, NULL);

 /*--- compute (00|g0)^1 ---*/
 _BUILD_00g0(Data,r12vrr_stack+491, r12vrr_stack+170, r12vrr_stack+121, r12vrr_stack+164, r12vrr_stack+24, NULL);

 /*--- compute (00|g0)^3 ---*/
 _BUILD_00g0(Data,r12vrr_stack+506, r12vrr_stack+111, r12vrr_stack+216, r12vrr_stack+15, r12vrr_stack+33, NULL);

 /*--- compute (p0|g0)^2 ---*/
 _BUILD_p0g0(Data,r12vrr_stack+521, r12vrr_stack+476, r12vrr_stack+506, NULL, NULL, r12vrr_stack+111);

 /*--- compute (p0|g0)^1 ---*/
 _BUILD_p0g0(Data,r12vrr_stack+566, r12vrr_stack+491, r12vrr_stack+476, NULL, NULL, r12vrr_stack+121);

 /*--- compute (d0|g0)^1 ---*/
 _BUILD_d0g0(Data,r12vrr_stack+611, r12vrr_stack+566, r12vrr_stack+521, r12vrr_stack+491, r12vrr_stack+476, r12vrr_stack+131);

 /*--- compute (00|p0)^0 ---*/
 _BUILD_00p0(Data,r12vrr_stack+24, Data->F+0, Data->F+1, NULL, NULL, NULL);

 /*--- compute (00|d0)^0 ---*/
 _BUILD_00d0(Data,r12vrr_stack+701, r12vrr_stack+24, r12vrr_stack+161, Data->F+0, Data->F+1, NULL);

 /*--- compute (00|f0)^0 ---*/
 _BUILD_00f0(Data,r12vrr_stack+707, r12vrr_stack+701, r12vrr_stack+164, r12vrr_stack+24, r12vrr_stack+161, NULL);

 /*--- compute (00|g0)^0 ---*/
 _BUILD_00g0(Data,r12vrr_stack+717, r12vrr_stack+707, r12vrr_stack+170, r12vrr_stack+701, r12vrr_stack+164, NULL);

 /*--- compute (p0|g0)^0 ---*/
 _BUILD_p0g0(Data,r12vrr_stack+732, r12vrr_stack+717, r12vrr_stack+491, NULL, NULL, r12vrr_stack+170);

 /*--- compute (d0|g0)^0 ---*/
 _BUILD_d0g0(Data,r12vrr_stack+777, r12vrr_stack+732, r12vrr_stack+566, r12vrr_stack+717, r12vrr_stack+491, r12vrr_stack+180);

 /*--- compute (00|p0)^7 ---*/
 _BUILD_00p0(Data,r12vrr_stack+27, Data->F+7, Data->F+8, NULL, NULL, NULL);

 /*--- compute (00|d0)^6 ---*/
 _BUILD_00d0(Data,r12vrr_stack+180, r12vrr_stack+21, r12vrr_stack+27, Data->F+6, Data->F+7, NULL);

 /*--- compute (00|f0)^5 ---*/
 _BUILD_00f0(Data,r12vrr_stack+186, r12vrr_stack+210, r12vrr_stack+180, r12vrr_stack+30, r12vrr_stack+21, NULL);

 /*--- compute (00|g0)^4 ---*/
 _BUILD_00g0(Data,r12vrr_stack+867, r12vrr_stack+216, r12vrr_stack+186, r12vrr_stack+33, r12vrr_stack+210, NULL);

 /*--- compute (p0|g0)^3 ---*/
 _BUILD_p0g0(Data,r12vrr_stack+882, r12vrr_stack+506, r12vrr_stack+867, NULL, NULL, r12vrr_stack+216);

 /*--- compute (d0|g0)^2 ---*/
 _BUILD_d0g0(Data,r12vrr_stack+927, r12vrr_stack+521, r12vrr_stack+882, r12vrr_stack+476, r12vrr_stack+506, r12vrr_stack+226);

 /*--- compute (f0|g0)^1 ---*/
 _BUILD_f0g0(Data,r12vrr_stack+1017, r12vrr_stack+611, r12vrr_stack+927, r12vrr_stack+566, r12vrr_stack+521, r12vrr_stack+256);

 /*--- compute (f0|g0)^0 ---*/
 _BUILD_f0g0(Data,r12vrr_stack+1167, r12vrr_stack+777, r12vrr_stack+611, r12vrr_stack+732, r12vrr_stack+566, r12vrr_stack+316);

 /*--- compute (g0|g0)^0 ---*/
 _BUILD_g0g0(Data,r12vrr_stack+1317, r12vrr_stack+1167, r12vrr_stack+1017, r12vrr_stack+777, r12vrr_stack+611, r12vrr_stack+376);

 /*--- compute (p0|00)^4 ---*/
 _BUILD_p000(Data,r12vrr_stack+196, Data->F+4, Data->F+5, NULL, NULL, NULL);

 /*--- compute (p0|p0)^4 ---*/
 _BUILD_p0p0(Data,r12vrr_stack+161, r12vrr_stack+0, r12vrr_stack+30, NULL, NULL, Data->F+5);

 /*--- compute (d0|p0)^3 ---*/
 _BUILD_d0p0(Data,r12vrr_stack+1542, r12vrr_stack+6, r12vrr_stack+161, r12vrr_stack+3, r12vrr_stack+0, r12vrr_stack+196);

 /*--- compute (p0|d0)^4 ---*/
 _BUILD_p0d0(Data,r12vrr_stack+1560, r12vrr_stack+33, r12vrr_stack+210, NULL, NULL, r12vrr_stack+30);

 /*--- compute (d0|d0)^3 ---*/
 _BUILD_d0d0(Data,r12vrr_stack+1578, r12vrr_stack+39, r12vrr_stack+1560, r12vrr_stack+15, r12vrr_stack+33, r12vrr_stack+161);

 /*--- compute (f0|d0)^2 ---*/
 _BUILD_f0d0(Data,r12vrr_stack+1614, r12vrr_stack+75, r12vrr_stack+1578, r12vrr_stack+57, r12vrr_stack+39, r12vrr_stack+1542);

 /*--- compute (p0|f0)^4 ---*/
 _BUILD_p0f0(Data,r12vrr_stack+1674, r12vrr_stack+216, r12vrr_stack+186, NULL, NULL, r12vrr_stack+210);

 /*--- compute (d0|f0)^3 ---*/
 _BUILD_d0f0(Data,r12vrr_stack+1704, r12vrr_stack+226, r12vrr_stack+1674, r12vrr_stack+111, r12vrr_stack+216, r12vrr_stack+1560);

 /*--- compute (f0|f0)^2 ---*/
 _BUILD_f0f0(Data,r12vrr_stack+1764, r12vrr_stack+256, r12vrr_stack+1704, r12vrr_stack+131, r12vrr_stack+226, r12vrr_stack+1578);

 /*--- compute (g0|f0)^1 ---*/
 _BUILD_g0f0(Data,r12vrr_stack+1864, r12vrr_stack+376, r12vrr_stack+1764, r12vrr_stack+316, r12vrr_stack+256, r12vrr_stack+1614);

 /*--- compute (00|p0)^8 ---*/
 _BUILD_00p0(Data,r12vrr_stack+3, Data->F+8, Data->F+9, NULL, NULL, NULL);

 /*--- compute (00|d0)^7 ---*/
 _BUILD_00d0(Data,r12vrr_stack+15, r12vrr_stack+27, r12vrr_stack+3, Data->F+7, Data->F+8, NULL);

 /*--- compute (00|f0)^6 ---*/
 _BUILD_00f0(Data,r12vrr_stack+316, r12vrr_stack+180, r12vrr_stack+15, r12vrr_stack+21, r12vrr_stack+27, NULL);

 /*--- compute (00|g0)^5 ---*/
 _BUILD_00g0(Data,r12vrr_stack+326, r12vrr_stack+186, r12vrr_stack+316, r12vrr_stack+210, r12vrr_stack+180, NULL);

 /*--- compute (p0|g0)^4 ---*/
 _BUILD_p0g0(Data,r12vrr_stack+2014, r12vrr_stack+867, r12vrr_stack+326, NULL, NULL, r12vrr_stack+186);

 /*--- compute (d0|g0)^3 ---*/
 _BUILD_d0g0(Data,r12vrr_stack+2059, r12vrr_stack+882, r12vrr_stack+2014, r12vrr_stack+506, r12vrr_stack+867, r12vrr_stack+1674);

 /*--- compute (f0|g0)^2 ---*/
 _BUILD_f0g0(Data,r12vrr_stack+2149, r12vrr_stack+927, r12vrr_stack+2059, r12vrr_stack+521, r12vrr_stack+882, r12vrr_stack+1704);

 /*--- compute (g0|g0)^1 ---*/
 _BUILD_g0g0(Data,r12vrr_stack+2299, r12vrr_stack+1017, r12vrr_stack+2149, r12vrr_stack+611, r12vrr_stack+927, r12vrr_stack+1764);

 /*--- compute (h0|g0)^0 ---*/
 _BUILD_h0g0(Data,r12vrr_stack+2524, r12vrr_stack+1317, r12vrr_stack+2299, r12vrr_stack+1167, r12vrr_stack+1017, r12vrr_stack+1864);

 /*--- compute (00|h0)^3 ---*/
 _BUILD_00h0(Data,r12vrr_stack+341, r12vrr_stack+506, r12vrr_stack+867, r12vrr_stack+111, r12vrr_stack+216, NULL);

 /*--- compute (00|h0)^2 ---*/
 _BUILD_00h0(Data,r12vrr_stack+131, r12vrr_stack+476, r12vrr_stack+506, r12vrr_stack+121, r12vrr_stack+111, NULL);

 /*--- compute (p0|h0)^2 ---*/
 _BUILD_p0h0(Data,r12vrr_stack+2839, r12vrr_stack+131, r12vrr_stack+341, NULL, NULL, r12vrr_stack+506);

 /*--- compute (00|h0)^1 ---*/
 _BUILD_00h0(Data,r12vrr_stack+2902, r12vrr_stack+491, r12vrr_stack+476, r12vrr_stack+170, r12vrr_stack+121, NULL);

 /*--- compute (p0|h0)^1 ---*/
 _BUILD_p0h0(Data,r12vrr_stack+2923, r12vrr_stack+2902, r12vrr_stack+131, NULL, NULL, r12vrr_stack+476);

 /*--- compute (00|h0)^4 ---*/
 _BUILD_00h0(Data,r12vrr_stack+2986, r12vrr_stack+867, r12vrr_stack+326, r12vrr_stack+216, r12vrr_stack+186, NULL);

 /*--- compute (p0|h0)^3 ---*/
 _BUILD_p0h0(Data,r12vrr_stack+3007, r12vrr_stack+341, r12vrr_stack+2986, NULL, NULL, r12vrr_stack+867);

 /*--- compute (d0|h0)^2 ---*/
 _BUILD_d0h0(Data,r12vrr_stack+3070, r12vrr_stack+2839, r12vrr_stack+3007, r12vrr_stack+131, r12vrr_stack+341, r12vrr_stack+882);

 /*--- compute (d0|h0)^1 ---*/
 _BUILD_d0h0(Data,r12vrr_stack+3196, r12vrr_stack+2923, r12vrr_stack+2839, r12vrr_stack+2902, r12vrr_stack+131, r12vrr_stack+521);

 /*--- compute (f0|h0)^1 ---*/
 _BUILD_f0h0(Data,r12vrr_stack+3322, r12vrr_stack+3196, r12vrr_stack+3070, r12vrr_stack+2923, r12vrr_stack+2839, r12vrr_stack+927);

 /*--- compute (00|h0)^0 ---*/
 _BUILD_00h0(Data,r12vrr_stack+521, r12vrr_stack+717, r12vrr_stack+491, r12vrr_stack+707, r12vrr_stack+170, NULL);

 /*--- compute (p0|h0)^0 ---*/
 _BUILD_p0h0(Data,r12vrr_stack+3532, r12vrr_stack+521, r12vrr_stack+2902, NULL, NULL, r12vrr_stack+491);

 /*--- compute (d0|h0)^0 ---*/
 _BUILD_d0h0(Data,r12vrr_stack+3595, r12vrr_stack+3532, r12vrr_stack+2923, r12vrr_stack+521, r12vrr_stack+2902, r12vrr_stack+566);

 /*--- compute (f0|h0)^0 ---*/
 _BUILD_f0h0(Data,r12vrr_stack+3721, r12vrr_stack+3595, r12vrr_stack+3196, r12vrr_stack+3532, r12vrr_stack+2923, r12vrr_stack+611);

 /*--- compute (00|p0)^9 ---*/
 _BUILD_00p0(Data,r12vrr_stack+170, Data->F+9, Data->F+10, NULL, NULL, NULL);

 /*--- compute (00|d0)^8 ---*/
 _BUILD_00d0(Data,r12vrr_stack+173, r12vrr_stack+3, r12vrr_stack+170, Data->F+8, Data->F+9, NULL);

 /*--- compute (00|f0)^7 ---*/
 _BUILD_00f0(Data,r12vrr_stack+542, r12vrr_stack+15, r12vrr_stack+173, r12vrr_stack+27, r12vrr_stack+3, NULL);

 /*--- compute (00|g0)^6 ---*/
 _BUILD_00g0(Data,r12vrr_stack+552, r12vrr_stack+316, r12vrr_stack+542, r12vrr_stack+180, r12vrr_stack+15, NULL);

 /*--- compute (00|h0)^5 ---*/
 _BUILD_00h0(Data,r12vrr_stack+567, r12vrr_stack+326, r12vrr_stack+552, r12vrr_stack+186, r12vrr_stack+316, NULL);

 /*--- compute (p0|h0)^4 ---*/
 _BUILD_p0h0(Data,r12vrr_stack+588, r12vrr_stack+2986, r12vrr_stack+567, NULL, NULL, r12vrr_stack+326);

 /*--- compute (d0|h0)^3 ---*/
 _BUILD_d0h0(Data,r12vrr_stack+3931, r12vrr_stack+3007, r12vrr_stack+588, r12vrr_stack+341, r12vrr_stack+2986, r12vrr_stack+2014);

 /*--- compute (f0|h0)^2 ---*/
 _BUILD_f0h0(Data,r12vrr_stack+4057, r12vrr_stack+3070, r12vrr_stack+3931, r12vrr_stack+2839, r12vrr_stack+3007, r12vrr_stack+2059);

 /*--- compute (g0|h0)^1 ---*/
 _BUILD_g0h0(Data,r12vrr_stack+4267, r12vrr_stack+3322, r12vrr_stack+4057, r12vrr_stack+3196, r12vrr_stack+3070, r12vrr_stack+2149);

 /*--- compute (g0|h0)^0 ---*/
 _BUILD_g0h0(Data,r12vrr_stack+4582, r12vrr_stack+3721, r12vrr_stack+3322, r12vrr_stack+3595, r12vrr_stack+3196, r12vrr_stack+1017);
 tmp = r12vrr_stack + 4582;
 target_ptr = Libr12->gvrr_classes[4][5];
 for(i=0;i<315;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (h0|h0)^0 ---*/
 _BUILD_h0h0(Data,r12vrr_stack+4897, r12vrr_stack+4582, r12vrr_stack+4267, r12vrr_stack+3721, r12vrr_stack+3322, r12vrr_stack+2299);
 tmp = r12vrr_stack + 4897;
 target_ptr = Libr12->gvrr_classes[5][5];
 for(i=0;i<441;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (00|i0)^2 ---*/
 _BUILD_00i0(Data,r12vrr_stack+651, r12vrr_stack+131, r12vrr_stack+341, r12vrr_stack+476, r12vrr_stack+506, NULL);

 /*--- compute (00|i0)^1 ---*/
 _BUILD_00i0(Data,r12vrr_stack+5338, r12vrr_stack+2902, r12vrr_stack+131, r12vrr_stack+491, r12vrr_stack+476, NULL);

 /*--- compute (00|i0)^3 ---*/
 _BUILD_00i0(Data,r12vrr_stack+5366, r12vrr_stack+341, r12vrr_stack+2986, r12vrr_stack+506, r12vrr_stack+867, NULL);

 /*--- compute (p0|i0)^2 ---*/
 _BUILD_p0i0(Data,r12vrr_stack+5394, r12vrr_stack+651, r12vrr_stack+5366, NULL, NULL, r12vrr_stack+341);

 /*--- compute (p0|i0)^1 ---*/
 _BUILD_p0i0(Data,r12vrr_stack+5478, r12vrr_stack+5338, r12vrr_stack+651, NULL, NULL, r12vrr_stack+131);

 /*--- compute (d0|i0)^1 ---*/
 _BUILD_d0i0(Data,r12vrr_stack+5562, r12vrr_stack+5478, r12vrr_stack+5394, r12vrr_stack+5338, r12vrr_stack+651, r12vrr_stack+2839);

 /*--- compute (00|i0)^0 ---*/
 _BUILD_00i0(Data,r12vrr_stack+2839, r12vrr_stack+521, r12vrr_stack+2902, r12vrr_stack+717, r12vrr_stack+491, NULL);

 /*--- compute (p0|i0)^0 ---*/
 _BUILD_p0i0(Data,r12vrr_stack+5730, r12vrr_stack+2839, r12vrr_stack+5338, NULL, NULL, r12vrr_stack+2902);

 /*--- compute (d0|i0)^0 ---*/
 _BUILD_d0i0(Data,r12vrr_stack+5814, r12vrr_stack+5730, r12vrr_stack+5478, r12vrr_stack+2839, r12vrr_stack+5338, r12vrr_stack+2923);

 /*--- compute (00|i0)^4 ---*/
 _BUILD_00i0(Data,r12vrr_stack+2923, r12vrr_stack+2986, r12vrr_stack+567, r12vrr_stack+867, r12vrr_stack+326, NULL);

 /*--- compute (p0|i0)^3 ---*/
 _BUILD_p0i0(Data,r12vrr_stack+5982, r12vrr_stack+5366, r12vrr_stack+2923, NULL, NULL, r12vrr_stack+2986);

 /*--- compute (d0|i0)^2 ---*/
 _BUILD_d0i0(Data,r12vrr_stack+6066, r12vrr_stack+5394, r12vrr_stack+5982, r12vrr_stack+651, r12vrr_stack+5366, r12vrr_stack+3007);

 /*--- compute (f0|i0)^1 ---*/
 _BUILD_f0i0(Data,r12vrr_stack+6234, r12vrr_stack+5562, r12vrr_stack+6066, r12vrr_stack+5478, r12vrr_stack+5394, r12vrr_stack+3070);

 /*--- compute (f0|i0)^0 ---*/
 _BUILD_f0i0(Data,r12vrr_stack+6514, r12vrr_stack+5814, r12vrr_stack+5562, r12vrr_stack+5730, r12vrr_stack+5478, r12vrr_stack+3196);

 /*--- compute (g0|i0)^0 ---*/
 _BUILD_g0i0(Data,r12vrr_stack+6794, r12vrr_stack+6514, r12vrr_stack+6234, r12vrr_stack+5814, r12vrr_stack+5562, r12vrr_stack+3322);
 tmp = r12vrr_stack + 6794;
 target_ptr = Libr12->gvrr_classes[4][6];
 for(i=0;i<420;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (00|p0)^10 ---*/
 _BUILD_00p0(Data,r12vrr_stack+3196, Data->F+10, Data->F+11, NULL, NULL, NULL);

 /*--- compute (00|d0)^9 ---*/
 _BUILD_00d0(Data,r12vrr_stack+3199, r12vrr_stack+170, r12vrr_stack+3196, Data->F+9, Data->F+10, NULL);

 /*--- compute (00|f0)^8 ---*/
 _BUILD_00f0(Data,r12vrr_stack+3205, r12vrr_stack+173, r12vrr_stack+3199, r12vrr_stack+3, r12vrr_stack+170, NULL);

 /*--- compute (00|g0)^7 ---*/
 _BUILD_00g0(Data,r12vrr_stack+3215, r12vrr_stack+542, r12vrr_stack+3205, r12vrr_stack+15, r12vrr_stack+173, NULL);

 /*--- compute (00|h0)^6 ---*/
 _BUILD_00h0(Data,r12vrr_stack+3230, r12vrr_stack+552, r12vrr_stack+3215, r12vrr_stack+316, r12vrr_stack+542, NULL);

 /*--- compute (00|i0)^5 ---*/
 _BUILD_00i0(Data,r12vrr_stack+3251, r12vrr_stack+567, r12vrr_stack+3230, r12vrr_stack+326, r12vrr_stack+552, NULL);

 /*--- compute (p0|i0)^4 ---*/
 _BUILD_p0i0(Data,r12vrr_stack+7214, r12vrr_stack+2923, r12vrr_stack+3251, NULL, NULL, r12vrr_stack+567);

 /*--- compute (d0|i0)^3 ---*/
 _BUILD_d0i0(Data,r12vrr_stack+7298, r12vrr_stack+5982, r12vrr_stack+7214, r12vrr_stack+5366, r12vrr_stack+2923, r12vrr_stack+588);

 /*--- compute (f0|i0)^2 ---*/
 _BUILD_f0i0(Data,r12vrr_stack+7466, r12vrr_stack+6066, r12vrr_stack+7298, r12vrr_stack+5394, r12vrr_stack+5982, r12vrr_stack+3931);

 /*--- compute (g0|i0)^1 ---*/
 _BUILD_g0i0(Data,r12vrr_stack+7746, r12vrr_stack+6234, r12vrr_stack+7466, r12vrr_stack+5562, r12vrr_stack+6066, r12vrr_stack+4057);

 /*--- compute (h0|i0)^0 ---*/
 _BUILD_h0i0(Data,r12vrr_stack+8166, r12vrr_stack+6794, r12vrr_stack+7746, r12vrr_stack+6514, r12vrr_stack+6234, r12vrr_stack+4267);
 tmp = r12vrr_stack + 8166;
 target_ptr = Libr12->gvrr_classes[5][6];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (00|k0)^2 ---*/
 am[0] = 0;  am[1] = 7;
 vrr_build_xxxx(am,Data,r12vrr_stack+3279, r12vrr_stack+651, r12vrr_stack+5366, r12vrr_stack+131, r12vrr_stack+341, NULL);

 /*--- compute (00|k0)^1 ---*/
 am[0] = 0;  am[1] = 7;
 vrr_build_xxxx(am,Data,r12vrr_stack+476, r12vrr_stack+5338, r12vrr_stack+651, r12vrr_stack+2902, r12vrr_stack+131, NULL);

 /*--- compute (00|k0)^3 ---*/
 am[0] = 0;  am[1] = 7;
 vrr_build_xxxx(am,Data,r12vrr_stack+111, r12vrr_stack+5366, r12vrr_stack+2923, r12vrr_stack+341, r12vrr_stack+2986, NULL);

 /*--- compute (p0|k0)^2 ---*/
 am[0] = 1;  am[1] = 7;
 vrr_build_xxxx(am,Data,r12vrr_stack+8754, r12vrr_stack+3279, r12vrr_stack+111, NULL, NULL, r12vrr_stack+5366);

 /*--- compute (p0|k0)^1 ---*/
 am[0] = 1;  am[1] = 7;
 vrr_build_xxxx(am,Data,r12vrr_stack+8862, r12vrr_stack+476, r12vrr_stack+3279, NULL, NULL, r12vrr_stack+651);

 /*--- compute (d0|k0)^1 ---*/
 am[0] = 2;  am[1] = 7;
 vrr_build_xxxx(am,Data,r12vrr_stack+8970, r12vrr_stack+8862, r12vrr_stack+8754, r12vrr_stack+476, r12vrr_stack+3279, r12vrr_stack+5394);

 /*--- compute (00|k0)^0 ---*/
 am[0] = 0;  am[1] = 7;
 vrr_build_xxxx(am,Data,r12vrr_stack+5394, r12vrr_stack+2839, r12vrr_stack+5338, r12vrr_stack+521, r12vrr_stack+2902, NULL);

 /*--- compute (p0|k0)^0 ---*/
 am[0] = 1;  am[1] = 7;
 vrr_build_xxxx(am,Data,r12vrr_stack+9186, r12vrr_stack+5394, r12vrr_stack+476, NULL, NULL, r12vrr_stack+5338);

 /*--- compute (d0|k0)^0 ---*/
 am[0] = 2;  am[1] = 7;
 vrr_build_xxxx(am,Data,r12vrr_stack+9294, r12vrr_stack+9186, r12vrr_stack+8862, r12vrr_stack+5394, r12vrr_stack+476, r12vrr_stack+5478);

 /*--- compute (00|k0)^4 ---*/
 am[0] = 0;  am[1] = 7;
 vrr_build_xxxx(am,Data,r12vrr_stack+5430, r12vrr_stack+2923, r12vrr_stack+3251, r12vrr_stack+2986, r12vrr_stack+567, NULL);

 /*--- compute (p0|k0)^3 ---*/
 am[0] = 1;  am[1] = 7;
 vrr_build_xxxx(am,Data,r12vrr_stack+9510, r12vrr_stack+111, r12vrr_stack+5430, NULL, NULL, r12vrr_stack+2923);

 /*--- compute (d0|k0)^2 ---*/
 am[0] = 2;  am[1] = 7;
 vrr_build_xxxx(am,Data,r12vrr_stack+9618, r12vrr_stack+8754, r12vrr_stack+9510, r12vrr_stack+3279, r12vrr_stack+111, r12vrr_stack+5982);

 /*--- compute (f0|k0)^1 ---*/
 am[0] = 3;  am[1] = 7;
 vrr_build_xxxx(am,Data,r12vrr_stack+9834, r12vrr_stack+8970, r12vrr_stack+9618, r12vrr_stack+8862, r12vrr_stack+8754, r12vrr_stack+6066);

 /*--- compute (f0|k0)^0 ---*/
 am[0] = 3;  am[1] = 7;
 vrr_build_xxxx(am,Data,r12vrr_stack+10194, r12vrr_stack+9294, r12vrr_stack+8970, r12vrr_stack+9186, r12vrr_stack+8862, r12vrr_stack+5562);

 /*--- compute (g0|k0)^0 ---*/
 am[0] = 4;  am[1] = 7;
 vrr_build_xxxx(am,Data,r12vrr_stack+10554, r12vrr_stack+10194, r12vrr_stack+9834, r12vrr_stack+9294, r12vrr_stack+8970, r12vrr_stack+6234);
 tmp = r12vrr_stack + 10554;
 target_ptr = Libr12->gvrr_classes[4][7];
 for(i=0;i<540;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (00|p0)^11 ---*/
 _BUILD_00p0(Data,r12vrr_stack+5466, Data->F+11, Data->F+12, NULL, NULL, NULL);

 /*--- compute (00|d0)^10 ---*/
 _BUILD_00d0(Data,r12vrr_stack+5469, r12vrr_stack+3196, r12vrr_stack+5466, Data->F+10, Data->F+11, NULL);

 /*--- compute (00|f0)^9 ---*/
 _BUILD_00f0(Data,r12vrr_stack+5475, r12vrr_stack+3199, r12vrr_stack+5469, r12vrr_stack+170, r12vrr_stack+3196, NULL);

 /*--- compute (00|g0)^8 ---*/
 _BUILD_00g0(Data,r12vrr_stack+5485, r12vrr_stack+3205, r12vrr_stack+5475, r12vrr_stack+173, r12vrr_stack+3199, NULL);

 /*--- compute (00|h0)^7 ---*/
 _BUILD_00h0(Data,r12vrr_stack+5500, r12vrr_stack+3215, r12vrr_stack+5485, r12vrr_stack+542, r12vrr_stack+3205, NULL);

 /*--- compute (00|i0)^6 ---*/
 _BUILD_00i0(Data,r12vrr_stack+5521, r12vrr_stack+3230, r12vrr_stack+5500, r12vrr_stack+552, r12vrr_stack+3215, NULL);

 /*--- compute (00|k0)^5 ---*/
 am[0] = 0;  am[1] = 7;
 vrr_build_xxxx(am,Data,r12vrr_stack+5549, r12vrr_stack+3251, r12vrr_stack+5521, r12vrr_stack+567, r12vrr_stack+3230, NULL);

 /*--- compute (p0|k0)^4 ---*/
 am[0] = 1;  am[1] = 7;
 vrr_build_xxxx(am,Data,r12vrr_stack+5585, r12vrr_stack+5430, r12vrr_stack+5549, NULL, NULL, r12vrr_stack+3251);

 /*--- compute (d0|k0)^3 ---*/
 am[0] = 2;  am[1] = 7;
 vrr_build_xxxx(am,Data,r12vrr_stack+11094, r12vrr_stack+9510, r12vrr_stack+5585, r12vrr_stack+111, r12vrr_stack+5430, r12vrr_stack+7214);

 /*--- compute (f0|k0)^2 ---*/
 am[0] = 3;  am[1] = 7;
 vrr_build_xxxx(am,Data,r12vrr_stack+11310, r12vrr_stack+9618, r12vrr_stack+11094, r12vrr_stack+8754, r12vrr_stack+9510, r12vrr_stack+7298);

 /*--- compute (g0|k0)^1 ---*/
 am[0] = 4;  am[1] = 7;
 vrr_build_xxxx(am,Data,r12vrr_stack+11670, r12vrr_stack+9834, r12vrr_stack+11310, r12vrr_stack+8970, r12vrr_stack+9618, r12vrr_stack+7466);

 /*--- compute (h0|k0)^0 ---*/
 am[0] = 5;  am[1] = 7;
 vrr_build_xxxx(am,Data,r12vrr_stack+12210, r12vrr_stack+10554, r12vrr_stack+11670, r12vrr_stack+10194, r12vrr_stack+9834, r12vrr_stack+7746);
 tmp = r12vrr_stack + 12210;
 target_ptr = Libr12->gvrr_classes[5][7];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (00|l0)^2 ---*/
 am[0] = 0;  am[1] = 8;
 vrr_build_xxxx(am,Data,r12vrr_stack+2867, r12vrr_stack+3279, r12vrr_stack+111, r12vrr_stack+651, r12vrr_stack+5366, NULL);

 /*--- compute (00|l0)^1 ---*/
 am[0] = 0;  am[1] = 8;
 vrr_build_xxxx(am,Data,r12vrr_stack+12966, r12vrr_stack+476, r12vrr_stack+3279, r12vrr_stack+5338, r12vrr_stack+651, NULL);

 /*--- compute (00|l0)^3 ---*/
 am[0] = 0;  am[1] = 8;
 vrr_build_xxxx(am,Data,r12vrr_stack+651, r12vrr_stack+111, r12vrr_stack+5430, r12vrr_stack+5366, r12vrr_stack+2923, NULL);

 /*--- compute (p0|l0)^2 ---*/
 am[0] = 1;  am[1] = 8;
 vrr_build_xxxx(am,Data,r12vrr_stack+13011, r12vrr_stack+2867, r12vrr_stack+651, NULL, NULL, r12vrr_stack+111);

 /*--- compute (p0|l0)^1 ---*/
 am[0] = 1;  am[1] = 8;
 vrr_build_xxxx(am,Data,r12vrr_stack+13146, r12vrr_stack+12966, r12vrr_stack+2867, NULL, NULL, r12vrr_stack+3279);

 /*--- compute (d0|l0)^1 ---*/
 am[0] = 2;  am[1] = 8;
 vrr_build_xxxx(am,Data,r12vrr_stack+13281, r12vrr_stack+13146, r12vrr_stack+13011, r12vrr_stack+12966, r12vrr_stack+2867, r12vrr_stack+8754);

 /*--- compute (00|l0)^0 ---*/
 am[0] = 0;  am[1] = 8;
 vrr_build_xxxx(am,Data,r12vrr_stack+8754, r12vrr_stack+5394, r12vrr_stack+476, r12vrr_stack+2839, r12vrr_stack+5338, NULL);

 /*--- compute (p0|l0)^0 ---*/
 am[0] = 1;  am[1] = 8;
 vrr_build_xxxx(am,Data,r12vrr_stack+13551, r12vrr_stack+8754, r12vrr_stack+12966, NULL, NULL, r12vrr_stack+476);

 /*--- compute (d0|l0)^0 ---*/
 am[0] = 2;  am[1] = 8;
 vrr_build_xxxx(am,Data,r12vrr_stack+13686, r12vrr_stack+13551, r12vrr_stack+13146, r12vrr_stack+8754, r12vrr_stack+12966, r12vrr_stack+8862);

 /*--- compute (00|l0)^4 ---*/
 am[0] = 0;  am[1] = 8;
 vrr_build_xxxx(am,Data,r12vrr_stack+13956, r12vrr_stack+5430, r12vrr_stack+5549, r12vrr_stack+2923, r12vrr_stack+3251, NULL);

 /*--- compute (p0|l0)^3 ---*/
 am[0] = 1;  am[1] = 8;
 vrr_build_xxxx(am,Data,r12vrr_stack+8799, r12vrr_stack+651, r12vrr_stack+13956, NULL, NULL, r12vrr_stack+5430);

 /*--- compute (d0|l0)^2 ---*/
 am[0] = 2;  am[1] = 8;
 vrr_build_xxxx(am,Data,r12vrr_stack+14001, r12vrr_stack+13011, r12vrr_stack+8799, r12vrr_stack+2867, r12vrr_stack+651, r12vrr_stack+9510);

 /*--- compute (f0|l0)^1 ---*/
 am[0] = 3;  am[1] = 8;
 vrr_build_xxxx(am,Data,r12vrr_stack+14271, r12vrr_stack+13281, r12vrr_stack+14001, r12vrr_stack+13146, r12vrr_stack+13011, r12vrr_stack+9618);

 /*--- compute (f0|l0)^0 ---*/
 am[0] = 3;  am[1] = 8;
 vrr_build_xxxx(am,Data,r12vrr_stack+14721, r12vrr_stack+13686, r12vrr_stack+13281, r12vrr_stack+13551, r12vrr_stack+13146, r12vrr_stack+8970);

 /*--- compute (g0|l0)^0 ---*/
 am[0] = 4;  am[1] = 8;
 vrr_build_xxxx(am,Data,r12vrr_stack+15171, r12vrr_stack+14721, r12vrr_stack+14271, r12vrr_stack+13686, r12vrr_stack+13281, r12vrr_stack+9834);
 tmp = r12vrr_stack + 15171;
 target_ptr = Libr12->gvrr_classes[4][8];
 for(i=0;i<675;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (00|p0)^12 ---*/
 _BUILD_00p0(Data,r12vrr_stack+170, Data->F+12, Data->F+13, NULL, NULL, NULL);

 /*--- compute (00|d0)^11 ---*/
 _BUILD_00d0(Data,r12vrr_stack+5338, r12vrr_stack+5466, r12vrr_stack+170, Data->F+11, Data->F+12, NULL);

 /*--- compute (00|f0)^10 ---*/
 _BUILD_00f0(Data,r12vrr_stack+5344, r12vrr_stack+5469, r12vrr_stack+5338, r12vrr_stack+3196, r12vrr_stack+5466, NULL);

 /*--- compute (00|g0)^9 ---*/
 _BUILD_00g0(Data,r12vrr_stack+5354, r12vrr_stack+5475, r12vrr_stack+5344, r12vrr_stack+3199, r12vrr_stack+5469, NULL);

 /*--- compute (00|h0)^8 ---*/
 _BUILD_00h0(Data,r12vrr_stack+5369, r12vrr_stack+5485, r12vrr_stack+5354, r12vrr_stack+3205, r12vrr_stack+5475, NULL);

 /*--- compute (00|i0)^7 ---*/
 _BUILD_00i0(Data,r12vrr_stack+8934, r12vrr_stack+5500, r12vrr_stack+5369, r12vrr_stack+3215, r12vrr_stack+5485, NULL);

 /*--- compute (00|k0)^6 ---*/
 am[0] = 0;  am[1] = 7;
 vrr_build_xxxx(am,Data,r12vrr_stack+8962, r12vrr_stack+5521, r12vrr_stack+8934, r12vrr_stack+3230, r12vrr_stack+5500, NULL);

 /*--- compute (00|l0)^5 ---*/
 am[0] = 0;  am[1] = 8;
 vrr_build_xxxx(am,Data,r12vrr_stack+8998, r12vrr_stack+5549, r12vrr_stack+8962, r12vrr_stack+3251, r12vrr_stack+5521, NULL);

 /*--- compute (p0|l0)^4 ---*/
 am[0] = 1;  am[1] = 8;
 vrr_build_xxxx(am,Data,r12vrr_stack+9043, r12vrr_stack+13956, r12vrr_stack+8998, NULL, NULL, r12vrr_stack+5549);

 /*--- compute (d0|l0)^3 ---*/
 am[0] = 2;  am[1] = 8;
 vrr_build_xxxx(am,Data,r12vrr_stack+15846, r12vrr_stack+8799, r12vrr_stack+9043, r12vrr_stack+651, r12vrr_stack+13956, r12vrr_stack+5585);

 /*--- compute (f0|l0)^2 ---*/
 am[0] = 3;  am[1] = 8;
 vrr_build_xxxx(am,Data,r12vrr_stack+16116, r12vrr_stack+14001, r12vrr_stack+15846, r12vrr_stack+13011, r12vrr_stack+8799, r12vrr_stack+11094);

 /*--- compute (g0|l0)^1 ---*/
 am[0] = 4;  am[1] = 8;
 vrr_build_xxxx(am,Data,r12vrr_stack+16566, r12vrr_stack+14271, r12vrr_stack+16116, r12vrr_stack+13281, r12vrr_stack+14001, r12vrr_stack+11310);

 /*--- compute (h0|l0)^0 ---*/
 am[0] = 5;  am[1] = 8;
 vrr_build_xxxx(am,Data,r12vrr_stack+17241, r12vrr_stack+15171, r12vrr_stack+16566, r12vrr_stack+14721, r12vrr_stack+14271, r12vrr_stack+11670);
 tmp = r12vrr_stack + 17241;
 target_ptr = Libr12->gvrr_classes[5][8];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (00|m0)^2 ---*/
 am[0] = 0;  am[1] = 9;
 vrr_build_xxxx(am,Data,r12vrr_stack+18186, r12vrr_stack+2867, r12vrr_stack+651, r12vrr_stack+3279, r12vrr_stack+111, NULL);

 /*--- compute (00|m0)^1 ---*/
 am[0] = 0;  am[1] = 9;
 vrr_build_xxxx(am,Data,r12vrr_stack+18241, r12vrr_stack+12966, r12vrr_stack+2867, r12vrr_stack+476, r12vrr_stack+3279, NULL);

 /*--- compute (00|m0)^3 ---*/
 am[0] = 0;  am[1] = 9;
 vrr_build_xxxx(am,Data,r12vrr_stack+18296, r12vrr_stack+651, r12vrr_stack+13956, r12vrr_stack+111, r12vrr_stack+5430, NULL);

 /*--- compute (p0|m0)^2 ---*/
 am[0] = 1;  am[1] = 9;
 vrr_build_xxxx(am,Data,r12vrr_stack+18351, r12vrr_stack+18186, r12vrr_stack+18296, NULL, NULL, r12vrr_stack+651);

 /*--- compute (p0|m0)^1 ---*/
 am[0] = 1;  am[1] = 9;
 vrr_build_xxxx(am,Data,r12vrr_stack+18516, r12vrr_stack+18241, r12vrr_stack+18186, NULL, NULL, r12vrr_stack+2867);

 /*--- compute (d0|m0)^1 ---*/
 am[0] = 2;  am[1] = 9;
 vrr_build_xxxx(am,Data,r12vrr_stack+18681, r12vrr_stack+18516, r12vrr_stack+18351, r12vrr_stack+18241, r12vrr_stack+18186, r12vrr_stack+13011);

 /*--- compute (00|m0)^0 ---*/
 am[0] = 0;  am[1] = 9;
 vrr_build_xxxx(am,Data,r12vrr_stack+13011, r12vrr_stack+8754, r12vrr_stack+12966, r12vrr_stack+5394, r12vrr_stack+476, NULL);

 /*--- compute (p0|m0)^0 ---*/
 am[0] = 1;  am[1] = 9;
 vrr_build_xxxx(am,Data,r12vrr_stack+19011, r12vrr_stack+13011, r12vrr_stack+18241, NULL, NULL, r12vrr_stack+12966);

 /*--- compute (d0|m0)^0 ---*/
 am[0] = 2;  am[1] = 9;
 vrr_build_xxxx(am,Data,r12vrr_stack+19176, r12vrr_stack+19011, r12vrr_stack+18516, r12vrr_stack+13011, r12vrr_stack+18241, r12vrr_stack+13146);

 /*--- compute (00|m0)^4 ---*/
 am[0] = 0;  am[1] = 9;
 vrr_build_xxxx(am,Data,r12vrr_stack+18241, r12vrr_stack+13956, r12vrr_stack+8998, r12vrr_stack+5430, r12vrr_stack+5549, NULL);

 /*--- compute (p0|m0)^3 ---*/
 am[0] = 1;  am[1] = 9;
 vrr_build_xxxx(am,Data,r12vrr_stack+12966, r12vrr_stack+18296, r12vrr_stack+18241, NULL, NULL, r12vrr_stack+13956);

 /*--- compute (d0|m0)^2 ---*/
 am[0] = 2;  am[1] = 9;
 vrr_build_xxxx(am,Data,r12vrr_stack+19506, r12vrr_stack+18351, r12vrr_stack+12966, r12vrr_stack+18186, r12vrr_stack+18296, r12vrr_stack+8799);

 /*--- compute (f0|m0)^1 ---*/
 am[0] = 3;  am[1] = 9;
 vrr_build_xxxx(am,Data,r12vrr_stack+19836, r12vrr_stack+18681, r12vrr_stack+19506, r12vrr_stack+18516, r12vrr_stack+18351, r12vrr_stack+14001);

 /*--- compute (f0|m0)^0 ---*/
 am[0] = 3;  am[1] = 9;
 vrr_build_xxxx(am,Data,r12vrr_stack+20386, r12vrr_stack+19176, r12vrr_stack+18681, r12vrr_stack+19011, r12vrr_stack+18516, r12vrr_stack+13281);

 /*--- compute (g0|m0)^0 ---*/
 am[0] = 4;  am[1] = 9;
 vrr_build_xxxx(am,Data,r12vrr_stack+20936, r12vrr_stack+20386, r12vrr_stack+19836, r12vrr_stack+19176, r12vrr_stack+18681, r12vrr_stack+14271);
 tmp = r12vrr_stack + 20936;
 target_ptr = Libr12->gvrr_classes[4][9];
 for(i=0;i<825;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (p0|00)^5 ---*/
 _BUILD_p000(Data,r12vrr_stack+18516, Data->F+5, Data->F+6, NULL, NULL, NULL);

 /*--- compute (d0|00)^4 ---*/
 _BUILD_d000(Data,r12vrr_stack+18519, r12vrr_stack+196, r12vrr_stack+18516, Data->F+4, Data->F+5, NULL);

 /*--- compute (p0|p0)^5 ---*/
 _BUILD_p0p0(Data,r12vrr_stack+3196, r12vrr_stack+30, r12vrr_stack+21, NULL, NULL, Data->F+6);

 /*--- compute (d0|p0)^4 ---*/
 _BUILD_d0p0(Data,r12vrr_stack+57, r12vrr_stack+161, r12vrr_stack+3196, r12vrr_stack+0, r12vrr_stack+30, r12vrr_stack+18516);

 /*--- compute (f0|p0)^3 ---*/
 _BUILD_f0p0(Data,r12vrr_stack+18525, r12vrr_stack+1542, r12vrr_stack+57, r12vrr_stack+6, r12vrr_stack+161, r12vrr_stack+18519);

 /*--- compute (p0|d0)^5 ---*/
 _BUILD_p0d0(Data,r12vrr_stack+18555, r12vrr_stack+210, r12vrr_stack+180, NULL, NULL, r12vrr_stack+21);

 /*--- compute (d0|d0)^4 ---*/
 _BUILD_d0d0(Data,r12vrr_stack+18573, r12vrr_stack+1560, r12vrr_stack+18555, r12vrr_stack+33, r12vrr_stack+210, r12vrr_stack+3196);

 /*--- compute (f0|d0)^3 ---*/
 _BUILD_f0d0(Data,r12vrr_stack+18609, r12vrr_stack+1578, r12vrr_stack+18573, r12vrr_stack+39, r12vrr_stack+1560, r12vrr_stack+57);

 /*--- compute (g0|d0)^2 ---*/
 _BUILD_g0d0(Data,r12vrr_stack+19011, r12vrr_stack+1614, r12vrr_stack+18609, r12vrr_stack+75, r12vrr_stack+1578, r12vrr_stack+18525);

 /*--- compute (p0|f0)^5 ---*/
 _BUILD_p0f0(Data,r12vrr_stack+75, r12vrr_stack+186, r12vrr_stack+316, NULL, NULL, r12vrr_stack+180);

 /*--- compute (d0|f0)^4 ---*/
 _BUILD_d0f0(Data,r12vrr_stack+19101, r12vrr_stack+1674, r12vrr_stack+75, r12vrr_stack+216, r12vrr_stack+186, r12vrr_stack+18555);

 /*--- compute (f0|f0)^3 ---*/
 _BUILD_f0f0(Data,r12vrr_stack+19161, r12vrr_stack+1704, r12vrr_stack+19101, r12vrr_stack+226, r12vrr_stack+1674, r12vrr_stack+18573);

 /*--- compute (g0|f0)^2 ---*/
 _BUILD_g0f0(Data,r12vrr_stack+19261, r12vrr_stack+1764, r12vrr_stack+19161, r12vrr_stack+256, r12vrr_stack+1704, r12vrr_stack+18609);

 /*--- compute (h0|f0)^1 ---*/
 _BUILD_h0f0(Data,r12vrr_stack+13131, r12vrr_stack+1864, r12vrr_stack+19261, r12vrr_stack+376, r12vrr_stack+1764, r12vrr_stack+19011);

 /*--- compute (p0|g0)^5 ---*/
 _BUILD_p0g0(Data,r12vrr_stack+216, r12vrr_stack+326, r12vrr_stack+552, NULL, NULL, r12vrr_stack+316);

 /*--- compute (d0|g0)^4 ---*/
 _BUILD_d0g0(Data,r12vrr_stack+19411, r12vrr_stack+2014, r12vrr_stack+216, r12vrr_stack+867, r12vrr_stack+326, r12vrr_stack+75);

 /*--- compute (f0|g0)^3 ---*/
 _BUILD_f0g0(Data,r12vrr_stack+13341, r12vrr_stack+2059, r12vrr_stack+19411, r12vrr_stack+882, r12vrr_stack+2014, r12vrr_stack+19101);

 /*--- compute (g0|g0)^2 ---*/
 _BUILD_g0g0(Data,r12vrr_stack+21761, r12vrr_stack+2149, r12vrr_stack+13341, r12vrr_stack+927, r12vrr_stack+2059, r12vrr_stack+19161);

 /*--- compute (h0|g0)^1 ---*/
 _BUILD_h0g0(Data,r12vrr_stack+21986, r12vrr_stack+2299, r12vrr_stack+21761, r12vrr_stack+1017, r12vrr_stack+2149, r12vrr_stack+19261);

 /*--- compute (i0|g0)^0 ---*/
 _BUILD_i0g0(Data,r12vrr_stack+22301, r12vrr_stack+2524, r12vrr_stack+21986, r12vrr_stack+1317, r12vrr_stack+2299, r12vrr_stack+13131);

 /*--- compute (p0|h0)^5 ---*/
 _BUILD_p0h0(Data,r12vrr_stack+867, r12vrr_stack+567, r12vrr_stack+3230, NULL, NULL, r12vrr_stack+552);

 /*--- compute (d0|h0)^4 ---*/
 _BUILD_d0h0(Data,r12vrr_stack+930, r12vrr_stack+588, r12vrr_stack+867, r12vrr_stack+2986, r12vrr_stack+567, r12vrr_stack+216);

 /*--- compute (f0|h0)^3 ---*/
 _BUILD_f0h0(Data,r12vrr_stack+22721, r12vrr_stack+3931, r12vrr_stack+930, r12vrr_stack+3007, r12vrr_stack+588, r12vrr_stack+19411);

 /*--- compute (g0|h0)^2 ---*/
 _BUILD_g0h0(Data,r12vrr_stack+22931, r12vrr_stack+4057, r12vrr_stack+22721, r12vrr_stack+3070, r12vrr_stack+3931, r12vrr_stack+13341);

 /*--- compute (h0|h0)^1 ---*/
 _BUILD_h0h0(Data,r12vrr_stack+23246, r12vrr_stack+4267, r12vrr_stack+22931, r12vrr_stack+3322, r12vrr_stack+4057, r12vrr_stack+21761);

 /*--- compute (i0|h0)^0 ---*/
 _BUILD_i0h0(Data,r12vrr_stack+23687, r12vrr_stack+4897, r12vrr_stack+23246, r12vrr_stack+4582, r12vrr_stack+4267, r12vrr_stack+21986);
 tmp = r12vrr_stack + 23687;
 target_ptr = Libr12->gvrr_classes[6][5];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (p0|i0)^5 ---*/
 _BUILD_p0i0(Data,r12vrr_stack+1056, r12vrr_stack+3251, r12vrr_stack+5521, NULL, NULL, r12vrr_stack+3230);

 /*--- compute (d0|i0)^4 ---*/
 _BUILD_d0i0(Data,r12vrr_stack+3279, r12vrr_stack+7214, r12vrr_stack+1056, r12vrr_stack+2923, r12vrr_stack+3251, r12vrr_stack+867);

 /*--- compute (f0|i0)^3 ---*/
 _BUILD_f0i0(Data,r12vrr_stack+2867, r12vrr_stack+7298, r12vrr_stack+3279, r12vrr_stack+5982, r12vrr_stack+7214, r12vrr_stack+930);

 /*--- compute (g0|i0)^2 ---*/
 _BUILD_g0i0(Data,r12vrr_stack+24275, r12vrr_stack+7466, r12vrr_stack+2867, r12vrr_stack+6066, r12vrr_stack+7298, r12vrr_stack+22721);

 /*--- compute (h0|i0)^1 ---*/
 _BUILD_h0i0(Data,r12vrr_stack+24695, r12vrr_stack+7746, r12vrr_stack+24275, r12vrr_stack+6234, r12vrr_stack+7466, r12vrr_stack+22931);

 /*--- compute (i0|i0)^0 ---*/
 _BUILD_i0i0(Data,r12vrr_stack+25283, r12vrr_stack+8166, r12vrr_stack+24695, r12vrr_stack+6794, r12vrr_stack+7746, r12vrr_stack+23246);
 tmp = r12vrr_stack + 25283;
 target_ptr = Libr12->gvrr_classes[6][6];
 for(i=0;i<784;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (p0|k0)^5 ---*/
 am[0] = 1;  am[1] = 7;
 vrr_build_xxxx(am,Data,r12vrr_stack+5982, r12vrr_stack+5549, r12vrr_stack+8962, NULL, NULL, r12vrr_stack+5521);

 /*--- compute (d0|k0)^4 ---*/
 am[0] = 2;  am[1] = 7;
 vrr_build_xxxx(am,Data,r12vrr_stack+6090, r12vrr_stack+5585, r12vrr_stack+5982, r12vrr_stack+5430, r12vrr_stack+5549, r12vrr_stack+1056);

 /*--- compute (f0|k0)^3 ---*/
 am[0] = 3;  am[1] = 7;
 vrr_build_xxxx(am,Data,r12vrr_stack+26067, r12vrr_stack+11094, r12vrr_stack+6090, r12vrr_stack+9510, r12vrr_stack+5585, r12vrr_stack+3279);

 /*--- compute (g0|k0)^2 ---*/
 am[0] = 4;  am[1] = 7;
 vrr_build_xxxx(am,Data,r12vrr_stack+26427, r12vrr_stack+11310, r12vrr_stack+26067, r12vrr_stack+9618, r12vrr_stack+11094, r12vrr_stack+2867);

 /*--- compute (h0|k0)^1 ---*/
 am[0] = 5;  am[1] = 7;
 vrr_build_xxxx(am,Data,r12vrr_stack+26967, r12vrr_stack+11670, r12vrr_stack+26427, r12vrr_stack+9834, r12vrr_stack+11310, r12vrr_stack+24275);

 /*--- compute (i0|k0)^0 ---*/
 am[0] = 6;  am[1] = 7;
 vrr_build_xxxx(am,Data,r12vrr_stack+27723, r12vrr_stack+12210, r12vrr_stack+26967, r12vrr_stack+10554, r12vrr_stack+11670, r12vrr_stack+24695);
 tmp = r12vrr_stack + 27723;
 target_ptr = Libr12->gvrr_classes[6][7];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (00|p0)^13 ---*/
 _BUILD_00p0(Data,r12vrr_stack+0, Data->F+13, Data->F+14, NULL, NULL, NULL);

 /*--- compute (00|d0)^12 ---*/
 _BUILD_00d0(Data,r12vrr_stack+9510, r12vrr_stack+170, r12vrr_stack+0, Data->F+12, Data->F+13, NULL);

 /*--- compute (00|f0)^11 ---*/
 _BUILD_00f0(Data,r12vrr_stack+9516, r12vrr_stack+5338, r12vrr_stack+9510, r12vrr_stack+5466, r12vrr_stack+170, NULL);

 /*--- compute (00|g0)^10 ---*/
 _BUILD_00g0(Data,r12vrr_stack+9526, r12vrr_stack+5344, r12vrr_stack+9516, r12vrr_stack+5469, r12vrr_stack+5338, NULL);

 /*--- compute (00|h0)^9 ---*/
 _BUILD_00h0(Data,r12vrr_stack+9541, r12vrr_stack+5354, r12vrr_stack+9526, r12vrr_stack+5475, r12vrr_stack+5344, NULL);

 /*--- compute (00|i0)^8 ---*/
 _BUILD_00i0(Data,r12vrr_stack+9562, r12vrr_stack+5369, r12vrr_stack+9541, r12vrr_stack+5485, r12vrr_stack+5354, NULL);

 /*--- compute (00|k0)^7 ---*/
 am[0] = 0;  am[1] = 7;
 vrr_build_xxxx(am,Data,r12vrr_stack+9590, r12vrr_stack+8934, r12vrr_stack+9562, r12vrr_stack+5500, r12vrr_stack+5369, NULL);

 /*--- compute (00|l0)^6 ---*/
 am[0] = 0;  am[1] = 8;
 vrr_build_xxxx(am,Data,r12vrr_stack+9626, r12vrr_stack+8962, r12vrr_stack+9590, r12vrr_stack+5521, r12vrr_stack+8934, NULL);

 /*--- compute (p0|l0)^5 ---*/
 am[0] = 1;  am[1] = 8;
 vrr_build_xxxx(am,Data,r12vrr_stack+9671, r12vrr_stack+8998, r12vrr_stack+9626, NULL, NULL, r12vrr_stack+8962);

 /*--- compute (d0|l0)^4 ---*/
 am[0] = 2;  am[1] = 8;
 vrr_build_xxxx(am,Data,r12vrr_stack+9806, r12vrr_stack+9043, r12vrr_stack+9671, r12vrr_stack+13956, r12vrr_stack+8998, r12vrr_stack+5982);

 /*--- compute (f0|l0)^3 ---*/
 am[0] = 3;  am[1] = 8;
 vrr_build_xxxx(am,Data,r12vrr_stack+28731, r12vrr_stack+15846, r12vrr_stack+9806, r12vrr_stack+8799, r12vrr_stack+9043, r12vrr_stack+6090);

 /*--- compute (g0|l0)^2 ---*/
 am[0] = 4;  am[1] = 8;
 vrr_build_xxxx(am,Data,r12vrr_stack+29181, r12vrr_stack+16116, r12vrr_stack+28731, r12vrr_stack+14001, r12vrr_stack+15846, r12vrr_stack+26067);

 /*--- compute (h0|l0)^1 ---*/
 am[0] = 5;  am[1] = 8;
 vrr_build_xxxx(am,Data,r12vrr_stack+29856, r12vrr_stack+16566, r12vrr_stack+29181, r12vrr_stack+14271, r12vrr_stack+16116, r12vrr_stack+26427);

 /*--- compute (i0|l0)^0 ---*/
 am[0] = 6;  am[1] = 8;
 vrr_build_xxxx(am,Data,r12vrr_stack+30801, r12vrr_stack+17241, r12vrr_stack+29856, r12vrr_stack+15171, r12vrr_stack+16566, r12vrr_stack+26967);
 tmp = r12vrr_stack + 30801;
 target_ptr = Libr12->gvrr_classes[6][8];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (00|m0)^5 ---*/
 am[0] = 0;  am[1] = 9;
 vrr_build_xxxx(am,Data,r12vrr_stack+5430, r12vrr_stack+8998, r12vrr_stack+9626, r12vrr_stack+5549, r12vrr_stack+8962, NULL);

 /*--- compute (p0|m0)^4 ---*/
 am[0] = 1;  am[1] = 9;
 vrr_build_xxxx(am,Data,r12vrr_stack+13956, r12vrr_stack+18241, r12vrr_stack+5430, NULL, NULL, r12vrr_stack+8998);

 /*--- compute (d0|m0)^3 ---*/
 am[0] = 2;  am[1] = 9;
 vrr_build_xxxx(am,Data,r12vrr_stack+14121, r12vrr_stack+12966, r12vrr_stack+13956, r12vrr_stack+18296, r12vrr_stack+18241, r12vrr_stack+9043);

 /*--- compute (f0|m0)^2 ---*/
 am[0] = 3;  am[1] = 9;
 vrr_build_xxxx(am,Data,r12vrr_stack+32061, r12vrr_stack+19506, r12vrr_stack+14121, r12vrr_stack+18351, r12vrr_stack+12966, r12vrr_stack+15846);

 /*--- compute (g0|m0)^1 ---*/
 am[0] = 4;  am[1] = 9;
 vrr_build_xxxx(am,Data,r12vrr_stack+32611, r12vrr_stack+19836, r12vrr_stack+32061, r12vrr_stack+18681, r12vrr_stack+19506, r12vrr_stack+16116);

 /*--- compute (h0|m0)^0 ---*/
 am[0] = 5;  am[1] = 9;
 vrr_build_xxxx(am,Data,r12vrr_stack+33436, r12vrr_stack+20936, r12vrr_stack+32611, r12vrr_stack+20386, r12vrr_stack+19836, r12vrr_stack+16566);
 tmp = r12vrr_stack + 33436;
 target_ptr = Libr12->gvrr_classes[5][9];
 for(i=0;i<1155;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (p0|00)^6 ---*/
 _BUILD_p000(Data,r12vrr_stack+18296, Data->F+6, Data->F+7, NULL, NULL, NULL);

 /*--- compute (d0|00)^5 ---*/
 _BUILD_d000(Data,r12vrr_stack+18299, r12vrr_stack+18516, r12vrr_stack+18296, Data->F+5, Data->F+6, NULL);

 /*--- compute (f0|00)^4 ---*/
 _BUILD_f000(Data,r12vrr_stack+18305, r12vrr_stack+18519, r12vrr_stack+18299, r12vrr_stack+196, r12vrr_stack+18516, NULL);

 /*--- compute (p0|p0)^6 ---*/
 _BUILD_p0p0(Data,r12vrr_stack+6, r12vrr_stack+21, r12vrr_stack+27, NULL, NULL, Data->F+7);

 /*--- compute (d0|p0)^5 ---*/
 _BUILD_d0p0(Data,r12vrr_stack+18315, r12vrr_stack+3196, r12vrr_stack+6, r12vrr_stack+30, r12vrr_stack+21, r12vrr_stack+18296);

 /*--- compute (f0|p0)^4 ---*/
 _BUILD_f0p0(Data,r12vrr_stack+18333, r12vrr_stack+57, r12vrr_stack+18315, r12vrr_stack+161, r12vrr_stack+3196, r12vrr_stack+18299);

 /*--- compute (g0|p0)^3 ---*/
 _BUILD_g0p0(Data,r12vrr_stack+18363, r12vrr_stack+18525, r12vrr_stack+18333, r12vrr_stack+1542, r12vrr_stack+57, r12vrr_stack+18305);

 /*--- compute (p0|d0)^6 ---*/
 _BUILD_p0d0(Data,r12vrr_stack+1542, r12vrr_stack+180, r12vrr_stack+15, NULL, NULL, r12vrr_stack+27);

 /*--- compute (d0|d0)^5 ---*/
 _BUILD_d0d0(Data,r12vrr_stack+18408, r12vrr_stack+18555, r12vrr_stack+1542, r12vrr_stack+210, r12vrr_stack+180, r12vrr_stack+6);

 /*--- compute (f0|d0)^4 ---*/
 _BUILD_f0d0(Data,r12vrr_stack+13491, r12vrr_stack+18573, r12vrr_stack+18408, r12vrr_stack+1560, r12vrr_stack+18555, r12vrr_stack+18315);

 /*--- compute (g0|d0)^3 ---*/
 _BUILD_g0d0(Data,r12vrr_stack+8799, r12vrr_stack+18609, r12vrr_stack+13491, r12vrr_stack+1578, r12vrr_stack+18573, r12vrr_stack+18333);

 /*--- compute (h0|d0)^2 ---*/
 _BUILD_h0d0(Data,r12vrr_stack+14451, r12vrr_stack+19011, r12vrr_stack+8799, r12vrr_stack+1614, r12vrr_stack+18609, r12vrr_stack+18363);

 /*--- compute (p0|f0)^6 ---*/
 _BUILD_p0f0(Data,r12vrr_stack+1560, r12vrr_stack+316, r12vrr_stack+542, NULL, NULL, r12vrr_stack+15);

 /*--- compute (d0|f0)^5 ---*/
 _BUILD_d0f0(Data,r12vrr_stack+1590, r12vrr_stack+75, r12vrr_stack+1560, r12vrr_stack+186, r12vrr_stack+316, r12vrr_stack+1542);

 /*--- compute (f0|f0)^4 ---*/
 _BUILD_f0f0(Data,r12vrr_stack+14577, r12vrr_stack+19101, r12vrr_stack+1590, r12vrr_stack+1674, r12vrr_stack+75, r12vrr_stack+18408);

 /*--- compute (g0|f0)^3 ---*/
 _BUILD_g0f0(Data,r12vrr_stack+6306, r12vrr_stack+19161, r12vrr_stack+14577, r12vrr_stack+1704, r12vrr_stack+19101, r12vrr_stack+13491);

 /*--- compute (h0|f0)^2 ---*/
 _BUILD_h0f0(Data,r12vrr_stack+18669, r12vrr_stack+19261, r12vrr_stack+6306, r12vrr_stack+1764, r12vrr_stack+19161, r12vrr_stack+8799);

 /*--- compute (i0|f0)^1 ---*/
 _BUILD_i0f0(Data,r12vrr_stack+34591, r12vrr_stack+13131, r12vrr_stack+18669, r12vrr_stack+1864, r12vrr_stack+19261, r12vrr_stack+14451);

 /*--- compute (p0|g0)^6 ---*/
 _BUILD_p0g0(Data,r12vrr_stack+8889, r12vrr_stack+552, r12vrr_stack+3215, NULL, NULL, r12vrr_stack+542);

 /*--- compute (d0|g0)^5 ---*/
 _BUILD_d0g0(Data,r12vrr_stack+1650, r12vrr_stack+216, r12vrr_stack+8889, r12vrr_stack+326, r12vrr_stack+552, r12vrr_stack+1560);

 /*--- compute (f0|g0)^4 ---*/
 _BUILD_f0g0(Data,r12vrr_stack+326, r12vrr_stack+19411, r12vrr_stack+1650, r12vrr_stack+2014, r12vrr_stack+216, r12vrr_stack+1590);

 /*--- compute (g0|g0)^3 ---*/
 _BUILD_g0g0(Data,r12vrr_stack+1740, r12vrr_stack+13341, r12vrr_stack+326, r12vrr_stack+2059, r12vrr_stack+19411, r12vrr_stack+14577);

 /*--- compute (h0|g0)^2 ---*/
 _BUILD_h0g0(Data,r12vrr_stack+34871, r12vrr_stack+21761, r12vrr_stack+1740, r12vrr_stack+2149, r12vrr_stack+13341, r12vrr_stack+6306);

 /*--- compute (i0|g0)^1 ---*/
 _BUILD_i0g0(Data,r12vrr_stack+35186, r12vrr_stack+21986, r12vrr_stack+34871, r12vrr_stack+2299, r12vrr_stack+21761, r12vrr_stack+18669);

 /*--- compute (k0|g0)^0 ---*/
 am[0] = 7;  am[1] = 4;
 vrr_build_xxxx(am,Data,r12vrr_stack+1965, r12vrr_stack+22301, r12vrr_stack+35186, r12vrr_stack+2524, r12vrr_stack+21986, r12vrr_stack+34591);

 /*--- compute (p0|h0)^6 ---*/
 _BUILD_p0h0(Data,r12vrr_stack+18444, r12vrr_stack+3230, r12vrr_stack+5500, NULL, NULL, r12vrr_stack+3215);

 /*--- compute (d0|h0)^5 ---*/
 _BUILD_d0h0(Data,r12vrr_stack+18879, r12vrr_stack+867, r12vrr_stack+18444, r12vrr_stack+567, r12vrr_stack+3230, r12vrr_stack+8889);

 /*--- compute (f0|h0)^4 ---*/
 _BUILD_f0h0(Data,r12vrr_stack+35606, r12vrr_stack+930, r12vrr_stack+18879, r12vrr_stack+588, r12vrr_stack+867, r12vrr_stack+1650);

 /*--- compute (g0|h0)^3 ---*/
 _BUILD_g0h0(Data,r12vrr_stack+35816, r12vrr_stack+22721, r12vrr_stack+35606, r12vrr_stack+3931, r12vrr_stack+930, r12vrr_stack+326);

 /*--- compute (h0|h0)^2 ---*/
 _BUILD_h0h0(Data,r12vrr_stack+36131, r12vrr_stack+22931, r12vrr_stack+35816, r12vrr_stack+4057, r12vrr_stack+22721, r12vrr_stack+1740);

 /*--- compute (i0|h0)^1 ---*/
 _BUILD_i0h0(Data,r12vrr_stack+36572, r12vrr_stack+23246, r12vrr_stack+36131, r12vrr_stack+4267, r12vrr_stack+22931, r12vrr_stack+34871);

 /*--- compute (k0|h0)^0 ---*/
 am[0] = 7;  am[1] = 5;
 vrr_build_xxxx(am,Data,r12vrr_stack+37160, r12vrr_stack+23687, r12vrr_stack+36572, r12vrr_stack+4897, r12vrr_stack+23246, r12vrr_stack+35186);
 tmp = r12vrr_stack + 37160;
 target_ptr = Libr12->gvrr_classes[7][5];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (p0|i0)^6 ---*/
 _BUILD_p0i0(Data,r12vrr_stack+3931, r12vrr_stack+5521, r12vrr_stack+8934, NULL, NULL, r12vrr_stack+5500);

 /*--- compute (d0|i0)^5 ---*/
 _BUILD_d0i0(Data,r12vrr_stack+4015, r12vrr_stack+1056, r12vrr_stack+3931, r12vrr_stack+3251, r12vrr_stack+5521, r12vrr_stack+18444);

 /*--- compute (f0|i0)^4 ---*/
 _BUILD_f0i0(Data,r12vrr_stack+4183, r12vrr_stack+3279, r12vrr_stack+4015, r12vrr_stack+7214, r12vrr_stack+1056, r12vrr_stack+18879);

 /*--- compute (g0|i0)^3 ---*/
 _BUILD_g0i0(Data,r12vrr_stack+37916, r12vrr_stack+2867, r12vrr_stack+4183, r12vrr_stack+7298, r12vrr_stack+3279, r12vrr_stack+35606);

 /*--- compute (h0|i0)^2 ---*/
 _BUILD_h0i0(Data,r12vrr_stack+38336, r12vrr_stack+24275, r12vrr_stack+37916, r12vrr_stack+7466, r12vrr_stack+2867, r12vrr_stack+35816);

 /*--- compute (i0|i0)^1 ---*/
 _BUILD_i0i0(Data,r12vrr_stack+38924, r12vrr_stack+24695, r12vrr_stack+38336, r12vrr_stack+7746, r12vrr_stack+24275, r12vrr_stack+36131);

 /*--- compute (k0|i0)^0 ---*/
 am[0] = 7;  am[1] = 6;
 vrr_build_xxxx(am,Data,r12vrr_stack+39708, r12vrr_stack+25283, r12vrr_stack+38924, r12vrr_stack+8166, r12vrr_stack+24695, r12vrr_stack+36572);
 tmp = r12vrr_stack + 39708;
 target_ptr = Libr12->gvrr_classes[7][6];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (p0|k0)^6 ---*/
 am[0] = 1;  am[1] = 7;
 vrr_build_xxxx(am,Data,r12vrr_stack+7214, r12vrr_stack+8962, r12vrr_stack+9590, NULL, NULL, r12vrr_stack+8934);

 /*--- compute (d0|k0)^5 ---*/
 am[0] = 2;  am[1] = 7;
 vrr_build_xxxx(am,Data,r12vrr_stack+7322, r12vrr_stack+5982, r12vrr_stack+7214, r12vrr_stack+5549, r12vrr_stack+8962, r12vrr_stack+3931);

 /*--- compute (f0|k0)^4 ---*/
 am[0] = 3;  am[1] = 7;
 vrr_build_xxxx(am,Data,r12vrr_stack+7538, r12vrr_stack+6090, r12vrr_stack+7322, r12vrr_stack+5585, r12vrr_stack+5982, r12vrr_stack+4015);

 /*--- compute (g0|k0)^3 ---*/
 am[0] = 4;  am[1] = 7;
 vrr_build_xxxx(am,Data,r12vrr_stack+40716, r12vrr_stack+26067, r12vrr_stack+7538, r12vrr_stack+11094, r12vrr_stack+6090, r12vrr_stack+4183);

 /*--- compute (h0|k0)^2 ---*/
 am[0] = 5;  am[1] = 7;
 vrr_build_xxxx(am,Data,r12vrr_stack+41256, r12vrr_stack+26427, r12vrr_stack+40716, r12vrr_stack+11310, r12vrr_stack+26067, r12vrr_stack+37916);

 /*--- compute (i0|k0)^1 ---*/
 am[0] = 6;  am[1] = 7;
 vrr_build_xxxx(am,Data,r12vrr_stack+42012, r12vrr_stack+26967, r12vrr_stack+41256, r12vrr_stack+11670, r12vrr_stack+26427, r12vrr_stack+38336);

 /*--- compute (k0|k0)^0 ---*/
 am[0] = 7;  am[1] = 7;
 vrr_build_xxxx(am,Data,r12vrr_stack+43020, r12vrr_stack+27723, r12vrr_stack+42012, r12vrr_stack+12210, r12vrr_stack+26967, r12vrr_stack+38924);
 tmp = r12vrr_stack + 43020;
 target_ptr = Libr12->gvrr_classes[7][7];
 for(i=0;i<1296;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (00|p0)^14 ---*/
 _BUILD_00p0(Data,r12vrr_stack+11094, Data->F+14, Data->F+15, NULL, NULL, NULL);

 /*--- compute (00|d0)^13 ---*/
 _BUILD_00d0(Data,r12vrr_stack+19005, r12vrr_stack+0, r12vrr_stack+11094, Data->F+13, Data->F+14, NULL);

 /*--- compute (00|f0)^12 ---*/
 _BUILD_00f0(Data,r12vrr_stack+11097, r12vrr_stack+9510, r12vrr_stack+19005, r12vrr_stack+170, r12vrr_stack+0, NULL);

 /*--- compute (00|g0)^11 ---*/
 _BUILD_00g0(Data,r12vrr_stack+11107, r12vrr_stack+9516, r12vrr_stack+11097, r12vrr_stack+5338, r12vrr_stack+9510, NULL);

 /*--- compute (00|h0)^10 ---*/
 _BUILD_00h0(Data,r12vrr_stack+11122, r12vrr_stack+9526, r12vrr_stack+11107, r12vrr_stack+5344, r12vrr_stack+9516, NULL);

 /*--- compute (00|i0)^9 ---*/
 _BUILD_00i0(Data,r12vrr_stack+3251, r12vrr_stack+9541, r12vrr_stack+11122, r12vrr_stack+5354, r12vrr_stack+9526, NULL);

 /*--- compute (00|k0)^8 ---*/
 am[0] = 0;  am[1] = 7;
 vrr_build_xxxx(am,Data,r12vrr_stack+11143, r12vrr_stack+9562, r12vrr_stack+3251, r12vrr_stack+5369, r12vrr_stack+9541, NULL);

 /*--- compute (00|l0)^7 ---*/
 am[0] = 0;  am[1] = 8;
 vrr_build_xxxx(am,Data,r12vrr_stack+476, r12vrr_stack+9590, r12vrr_stack+11143, r12vrr_stack+8934, r12vrr_stack+9562, NULL);

 /*--- compute (p0|l0)^6 ---*/
 am[0] = 1;  am[1] = 8;
 vrr_build_xxxx(am,Data,r12vrr_stack+11179, r12vrr_stack+9626, r12vrr_stack+476, NULL, NULL, r12vrr_stack+9590);

 /*--- compute (d0|l0)^5 ---*/
 am[0] = 2;  am[1] = 8;
 vrr_build_xxxx(am,Data,r12vrr_stack+11314, r12vrr_stack+9671, r12vrr_stack+11179, r12vrr_stack+8998, r12vrr_stack+9626, r12vrr_stack+7214);

 /*--- compute (f0|l0)^4 ---*/
 am[0] = 3;  am[1] = 8;
 vrr_build_xxxx(am,Data,r12vrr_stack+11584, r12vrr_stack+9806, r12vrr_stack+11314, r12vrr_stack+9043, r12vrr_stack+9671, r12vrr_stack+7322);

 /*--- compute (g0|l0)^3 ---*/
 am[0] = 4;  am[1] = 8;
 vrr_build_xxxx(am,Data,r12vrr_stack+44316, r12vrr_stack+28731, r12vrr_stack+11584, r12vrr_stack+15846, r12vrr_stack+9806, r12vrr_stack+7538);

 /*--- compute (h0|l0)^2 ---*/
 am[0] = 5;  am[1] = 8;
 vrr_build_xxxx(am,Data,r12vrr_stack+44991, r12vrr_stack+29181, r12vrr_stack+44316, r12vrr_stack+16116, r12vrr_stack+28731, r12vrr_stack+40716);

 /*--- compute (i0|l0)^1 ---*/
 am[0] = 6;  am[1] = 8;
 vrr_build_xxxx(am,Data,r12vrr_stack+45936, r12vrr_stack+29856, r12vrr_stack+44991, r12vrr_stack+16566, r12vrr_stack+29181, r12vrr_stack+41256);

 /*--- compute (k0|l0)^0 ---*/
 am[0] = 7;  am[1] = 8;
 vrr_build_xxxx(am,Data,r12vrr_stack+47196, r12vrr_stack+30801, r12vrr_stack+45936, r12vrr_stack+17241, r12vrr_stack+29856, r12vrr_stack+42012);
 tmp = r12vrr_stack + 47196;
 target_ptr = Libr12->gvrr_classes[7][8];
 for(i=0;i<1620;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (00|m0)^6 ---*/
 am[0] = 0;  am[1] = 9;
 vrr_build_xxxx(am,Data,r12vrr_stack+261, r12vrr_stack+9626, r12vrr_stack+476, r12vrr_stack+8962, r12vrr_stack+9590, NULL);

 /*--- compute (p0|m0)^5 ---*/
 am[0] = 1;  am[1] = 9;
 vrr_build_xxxx(am,Data,r12vrr_stack+15846, r12vrr_stack+5430, r12vrr_stack+261, NULL, NULL, r12vrr_stack+9626);

 /*--- compute (d0|m0)^4 ---*/
 am[0] = 2;  am[1] = 9;
 vrr_build_xxxx(am,Data,r12vrr_stack+16011, r12vrr_stack+13956, r12vrr_stack+15846, r12vrr_stack+18241, r12vrr_stack+5430, r12vrr_stack+9671);

 /*--- compute (f0|m0)^3 ---*/
 am[0] = 3;  am[1] = 9;
 vrr_build_xxxx(am,Data,r12vrr_stack+16341, r12vrr_stack+14121, r12vrr_stack+16011, r12vrr_stack+12966, r12vrr_stack+13956, r12vrr_stack+9806);

 /*--- compute (g0|m0)^2 ---*/
 am[0] = 4;  am[1] = 9;
 vrr_build_xxxx(am,Data,r12vrr_stack+48816, r12vrr_stack+32061, r12vrr_stack+16341, r12vrr_stack+19506, r12vrr_stack+14121, r12vrr_stack+28731);

 /*--- compute (h0|m0)^1 ---*/
 am[0] = 5;  am[1] = 9;
 vrr_build_xxxx(am,Data,r12vrr_stack+49641, r12vrr_stack+32611, r12vrr_stack+48816, r12vrr_stack+19836, r12vrr_stack+32061, r12vrr_stack+29181);

 /*--- compute (i0|m0)^0 ---*/
 am[0] = 6;  am[1] = 9;
 vrr_build_xxxx(am,Data,r12vrr_stack+50796, r12vrr_stack+33436, r12vrr_stack+49641, r12vrr_stack+20936, r12vrr_stack+32611, r12vrr_stack+29856);
 tmp = r12vrr_stack + 50796;
 target_ptr = Libr12->gvrr_classes[6][9];
 for(i=0;i<1540;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (p0|00)^7 ---*/
 _BUILD_p000(Data,r12vrr_stack+12966, Data->F+7, Data->F+8, NULL, NULL, NULL);

 /*--- compute (d0|00)^6 ---*/
 _BUILD_d000(Data,r12vrr_stack+12969, r12vrr_stack+18296, r12vrr_stack+12966, Data->F+6, Data->F+7, NULL);

 /*--- compute (f0|00)^5 ---*/
 _BUILD_f000(Data,r12vrr_stack+12975, r12vrr_stack+18299, r12vrr_stack+12969, r12vrr_stack+18516, r12vrr_stack+18296, NULL);

 /*--- compute (g0|00)^4 ---*/
 _BUILD_g000(Data,r12vrr_stack+12985, r12vrr_stack+18305, r12vrr_stack+12975, r12vrr_stack+18519, r12vrr_stack+18299, NULL);

 /*--- compute (p0|p0)^7 ---*/
 _BUILD_p0p0(Data,r12vrr_stack+13000, r12vrr_stack+27, r12vrr_stack+3, NULL, NULL, Data->F+8);

 /*--- compute (d0|p0)^6 ---*/
 _BUILD_d0p0(Data,r12vrr_stack+18507, r12vrr_stack+6, r12vrr_stack+13000, r12vrr_stack+21, r12vrr_stack+27, r12vrr_stack+12966);

 /*--- compute (f0|p0)^5 ---*/
 _BUILD_f0p0(Data,r12vrr_stack+27, r12vrr_stack+18315, r12vrr_stack+18507, r12vrr_stack+3196, r12vrr_stack+6, r12vrr_stack+12969);

 /*--- compute (g0|p0)^4 ---*/
 _BUILD_g0p0(Data,r12vrr_stack+13009, r12vrr_stack+18333, r12vrr_stack+27, r12vrr_stack+57, r12vrr_stack+18315, r12vrr_stack+12975);

 /*--- compute (h0|p0)^3 ---*/
 _BUILD_h0p0(Data,r12vrr_stack+13054, r12vrr_stack+18363, r12vrr_stack+13009, r12vrr_stack+18525, r12vrr_stack+18333, r12vrr_stack+12985);

 /*--- compute (p0|d0)^7 ---*/
 _BUILD_p0d0(Data,r12vrr_stack+57, r12vrr_stack+15, r12vrr_stack+173, NULL, NULL, r12vrr_stack+3);

 /*--- compute (d0|d0)^6 ---*/
 _BUILD_d0d0(Data,r12vrr_stack+16891, r12vrr_stack+1542, r12vrr_stack+57, r12vrr_stack+180, r12vrr_stack+15, r12vrr_stack+13000);

 /*--- compute (f0|d0)^5 ---*/
 _BUILD_f0d0(Data,r12vrr_stack+16927, r12vrr_stack+18408, r12vrr_stack+16891, r12vrr_stack+18555, r12vrr_stack+1542, r12vrr_stack+18507);

 /*--- compute (g0|d0)^4 ---*/
 _BUILD_g0d0(Data,r12vrr_stack+16987, r12vrr_stack+13491, r12vrr_stack+16927, r12vrr_stack+18573, r12vrr_stack+18408, r12vrr_stack+27);

 /*--- compute (h0|d0)^3 ---*/
 _BUILD_h0d0(Data,r12vrr_stack+17077, r12vrr_stack+8799, r12vrr_stack+16987, r12vrr_stack+18609, r12vrr_stack+13491, r12vrr_stack+13009);

 /*--- compute (i0|d0)^2 ---*/
 _BUILD_i0d0(Data,r12vrr_stack+8998, r12vrr_stack+14451, r12vrr_stack+17077, r12vrr_stack+19011, r12vrr_stack+8799, r12vrr_stack+13054);

 /*--- compute (p0|f0)^7 ---*/
 _BUILD_p0f0(Data,r12vrr_stack+27, r12vrr_stack+542, r12vrr_stack+3205, NULL, NULL, r12vrr_stack+173);

 /*--- compute (d0|f0)^6 ---*/
 _BUILD_d0f0(Data,r12vrr_stack+13491, r12vrr_stack+1560, r12vrr_stack+27, r12vrr_stack+316, r12vrr_stack+542, r12vrr_stack+57);

 /*--- compute (f0|f0)^5 ---*/
 _BUILD_f0f0(Data,r12vrr_stack+14451, r12vrr_stack+1590, r12vrr_stack+13491, r12vrr_stack+75, r12vrr_stack+1560, r12vrr_stack+16891);

 /*--- compute (g0|f0)^4 ---*/
 _BUILD_g0f0(Data,r12vrr_stack+57, r12vrr_stack+14577, r12vrr_stack+14451, r12vrr_stack+19101, r12vrr_stack+1590, r12vrr_stack+16927);

 /*--- compute (h0|f0)^3 ---*/
 _BUILD_h0f0(Data,r12vrr_stack+7898, r12vrr_stack+6306, r12vrr_stack+57, r12vrr_stack+19161, r12vrr_stack+14577, r12vrr_stack+16987);

 /*--- compute (i0|f0)^2 ---*/
 _BUILD_i0f0(Data,r12vrr_stack+19501, r12vrr_stack+18669, r12vrr_stack+7898, r12vrr_stack+19261, r12vrr_stack+6306, r12vrr_stack+17077);

 /*--- compute (k0|f0)^1 ---*/
 am[0] = 7;  am[1] = 3;
 vrr_build_xxxx(am,Data,r12vrr_stack+19011, r12vrr_stack+34591, r12vrr_stack+19501, r12vrr_stack+13131, r12vrr_stack+18669, r12vrr_stack+8998);

 /*--- compute (p0|g0)^7 ---*/
 _BUILD_p0g0(Data,r12vrr_stack+8998, r12vrr_stack+3215, r12vrr_stack+5485, NULL, NULL, r12vrr_stack+3205);

 /*--- compute (d0|g0)^6 ---*/
 _BUILD_d0g0(Data,r12vrr_stack+8799, r12vrr_stack+8889, r12vrr_stack+8998, r12vrr_stack+552, r12vrr_stack+3215, r12vrr_stack+27);

 /*--- compute (f0|g0)^5 ---*/
 _BUILD_f0g0(Data,r12vrr_stack+34591, r12vrr_stack+1650, r12vrr_stack+8799, r12vrr_stack+216, r12vrr_stack+8889, r12vrr_stack+13491);

 /*--- compute (g0|g0)^4 ---*/
 _BUILD_g0g0(Data,r12vrr_stack+16891, r12vrr_stack+326, r12vrr_stack+34591, r12vrr_stack+19411, r12vrr_stack+1650, r12vrr_stack+14451);

 /*--- compute (h0|g0)^3 ---*/
 _BUILD_h0g0(Data,r12vrr_stack+18507, r12vrr_stack+1740, r12vrr_stack+16891, r12vrr_stack+13341, r12vrr_stack+326, r12vrr_stack+57);

 /*--- compute (i0|g0)^2 ---*/
 _BUILD_i0g0(Data,r12vrr_stack+12966, r12vrr_stack+34871, r12vrr_stack+18507, r12vrr_stack+21761, r12vrr_stack+1740, r12vrr_stack+7898);

 /*--- compute (k0|g0)^1 ---*/
 am[0] = 7;  am[1] = 4;
 vrr_build_xxxx(am,Data,r12vrr_stack+19781, r12vrr_stack+35186, r12vrr_stack+12966, r12vrr_stack+21986, r12vrr_stack+34871, r12vrr_stack+19501);

 /*--- compute (l0|g0)^0 ---*/
 am[0] = 8;  am[1] = 4;
 vrr_build_xxxx(am,Data,r12vrr_stack+52336, r12vrr_stack+1965, r12vrr_stack+19781, r12vrr_stack+22301, r12vrr_stack+35186, r12vrr_stack+19011);

 /*--- compute (p0|h0)^7 ---*/
 _BUILD_p0h0(Data,r12vrr_stack+19011, r12vrr_stack+5500, r12vrr_stack+5369, NULL, NULL, r12vrr_stack+5485);

 /*--- compute (d0|h0)^6 ---*/
 _BUILD_d0h0(Data,r12vrr_stack+19074, r12vrr_stack+18444, r12vrr_stack+19011, r12vrr_stack+3230, r12vrr_stack+5500, r12vrr_stack+8998);

 /*--- compute (f0|h0)^5 ---*/
 _BUILD_f0h0(Data,r12vrr_stack+19200, r12vrr_stack+18879, r12vrr_stack+19074, r12vrr_stack+867, r12vrr_stack+18444, r12vrr_stack+8799);

 /*--- compute (g0|h0)^4 ---*/
 _BUILD_g0h0(Data,r12vrr_stack+19410, r12vrr_stack+35606, r12vrr_stack+19200, r12vrr_stack+930, r12vrr_stack+18879, r12vrr_stack+34591);

 /*--- compute (h0|h0)^3 ---*/
 _BUILD_h0h0(Data,r12vrr_stack+34591, r12vrr_stack+35816, r12vrr_stack+19410, r12vrr_stack+22721, r12vrr_stack+35606, r12vrr_stack+16891);

 /*--- compute (i0|h0)^2 ---*/
 _BUILD_i0h0(Data,r12vrr_stack+35032, r12vrr_stack+36131, r12vrr_stack+34591, r12vrr_stack+22931, r12vrr_stack+35816, r12vrr_stack+18507);

 /*--- compute (k0|h0)^1 ---*/
 am[0] = 7;  am[1] = 5;
 vrr_build_xxxx(am,Data,r12vrr_stack+18186, r12vrr_stack+36572, r12vrr_stack+35032, r12vrr_stack+23246, r12vrr_stack+36131, r12vrr_stack+12966);

 /*--- compute (l0|h0)^0 ---*/
 am[0] = 8;  am[1] = 5;
 vrr_build_xxxx(am,Data,r12vrr_stack+22721, r12vrr_stack+37160, r12vrr_stack+18186, r12vrr_stack+23687, r12vrr_stack+36572, r12vrr_stack+19781);
 tmp = r12vrr_stack + 22721;
 target_ptr = Libr12->gvrr_classes[8][5];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (p0|i0)^7 ---*/
 _BUILD_p0i0(Data,r12vrr_stack+12966, r12vrr_stack+8934, r12vrr_stack+9562, NULL, NULL, r12vrr_stack+5369);

 /*--- compute (d0|i0)^6 ---*/
 _BUILD_d0i0(Data,r12vrr_stack+13050, r12vrr_stack+3931, r12vrr_stack+12966, r12vrr_stack+5521, r12vrr_stack+8934, r12vrr_stack+19011);

 /*--- compute (f0|i0)^5 ---*/
 _BUILD_f0i0(Data,r12vrr_stack+13218, r12vrr_stack+4015, r12vrr_stack+13050, r12vrr_stack+1056, r12vrr_stack+3931, r12vrr_stack+19074);

 /*--- compute (g0|i0)^4 ---*/
 _BUILD_g0i0(Data,r12vrr_stack+35620, r12vrr_stack+4183, r12vrr_stack+13218, r12vrr_stack+3279, r12vrr_stack+4015, r12vrr_stack+19200);

 /*--- compute (h0|i0)^3 ---*/
 _BUILD_h0i0(Data,r12vrr_stack+36040, r12vrr_stack+37916, r12vrr_stack+35620, r12vrr_stack+2867, r12vrr_stack+4183, r12vrr_stack+19410);

 /*--- compute (i0|i0)^2 ---*/
 _BUILD_i0i0(Data,r12vrr_stack+19011, r12vrr_stack+38336, r12vrr_stack+36040, r12vrr_stack+24275, r12vrr_stack+37916, r12vrr_stack+34591);

 /*--- compute (k0|i0)^1 ---*/
 am[0] = 7;  am[1] = 6;
 vrr_build_xxxx(am,Data,r12vrr_stack+53011, r12vrr_stack+38924, r12vrr_stack+19011, r12vrr_stack+24695, r12vrr_stack+38336, r12vrr_stack+35032);

 /*--- compute (l0|i0)^0 ---*/
 am[0] = 8;  am[1] = 6;
 vrr_build_xxxx(am,Data,r12vrr_stack+54019, r12vrr_stack+39708, r12vrr_stack+53011, r12vrr_stack+25283, r12vrr_stack+38924, r12vrr_stack+18186);
 tmp = r12vrr_stack + 54019;
 target_ptr = Libr12->gvrr_classes[8][6];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (p0|k0)^7 ---*/
 am[0] = 1;  am[1] = 7;
 vrr_build_xxxx(am,Data,r12vrr_stack+18186, r12vrr_stack+9590, r12vrr_stack+11143, NULL, NULL, r12vrr_stack+9562);

 /*--- compute (d0|k0)^6 ---*/
 am[0] = 2;  am[1] = 7;
 vrr_build_xxxx(am,Data,r12vrr_stack+18294, r12vrr_stack+7214, r12vrr_stack+18186, r12vrr_stack+8962, r12vrr_stack+9590, r12vrr_stack+12966);

 /*--- compute (f0|k0)^5 ---*/
 am[0] = 3;  am[1] = 7;
 vrr_build_xxxx(am,Data,r12vrr_stack+18510, r12vrr_stack+7322, r12vrr_stack+18294, r12vrr_stack+5982, r12vrr_stack+7214, r12vrr_stack+13050);

 /*--- compute (g0|k0)^4 ---*/
 am[0] = 4;  am[1] = 7;
 vrr_build_xxxx(am,Data,r12vrr_stack+21761, r12vrr_stack+7538, r12vrr_stack+18510, r12vrr_stack+6090, r12vrr_stack+7322, r12vrr_stack+13218);

 /*--- compute (h0|k0)^3 ---*/
 am[0] = 5;  am[1] = 7;
 vrr_build_xxxx(am,Data,r12vrr_stack+34591, r12vrr_stack+40716, r12vrr_stack+21761, r12vrr_stack+26067, r12vrr_stack+7538, r12vrr_stack+35620);

 /*--- compute (i0|k0)^2 ---*/
 am[0] = 6;  am[1] = 7;
 vrr_build_xxxx(am,Data,r12vrr_stack+24275, r12vrr_stack+41256, r12vrr_stack+34591, r12vrr_stack+26427, r12vrr_stack+40716, r12vrr_stack+36040);

 /*--- compute (k0|k0)^1 ---*/
 am[0] = 7;  am[1] = 7;
 vrr_build_xxxx(am,Data,r12vrr_stack+35347, r12vrr_stack+42012, r12vrr_stack+24275, r12vrr_stack+26967, r12vrr_stack+41256, r12vrr_stack+19011);

 /*--- compute (l0|k0)^0 ---*/
 am[0] = 8;  am[1] = 7;
 vrr_build_xxxx(am,Data,r12vrr_stack+26067, r12vrr_stack+43020, r12vrr_stack+35347, r12vrr_stack+27723, r12vrr_stack+42012, r12vrr_stack+53011);
 tmp = r12vrr_stack + 26067;
 target_ptr = Libr12->gvrr_classes[8][7];
 for(i=0;i<1620;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (00|p0)^15 ---*/
 _BUILD_00p0(Data,r12vrr_stack+53011, Data->F+15, Data->F+16, NULL, NULL, NULL);

 /*--- compute (00|d0)^14 ---*/
 _BUILD_00d0(Data,r12vrr_stack+53014, r12vrr_stack+11094, r12vrr_stack+53011, Data->F+14, Data->F+15, NULL);

 /*--- compute (00|f0)^13 ---*/
 _BUILD_00f0(Data,r12vrr_stack+53020, r12vrr_stack+19005, r12vrr_stack+53014, r12vrr_stack+0, r12vrr_stack+11094, NULL);

 /*--- compute (00|g0)^12 ---*/
 _BUILD_00g0(Data,r12vrr_stack+0, r12vrr_stack+11097, r12vrr_stack+53020, r12vrr_stack+9510, r12vrr_stack+19005, NULL);

 /*--- compute (00|h0)^11 ---*/
 _BUILD_00h0(Data,r12vrr_stack+23666, r12vrr_stack+11107, r12vrr_stack+0, r12vrr_stack+9516, r12vrr_stack+11097, NULL);

 /*--- compute (00|i0)^10 ---*/
 _BUILD_00i0(Data,r12vrr_stack+53011, r12vrr_stack+11122, r12vrr_stack+23666, r12vrr_stack+9526, r12vrr_stack+11107, NULL);

 /*--- compute (00|k0)^9 ---*/
 am[0] = 0;  am[1] = 7;
 vrr_build_xxxx(am,Data,r12vrr_stack+27687, r12vrr_stack+3251, r12vrr_stack+53011, r12vrr_stack+9541, r12vrr_stack+11122, NULL);

 /*--- compute (00|l0)^8 ---*/
 am[0] = 0;  am[1] = 8;
 vrr_build_xxxx(am,Data,r12vrr_stack+53011, r12vrr_stack+11143, r12vrr_stack+27687, r12vrr_stack+9562, r12vrr_stack+3251, NULL);

 /*--- compute (p0|l0)^7 ---*/
 am[0] = 1;  am[1] = 8;
 vrr_build_xxxx(am,Data,r12vrr_stack+53056, r12vrr_stack+476, r12vrr_stack+53011, NULL, NULL, r12vrr_stack+11143);

 /*--- compute (d0|l0)^6 ---*/
 am[0] = 2;  am[1] = 8;
 vrr_build_xxxx(am,Data,r12vrr_stack+14451, r12vrr_stack+11179, r12vrr_stack+53056, r12vrr_stack+9626, r12vrr_stack+476, r12vrr_stack+18186);

 /*--- compute (f0|l0)^5 ---*/
 am[0] = 3;  am[1] = 8;
 vrr_build_xxxx(am,Data,r12vrr_stack+53056, r12vrr_stack+11314, r12vrr_stack+14451, r12vrr_stack+9671, r12vrr_stack+11179, r12vrr_stack+18294);

 /*--- compute (g0|l0)^4 ---*/
 am[0] = 4;  am[1] = 8;
 vrr_build_xxxx(am,Data,r12vrr_stack+40716, r12vrr_stack+11584, r12vrr_stack+53056, r12vrr_stack+9806, r12vrr_stack+11314, r12vrr_stack+18510);

 /*--- compute (h0|l0)^3 ---*/
 am[0] = 5;  am[1] = 8;
 vrr_build_xxxx(am,Data,r12vrr_stack+53056, r12vrr_stack+44316, r12vrr_stack+40716, r12vrr_stack+28731, r12vrr_stack+11584, r12vrr_stack+21761);

 /*--- compute (i0|l0)^2 ---*/
 am[0] = 6;  am[1] = 8;
 vrr_build_xxxx(am,Data,r12vrr_stack+40716, r12vrr_stack+44991, r12vrr_stack+53056, r12vrr_stack+29181, r12vrr_stack+44316, r12vrr_stack+34591);

 /*--- compute (k0|l0)^1 ---*/
 am[0] = 7;  am[1] = 8;
 vrr_build_xxxx(am,Data,r12vrr_stack+18186, r12vrr_stack+45936, r12vrr_stack+40716, r12vrr_stack+29856, r12vrr_stack+44991, r12vrr_stack+24275);

 /*--- compute (l0|l0)^0 ---*/
 am[0] = 8;  am[1] = 8;
 vrr_build_xxxx(am,Data,r12vrr_stack+40716, r12vrr_stack+47196, r12vrr_stack+18186, r12vrr_stack+30801, r12vrr_stack+45936, r12vrr_stack+35347);

 /*--- compute (00|m0)^7 ---*/
 am[0] = 0;  am[1] = 9;
 vrr_build_xxxx(am,Data,r12vrr_stack+18186, r12vrr_stack+476, r12vrr_stack+53011, r12vrr_stack+9590, r12vrr_stack+11143, NULL);

 /*--- compute (p0|m0)^6 ---*/
 am[0] = 1;  am[1] = 9;
 vrr_build_xxxx(am,Data,r12vrr_stack+53011, r12vrr_stack+261, r12vrr_stack+18186, NULL, NULL, r12vrr_stack+476);

 /*--- compute (d0|m0)^5 ---*/
 am[0] = 2;  am[1] = 9;
 vrr_build_xxxx(am,Data,r12vrr_stack+18186, r12vrr_stack+15846, r12vrr_stack+53011, r12vrr_stack+5430, r12vrr_stack+261, r12vrr_stack+11179);

 /*--- compute (f0|m0)^4 ---*/
 am[0] = 3;  am[1] = 9;
 vrr_build_xxxx(am,Data,r12vrr_stack+53011, r12vrr_stack+16011, r12vrr_stack+18186, r12vrr_stack+13956, r12vrr_stack+15846, r12vrr_stack+11314);

 /*--- compute (g0|m0)^3 ---*/
 am[0] = 4;  am[1] = 9;
 vrr_build_xxxx(am,Data,r12vrr_stack+18186, r12vrr_stack+16341, r12vrr_stack+53011, r12vrr_stack+14121, r12vrr_stack+16011, r12vrr_stack+11584);

 /*--- compute (h0|m0)^2 ---*/
 am[0] = 5;  am[1] = 9;
 vrr_build_xxxx(am,Data,r12vrr_stack+19011, r12vrr_stack+48816, r12vrr_stack+18186, r12vrr_stack+32061, r12vrr_stack+16341, r12vrr_stack+44316);

 /*--- compute (i0|m0)^1 ---*/
 am[0] = 6;  am[1] = 9;
 vrr_build_xxxx(am,Data,r12vrr_stack+34591, r12vrr_stack+49641, r12vrr_stack+19011, r12vrr_stack+32611, r12vrr_stack+48816, r12vrr_stack+44991);

 /*--- compute (k0|m0)^0 ---*/
 am[0] = 7;  am[1] = 9;
 vrr_build_xxxx(am,Data,r12vrr_stack+18186, r12vrr_stack+50796, r12vrr_stack+34591, r12vrr_stack+33436, r12vrr_stack+49641, r12vrr_stack+45936);

 /*--- compute (00||p0)^0 ---*/
 _R_BUILD_00p0(Data,r12vrr_stack+34591, &(Data->ss_r12_ss), NULL, r12vrr_stack+24, Data->F+0, NULL, NULL);

 /*--- compute (00||d0)^0 ---*/
 _R_BUILD_00d0(Data,r12vrr_stack+34594, r12vrr_stack+34591, &(Data->ss_r12_ss), r12vrr_stack+701, r12vrr_stack+24, Data->F+0, NULL);

 /*--- compute (00||f0)^0 ---*/
 _R_BUILD_00f0(Data,r12vrr_stack+34600, r12vrr_stack+34594, r12vrr_stack+34591, r12vrr_stack+707, r12vrr_stack+701, r12vrr_stack+24, NULL);

 /*--- compute (00||g0)^0 ---*/
 _R_BUILD_00g0(Data,r12vrr_stack+34610, r12vrr_stack+34600, r12vrr_stack+34594, r12vrr_stack+717, r12vrr_stack+707, r12vrr_stack+701, NULL);

 /*--- compute (00||h0)^0 ---*/
 _R_BUILD_00h0(Data,r12vrr_stack+23666, r12vrr_stack+34610, r12vrr_stack+34600, r12vrr_stack+521, r12vrr_stack+717, r12vrr_stack+707, NULL);

 /*--- compute (p0||h0)^0 ---*/
 _R_BUILD_p0h0(Data,r12vrr_stack+34625, r12vrr_stack+23666, NULL, r12vrr_stack+3532, r12vrr_stack+521, NULL, r12vrr_stack+717);

 /*--- compute (d0||h0)^0 ---*/
 _R_BUILD_d0h0(Data,r12vrr_stack+34688, r12vrr_stack+34625, r12vrr_stack+23666, r12vrr_stack+3595, r12vrr_stack+3532, r12vrr_stack+521, r12vrr_stack+732);

 /*--- compute (f0||h0)^0 ---*/
 _R_BUILD_f0h0(Data,r12vrr_stack+34814, r12vrr_stack+34688, r12vrr_stack+34625, r12vrr_stack+3721, r12vrr_stack+3595, r12vrr_stack+3532, r12vrr_stack+777);

 /*--- compute (g0||h0)^0 ---*/
 _R_BUILD_g0h0(Data,r12vrr_stack+732, r12vrr_stack+34814, r12vrr_stack+34688, r12vrr_stack+4582, r12vrr_stack+3721, r12vrr_stack+3595, r12vrr_stack+1167);
 tmp = r12vrr_stack + 732;
 target_ptr = Libr12->rvrr_classes[4][5];
 for(i=0;i<315;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (h0||h0)^0 ---*/
 _R_BUILD_h0h0(Data,r12vrr_stack+35024, r12vrr_stack+732, r12vrr_stack+34814, r12vrr_stack+4897, r12vrr_stack+4582, r12vrr_stack+3721, r12vrr_stack+1317);
 tmp = r12vrr_stack + 35024;
 target_ptr = Libr12->rvrr_classes[5][5];
 for(i=0;i<441;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (i0||h0)^0 ---*/
 _R_BUILD_i0h0(Data,r12vrr_stack+35465, r12vrr_stack+35024, r12vrr_stack+732, r12vrr_stack+23687, r12vrr_stack+4897, r12vrr_stack+4582, r12vrr_stack+2524);
 tmp = r12vrr_stack + 35465;
 target_ptr = Libr12->rvrr_classes[6][5];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (00||i0)^0 ---*/
 _R_BUILD_00i0(Data,r12vrr_stack+732, r12vrr_stack+23666, r12vrr_stack+34610, r12vrr_stack+2839, r12vrr_stack+521, r12vrr_stack+717, NULL);

 /*--- compute (p0||i0)^0 ---*/
 _R_BUILD_p0i0(Data,r12vrr_stack+760, r12vrr_stack+732, NULL, r12vrr_stack+5730, r12vrr_stack+2839, NULL, r12vrr_stack+521);

 /*--- compute (d0||i0)^0 ---*/
 _R_BUILD_d0i0(Data,r12vrr_stack+844, r12vrr_stack+760, r12vrr_stack+732, r12vrr_stack+5814, r12vrr_stack+5730, r12vrr_stack+2839, r12vrr_stack+3532);

 /*--- compute (f0||i0)^0 ---*/
 _R_BUILD_f0i0(Data,r12vrr_stack+1012, r12vrr_stack+844, r12vrr_stack+760, r12vrr_stack+6514, r12vrr_stack+5814, r12vrr_stack+5730, r12vrr_stack+3595);

 /*--- compute (g0||i0)^0 ---*/
 _R_BUILD_g0i0(Data,r12vrr_stack+34591, r12vrr_stack+1012, r12vrr_stack+844, r12vrr_stack+6794, r12vrr_stack+6514, r12vrr_stack+5814, r12vrr_stack+3721);
 tmp = r12vrr_stack + 34591;
 target_ptr = Libr12->rvrr_classes[4][6];
 for(i=0;i<420;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (h0||i0)^0 ---*/
 _R_BUILD_h0i0(Data,r12vrr_stack+36053, r12vrr_stack+34591, r12vrr_stack+1012, r12vrr_stack+8166, r12vrr_stack+6794, r12vrr_stack+6514, r12vrr_stack+4582);
 tmp = r12vrr_stack + 36053;
 target_ptr = Libr12->rvrr_classes[5][6];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (i0||i0)^0 ---*/
 _R_BUILD_i0i0(Data,r12vrr_stack+48816, r12vrr_stack+36053, r12vrr_stack+34591, r12vrr_stack+25283, r12vrr_stack+8166, r12vrr_stack+6794, r12vrr_stack+4897);
 tmp = r12vrr_stack + 48816;
 target_ptr = Libr12->rvrr_classes[6][6];
 for(i=0;i<784;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (00||k0)^0 ---*/
 _R_BUILD_00k0(Data,r12vrr_stack+27687, r12vrr_stack+732, r12vrr_stack+23666, r12vrr_stack+5394, r12vrr_stack+2839, r12vrr_stack+521, NULL);

 /*--- compute (p0||k0)^0 ---*/
 _R_BUILD_p0k0(Data,r12vrr_stack+34591, r12vrr_stack+27687, NULL, r12vrr_stack+9186, r12vrr_stack+5394, NULL, r12vrr_stack+2839);

 /*--- compute (d0||k0)^0 ---*/
 _R_BUILD_d0k0(Data,r12vrr_stack+34699, r12vrr_stack+34591, r12vrr_stack+27687, r12vrr_stack+9294, r12vrr_stack+9186, r12vrr_stack+5394, r12vrr_stack+5730);

 /*--- compute (f0||k0)^0 ---*/
 _R_BUILD_f0k0(Data,r12vrr_stack+760, r12vrr_stack+34699, r12vrr_stack+34591, r12vrr_stack+10194, r12vrr_stack+9294, r12vrr_stack+9186, r12vrr_stack+5814);

 /*--- compute (g0||k0)^0 ---*/
 _R_BUILD_g0k0(Data,r12vrr_stack+21761, r12vrr_stack+760, r12vrr_stack+34699, r12vrr_stack+10554, r12vrr_stack+10194, r12vrr_stack+9294, r12vrr_stack+6514);
 tmp = r12vrr_stack + 21761;
 target_ptr = Libr12->rvrr_classes[4][7];
 for(i=0;i<540;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (h0||k0)^0 ---*/
 _R_BUILD_h0k0(Data,r12vrr_stack+49600, r12vrr_stack+21761, r12vrr_stack+760, r12vrr_stack+12210, r12vrr_stack+10554, r12vrr_stack+10194, r12vrr_stack+6794);
 tmp = r12vrr_stack + 49600;
 target_ptr = Libr12->rvrr_classes[5][7];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (i0||k0)^0 ---*/
 _R_BUILD_i0k0(Data,r12vrr_stack+53011, r12vrr_stack+49600, r12vrr_stack+21761, r12vrr_stack+27723, r12vrr_stack+12210, r12vrr_stack+10554, r12vrr_stack+8166);
 tmp = r12vrr_stack + 53011;
 target_ptr = Libr12->rvrr_classes[6][7];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (00||l0)^0 ---*/
 _R_BUILD_00l0(Data,r12vrr_stack+21761, r12vrr_stack+27687, r12vrr_stack+732, r12vrr_stack+8754, r12vrr_stack+5394, r12vrr_stack+2839, NULL);

 /*--- compute (p0||l0)^0 ---*/
 _R_BUILD_p0l0(Data,r12vrr_stack+2839, r12vrr_stack+21761, NULL, r12vrr_stack+13551, r12vrr_stack+8754, NULL, r12vrr_stack+5394);

 /*--- compute (d0||l0)^0 ---*/
 _R_BUILD_d0l0(Data,r12vrr_stack+2974, r12vrr_stack+2839, r12vrr_stack+21761, r12vrr_stack+13686, r12vrr_stack+13551, r12vrr_stack+8754, r12vrr_stack+9186);

 /*--- compute (f0||l0)^0 ---*/
 _R_BUILD_f0l0(Data,r12vrr_stack+8754, r12vrr_stack+2974, r12vrr_stack+2839, r12vrr_stack+14721, r12vrr_stack+13686, r12vrr_stack+13551, r12vrr_stack+9294);

 /*--- compute (g0||l0)^0 ---*/
 _R_BUILD_g0l0(Data,r12vrr_stack+9204, r12vrr_stack+8754, r12vrr_stack+2974, r12vrr_stack+15171, r12vrr_stack+14721, r12vrr_stack+13686, r12vrr_stack+10194);
 tmp = r12vrr_stack + 9204;
 target_ptr = Libr12->rvrr_classes[4][8];
 for(i=0;i<675;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (h0||l0)^0 ---*/
 _R_BUILD_h0l0(Data,r12vrr_stack+44316, r12vrr_stack+9204, r12vrr_stack+8754, r12vrr_stack+17241, r12vrr_stack+15171, r12vrr_stack+14721, r12vrr_stack+10554);
 tmp = r12vrr_stack + 44316;
 target_ptr = Libr12->rvrr_classes[5][8];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (i0||l0)^0 ---*/
 _R_BUILD_i0l0(Data,r12vrr_stack+45261, r12vrr_stack+44316, r12vrr_stack+9204, r12vrr_stack+30801, r12vrr_stack+17241, r12vrr_stack+15171, r12vrr_stack+12210);
 tmp = r12vrr_stack + 45261;
 target_ptr = Libr12->rvrr_classes[6][8];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (g0|[r12,T2]|h0)^0 ---*/
 _T2_BUILD_g0h0(Data,&(Libr12->ShellQuartet),r12vrr_stack+8754, r12vrr_stack+4582, r12vrr_stack+6794, r12vrr_stack+4897, r12vrr_stack+2524, r12vrr_stack+1317);
 tmp = r12vrr_stack + 8754;
 target_ptr = Libr12->t2vrr_classes[4][5];
 for(i=0;i<315;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (g0|[r12,T2]|i0)^0 ---*/
 _T2_BUILD_g0i0(Data,&(Libr12->ShellQuartet),r12vrr_stack+9069, r12vrr_stack+6794, r12vrr_stack+10554, r12vrr_stack+8166, r12vrr_stack+4897, r12vrr_stack+4582);
 tmp = r12vrr_stack + 9069;
 target_ptr = Libr12->t2vrr_classes[4][6];
 for(i=0;i<420;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (g0|[r12,T2]|k0)^0 ---*/
 _T2_BUILD_g0k0(Data,&(Libr12->ShellQuartet),r12vrr_stack+21761, r12vrr_stack+10554, r12vrr_stack+15171, r12vrr_stack+12210, r12vrr_stack+8166, r12vrr_stack+6794);
 tmp = r12vrr_stack + 21761;
 target_ptr = Libr12->t2vrr_classes[4][7];
 for(i=0;i<540;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (g0|[r12,T2]|l0)^0 ---*/
 _T2_BUILD_g0l0(Data,&(Libr12->ShellQuartet),r12vrr_stack+46521, r12vrr_stack+15171, r12vrr_stack+20936, r12vrr_stack+17241, r12vrr_stack+12210, r12vrr_stack+10554);
 tmp = r12vrr_stack + 46521;
 target_ptr = Libr12->t2vrr_classes[4][8];
 for(i=0;i<675;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (h0|[r12,T2]|h0)^0 ---*/
 _T2_BUILD_h0h0(Data,&(Libr12->ShellQuartet),r12vrr_stack+9489, r12vrr_stack+4897, r12vrr_stack+8166, r12vrr_stack+23687, r12vrr_stack+22301, r12vrr_stack+2524);
 tmp = r12vrr_stack + 9489;
 target_ptr = Libr12->t2vrr_classes[5][5];
 for(i=0;i<441;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (h0|[r12,T2]|i0)^0 ---*/
 _T2_BUILD_h0i0(Data,&(Libr12->ShellQuartet),r12vrr_stack+32061, r12vrr_stack+8166, r12vrr_stack+12210, r12vrr_stack+25283, r12vrr_stack+23687, r12vrr_stack+4897);
 tmp = r12vrr_stack + 32061;
 target_ptr = Libr12->t2vrr_classes[5][6];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (h0|[r12,T2]|k0)^0 ---*/
 _T2_BUILD_h0k0(Data,&(Libr12->ShellQuartet),r12vrr_stack+32649, r12vrr_stack+12210, r12vrr_stack+17241, r12vrr_stack+27723, r12vrr_stack+25283, r12vrr_stack+8166);
 tmp = r12vrr_stack + 32649;
 target_ptr = Libr12->t2vrr_classes[5][7];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (h0|[r12,T2]|l0)^0 ---*/
 _T2_BUILD_h0l0(Data,&(Libr12->ShellQuartet),r12vrr_stack+15846, r12vrr_stack+17241, r12vrr_stack+33436, r12vrr_stack+30801, r12vrr_stack+27723, r12vrr_stack+12210);
 tmp = r12vrr_stack + 15846;
 target_ptr = Libr12->t2vrr_classes[5][8];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (i0|[r12,T2]|h0)^0 ---*/
 _T2_BUILD_i0h0(Data,&(Libr12->ShellQuartet),r12vrr_stack+24275, r12vrr_stack+23687, r12vrr_stack+25283, r12vrr_stack+37160, r12vrr_stack+1965, r12vrr_stack+22301);
 tmp = r12vrr_stack + 24275;
 target_ptr = Libr12->t2vrr_classes[6][5];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (i0|[r12,T2]|i0)^0 ---*/
 _T2_BUILD_i0i0(Data,&(Libr12->ShellQuartet),r12vrr_stack+28731, r12vrr_stack+25283, r12vrr_stack+27723, r12vrr_stack+39708, r12vrr_stack+37160, r12vrr_stack+23687);
 tmp = r12vrr_stack + 28731;
 target_ptr = Libr12->t2vrr_classes[6][6];
 for(i=0;i<784;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (i0|[r12,T2]|k0)^0 ---*/
 _T2_BUILD_i0k0(Data,&(Libr12->ShellQuartet),r12vrr_stack+29515, r12vrr_stack+27723, r12vrr_stack+30801, r12vrr_stack+43020, r12vrr_stack+39708, r12vrr_stack+25283);
 tmp = r12vrr_stack + 29515;
 target_ptr = Libr12->t2vrr_classes[6][7];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (i0|[r12,T2]|l0)^0 ---*/
 _T2_BUILD_i0l0(Data,&(Libr12->ShellQuartet),r12vrr_stack+0, r12vrr_stack+30801, r12vrr_stack+50796, r12vrr_stack+47196, r12vrr_stack+43020, r12vrr_stack+27723);
 tmp = r12vrr_stack + 0;
 target_ptr = Libr12->t2vrr_classes[6][8];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (k0|[r12,T2]|h0)^0 ---*/
 _T2_BUILD_k0h0(Data,&(Libr12->ShellQuartet),r12vrr_stack+11094, r12vrr_stack+37160, r12vrr_stack+39708, r12vrr_stack+22721, r12vrr_stack+52336, r12vrr_stack+1965);
 tmp = r12vrr_stack + 11094;
 target_ptr = Libr12->t2vrr_classes[7][5];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (k0|[r12,T2]|i0)^0 ---*/
 _T2_BUILD_k0i0(Data,&(Libr12->ShellQuartet),r12vrr_stack+1260, r12vrr_stack+39708, r12vrr_stack+43020, r12vrr_stack+54019, r12vrr_stack+22721, r12vrr_stack+37160);
 tmp = r12vrr_stack + 1260;
 target_ptr = Libr12->t2vrr_classes[7][6];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (k0|[r12,T2]|k0)^0 ---*/
 _T2_BUILD_k0k0(Data,&(Libr12->ShellQuartet),r12vrr_stack+2268, r12vrr_stack+43020, r12vrr_stack+47196, r12vrr_stack+26067, r12vrr_stack+54019, r12vrr_stack+39708);
 tmp = r12vrr_stack + 2268;
 target_ptr = Libr12->t2vrr_classes[7][7];
 for(i=0;i<1296;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (k0|[r12,T2]|l0)^0 ---*/
 _T2_BUILD_k0l0(Data,&(Libr12->ShellQuartet),r12vrr_stack+12966, r12vrr_stack+47196, r12vrr_stack+18186, r12vrr_stack+40716, r12vrr_stack+26067, r12vrr_stack+43020);
 tmp = r12vrr_stack + 12966;
 target_ptr = Libr12->t2vrr_classes[7][8];
 for(i=0;i<1620;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (g0|[r12,T1]|h0)^0 ---*/
 _T1_BUILD_g0h0(Data,&(Libr12->ShellQuartet),r12vrr_stack+52336, r12vrr_stack+4582, r12vrr_stack+4897, r12vrr_stack+6794, r12vrr_stack+6514, r12vrr_stack+3721);
 tmp = r12vrr_stack + 52336;
 target_ptr = Libr12->t1vrr_classes[4][5];
 for(i=0;i<315;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (g0|[r12,T1]|i0)^0 ---*/
 _T1_BUILD_g0i0(Data,&(Libr12->ShellQuartet),r12vrr_stack+24863, r12vrr_stack+6794, r12vrr_stack+8166, r12vrr_stack+10554, r12vrr_stack+10194, r12vrr_stack+6514);
 tmp = r12vrr_stack + 24863;
 target_ptr = Libr12->t1vrr_classes[4][6];
 for(i=0;i<420;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (g0|[r12,T1]|k0)^0 ---*/
 _T1_BUILD_g0k0(Data,&(Libr12->ShellQuartet),r12vrr_stack+3564, r12vrr_stack+10554, r12vrr_stack+12210, r12vrr_stack+15171, r12vrr_stack+14721, r12vrr_stack+10194);
 tmp = r12vrr_stack + 3564;
 target_ptr = Libr12->t1vrr_classes[4][7];
 for(i=0;i<540;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (g0|[r12,T1]|l0)^0 ---*/
 _T1_BUILD_g0l0(Data,&(Libr12->ShellQuartet),r12vrr_stack+7214, r12vrr_stack+15171, r12vrr_stack+17241, r12vrr_stack+20936, r12vrr_stack+20386, r12vrr_stack+14721);
 tmp = r12vrr_stack + 7214;
 target_ptr = Libr12->t1vrr_classes[4][8];
 for(i=0;i<675;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (h0|[r12,T1]|h0)^0 ---*/
 _T1_BUILD_h0h0(Data,&(Libr12->ShellQuartet),r12vrr_stack+9930, r12vrr_stack+4897, r12vrr_stack+23687, r12vrr_stack+8166, r12vrr_stack+6794, r12vrr_stack+4582);
 tmp = r12vrr_stack + 9930;
 target_ptr = Libr12->t1vrr_classes[5][5];
 for(i=0;i<441;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (h0|[r12,T1]|i0)^0 ---*/
 _T1_BUILD_h0i0(Data,&(Libr12->ShellQuartet),r12vrr_stack+20166, r12vrr_stack+8166, r12vrr_stack+25283, r12vrr_stack+12210, r12vrr_stack+10554, r12vrr_stack+6794);
 tmp = r12vrr_stack + 20166;
 target_ptr = Libr12->t1vrr_classes[5][6];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (h0|[r12,T1]|k0)^0 ---*/
 _T1_BUILD_h0k0(Data,&(Libr12->ShellQuartet),r12vrr_stack+4104, r12vrr_stack+12210, r12vrr_stack+27723, r12vrr_stack+17241, r12vrr_stack+15171, r12vrr_stack+10554);
 tmp = r12vrr_stack + 4104;
 target_ptr = Libr12->t1vrr_classes[5][7];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (h0|[r12,T1]|l0)^0 ---*/
 _T1_BUILD_h0l0(Data,&(Libr12->ShellQuartet),r12vrr_stack+37916, r12vrr_stack+17241, r12vrr_stack+30801, r12vrr_stack+33436, r12vrr_stack+20936, r12vrr_stack+15171);
 tmp = r12vrr_stack + 37916;
 target_ptr = Libr12->t1vrr_classes[5][8];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (i0|[r12,T1]|h0)^0 ---*/
 _T1_BUILD_i0h0(Data,&(Libr12->ShellQuartet),r12vrr_stack+10371, r12vrr_stack+23687, r12vrr_stack+37160, r12vrr_stack+25283, r12vrr_stack+8166, r12vrr_stack+4897);
 tmp = r12vrr_stack + 10371;
 target_ptr = Libr12->t1vrr_classes[6][5];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (i0|[r12,T1]|i0)^0 ---*/
 _T1_BUILD_i0i0(Data,&(Libr12->ShellQuartet),r12vrr_stack+20754, r12vrr_stack+25283, r12vrr_stack+39708, r12vrr_stack+27723, r12vrr_stack+12210, r12vrr_stack+8166);
 tmp = r12vrr_stack + 20754;
 target_ptr = Libr12->t1vrr_classes[6][6];
 for(i=0;i<784;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (i0|[r12,T1]|k0)^0 ---*/
 _T1_BUILD_i0k0(Data,&(Libr12->ShellQuartet),r12vrr_stack+14586, r12vrr_stack+27723, r12vrr_stack+43020, r12vrr_stack+30801, r12vrr_stack+17241, r12vrr_stack+12210);
 tmp = r12vrr_stack + 14586;
 target_ptr = Libr12->t1vrr_classes[6][7];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (i0|[r12,T1]|l0)^0 ---*/
 _T1_BUILD_i0l0(Data,&(Libr12->ShellQuartet),r12vrr_stack+5338, r12vrr_stack+30801, r12vrr_stack+47196, r12vrr_stack+50796, r12vrr_stack+33436, r12vrr_stack+17241);
 tmp = r12vrr_stack + 5338;
 target_ptr = Libr12->t1vrr_classes[6][8];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (k0|[r12,T1]|h0)^0 ---*/
 _T1_BUILD_k0h0(Data,&(Libr12->ShellQuartet),r12vrr_stack+33405, r12vrr_stack+37160, r12vrr_stack+22721, r12vrr_stack+39708, r12vrr_stack+25283, r12vrr_stack+23687);
 tmp = r12vrr_stack + 33405;
 target_ptr = Libr12->t1vrr_classes[7][5];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (k0|[r12,T1]|i0)^0 ---*/
 _T1_BUILD_k0i0(Data,&(Libr12->ShellQuartet),r12vrr_stack+55279, r12vrr_stack+39708, r12vrr_stack+54019, r12vrr_stack+43020, r12vrr_stack+27723, r12vrr_stack+25283);
 tmp = r12vrr_stack + 55279;
 target_ptr = Libr12->t1vrr_classes[7][6];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (k0|[r12,T1]|k0)^0 ---*/
 _T1_BUILD_k0k0(Data,&(Libr12->ShellQuartet),r12vrr_stack+56287, r12vrr_stack+43020, r12vrr_stack+26067, r12vrr_stack+47196, r12vrr_stack+30801, r12vrr_stack+27723);
 tmp = r12vrr_stack + 56287;
 target_ptr = Libr12->t1vrr_classes[7][7];
 for(i=0;i<1296;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (k0|[r12,T1]|l0)^0 ---*/
 _T1_BUILD_k0l0(Data,&(Libr12->ShellQuartet),r12vrr_stack+26067, r12vrr_stack+47196, r12vrr_stack+40716, r12vrr_stack+18186, r12vrr_stack+50796, r12vrr_stack+30801);
 tmp = r12vrr_stack + 26067;
 target_ptr = Libr12->t1vrr_classes[7][8];
 for(i=0;i<1620;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (k0||h0)^0 ---*/
 _R_BUILD_k0h0(Data,r12vrr_stack+18186, r12vrr_stack+35465, r12vrr_stack+35024, r12vrr_stack+37160, r12vrr_stack+23687, r12vrr_stack+4897, r12vrr_stack+22301);
 tmp = r12vrr_stack + 18186;
 target_ptr = Libr12->rvrr_classes[7][5];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (k0||i0)^0 ---*/
 _R_BUILD_k0i0(Data,r12vrr_stack+22301, r12vrr_stack+48816, r12vrr_stack+36053, r12vrr_stack+39708, r12vrr_stack+25283, r12vrr_stack+8166, r12vrr_stack+23687);
 tmp = r12vrr_stack + 22301;
 target_ptr = Libr12->rvrr_classes[7][6];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (k0||k0)^0 ---*/
 _R_BUILD_k0k0(Data,r12vrr_stack+50356, r12vrr_stack+53011, r12vrr_stack+49600, r12vrr_stack+43020, r12vrr_stack+27723, r12vrr_stack+12210, r12vrr_stack+25283);
 tmp = r12vrr_stack + 50356;
 target_ptr = Libr12->rvrr_classes[7][7];
 for(i=0;i<1296;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (k0||l0)^0 ---*/
 _R_BUILD_k0l0(Data,r12vrr_stack+52651, r12vrr_stack+45261, r12vrr_stack+44316, r12vrr_stack+47196, r12vrr_stack+30801, r12vrr_stack+17241, r12vrr_stack+27723);
 tmp = r12vrr_stack + 52651;
 target_ptr = Libr12->rvrr_classes[7][8];
 for(i=0;i<1620;i++)
   target_ptr[i] += tmp[i];


}

