/*
 *  Copyright (C) 1996-2017 Edward F. Valeev and Justin T. Fermann
 *
 *  This file is part of Libint.
 *
 *  Libint is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU Lesser General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  Libint is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public License
 *  along with Libint.  If not, see <http://www.gnu.org/licenses/>.
 *
 */

#include <stdio.h>
#include <libint/libint.h>
#include "libr12.h"
#include <libint/vrr_header.h>
#include "r12_vrr_header.h"

void vrr_grt_order_p0gp(Libr12_t *Libr12, prim_data *Data)
{
 REALTYPE *r12vrr_stack = Libr12->r12vrr_stack;
 REALTYPE *tmp, *target_ptr;
 int i, am[2];

 /*--- compute (00|p0)^2 ---*/
 _BUILD_00p0(Data,r12vrr_stack+0, Data->F+2, Data->F+3, NULL, NULL, NULL);

 /*--- compute (00|p0)^1 ---*/
 _BUILD_00p0(Data,r12vrr_stack+3, Data->F+1, Data->F+2, NULL, NULL, NULL);

 /*--- compute (00|d0)^1 ---*/
 _BUILD_00d0(Data,r12vrr_stack+6, r12vrr_stack+3, r12vrr_stack+0, Data->F+1, Data->F+2, NULL);

 /*--- compute (00|p0)^3 ---*/
 _BUILD_00p0(Data,r12vrr_stack+12, Data->F+3, Data->F+4, NULL, NULL, NULL);

 /*--- compute (00|d0)^2 ---*/
 _BUILD_00d0(Data,r12vrr_stack+15, r12vrr_stack+0, r12vrr_stack+12, Data->F+2, Data->F+3, NULL);

 /*--- compute (00|f0)^1 ---*/
 _BUILD_00f0(Data,r12vrr_stack+21, r12vrr_stack+6, r12vrr_stack+15, r12vrr_stack+3, r12vrr_stack+0, NULL);

 /*--- compute (00|p0)^0 ---*/
 _BUILD_00p0(Data,r12vrr_stack+31, Data->F+0, Data->F+1, NULL, NULL, NULL);

 /*--- compute (00|d0)^0 ---*/
 _BUILD_00d0(Data,r12vrr_stack+34, r12vrr_stack+31, r12vrr_stack+3, Data->F+0, Data->F+1, NULL);

 /*--- compute (00|f0)^0 ---*/
 _BUILD_00f0(Data,r12vrr_stack+40, r12vrr_stack+34, r12vrr_stack+6, r12vrr_stack+31, r12vrr_stack+3, NULL);

 /*--- compute (p0|f0)^0 ---*/
 _BUILD_p0f0(Data,r12vrr_stack+50, r12vrr_stack+40, r12vrr_stack+21, NULL, NULL, r12vrr_stack+6);

 /*--- compute (p0|d0)^1 ---*/
 _BUILD_p0d0(Data,r12vrr_stack+80, r12vrr_stack+6, r12vrr_stack+15, NULL, NULL, r12vrr_stack+0);

 /*--- compute (00|p0)^4 ---*/
 _BUILD_00p0(Data,r12vrr_stack+3, Data->F+4, Data->F+5, NULL, NULL, NULL);

 /*--- compute (00|d0)^3 ---*/
 _BUILD_00d0(Data,r12vrr_stack+98, r12vrr_stack+12, r12vrr_stack+3, Data->F+3, Data->F+4, NULL);

 /*--- compute (00|f0)^2 ---*/
 _BUILD_00f0(Data,r12vrr_stack+104, r12vrr_stack+15, r12vrr_stack+98, r12vrr_stack+0, r12vrr_stack+12, NULL);

 /*--- compute (p0|f0)^1 ---*/
 _BUILD_p0f0(Data,r12vrr_stack+114, r12vrr_stack+21, r12vrr_stack+104, NULL, NULL, r12vrr_stack+15);

 /*--- compute (d0|f0)^0 ---*/
 _BUILD_d0f0(Data,r12vrr_stack+144, r12vrr_stack+50, r12vrr_stack+114, r12vrr_stack+40, r12vrr_stack+21, r12vrr_stack+80);

 /*--- compute (00|g0)^1 ---*/
 _BUILD_00g0(Data,r12vrr_stack+80, r12vrr_stack+21, r12vrr_stack+104, r12vrr_stack+6, r12vrr_stack+15, NULL);

 /*--- compute (00|g0)^0 ---*/
 _BUILD_00g0(Data,r12vrr_stack+204, r12vrr_stack+40, r12vrr_stack+21, r12vrr_stack+34, r12vrr_stack+6, NULL);

 /*--- compute (00|p0)^5 ---*/
 _BUILD_00p0(Data,r12vrr_stack+95, Data->F+5, Data->F+6, NULL, NULL, NULL);

 /*--- compute (00|d0)^4 ---*/
 _BUILD_00d0(Data,r12vrr_stack+6, r12vrr_stack+3, r12vrr_stack+95, Data->F+4, Data->F+5, NULL);

 /*--- compute (00|f0)^3 ---*/
 _BUILD_00f0(Data,r12vrr_stack+219, r12vrr_stack+98, r12vrr_stack+6, r12vrr_stack+12, r12vrr_stack+3, NULL);

 /*--- compute (00|g0)^2 ---*/
 _BUILD_00g0(Data,r12vrr_stack+229, r12vrr_stack+104, r12vrr_stack+219, r12vrr_stack+15, r12vrr_stack+98, NULL);

 /*--- compute (p0|g0)^1 ---*/
 _BUILD_p0g0(Data,r12vrr_stack+244, r12vrr_stack+80, r12vrr_stack+229, NULL, NULL, r12vrr_stack+104);

 /*--- compute (p0|g0)^0 ---*/
 _BUILD_p0g0(Data,r12vrr_stack+289, r12vrr_stack+204, r12vrr_stack+80, NULL, NULL, r12vrr_stack+21);
 tmp = r12vrr_stack + 289;
 target_ptr = Libr12->gvrr_classes[1][4];
 for(i=0;i<45;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (d0|g0)^0 ---*/
 _BUILD_d0g0(Data,r12vrr_stack+334, r12vrr_stack+289, r12vrr_stack+244, r12vrr_stack+204, r12vrr_stack+80, r12vrr_stack+114);
 tmp = r12vrr_stack + 334;
 target_ptr = Libr12->gvrr_classes[2][4];
 for(i=0;i<90;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (00|h0)^1 ---*/
 _BUILD_00h0(Data,r12vrr_stack+114, r12vrr_stack+80, r12vrr_stack+229, r12vrr_stack+21, r12vrr_stack+104, NULL);

 /*--- compute (00|h0)^0 ---*/
 _BUILD_00h0(Data,r12vrr_stack+424, r12vrr_stack+204, r12vrr_stack+80, r12vrr_stack+40, r12vrr_stack+21, NULL);

 /*--- compute (p0|h0)^0 ---*/
 _BUILD_p0h0(Data,r12vrr_stack+445, r12vrr_stack+424, r12vrr_stack+114, NULL, NULL, r12vrr_stack+80);
 tmp = r12vrr_stack + 445;
 target_ptr = Libr12->gvrr_classes[1][5];
 for(i=0;i<63;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (00|p0)^6 ---*/
 _BUILD_00p0(Data,r12vrr_stack+0, Data->F+6, Data->F+7, NULL, NULL, NULL);

 /*--- compute (00|d0)^5 ---*/
 _BUILD_00d0(Data,r12vrr_stack+135, r12vrr_stack+95, r12vrr_stack+0, Data->F+5, Data->F+6, NULL);

 /*--- compute (00|f0)^4 ---*/
 _BUILD_00f0(Data,r12vrr_stack+12, r12vrr_stack+6, r12vrr_stack+135, r12vrr_stack+3, r12vrr_stack+95, NULL);

 /*--- compute (00|g0)^3 ---*/
 _BUILD_00g0(Data,r12vrr_stack+508, r12vrr_stack+219, r12vrr_stack+12, r12vrr_stack+98, r12vrr_stack+6, NULL);

 /*--- compute (00|h0)^2 ---*/
 _BUILD_00h0(Data,r12vrr_stack+0, r12vrr_stack+229, r12vrr_stack+508, r12vrr_stack+104, r12vrr_stack+219, NULL);

 /*--- compute (p0|h0)^1 ---*/
 _BUILD_p0h0(Data,r12vrr_stack+508, r12vrr_stack+114, r12vrr_stack+0, NULL, NULL, r12vrr_stack+229);

 /*--- compute (d0|h0)^0 ---*/
 _BUILD_d0h0(Data,r12vrr_stack+571, r12vrr_stack+445, r12vrr_stack+508, r12vrr_stack+424, r12vrr_stack+114, r12vrr_stack+244);

 /*--- compute (00|i0)^1 ---*/
 _BUILD_00i0(Data,r12vrr_stack+244, r12vrr_stack+114, r12vrr_stack+0, r12vrr_stack+80, r12vrr_stack+229, NULL);

 /*--- compute (00|i0)^0 ---*/
 _BUILD_00i0(Data,r12vrr_stack+0, r12vrr_stack+424, r12vrr_stack+114, r12vrr_stack+204, r12vrr_stack+80, NULL);

 /*--- compute (p0|i0)^0 ---*/
 _BUILD_p0i0(Data,r12vrr_stack+697, r12vrr_stack+0, r12vrr_stack+244, NULL, NULL, r12vrr_stack+114);

 /*--- compute (00||p0)^0 ---*/
 _R_BUILD_00p0(Data,r12vrr_stack+28, &(Data->ss_r12_ss), NULL, r12vrr_stack+31, Data->F+0, NULL, NULL);

 /*--- compute (00||d0)^0 ---*/
 _R_BUILD_00d0(Data,r12vrr_stack+80, r12vrr_stack+28, &(Data->ss_r12_ss), r12vrr_stack+34, r12vrr_stack+31, Data->F+0, NULL);

 /*--- compute (00||f0)^0 ---*/
 _R_BUILD_00f0(Data,r12vrr_stack+86, r12vrr_stack+80, r12vrr_stack+28, r12vrr_stack+40, r12vrr_stack+34, r12vrr_stack+31, NULL);

 /*--- compute (00||g0)^0 ---*/
 _R_BUILD_00g0(Data,r12vrr_stack+96, r12vrr_stack+86, r12vrr_stack+80, r12vrr_stack+204, r12vrr_stack+40, r12vrr_stack+34, NULL);

 /*--- compute (00||h0)^0 ---*/
 _R_BUILD_00h0(Data,r12vrr_stack+111, r12vrr_stack+96, r12vrr_stack+86, r12vrr_stack+424, r12vrr_stack+204, r12vrr_stack+40, NULL);

 /*--- compute (p0|[r12,T2]|g0)^0 ---*/
 _T2_BUILD_p0g0(Data,&(Libr12->ShellQuartet),r12vrr_stack+508, r12vrr_stack+289, r12vrr_stack+445, r12vrr_stack+334, r12vrr_stack+144, r12vrr_stack+50);
 tmp = r12vrr_stack + 508;
 target_ptr = Libr12->t2vrr_classes[1][4];
 for(i=0;i<45;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (p0|[r12,T2]|h0)^0 ---*/
 _T2_BUILD_p0h0(Data,&(Libr12->ShellQuartet),r12vrr_stack+132, r12vrr_stack+445, r12vrr_stack+697, r12vrr_stack+571, r12vrr_stack+334, r12vrr_stack+289);
 tmp = r12vrr_stack + 132;
 target_ptr = Libr12->t2vrr_classes[1][5];
 for(i=0;i<63;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (p0|[r12,T1]|g0)^0 ---*/
 _T1_BUILD_p0g0(Data,&(Libr12->ShellQuartet),r12vrr_stack+50, r12vrr_stack+289, r12vrr_stack+334, r12vrr_stack+445, r12vrr_stack+424, r12vrr_stack+204);
 tmp = r12vrr_stack + 50;
 target_ptr = Libr12->t1vrr_classes[1][4];
 for(i=0;i<45;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (p0|[r12,T1]|h0)^0 ---*/
 _T1_BUILD_p0h0(Data,&(Libr12->ShellQuartet),r12vrr_stack+334, r12vrr_stack+445, r12vrr_stack+571, r12vrr_stack+697, r12vrr_stack+0, r12vrr_stack+424);
 tmp = r12vrr_stack + 334;
 target_ptr = Libr12->t1vrr_classes[1][5];
 for(i=0;i<63;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (p0||g0)^0 ---*/
 _R_BUILD_p0g0(Data,r12vrr_stack+553, r12vrr_stack+96, NULL, r12vrr_stack+289, r12vrr_stack+204, NULL, r12vrr_stack+40);
 tmp = r12vrr_stack + 553;
 target_ptr = Libr12->rvrr_classes[1][4];
 for(i=0;i<45;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (p0||h0)^0 ---*/
 _R_BUILD_p0h0(Data,r12vrr_stack+598, r12vrr_stack+111, NULL, r12vrr_stack+445, r12vrr_stack+424, NULL, r12vrr_stack+204);
 tmp = r12vrr_stack + 598;
 target_ptr = Libr12->rvrr_classes[1][5];
 for(i=0;i<63;i++)
   target_ptr[i] += tmp[i];


}

