/*
 *  Copyright (C) 1996-2017 Edward F. Valeev and Justin T. Fermann
 *
 *  This file is part of Libint.
 *
 *  Libint is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU Lesser General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  Libint is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public License
 *  along with Libint.  If not, see <http://www.gnu.org/licenses/>.
 *
 */

#include <stdio.h>
#include <libint/libint.h>
#include "libr12.h"
#include <libint/vrr_header.h>
#include "r12_vrr_header.h"

void vrr_grt_order_p0hp(Libr12_t *Libr12, prim_data *Data)
{
 REALTYPE *r12vrr_stack = Libr12->r12vrr_stack;
 REALTYPE *tmp, *target_ptr;
 int i, am[2];

 /*--- compute (00|p0)^2 ---*/
 _BUILD_00p0(Data,r12vrr_stack+0, Data->F+2, Data->F+3, NULL, NULL, NULL);

 /*--- compute (00|p0)^1 ---*/
 _BUILD_00p0(Data,r12vrr_stack+3, Data->F+1, Data->F+2, NULL, NULL, NULL);

 /*--- compute (00|p0)^3 ---*/
 _BUILD_00p0(Data,r12vrr_stack+6, Data->F+3, Data->F+4, NULL, NULL, NULL);

 /*--- compute (00|d0)^2 ---*/
 _BUILD_00d0(Data,r12vrr_stack+9, r12vrr_stack+0, r12vrr_stack+6, Data->F+2, Data->F+3, NULL);

 /*--- compute (00|d0)^1 ---*/
 _BUILD_00d0(Data,r12vrr_stack+15, r12vrr_stack+3, r12vrr_stack+0, Data->F+1, Data->F+2, NULL);

 /*--- compute (00|f0)^1 ---*/
 _BUILD_00f0(Data,r12vrr_stack+21, r12vrr_stack+15, r12vrr_stack+9, r12vrr_stack+3, r12vrr_stack+0, NULL);

 /*--- compute (00|p0)^4 ---*/
 _BUILD_00p0(Data,r12vrr_stack+31, Data->F+4, Data->F+5, NULL, NULL, NULL);

 /*--- compute (00|d0)^3 ---*/
 _BUILD_00d0(Data,r12vrr_stack+34, r12vrr_stack+6, r12vrr_stack+31, Data->F+3, Data->F+4, NULL);

 /*--- compute (00|f0)^2 ---*/
 _BUILD_00f0(Data,r12vrr_stack+40, r12vrr_stack+9, r12vrr_stack+34, r12vrr_stack+0, r12vrr_stack+6, NULL);

 /*--- compute (00|g0)^1 ---*/
 _BUILD_00g0(Data,r12vrr_stack+50, r12vrr_stack+21, r12vrr_stack+40, r12vrr_stack+15, r12vrr_stack+9, NULL);

 /*--- compute (00|p0)^0 ---*/
 _BUILD_00p0(Data,r12vrr_stack+0, Data->F+0, Data->F+1, NULL, NULL, NULL);

 /*--- compute (00|d0)^0 ---*/
 _BUILD_00d0(Data,r12vrr_stack+65, r12vrr_stack+0, r12vrr_stack+3, Data->F+0, Data->F+1, NULL);

 /*--- compute (00|f0)^0 ---*/
 _BUILD_00f0(Data,r12vrr_stack+71, r12vrr_stack+65, r12vrr_stack+15, r12vrr_stack+0, r12vrr_stack+3, NULL);

 /*--- compute (00|g0)^0 ---*/
 _BUILD_00g0(Data,r12vrr_stack+81, r12vrr_stack+71, r12vrr_stack+21, r12vrr_stack+65, r12vrr_stack+15, NULL);

 /*--- compute (p0|g0)^0 ---*/
 _BUILD_p0g0(Data,r12vrr_stack+96, r12vrr_stack+81, r12vrr_stack+50, NULL, NULL, r12vrr_stack+21);

 /*--- compute (p0|f0)^1 ---*/
 _BUILD_p0f0(Data,r12vrr_stack+141, r12vrr_stack+21, r12vrr_stack+40, NULL, NULL, r12vrr_stack+9);

 /*--- compute (00|p0)^5 ---*/
 _BUILD_00p0(Data,r12vrr_stack+3, Data->F+5, Data->F+6, NULL, NULL, NULL);

 /*--- compute (00|d0)^4 ---*/
 _BUILD_00d0(Data,r12vrr_stack+15, r12vrr_stack+31, r12vrr_stack+3, Data->F+4, Data->F+5, NULL);

 /*--- compute (00|f0)^3 ---*/
 _BUILD_00f0(Data,r12vrr_stack+171, r12vrr_stack+34, r12vrr_stack+15, r12vrr_stack+6, r12vrr_stack+31, NULL);

 /*--- compute (00|g0)^2 ---*/
 _BUILD_00g0(Data,r12vrr_stack+181, r12vrr_stack+40, r12vrr_stack+171, r12vrr_stack+9, r12vrr_stack+34, NULL);

 /*--- compute (p0|g0)^1 ---*/
 _BUILD_p0g0(Data,r12vrr_stack+196, r12vrr_stack+50, r12vrr_stack+181, NULL, NULL, r12vrr_stack+40);

 /*--- compute (d0|g0)^0 ---*/
 _BUILD_d0g0(Data,r12vrr_stack+241, r12vrr_stack+96, r12vrr_stack+196, r12vrr_stack+81, r12vrr_stack+50, r12vrr_stack+141);

 /*--- compute (00|h0)^1 ---*/
 _BUILD_00h0(Data,r12vrr_stack+141, r12vrr_stack+50, r12vrr_stack+181, r12vrr_stack+21, r12vrr_stack+40, NULL);

 /*--- compute (00|h0)^0 ---*/
 _BUILD_00h0(Data,r12vrr_stack+331, r12vrr_stack+81, r12vrr_stack+50, r12vrr_stack+71, r12vrr_stack+21, NULL);

 /*--- compute (00|p0)^6 ---*/
 _BUILD_00p0(Data,r12vrr_stack+21, Data->F+6, Data->F+7, NULL, NULL, NULL);

 /*--- compute (00|d0)^5 ---*/
 _BUILD_00d0(Data,r12vrr_stack+24, r12vrr_stack+3, r12vrr_stack+21, Data->F+5, Data->F+6, NULL);

 /*--- compute (00|f0)^4 ---*/
 _BUILD_00f0(Data,r12vrr_stack+352, r12vrr_stack+15, r12vrr_stack+24, r12vrr_stack+31, r12vrr_stack+3, NULL);

 /*--- compute (00|g0)^3 ---*/
 _BUILD_00g0(Data,r12vrr_stack+362, r12vrr_stack+171, r12vrr_stack+352, r12vrr_stack+34, r12vrr_stack+15, NULL);

 /*--- compute (00|h0)^2 ---*/
 _BUILD_00h0(Data,r12vrr_stack+377, r12vrr_stack+181, r12vrr_stack+362, r12vrr_stack+40, r12vrr_stack+171, NULL);

 /*--- compute (p0|h0)^1 ---*/
 _BUILD_p0h0(Data,r12vrr_stack+398, r12vrr_stack+141, r12vrr_stack+377, NULL, NULL, r12vrr_stack+181);

 /*--- compute (p0|h0)^0 ---*/
 _BUILD_p0h0(Data,r12vrr_stack+461, r12vrr_stack+331, r12vrr_stack+141, NULL, NULL, r12vrr_stack+50);
 tmp = r12vrr_stack + 461;
 target_ptr = Libr12->gvrr_classes[1][5];
 for(i=0;i<63;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (d0|h0)^0 ---*/
 _BUILD_d0h0(Data,r12vrr_stack+524, r12vrr_stack+461, r12vrr_stack+398, r12vrr_stack+331, r12vrr_stack+141, r12vrr_stack+196);
 tmp = r12vrr_stack + 524;
 target_ptr = Libr12->gvrr_classes[2][5];
 for(i=0;i<126;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (00|i0)^1 ---*/
 _BUILD_00i0(Data,r12vrr_stack+196, r12vrr_stack+141, r12vrr_stack+377, r12vrr_stack+50, r12vrr_stack+181, NULL);

 /*--- compute (00|i0)^0 ---*/
 _BUILD_00i0(Data,r12vrr_stack+650, r12vrr_stack+331, r12vrr_stack+141, r12vrr_stack+81, r12vrr_stack+50, NULL);

 /*--- compute (p0|i0)^0 ---*/
 _BUILD_p0i0(Data,r12vrr_stack+678, r12vrr_stack+650, r12vrr_stack+196, NULL, NULL, r12vrr_stack+141);
 tmp = r12vrr_stack + 678;
 target_ptr = Libr12->gvrr_classes[1][6];
 for(i=0;i<84;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (00|p0)^7 ---*/
 _BUILD_00p0(Data,r12vrr_stack+224, Data->F+7, Data->F+8, NULL, NULL, NULL);

 /*--- compute (00|d0)^6 ---*/
 _BUILD_00d0(Data,r12vrr_stack+227, r12vrr_stack+21, r12vrr_stack+224, Data->F+6, Data->F+7, NULL);

 /*--- compute (00|f0)^5 ---*/
 _BUILD_00f0(Data,r12vrr_stack+30, r12vrr_stack+24, r12vrr_stack+227, r12vrr_stack+3, r12vrr_stack+21, NULL);

 /*--- compute (00|g0)^4 ---*/
 _BUILD_00g0(Data,r12vrr_stack+224, r12vrr_stack+352, r12vrr_stack+30, r12vrr_stack+15, r12vrr_stack+24, NULL);

 /*--- compute (00|h0)^3 ---*/
 _BUILD_00h0(Data,r12vrr_stack+3, r12vrr_stack+362, r12vrr_stack+224, r12vrr_stack+171, r12vrr_stack+352, NULL);

 /*--- compute (00|i0)^2 ---*/
 _BUILD_00i0(Data,r12vrr_stack+24, r12vrr_stack+377, r12vrr_stack+3, r12vrr_stack+181, r12vrr_stack+362, NULL);

 /*--- compute (p0|i0)^1 ---*/
 _BUILD_p0i0(Data,r12vrr_stack+762, r12vrr_stack+196, r12vrr_stack+24, NULL, NULL, r12vrr_stack+377);

 /*--- compute (d0|i0)^0 ---*/
 _BUILD_d0i0(Data,r12vrr_stack+846, r12vrr_stack+678, r12vrr_stack+762, r12vrr_stack+650, r12vrr_stack+196, r12vrr_stack+398);

 /*--- compute (00|k0)^1 ---*/
 am[0] = 0;  am[1] = 7;
 vrr_build_xxxx(am,Data,r12vrr_stack+398, r12vrr_stack+196, r12vrr_stack+24, r12vrr_stack+141, r12vrr_stack+377, NULL);

 /*--- compute (00|k0)^0 ---*/
 am[0] = 0;  am[1] = 7;
 vrr_build_xxxx(am,Data,r12vrr_stack+762, r12vrr_stack+650, r12vrr_stack+196, r12vrr_stack+331, r12vrr_stack+141, NULL);

 /*--- compute (p0|k0)^0 ---*/
 am[0] = 1;  am[1] = 7;
 vrr_build_xxxx(am,Data,r12vrr_stack+1014, r12vrr_stack+762, r12vrr_stack+398, NULL, NULL, r12vrr_stack+196);

 /*--- compute (00||p0)^0 ---*/
 _R_BUILD_00p0(Data,r12vrr_stack+141, &(Data->ss_r12_ss), NULL, r12vrr_stack+0, Data->F+0, NULL, NULL);

 /*--- compute (00||d0)^0 ---*/
 _R_BUILD_00d0(Data,r12vrr_stack+144, r12vrr_stack+141, &(Data->ss_r12_ss), r12vrr_stack+65, r12vrr_stack+0, Data->F+0, NULL);

 /*--- compute (00||f0)^0 ---*/
 _R_BUILD_00f0(Data,r12vrr_stack+150, r12vrr_stack+144, r12vrr_stack+141, r12vrr_stack+71, r12vrr_stack+65, r12vrr_stack+0, NULL);

 /*--- compute (00||g0)^0 ---*/
 _R_BUILD_00g0(Data,r12vrr_stack+0, r12vrr_stack+150, r12vrr_stack+144, r12vrr_stack+81, r12vrr_stack+71, r12vrr_stack+65, NULL);

 /*--- compute (00||h0)^0 ---*/
 _R_BUILD_00h0(Data,r12vrr_stack+15, r12vrr_stack+0, r12vrr_stack+150, r12vrr_stack+331, r12vrr_stack+81, r12vrr_stack+71, NULL);

 /*--- compute (00||i0)^0 ---*/
 _R_BUILD_00i0(Data,r12vrr_stack+36, r12vrr_stack+15, r12vrr_stack+0, r12vrr_stack+650, r12vrr_stack+331, r12vrr_stack+81, NULL);

 /*--- compute (p0|[r12,T2]|h0)^0 ---*/
 _T2_BUILD_p0h0(Data,&(Libr12->ShellQuartet),r12vrr_stack+141, r12vrr_stack+461, r12vrr_stack+678, r12vrr_stack+524, r12vrr_stack+241, r12vrr_stack+96);
 tmp = r12vrr_stack + 141;
 target_ptr = Libr12->t2vrr_classes[1][5];
 for(i=0;i<63;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (p0|[r12,T2]|i0)^0 ---*/
 _T2_BUILD_p0i0(Data,&(Libr12->ShellQuartet),r12vrr_stack+204, r12vrr_stack+678, r12vrr_stack+1014, r12vrr_stack+846, r12vrr_stack+524, r12vrr_stack+461);
 tmp = r12vrr_stack + 204;
 target_ptr = Libr12->t2vrr_classes[1][6];
 for(i=0;i<84;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (p0|[r12,T1]|h0)^0 ---*/
 _T1_BUILD_p0h0(Data,&(Libr12->ShellQuartet),r12vrr_stack+352, r12vrr_stack+461, r12vrr_stack+524, r12vrr_stack+678, r12vrr_stack+650, r12vrr_stack+331);
 tmp = r12vrr_stack + 352;
 target_ptr = Libr12->t1vrr_classes[1][5];
 for(i=0;i<63;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (p0|[r12,T1]|i0)^0 ---*/
 _T1_BUILD_p0i0(Data,&(Libr12->ShellQuartet),r12vrr_stack+524, r12vrr_stack+678, r12vrr_stack+846, r12vrr_stack+1014, r12vrr_stack+762, r12vrr_stack+650);
 tmp = r12vrr_stack + 524;
 target_ptr = Libr12->t1vrr_classes[1][6];
 for(i=0;i<84;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (p0||h0)^0 ---*/
 _R_BUILD_p0h0(Data,r12vrr_stack+762, r12vrr_stack+15, NULL, r12vrr_stack+461, r12vrr_stack+331, NULL, r12vrr_stack+81);
 tmp = r12vrr_stack + 762;
 target_ptr = Libr12->rvrr_classes[1][5];
 for(i=0;i<63;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (p0||i0)^0 ---*/
 _R_BUILD_p0i0(Data,r12vrr_stack+825, r12vrr_stack+36, NULL, r12vrr_stack+678, r12vrr_stack+650, NULL, r12vrr_stack+331);
 tmp = r12vrr_stack + 825;
 target_ptr = Libr12->rvrr_classes[1][6];
 for(i=0;i<84;i++)
   target_ptr[i] += tmp[i];


}

