/*
 *  Copyright (C) 1996-2017 Edward F. Valeev and Justin T. Fermann
 *
 *  This file is part of Libint.
 *
 *  Libint is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU Lesser General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  Libint is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public License
 *  along with Libint.  If not, see <http://www.gnu.org/licenses/>.
 *
 */

#include <stdio.h>
#include <libint/libint.h>
#include "libr12.h"
#include <libint/vrr_header.h>
#include "r12_vrr_header.h"

void vrr_grt_order_p0pp(Libr12_t *Libr12, prim_data *Data)
{
 REALTYPE *r12vrr_stack = Libr12->r12vrr_stack;
 REALTYPE *tmp, *target_ptr;
 int i, am[2];

 /*--- compute (p0|00)^0 ---*/
 _BUILD_p000(Data,r12vrr_stack+0, Data->F+0, Data->F+1, NULL, NULL, NULL);

 /*--- compute (p0|00)^1 ---*/
 _BUILD_p000(Data,r12vrr_stack+3, Data->F+1, Data->F+2, NULL, NULL, NULL);

 /*--- compute (d0|00)^0 ---*/
 _BUILD_d000(Data,r12vrr_stack+6, r12vrr_stack+0, r12vrr_stack+3, Data->F+0, Data->F+1, NULL);

 /*--- compute (00|p0)^1 ---*/
 _BUILD_00p0(Data,r12vrr_stack+12, Data->F+1, Data->F+2, NULL, NULL, NULL);

 /*--- compute (00|p0)^0 ---*/
 _BUILD_00p0(Data,r12vrr_stack+15, Data->F+0, Data->F+1, NULL, NULL, NULL);

 /*--- compute (00|p0)^2 ---*/
 _BUILD_00p0(Data,r12vrr_stack+18, Data->F+2, Data->F+3, NULL, NULL, NULL);

 /*--- compute (p0|p0)^1 ---*/
 _BUILD_p0p0(Data,r12vrr_stack+21, r12vrr_stack+12, r12vrr_stack+18, NULL, NULL, Data->F+2);

 /*--- compute (p0|p0)^0 ---*/
 _BUILD_p0p0(Data,r12vrr_stack+30, r12vrr_stack+15, r12vrr_stack+12, NULL, NULL, Data->F+1);
 tmp = r12vrr_stack + 30;
 target_ptr = Libr12->gvrr_classes[1][1];
 for(i=0;i<9;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (d0|p0)^0 ---*/
 _BUILD_d0p0(Data,r12vrr_stack+39, r12vrr_stack+30, r12vrr_stack+21, r12vrr_stack+15, r12vrr_stack+12, r12vrr_stack+3);
 tmp = r12vrr_stack + 39;
 target_ptr = Libr12->gvrr_classes[2][1];
 for(i=0;i<18;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (00|d0)^1 ---*/
 _BUILD_00d0(Data,r12vrr_stack+57, r12vrr_stack+12, r12vrr_stack+18, Data->F+1, Data->F+2, NULL);

 /*--- compute (00|d0)^0 ---*/
 _BUILD_00d0(Data,r12vrr_stack+63, r12vrr_stack+15, r12vrr_stack+12, Data->F+0, Data->F+1, NULL);

 /*--- compute (p0|d0)^0 ---*/
 _BUILD_p0d0(Data,r12vrr_stack+69, r12vrr_stack+63, r12vrr_stack+57, NULL, NULL, r12vrr_stack+12);
 tmp = r12vrr_stack + 69;
 target_ptr = Libr12->gvrr_classes[1][2];
 for(i=0;i<18;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (00|p0)^3 ---*/
 _BUILD_00p0(Data,r12vrr_stack+3, Data->F+3, Data->F+4, NULL, NULL, NULL);

 /*--- compute (00|d0)^2 ---*/
 _BUILD_00d0(Data,r12vrr_stack+87, r12vrr_stack+18, r12vrr_stack+3, Data->F+2, Data->F+3, NULL);

 /*--- compute (p0|d0)^1 ---*/
 _BUILD_p0d0(Data,r12vrr_stack+93, r12vrr_stack+57, r12vrr_stack+87, NULL, NULL, r12vrr_stack+18);

 /*--- compute (d0|d0)^0 ---*/
 _BUILD_d0d0(Data,r12vrr_stack+111, r12vrr_stack+69, r12vrr_stack+93, r12vrr_stack+63, r12vrr_stack+57, r12vrr_stack+21);

 /*--- compute (00|f0)^1 ---*/
 _BUILD_00f0(Data,r12vrr_stack+93, r12vrr_stack+57, r12vrr_stack+87, r12vrr_stack+12, r12vrr_stack+18, NULL);

 /*--- compute (00|f0)^0 ---*/
 _BUILD_00f0(Data,r12vrr_stack+18, r12vrr_stack+63, r12vrr_stack+57, r12vrr_stack+15, r12vrr_stack+12, NULL);

 /*--- compute (p0|f0)^0 ---*/
 _BUILD_p0f0(Data,r12vrr_stack+147, r12vrr_stack+18, r12vrr_stack+93, NULL, NULL, r12vrr_stack+57);

 /*--- compute (00||p0)^0 ---*/
 _R_BUILD_00p0(Data,r12vrr_stack+12, &(Data->ss_r12_ss), NULL, r12vrr_stack+15, Data->F+0, NULL, NULL);

 /*--- compute (00||d0)^0 ---*/
 _R_BUILD_00d0(Data,r12vrr_stack+57, r12vrr_stack+12, &(Data->ss_r12_ss), r12vrr_stack+63, r12vrr_stack+15, Data->F+0, NULL);

 /*--- compute (p0|[r12,T2]|p0)^0 ---*/
 _T2_BUILD_p0p0(Data,&(Libr12->ShellQuartet),r12vrr_stack+87, r12vrr_stack+30, r12vrr_stack+69, r12vrr_stack+39, r12vrr_stack+6, r12vrr_stack+0);
 tmp = r12vrr_stack + 87;
 target_ptr = Libr12->t2vrr_classes[1][1];
 for(i=0;i<9;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (p0|[r12,T2]|d0)^0 ---*/
 _T2_BUILD_p0d0(Data,&(Libr12->ShellQuartet),r12vrr_stack+177, r12vrr_stack+69, r12vrr_stack+147, r12vrr_stack+111, r12vrr_stack+39, r12vrr_stack+30);
 tmp = r12vrr_stack + 177;
 target_ptr = Libr12->t2vrr_classes[1][2];
 for(i=0;i<18;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (p0|[r12,T1]|p0)^0 ---*/
 _T1_BUILD_p0p0(Data,&(Libr12->ShellQuartet),r12vrr_stack+0, r12vrr_stack+30, r12vrr_stack+39, r12vrr_stack+69, r12vrr_stack+63, r12vrr_stack+15);
 tmp = r12vrr_stack + 0;
 target_ptr = Libr12->t1vrr_classes[1][1];
 for(i=0;i<9;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (p0|[r12,T1]|d0)^0 ---*/
 _T1_BUILD_p0d0(Data,&(Libr12->ShellQuartet),r12vrr_stack+39, r12vrr_stack+69, r12vrr_stack+111, r12vrr_stack+147, r12vrr_stack+18, r12vrr_stack+63);
 tmp = r12vrr_stack + 39;
 target_ptr = Libr12->t1vrr_classes[1][2];
 for(i=0;i<18;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (p0||p0)^0 ---*/
 _R_BUILD_p0p0(Data,r12vrr_stack+18, r12vrr_stack+12, NULL, r12vrr_stack+30, r12vrr_stack+15, NULL, Data->F+0);
 tmp = r12vrr_stack + 18;
 target_ptr = Libr12->rvrr_classes[1][1];
 for(i=0;i<9;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (p0||d0)^0 ---*/
 _R_BUILD_p0d0(Data,r12vrr_stack+96, r12vrr_stack+57, NULL, r12vrr_stack+69, r12vrr_stack+63, NULL, r12vrr_stack+15);
 tmp = r12vrr_stack + 96;
 target_ptr = Libr12->rvrr_classes[1][2];
 for(i=0;i<18;i++)
   target_ptr[i] += tmp[i];


}

