/*
 *  Copyright (C) 1996-2017 Edward F. Valeev and Justin T. Fermann
 *
 *  This file is part of Libint.
 *
 *  Libint is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU Lesser General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  Libint is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public License
 *  along with Libint.  If not, see <http://www.gnu.org/licenses/>.
 *
 */

#include <stdio.h>
#include <string.h>
#include <libint/libint.h>
#include "libderiv.h"
#include <libint/hrr_header.h>

#include "d1hrr_header.h"

extern void d12vrr_order_hpgf(Libderiv_t *, prim_data *);

  /* Computes derivatives of (hp|gf) integrals */

void d12hrr_order_hpgf(Libderiv_t *Libderiv, int num_prim_comb)
{
 prim_data *Data = Libderiv->PrimQuartet;
 double *int_stack = Libderiv->int_stack;
 double *zero_stack = Libderiv->zero_stack;
 int i,j;
 double tmp, *target;

 Libderiv->deriv_classes[6][7][11] = int_stack + 0;
 Libderiv->deriv_classes[6][7][10] = int_stack + 1008;
 Libderiv->deriv_classes[6][7][9] = int_stack + 2016;
 Libderiv->deriv_classes[6][7][8] = int_stack + 3024;
 Libderiv->deriv_classes[6][7][7] = int_stack + 4032;
 Libderiv->dvrr_classes[6][6] = int_stack + 5040;
 Libderiv->deriv_classes[6][7][6] = int_stack + 5824;
 Libderiv->deriv_classes[6][7][2] = int_stack + 6832;
 Libderiv->deriv_classes[6][7][1] = int_stack + 7840;
 Libderiv->dvrr_classes[5][7] = int_stack + 8848;
 Libderiv->deriv_classes[6][7][0] = int_stack + 9604;
 Libderiv->deriv2_classes[5][4][143] = int_stack + 10612;
 Libderiv->deriv2_classes[5][5][143] = int_stack + 10927;
 Libderiv->deriv2_classes[5][6][143] = int_stack + 11368;
 Libderiv->deriv2_classes[5][7][143] = int_stack + 11956;
 Libderiv->deriv2_classes[6][4][143] = int_stack + 12712;
 Libderiv->deriv2_classes[6][5][143] = int_stack + 13132;
 Libderiv->deriv2_classes[6][6][143] = int_stack + 13720;
 Libderiv->deriv2_classes[6][7][143] = int_stack + 14504;
 Libderiv->deriv2_classes[5][4][131] = int_stack + 15512;
 Libderiv->deriv2_classes[5][5][131] = int_stack + 15827;
 Libderiv->deriv2_classes[5][6][131] = int_stack + 16268;
 Libderiv->deriv2_classes[5][7][131] = int_stack + 16856;
 Libderiv->deriv2_classes[6][4][131] = int_stack + 17612;
 Libderiv->deriv2_classes[6][5][131] = int_stack + 18032;
 Libderiv->deriv2_classes[6][6][131] = int_stack + 18620;
 Libderiv->deriv2_classes[6][7][131] = int_stack + 19404;
 Libderiv->deriv2_classes[5][4][130] = int_stack + 20412;
 Libderiv->deriv2_classes[5][5][130] = int_stack + 20727;
 Libderiv->deriv2_classes[5][6][130] = int_stack + 21168;
 Libderiv->deriv2_classes[5][7][130] = int_stack + 21756;
 Libderiv->deriv2_classes[6][4][130] = int_stack + 22512;
 Libderiv->deriv2_classes[6][5][130] = int_stack + 22932;
 Libderiv->deriv2_classes[6][6][130] = int_stack + 23520;
 Libderiv->deriv2_classes[6][7][130] = int_stack + 24304;
 Libderiv->deriv2_classes[5][4][119] = int_stack + 25312;
 Libderiv->deriv2_classes[5][5][119] = int_stack + 25627;
 Libderiv->deriv2_classes[5][6][119] = int_stack + 26068;
 Libderiv->deriv2_classes[5][7][119] = int_stack + 26656;
 Libderiv->deriv2_classes[6][4][119] = int_stack + 27412;
 Libderiv->deriv2_classes[6][5][119] = int_stack + 27832;
 Libderiv->deriv2_classes[6][6][119] = int_stack + 28420;
 Libderiv->deriv2_classes[6][7][119] = int_stack + 29204;
 Libderiv->deriv2_classes[5][4][118] = int_stack + 30212;
 Libderiv->deriv2_classes[5][5][118] = int_stack + 30527;
 Libderiv->deriv2_classes[5][6][118] = int_stack + 30968;
 Libderiv->deriv2_classes[5][7][118] = int_stack + 31556;
 Libderiv->deriv2_classes[6][4][118] = int_stack + 32312;
 Libderiv->deriv2_classes[6][5][118] = int_stack + 32732;
 Libderiv->deriv2_classes[6][6][118] = int_stack + 33320;
 Libderiv->deriv2_classes[6][7][118] = int_stack + 34104;
 Libderiv->deriv2_classes[5][4][117] = int_stack + 35112;
 Libderiv->deriv2_classes[5][5][117] = int_stack + 35427;
 Libderiv->deriv2_classes[5][6][117] = int_stack + 35868;
 Libderiv->deriv2_classes[5][7][117] = int_stack + 36456;
 Libderiv->deriv2_classes[6][4][117] = int_stack + 37212;
 Libderiv->deriv2_classes[6][5][117] = int_stack + 37632;
 Libderiv->deriv2_classes[6][6][117] = int_stack + 38220;
 Libderiv->deriv2_classes[6][7][117] = int_stack + 39004;
 Libderiv->deriv2_classes[5][4][107] = int_stack + 40012;
 Libderiv->deriv2_classes[5][5][107] = int_stack + 40327;
 Libderiv->deriv2_classes[5][6][107] = int_stack + 40768;
 Libderiv->deriv2_classes[5][7][107] = int_stack + 41356;
 Libderiv->deriv2_classes[6][4][107] = int_stack + 42112;
 Libderiv->deriv2_classes[6][5][107] = int_stack + 42532;
 Libderiv->deriv2_classes[6][6][107] = int_stack + 43120;
 Libderiv->deriv2_classes[6][7][107] = int_stack + 43904;
 Libderiv->deriv2_classes[5][4][106] = int_stack + 44912;
 Libderiv->deriv2_classes[5][5][106] = int_stack + 45227;
 Libderiv->deriv2_classes[5][6][106] = int_stack + 45668;
 Libderiv->deriv2_classes[5][7][106] = int_stack + 46256;
 Libderiv->deriv2_classes[6][4][106] = int_stack + 47012;
 Libderiv->deriv2_classes[6][5][106] = int_stack + 47432;
 Libderiv->deriv2_classes[6][6][106] = int_stack + 48020;
 Libderiv->deriv2_classes[6][7][106] = int_stack + 48804;
 Libderiv->deriv2_classes[5][4][105] = int_stack + 49812;
 Libderiv->deriv2_classes[5][5][105] = int_stack + 50127;
 Libderiv->deriv2_classes[5][6][105] = int_stack + 50568;
 Libderiv->deriv2_classes[5][7][105] = int_stack + 51156;
 Libderiv->deriv2_classes[6][4][105] = int_stack + 51912;
 Libderiv->deriv2_classes[6][5][105] = int_stack + 52332;
 Libderiv->deriv2_classes[6][6][105] = int_stack + 52920;
 Libderiv->deriv2_classes[6][7][105] = int_stack + 53704;
 Libderiv->deriv2_classes[5][4][104] = int_stack + 54712;
 Libderiv->deriv2_classes[5][5][104] = int_stack + 55027;
 Libderiv->deriv2_classes[5][6][104] = int_stack + 55468;
 Libderiv->deriv2_classes[5][7][104] = int_stack + 56056;
 Libderiv->deriv2_classes[6][4][104] = int_stack + 56812;
 Libderiv->deriv2_classes[6][5][104] = int_stack + 57232;
 Libderiv->deriv2_classes[6][6][104] = int_stack + 57820;
 Libderiv->deriv2_classes[6][7][104] = int_stack + 58604;
 Libderiv->deriv2_classes[5][4][95] = int_stack + 59612;
 Libderiv->deriv2_classes[5][5][95] = int_stack + 59927;
 Libderiv->deriv2_classes[5][6][95] = int_stack + 60368;
 Libderiv->deriv2_classes[5][7][95] = int_stack + 60956;
 Libderiv->deriv2_classes[6][4][95] = int_stack + 61712;
 Libderiv->deriv2_classes[6][5][95] = int_stack + 62132;
 Libderiv->deriv2_classes[6][6][95] = int_stack + 62720;
 Libderiv->deriv2_classes[6][7][95] = int_stack + 63504;
 Libderiv->deriv2_classes[5][4][94] = int_stack + 64512;
 Libderiv->deriv2_classes[5][5][94] = int_stack + 64827;
 Libderiv->deriv2_classes[5][6][94] = int_stack + 65268;
 Libderiv->deriv2_classes[5][7][94] = int_stack + 65856;
 Libderiv->deriv2_classes[6][4][94] = int_stack + 66612;
 Libderiv->deriv2_classes[6][5][94] = int_stack + 67032;
 Libderiv->deriv2_classes[6][6][94] = int_stack + 67620;
 Libderiv->deriv2_classes[6][7][94] = int_stack + 68404;
 Libderiv->deriv2_classes[5][4][93] = int_stack + 69412;
 Libderiv->deriv2_classes[5][5][93] = int_stack + 69727;
 Libderiv->deriv2_classes[5][6][93] = int_stack + 70168;
 Libderiv->deriv2_classes[5][7][93] = int_stack + 70756;
 Libderiv->deriv2_classes[6][4][93] = int_stack + 71512;
 Libderiv->deriv2_classes[6][5][93] = int_stack + 71932;
 Libderiv->deriv2_classes[6][6][93] = int_stack + 72520;
 Libderiv->deriv2_classes[6][7][93] = int_stack + 73304;
 Libderiv->deriv2_classes[5][4][92] = int_stack + 74312;
 Libderiv->deriv2_classes[5][5][92] = int_stack + 74627;
 Libderiv->deriv2_classes[5][6][92] = int_stack + 75068;
 Libderiv->deriv2_classes[5][7][92] = int_stack + 75656;
 Libderiv->deriv2_classes[6][4][92] = int_stack + 76412;
 Libderiv->deriv2_classes[6][5][92] = int_stack + 76832;
 Libderiv->deriv2_classes[6][6][92] = int_stack + 77420;
 Libderiv->deriv2_classes[6][7][92] = int_stack + 78204;
 Libderiv->deriv2_classes[5][4][91] = int_stack + 79212;
 Libderiv->deriv2_classes[5][5][91] = int_stack + 79527;
 Libderiv->deriv2_classes[5][6][91] = int_stack + 79968;
 Libderiv->deriv2_classes[5][7][91] = int_stack + 80556;
 Libderiv->deriv2_classes[6][4][91] = int_stack + 81312;
 Libderiv->deriv2_classes[6][5][91] = int_stack + 81732;
 Libderiv->deriv2_classes[6][6][91] = int_stack + 82320;
 Libderiv->deriv2_classes[6][7][91] = int_stack + 83104;
 Libderiv->deriv2_classes[5][4][83] = int_stack + 84112;
 Libderiv->deriv2_classes[5][5][83] = int_stack + 84427;
 Libderiv->deriv2_classes[5][6][83] = int_stack + 84868;
 Libderiv->deriv2_classes[5][7][83] = int_stack + 85456;
 Libderiv->deriv_classes[6][4][11] = int_stack + 86212;
 Libderiv->deriv2_classes[6][4][83] = int_stack + 86632;
 Libderiv->deriv_classes[6][5][11] = int_stack + 87052;
 Libderiv->deriv2_classes[6][5][83] = int_stack + 87640;
 Libderiv->deriv_classes[6][6][11] = int_stack + 88228;
 Libderiv->deriv2_classes[6][6][83] = int_stack + 89012;
 Libderiv->deriv2_classes[6][7][83] = int_stack + 89796;
 Libderiv->deriv2_classes[5][4][82] = int_stack + 90804;
 Libderiv->deriv2_classes[5][5][82] = int_stack + 91119;
 Libderiv->deriv2_classes[5][6][82] = int_stack + 91560;
 Libderiv->deriv2_classes[5][7][82] = int_stack + 92148;
 Libderiv->deriv_classes[6][4][10] = int_stack + 92904;
 Libderiv->deriv2_classes[6][4][82] = int_stack + 93324;
 Libderiv->deriv_classes[6][5][10] = int_stack + 93744;
 Libderiv->deriv2_classes[6][5][82] = int_stack + 94332;
 Libderiv->deriv_classes[6][6][10] = int_stack + 94920;
 Libderiv->deriv2_classes[6][6][82] = int_stack + 95704;
 Libderiv->deriv2_classes[6][7][82] = int_stack + 96488;
 Libderiv->deriv2_classes[5][4][81] = int_stack + 97496;
 Libderiv->deriv2_classes[5][5][81] = int_stack + 97811;
 Libderiv->deriv2_classes[5][6][81] = int_stack + 98252;
 Libderiv->deriv2_classes[5][7][81] = int_stack + 98840;
 Libderiv->deriv_classes[6][4][9] = int_stack + 99596;
 Libderiv->deriv2_classes[6][4][81] = int_stack + 100016;
 Libderiv->deriv_classes[6][5][9] = int_stack + 100436;
 Libderiv->deriv2_classes[6][5][81] = int_stack + 101024;
 Libderiv->deriv_classes[6][6][9] = int_stack + 101612;
 Libderiv->deriv2_classes[6][6][81] = int_stack + 102396;
 Libderiv->deriv2_classes[6][7][81] = int_stack + 103180;
 Libderiv->deriv2_classes[5][4][80] = int_stack + 104188;
 Libderiv->deriv2_classes[5][5][80] = int_stack + 104503;
 Libderiv->deriv2_classes[5][6][80] = int_stack + 104944;
 Libderiv->deriv2_classes[5][7][80] = int_stack + 105532;
 Libderiv->deriv_classes[6][4][8] = int_stack + 106288;
 Libderiv->deriv2_classes[6][4][80] = int_stack + 106708;
 Libderiv->deriv_classes[6][5][8] = int_stack + 107128;
 Libderiv->deriv2_classes[6][5][80] = int_stack + 107716;
 Libderiv->deriv_classes[6][6][8] = int_stack + 108304;
 Libderiv->deriv2_classes[6][6][80] = int_stack + 109088;
 Libderiv->deriv2_classes[6][7][80] = int_stack + 109872;
 Libderiv->deriv2_classes[5][4][79] = int_stack + 110880;
 Libderiv->deriv2_classes[5][5][79] = int_stack + 111195;
 Libderiv->deriv2_classes[5][6][79] = int_stack + 111636;
 Libderiv->deriv2_classes[5][7][79] = int_stack + 112224;
 Libderiv->deriv_classes[6][4][7] = int_stack + 112980;
 Libderiv->deriv2_classes[6][4][79] = int_stack + 113400;
 Libderiv->deriv_classes[6][5][7] = int_stack + 113820;
 Libderiv->deriv2_classes[6][5][79] = int_stack + 114408;
 Libderiv->deriv_classes[6][6][7] = int_stack + 114996;
 Libderiv->deriv2_classes[6][6][79] = int_stack + 115780;
 Libderiv->deriv2_classes[6][7][79] = int_stack + 116564;
 Libderiv->deriv2_classes[5][4][78] = int_stack + 117572;
 Libderiv->deriv2_classes[5][5][78] = int_stack + 117887;
 Libderiv->deriv2_classes[5][6][78] = int_stack + 118328;
 Libderiv->deriv2_classes[5][7][78] = int_stack + 118916;
 Libderiv->dvrr_classes[6][4] = int_stack + 119672;
 Libderiv->deriv_classes[6][4][6] = int_stack + 120092;
 Libderiv->deriv2_classes[6][4][78] = int_stack + 120512;
 Libderiv->dvrr_classes[6][5] = int_stack + 120932;
 Libderiv->deriv_classes[6][5][6] = int_stack + 121520;
 Libderiv->deriv2_classes[6][5][78] = int_stack + 122108;
 Libderiv->deriv_classes[6][6][6] = int_stack + 122696;
 Libderiv->deriv2_classes[6][6][78] = int_stack + 123480;
 Libderiv->deriv2_classes[6][7][78] = int_stack + 124264;
 Libderiv->deriv2_classes[5][4][35] = int_stack + 125272;
 Libderiv->deriv2_classes[5][5][35] = int_stack + 125587;
 Libderiv->deriv2_classes[5][6][35] = int_stack + 126028;
 Libderiv->deriv2_classes[5][7][35] = int_stack + 126616;
 Libderiv->deriv2_classes[6][4][35] = int_stack + 127372;
 Libderiv->deriv2_classes[6][5][35] = int_stack + 127792;
 Libderiv->deriv2_classes[6][6][35] = int_stack + 128380;
 Libderiv->deriv2_classes[6][7][35] = int_stack + 129164;
 Libderiv->deriv2_classes[5][4][34] = int_stack + 130172;
 Libderiv->deriv2_classes[5][5][34] = int_stack + 130487;
 Libderiv->deriv2_classes[5][6][34] = int_stack + 130928;
 Libderiv->deriv2_classes[5][7][34] = int_stack + 131516;
 Libderiv->deriv2_classes[6][4][34] = int_stack + 132272;
 Libderiv->deriv2_classes[6][5][34] = int_stack + 132692;
 Libderiv->deriv2_classes[6][6][34] = int_stack + 133280;
 Libderiv->deriv2_classes[6][7][34] = int_stack + 134064;
 Libderiv->deriv2_classes[5][4][33] = int_stack + 135072;
 Libderiv->deriv2_classes[5][5][33] = int_stack + 135387;
 Libderiv->deriv2_classes[5][6][33] = int_stack + 135828;
 Libderiv->deriv2_classes[5][7][33] = int_stack + 136416;
 Libderiv->deriv2_classes[6][4][33] = int_stack + 137172;
 Libderiv->deriv2_classes[6][5][33] = int_stack + 137592;
 Libderiv->deriv2_classes[6][6][33] = int_stack + 138180;
 Libderiv->deriv2_classes[6][7][33] = int_stack + 138964;
 Libderiv->deriv2_classes[5][4][32] = int_stack + 139972;
 Libderiv->deriv2_classes[5][5][32] = int_stack + 140287;
 Libderiv->deriv2_classes[5][6][32] = int_stack + 140728;
 Libderiv->deriv2_classes[5][7][32] = int_stack + 141316;
 Libderiv->deriv2_classes[6][4][32] = int_stack + 142072;
 Libderiv->deriv2_classes[6][5][32] = int_stack + 142492;
 Libderiv->deriv2_classes[6][6][32] = int_stack + 143080;
 Libderiv->deriv2_classes[6][7][32] = int_stack + 143864;
 Libderiv->deriv2_classes[5][4][31] = int_stack + 144872;
 Libderiv->deriv2_classes[5][5][31] = int_stack + 145187;
 Libderiv->deriv2_classes[5][6][31] = int_stack + 145628;
 Libderiv->deriv2_classes[5][7][31] = int_stack + 146216;
 Libderiv->deriv2_classes[6][4][31] = int_stack + 146972;
 Libderiv->deriv2_classes[6][5][31] = int_stack + 147392;
 Libderiv->deriv2_classes[6][6][31] = int_stack + 147980;
 Libderiv->deriv2_classes[6][7][31] = int_stack + 148764;
 Libderiv->deriv2_classes[5][4][30] = int_stack + 149772;
 Libderiv->deriv2_classes[5][5][30] = int_stack + 150087;
 Libderiv->deriv2_classes[5][6][30] = int_stack + 150528;
 Libderiv->deriv2_classes[5][7][30] = int_stack + 151116;
 Libderiv->deriv_classes[6][4][2] = int_stack + 151872;
 Libderiv->deriv2_classes[6][4][30] = int_stack + 152292;
 Libderiv->deriv_classes[6][5][2] = int_stack + 152712;
 Libderiv->deriv2_classes[6][5][30] = int_stack + 153300;
 Libderiv->deriv_classes[6][6][2] = int_stack + 153888;
 Libderiv->deriv2_classes[6][6][30] = int_stack + 154672;
 Libderiv->deriv2_classes[6][7][30] = int_stack + 155456;
 Libderiv->deriv2_classes[5][4][26] = int_stack + 156464;
 Libderiv->deriv2_classes[5][5][26] = int_stack + 156779;
 Libderiv->deriv2_classes[5][6][26] = int_stack + 157220;
 Libderiv->deriv2_classes[5][7][26] = int_stack + 157808;
 Libderiv->deriv2_classes[6][4][26] = int_stack + 158564;
 Libderiv->deriv2_classes[6][5][26] = int_stack + 158984;
 Libderiv->deriv2_classes[6][6][26] = int_stack + 159572;
 Libderiv->deriv2_classes[6][7][26] = int_stack + 160356;
 Libderiv->deriv2_classes[5][4][23] = int_stack + 161364;
 Libderiv->deriv2_classes[5][5][23] = int_stack + 161679;
 Libderiv->deriv2_classes[5][6][23] = int_stack + 162120;
 Libderiv->deriv2_classes[5][7][23] = int_stack + 162708;
 Libderiv->deriv2_classes[6][4][23] = int_stack + 163464;
 Libderiv->deriv2_classes[6][5][23] = int_stack + 163884;
 Libderiv->deriv2_classes[6][6][23] = int_stack + 164472;
 Libderiv->deriv2_classes[6][7][23] = int_stack + 165256;
 Libderiv->deriv2_classes[5][4][22] = int_stack + 166264;
 Libderiv->deriv2_classes[5][5][22] = int_stack + 166579;
 Libderiv->deriv2_classes[5][6][22] = int_stack + 167020;
 Libderiv->deriv2_classes[5][7][22] = int_stack + 167608;
 Libderiv->deriv2_classes[6][4][22] = int_stack + 168364;
 Libderiv->deriv2_classes[6][5][22] = int_stack + 168784;
 Libderiv->deriv2_classes[6][6][22] = int_stack + 169372;
 Libderiv->deriv2_classes[6][7][22] = int_stack + 170156;
 Libderiv->deriv2_classes[5][4][21] = int_stack + 171164;
 Libderiv->deriv2_classes[5][5][21] = int_stack + 171479;
 Libderiv->deriv2_classes[5][6][21] = int_stack + 171920;
 Libderiv->deriv2_classes[5][7][21] = int_stack + 172508;
 Libderiv->deriv2_classes[6][4][21] = int_stack + 173264;
 Libderiv->deriv2_classes[6][5][21] = int_stack + 173684;
 Libderiv->deriv2_classes[6][6][21] = int_stack + 174272;
 Libderiv->deriv2_classes[6][7][21] = int_stack + 175056;
 Libderiv->deriv2_classes[5][4][20] = int_stack + 176064;
 Libderiv->deriv2_classes[5][5][20] = int_stack + 176379;
 Libderiv->deriv2_classes[5][6][20] = int_stack + 176820;
 Libderiv->deriv2_classes[5][7][20] = int_stack + 177408;
 Libderiv->deriv2_classes[6][4][20] = int_stack + 178164;
 Libderiv->deriv2_classes[6][5][20] = int_stack + 178584;
 Libderiv->deriv2_classes[6][6][20] = int_stack + 179172;
 Libderiv->deriv2_classes[6][7][20] = int_stack + 179956;
 Libderiv->deriv2_classes[5][4][19] = int_stack + 180964;
 Libderiv->deriv2_classes[5][5][19] = int_stack + 181279;
 Libderiv->deriv2_classes[5][6][19] = int_stack + 181720;
 Libderiv->deriv2_classes[5][7][19] = int_stack + 182308;
 Libderiv->deriv2_classes[6][4][19] = int_stack + 183064;
 Libderiv->deriv2_classes[6][5][19] = int_stack + 183484;
 Libderiv->deriv2_classes[6][6][19] = int_stack + 184072;
 Libderiv->deriv2_classes[6][7][19] = int_stack + 184856;
 Libderiv->deriv2_classes[5][4][18] = int_stack + 185864;
 Libderiv->deriv2_classes[5][5][18] = int_stack + 186179;
 Libderiv->deriv2_classes[5][6][18] = int_stack + 186620;
 Libderiv->deriv2_classes[5][7][18] = int_stack + 187208;
 Libderiv->deriv_classes[6][4][1] = int_stack + 187964;
 Libderiv->deriv2_classes[6][4][18] = int_stack + 188384;
 Libderiv->deriv_classes[6][5][1] = int_stack + 188804;
 Libderiv->deriv2_classes[6][5][18] = int_stack + 189392;
 Libderiv->deriv_classes[6][6][1] = int_stack + 189980;
 Libderiv->deriv2_classes[6][6][18] = int_stack + 190764;
 Libderiv->deriv2_classes[6][7][18] = int_stack + 191548;
 Libderiv->deriv2_classes[5][4][14] = int_stack + 192556;
 Libderiv->deriv2_classes[5][5][14] = int_stack + 192871;
 Libderiv->deriv2_classes[5][6][14] = int_stack + 193312;
 Libderiv->deriv2_classes[5][7][14] = int_stack + 193900;
 Libderiv->deriv2_classes[6][4][14] = int_stack + 194656;
 Libderiv->deriv2_classes[6][5][14] = int_stack + 195076;
 Libderiv->deriv2_classes[6][6][14] = int_stack + 195664;
 Libderiv->deriv2_classes[6][7][14] = int_stack + 196448;
 Libderiv->deriv2_classes[5][4][13] = int_stack + 197456;
 Libderiv->deriv2_classes[5][5][13] = int_stack + 197771;
 Libderiv->deriv2_classes[5][6][13] = int_stack + 198212;
 Libderiv->deriv2_classes[5][7][13] = int_stack + 198800;
 Libderiv->deriv2_classes[6][4][13] = int_stack + 199556;
 Libderiv->deriv2_classes[6][5][13] = int_stack + 199976;
 Libderiv->deriv2_classes[6][6][13] = int_stack + 200564;
 Libderiv->deriv2_classes[6][7][13] = int_stack + 201348;
 Libderiv->deriv_classes[5][4][11] = int_stack + 202356;
 Libderiv->deriv_classes[5][5][11] = int_stack + 202671;
 Libderiv->deriv_classes[5][6][11] = int_stack + 203112;
 Libderiv->deriv_classes[5][7][11] = int_stack + 203700;
 Libderiv->deriv2_classes[5][4][11] = int_stack + 204456;
 Libderiv->deriv2_classes[5][5][11] = int_stack + 204771;
 Libderiv->deriv2_classes[5][6][11] = int_stack + 205212;
 Libderiv->deriv2_classes[5][7][11] = int_stack + 205800;
 Libderiv->deriv2_classes[6][4][11] = int_stack + 206556;
 Libderiv->deriv2_classes[6][5][11] = int_stack + 206976;
 Libderiv->deriv2_classes[6][6][11] = int_stack + 207564;
 Libderiv->deriv2_classes[6][7][11] = int_stack + 208348;
 Libderiv->deriv_classes[5][4][10] = int_stack + 209356;
 Libderiv->deriv_classes[5][5][10] = int_stack + 209671;
 Libderiv->deriv_classes[5][6][10] = int_stack + 210112;
 Libderiv->deriv_classes[5][7][10] = int_stack + 210700;
 Libderiv->deriv2_classes[5][4][10] = int_stack + 211456;
 Libderiv->deriv2_classes[5][5][10] = int_stack + 211771;
 Libderiv->deriv2_classes[5][6][10] = int_stack + 212212;
 Libderiv->deriv2_classes[5][7][10] = int_stack + 212800;
 Libderiv->deriv2_classes[6][4][10] = int_stack + 213556;
 Libderiv->deriv2_classes[6][5][10] = int_stack + 213976;
 Libderiv->deriv2_classes[6][6][10] = int_stack + 214564;
 Libderiv->deriv2_classes[6][7][10] = int_stack + 215348;
 Libderiv->deriv_classes[5][4][9] = int_stack + 216356;
 Libderiv->deriv_classes[5][5][9] = int_stack + 216671;
 Libderiv->deriv_classes[5][6][9] = int_stack + 217112;
 Libderiv->deriv_classes[5][7][9] = int_stack + 217700;
 Libderiv->deriv2_classes[5][4][9] = int_stack + 218456;
 Libderiv->deriv2_classes[5][5][9] = int_stack + 218771;
 Libderiv->deriv2_classes[5][6][9] = int_stack + 219212;
 Libderiv->deriv2_classes[5][7][9] = int_stack + 219800;
 Libderiv->deriv2_classes[6][4][9] = int_stack + 220556;
 Libderiv->deriv2_classes[6][5][9] = int_stack + 220976;
 Libderiv->deriv2_classes[6][6][9] = int_stack + 221564;
 Libderiv->deriv2_classes[6][7][9] = int_stack + 222348;
 Libderiv->deriv_classes[5][4][8] = int_stack + 223356;
 Libderiv->deriv_classes[5][5][8] = int_stack + 223671;
 Libderiv->deriv_classes[5][6][8] = int_stack + 224112;
 Libderiv->deriv_classes[5][7][8] = int_stack + 224700;
 Libderiv->deriv2_classes[5][4][8] = int_stack + 225456;
 Libderiv->deriv2_classes[5][5][8] = int_stack + 225771;
 Libderiv->deriv2_classes[5][6][8] = int_stack + 226212;
 Libderiv->deriv2_classes[5][7][8] = int_stack + 226800;
 Libderiv->deriv2_classes[6][4][8] = int_stack + 227556;
 Libderiv->deriv2_classes[6][5][8] = int_stack + 227976;
 Libderiv->deriv2_classes[6][6][8] = int_stack + 228564;
 Libderiv->deriv2_classes[6][7][8] = int_stack + 229348;
 Libderiv->deriv_classes[5][4][7] = int_stack + 230356;
 Libderiv->deriv_classes[5][5][7] = int_stack + 230671;
 Libderiv->deriv_classes[5][6][7] = int_stack + 231112;
 Libderiv->deriv_classes[5][7][7] = int_stack + 231700;
 Libderiv->deriv2_classes[5][4][7] = int_stack + 232456;
 Libderiv->deriv2_classes[5][5][7] = int_stack + 232771;
 Libderiv->deriv2_classes[5][6][7] = int_stack + 233212;
 Libderiv->deriv2_classes[5][7][7] = int_stack + 233800;
 Libderiv->deriv2_classes[6][4][7] = int_stack + 234556;
 Libderiv->deriv2_classes[6][5][7] = int_stack + 234976;
 Libderiv->deriv2_classes[6][6][7] = int_stack + 235564;
 Libderiv->deriv2_classes[6][7][7] = int_stack + 236348;
 Libderiv->dvrr_classes[5][4] = int_stack + 237356;
 Libderiv->deriv_classes[5][4][6] = int_stack + 237671;
 Libderiv->dvrr_classes[5][5] = int_stack + 237986;
 Libderiv->deriv_classes[5][5][6] = int_stack + 238427;
 Libderiv->dvrr_classes[5][6] = int_stack + 238868;
 Libderiv->deriv_classes[5][6][6] = int_stack + 239456;
 Libderiv->deriv_classes[5][7][6] = int_stack + 240044;
 Libderiv->deriv2_classes[5][4][6] = int_stack + 240800;
 Libderiv->deriv2_classes[5][5][6] = int_stack + 241115;
 Libderiv->deriv2_classes[5][6][6] = int_stack + 241556;
 Libderiv->deriv2_classes[5][7][6] = int_stack + 242144;
 Libderiv->deriv_classes[6][4][0] = int_stack + 242900;
 Libderiv->deriv2_classes[6][4][6] = int_stack + 243320;
 Libderiv->deriv_classes[6][5][0] = int_stack + 243740;
 Libderiv->deriv2_classes[6][5][6] = int_stack + 244328;
 Libderiv->deriv_classes[6][6][0] = int_stack + 244916;
 Libderiv->deriv2_classes[6][6][6] = int_stack + 245700;
 Libderiv->deriv2_classes[6][7][6] = int_stack + 246484;
 Libderiv->deriv_classes[5][4][2] = int_stack + 247492;
 Libderiv->deriv_classes[5][5][2] = int_stack + 247807;
 Libderiv->deriv_classes[5][6][2] = int_stack + 248248;
 Libderiv->deriv_classes[5][7][2] = int_stack + 248836;
 Libderiv->deriv2_classes[5][4][2] = int_stack + 249592;
 Libderiv->deriv2_classes[5][5][2] = int_stack + 249907;
 Libderiv->deriv2_classes[5][6][2] = int_stack + 250348;
 Libderiv->deriv2_classes[5][7][2] = int_stack + 250936;
 Libderiv->deriv2_classes[6][4][2] = int_stack + 251692;
 Libderiv->deriv2_classes[6][5][2] = int_stack + 252112;
 Libderiv->deriv2_classes[6][6][2] = int_stack + 252700;
 Libderiv->deriv2_classes[6][7][2] = int_stack + 253484;
 Libderiv->deriv_classes[5][4][1] = int_stack + 254492;
 Libderiv->deriv_classes[5][5][1] = int_stack + 254807;
 Libderiv->deriv_classes[5][6][1] = int_stack + 255248;
 Libderiv->deriv_classes[5][7][1] = int_stack + 255836;
 Libderiv->deriv2_classes[5][4][1] = int_stack + 256592;
 Libderiv->deriv2_classes[5][5][1] = int_stack + 256907;
 Libderiv->deriv2_classes[5][6][1] = int_stack + 257348;
 Libderiv->deriv2_classes[5][7][1] = int_stack + 257936;
 Libderiv->deriv2_classes[6][4][1] = int_stack + 258692;
 Libderiv->deriv2_classes[6][5][1] = int_stack + 259112;
 Libderiv->deriv2_classes[6][6][1] = int_stack + 259700;
 Libderiv->deriv2_classes[6][7][1] = int_stack + 260484;
 Libderiv->deriv_classes[5][4][0] = int_stack + 261492;
 Libderiv->deriv_classes[5][5][0] = int_stack + 261807;
 Libderiv->deriv_classes[5][6][0] = int_stack + 262248;
 Libderiv->deriv_classes[5][7][0] = int_stack + 262836;
 Libderiv->deriv2_classes[5][4][0] = int_stack + 263592;
 Libderiv->deriv2_classes[5][5][0] = int_stack + 263907;
 Libderiv->deriv2_classes[5][6][0] = int_stack + 264348;
 Libderiv->deriv2_classes[5][7][0] = int_stack + 264936;
 Libderiv->deriv2_classes[6][4][0] = int_stack + 265692;
 Libderiv->deriv2_classes[6][5][0] = int_stack + 266112;
 Libderiv->deriv2_classes[6][6][0] = int_stack + 266700;
 Libderiv->deriv2_classes[6][7][0] = int_stack + 267484;
 memset(int_stack,0,2147936);

 Libderiv->dvrr_stack = int_stack + 615454;
 for(i=0;i<num_prim_comb;i++) {
   d12vrr_order_hpgf(Libderiv, Data);
   Data++;
 }

 /*--- compute (h0|gp) ---*/
   hrr3_build_gp(Libderiv->CD,int_stack+268492,int_stack+237986,int_stack+237356,21);
 /*--- compute (h0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+269437,int_stack+238868,int_stack+237986,21);
 /*--- compute (h0|gd) ---*/
   hrr3_build_gd(Libderiv->CD,int_stack+270760,int_stack+269437,int_stack+268492,21);
 /*--- compute (h0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+272650,int_stack+202671,int_stack+202356, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+237356,21);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+273595,int_stack+203112,int_stack+202671, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+237986,21);
 /*--- compute (h0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+274918,int_stack+273595,int_stack+272650, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+268492,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+276808,int_stack+203700,int_stack+203112, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+238868,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+278572,int_stack+276808,int_stack+273595, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+269437,21);
 /*--- compute (h0|gf) ---*/
   d1hrr3_build_gf(Libderiv->CD,int_stack+281218,int_stack+278572,int_stack+274918, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+270760,21);
 /*--- compute (i0|gp) ---*/
   hrr3_build_gp(Libderiv->CD,int_stack+276808,int_stack+120932,int_stack+119672,28);
 /*--- compute (i0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+278068,int_stack+5040,int_stack+120932,28);
 /*--- compute (i0|gd) ---*/
   hrr3_build_gd(Libderiv->CD,int_stack+284368,int_stack+278068,int_stack+276808,28);
 /*--- compute (i0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+279832,int_stack+87052,int_stack+86212, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+119672,28);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+286888,int_stack+88228,int_stack+87052, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+120932,28);
 /*--- compute (i0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+288652,int_stack+286888,int_stack+279832, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+276808,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+291172,int_stack+0,int_stack+88228, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+5040,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+293524,int_stack+291172,int_stack+286888, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+278068,28);
 /*--- compute (i0|gf) ---*/
   d1hrr3_build_gf(Libderiv->CD,int_stack+297052,int_stack+293524,int_stack+288652, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+284368,28);
 /*--- compute (h0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+291172,int_stack+209671,int_stack+209356, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+237356, 0.0, zero_stack,21);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+292117,int_stack+210112,int_stack+209671, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+237986, 0.0, zero_stack,21);
 /*--- compute (h0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+293440,int_stack+292117,int_stack+291172, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+268492, 0.0, zero_stack,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+301252,int_stack+210700,int_stack+210112, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+238868, 0.0, zero_stack,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+303016,int_stack+301252,int_stack+292117, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+269437, 0.0, zero_stack,21);
 /*--- compute (h0|gf) ---*/
   d1hrr3_build_gf(Libderiv->CD,int_stack+305662,int_stack+303016,int_stack+293440, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+270760, 0.0, zero_stack,21);
 /*--- compute (i0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+301252,int_stack+93744,int_stack+92904, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+119672, 0.0, zero_stack,28);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+302512,int_stack+94920,int_stack+93744, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+120932, 0.0, zero_stack,28);
 /*--- compute (i0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+308812,int_stack+302512,int_stack+301252, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+276808, 0.0, zero_stack,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+311332,int_stack+1008,int_stack+94920, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+5040, 0.0, zero_stack,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+313684,int_stack+311332,int_stack+302512, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+278068, 0.0, zero_stack,28);
 /*--- compute (i0|gf) ---*/
   d1hrr3_build_gf(Libderiv->CD,int_stack+317212,int_stack+313684,int_stack+308812, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+284368, 0.0, zero_stack,28);
 /*--- compute (h0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+311332,int_stack+216671,int_stack+216356, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+237356, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+312277,int_stack+217112,int_stack+216671, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+237986, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+313600,int_stack+312277,int_stack+311332, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+268492, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+0,int_stack+217700,int_stack+217112, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+238868, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+321412,int_stack+0,int_stack+312277, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+269437, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|gf) ---*/
   d1hrr3_build_gf(Libderiv->CD,int_stack+324058,int_stack+321412,int_stack+313600, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+270760, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (i0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+321412,int_stack+100436,int_stack+99596, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+119672, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+0,int_stack+101612,int_stack+100436, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+120932, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+327208,int_stack+0,int_stack+321412, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+276808, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+329728,int_stack+2016,int_stack+101612, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+5040, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+332080,int_stack+329728,int_stack+0, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+278068, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|gf) ---*/
   d1hrr3_build_gf(Libderiv->CD,int_stack+335608,int_stack+332080,int_stack+327208, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+284368, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (h0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+329728,int_stack+223671,int_stack+223356, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+237356, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+330673,int_stack+224112,int_stack+223671, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+237986, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+331996,int_stack+330673,int_stack+329728, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+268492, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+339808,int_stack+224700,int_stack+224112, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+238868, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+341572,int_stack+339808,int_stack+330673, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+269437, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|gf) ---*/
   d1hrr3_build_gf(Libderiv->CD,int_stack+344218,int_stack+341572,int_stack+331996, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+270760, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (i0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+1764,int_stack+107128,int_stack+106288, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+119672, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+339808,int_stack+108304,int_stack+107128, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+120932, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+341572,int_stack+339808,int_stack+1764, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+276808, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+347368,int_stack+3024,int_stack+108304, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+5040, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+349720,int_stack+347368,int_stack+339808, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+278068, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|gf) ---*/
   d1hrr3_build_gf(Libderiv->CD,int_stack+353248,int_stack+349720,int_stack+341572, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+284368, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (h0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+347368,int_stack+230671,int_stack+230356, 0.0, zero_stack, 1.0, int_stack+237356, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+348313,int_stack+231112,int_stack+230671, 0.0, zero_stack, 1.0, int_stack+237986, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+349636,int_stack+348313,int_stack+347368, 0.0, zero_stack, 1.0, int_stack+268492, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+357448,int_stack+231700,int_stack+231112, 0.0, zero_stack, 1.0, int_stack+238868, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+359212,int_stack+357448,int_stack+348313, 0.0, zero_stack, 1.0, int_stack+269437, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|gf) ---*/
   d1hrr3_build_gf(Libderiv->CD,int_stack+361858,int_stack+359212,int_stack+349636, 0.0, zero_stack, 1.0, int_stack+270760, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (i0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+357448,int_stack+113820,int_stack+112980, 0.0, zero_stack, 1.0, int_stack+119672, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+358708,int_stack+114996,int_stack+113820, 0.0, zero_stack, 1.0, int_stack+120932, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+365008,int_stack+358708,int_stack+357448, 0.0, zero_stack, 1.0, int_stack+276808, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+367528,int_stack+4032,int_stack+114996, 0.0, zero_stack, 1.0, int_stack+5040, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+369880,int_stack+367528,int_stack+358708, 0.0, zero_stack, 1.0, int_stack+278068, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|gf) ---*/
   d1hrr3_build_gf(Libderiv->CD,int_stack+373408,int_stack+369880,int_stack+365008, 0.0, zero_stack, 1.0, int_stack+284368, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (h0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+367528,int_stack+238427,int_stack+237671, 1.0, int_stack+237356, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+368473,int_stack+239456,int_stack+238427, 1.0, int_stack+237986, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+369796,int_stack+368473,int_stack+367528, 1.0, int_stack+268492, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+3024,int_stack+240044,int_stack+239456, 1.0, int_stack+238868, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+377608,int_stack+3024,int_stack+368473, 1.0, int_stack+269437, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|gf) ---*/
   d1hrr3_build_gf(Libderiv->CD,int_stack+380254,int_stack+377608,int_stack+369796, 1.0, int_stack+270760, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (i0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+377608,int_stack+121520,int_stack+120092, 1.0, int_stack+119672, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+3024,int_stack+122696,int_stack+121520, 1.0, int_stack+120932, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+383404,int_stack+3024,int_stack+377608, 1.0, int_stack+276808, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+385924,int_stack+5824,int_stack+122696, 1.0, int_stack+5040, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+388276,int_stack+385924,int_stack+3024, 1.0, int_stack+278068, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|gf) ---*/
   d1hrr3_build_gf(Libderiv->CD,int_stack+391804,int_stack+388276,int_stack+383404, 1.0, int_stack+284368, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (h0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+284368,int_stack+8848,int_stack+238868,21);
 /*--- compute (h0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+385924,int_stack+284368,int_stack+269437,21);
 /*--- compute (h0|gf) ---*/
   hrr3_build_gf(Libderiv->CD,int_stack+388570,int_stack+385924,int_stack+270760,21);
 /*--- compute (h0|gp) ---*/
   hrr3_build_gp(Libderiv->CD,int_stack+385924,int_stack+247807,int_stack+247492,21);
 /*--- compute (h0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+386869,int_stack+248248,int_stack+247807,21);
 /*--- compute (h0|gd) ---*/
   hrr3_build_gd(Libderiv->CD,int_stack+284368,int_stack+386869,int_stack+385924,21);
 /*--- compute (h0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+276808,int_stack+248836,int_stack+248248,21);
 /*--- compute (h0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+268492,int_stack+276808,int_stack+386869,21);
 /*--- compute (h0|gf) ---*/
   hrr3_build_gf(Libderiv->CD,int_stack+396004,int_stack+268492,int_stack+284368,21);
 /*--- compute (i0|gp) ---*/
   hrr3_build_gp(Libderiv->CD,int_stack+268492,int_stack+152712,int_stack+151872,28);
 /*--- compute (i0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+269752,int_stack+153888,int_stack+152712,28);
 /*--- compute (i0|gd) ---*/
   hrr3_build_gd(Libderiv->CD,int_stack+276808,int_stack+269752,int_stack+268492,28);
 /*--- compute (i0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+399154,int_stack+6832,int_stack+153888,28);
 /*--- compute (i0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+401506,int_stack+399154,int_stack+269752,28);
 /*--- compute (i0|gf) ---*/
   hrr3_build_gf(Libderiv->CD,int_stack+405034,int_stack+401506,int_stack+276808,28);
 /*--- compute (h0|gp) ---*/
   hrr3_build_gp(Libderiv->CD,int_stack+399154,int_stack+254807,int_stack+254492,21);
 /*--- compute (h0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+400099,int_stack+255248,int_stack+254807,21);
 /*--- compute (h0|gd) ---*/
   hrr3_build_gd(Libderiv->CD,int_stack+401422,int_stack+400099,int_stack+399154,21);
 /*--- compute (h0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+4788,int_stack+255836,int_stack+255248,21);
 /*--- compute (h0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+409234,int_stack+4788,int_stack+400099,21);
 /*--- compute (h0|gf) ---*/
   hrr3_build_gf(Libderiv->CD,int_stack+411880,int_stack+409234,int_stack+401422,21);
 /*--- compute (i0|gp) ---*/
   hrr3_build_gp(Libderiv->CD,int_stack+409234,int_stack+188804,int_stack+187964,28);
 /*--- compute (i0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+4788,int_stack+189980,int_stack+188804,28);
 /*--- compute (i0|gd) ---*/
   hrr3_build_gd(Libderiv->CD,int_stack+415030,int_stack+4788,int_stack+409234,28);
 /*--- compute (i0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+417550,int_stack+7840,int_stack+189980,28);
 /*--- compute (i0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+419902,int_stack+417550,int_stack+4788,28);
 /*--- compute (i0|gf) ---*/
   hrr3_build_gf(Libderiv->CD,int_stack+423430,int_stack+419902,int_stack+415030,28);
 /*--- compute (h0|gp) ---*/
   hrr3_build_gp(Libderiv->CD,int_stack+417550,int_stack+261807,int_stack+261492,21);
 /*--- compute (h0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+418495,int_stack+262248,int_stack+261807,21);
 /*--- compute (h0|gd) ---*/
   hrr3_build_gd(Libderiv->CD,int_stack+419818,int_stack+418495,int_stack+417550,21);
 /*--- compute (h0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+6552,int_stack+262836,int_stack+262248,21);
 /*--- compute (h0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+427630,int_stack+6552,int_stack+418495,21);
 /*--- compute (h0|gf) ---*/
   hrr3_build_gf(Libderiv->CD,int_stack+430276,int_stack+427630,int_stack+419818,21);
 /*--- compute (i0|gp) ---*/
   hrr3_build_gp(Libderiv->CD,int_stack+427630,int_stack+243740,int_stack+242900,28);
 /*--- compute (i0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+6552,int_stack+244916,int_stack+243740,28);
 /*--- compute (i0|gd) ---*/
   hrr3_build_gd(Libderiv->CD,int_stack+433426,int_stack+6552,int_stack+427630,28);
 /*--- compute (i0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+435946,int_stack+9604,int_stack+244916,28);
 /*--- compute (i0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+438298,int_stack+435946,int_stack+6552,28);
 /*--- compute (i0|gf) ---*/
   hrr3_build_gf(Libderiv->CD,int_stack+441826,int_stack+438298,int_stack+433426,28);
 /*--- compute (h0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+435946,int_stack+10927,int_stack+10612, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+202356,21);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+436891,int_stack+11368,int_stack+10927, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+202671,21);
 /*--- compute (h0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+438214,int_stack+436891,int_stack+435946, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+272650,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+8316,int_stack+11956,int_stack+11368, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+203112,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+446026,int_stack+8316,int_stack+436891, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+273595,21);
 /*--- compute (h0|gf) ---*/
   d1hrr3_build_gf(Libderiv->CD,int_stack+8316,int_stack+446026,int_stack+438214, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+274918,21);
 /*--- compute (i0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+446026,int_stack+13132,int_stack+12712, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+86212,28);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+435946,int_stack+13720,int_stack+13132, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+87052,28);
 /*--- compute (i0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+437710,int_stack+435946,int_stack+446026, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+279832,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+446026,int_stack+14504,int_stack+13720, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+88228,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+11466,int_stack+446026,int_stack+435946, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+286888,28);
 /*--- compute (i0|gf) ---*/
   d1hrr3_build_gf(Libderiv->CD,int_stack+446026,int_stack+11466,int_stack+437710, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+288652,28);
 /*--- compute (h0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+11466,int_stack+15827,int_stack+15512, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+202356, 1.0, int_stack+209356,21);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+12411,int_stack+16268,int_stack+15827, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+202671, 1.0, int_stack+209671,21);
 /*--- compute (h0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+13734,int_stack+12411,int_stack+11466, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+272650, 1.0, int_stack+291172,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+435946,int_stack+16856,int_stack+16268, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+203112, 1.0, int_stack+210112,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+437710,int_stack+435946,int_stack+12411, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+273595, 1.0, int_stack+292117,21);
 /*--- compute (h0|gf) ---*/
   d1hrr3_build_gf(Libderiv->CD,int_stack+450226,int_stack+437710,int_stack+13734, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+274918, 1.0, int_stack+293440,21);
 /*--- compute (i0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+435946,int_stack+18032,int_stack+17612, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+86212, 1.0, int_stack+92904,28);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+437206,int_stack+18620,int_stack+18032, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+87052, 1.0, int_stack+93744,28);
 /*--- compute (i0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+438970,int_stack+437206,int_stack+435946, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+279832, 1.0, int_stack+301252,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+11466,int_stack+19404,int_stack+18620, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+88228, 1.0, int_stack+94920,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+13818,int_stack+11466,int_stack+437206, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+286888, 1.0, int_stack+302512,28);
 /*--- compute (i0|gf) ---*/
   d1hrr3_build_gf(Libderiv->CD,int_stack+453376,int_stack+13818,int_stack+438970, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+288652, 1.0, int_stack+308812,28);
 /*--- compute (h0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+11466,int_stack+20727,int_stack+20412, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+209356, 0.0, zero_stack,21);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+12411,int_stack+21168,int_stack+20727, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+209671, 0.0, zero_stack,21);
 /*--- compute (h0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+13734,int_stack+12411,int_stack+11466, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+291172, 0.0, zero_stack,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+15624,int_stack+21756,int_stack+21168, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+210112, 0.0, zero_stack,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+17388,int_stack+15624,int_stack+12411, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+292117, 0.0, zero_stack,21);
 /*--- compute (h0|gf) ---*/
   d1hrr3_build_gf(Libderiv->CD,int_stack+435946,int_stack+17388,int_stack+13734, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+293440, 0.0, zero_stack,21);
 /*--- compute (i0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+11466,int_stack+22932,int_stack+22512, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+92904, 0.0, zero_stack,28);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+12726,int_stack+23520,int_stack+22932, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+93744, 0.0, zero_stack,28);
 /*--- compute (i0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+14490,int_stack+12726,int_stack+11466, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+301252, 0.0, zero_stack,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+17010,int_stack+24304,int_stack+23520, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+94920, 0.0, zero_stack,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+19362,int_stack+17010,int_stack+12726, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+302512, 0.0, zero_stack,28);
 /*--- compute (i0|gf) ---*/
   d1hrr3_build_gf(Libderiv->CD,int_stack+457576,int_stack+19362,int_stack+14490, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+308812, 0.0, zero_stack,28);
 /*--- compute (h0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+11466,int_stack+25627,int_stack+25312, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+202356, 0.0, zero_stack, 1.0, int_stack+216356,21);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+12411,int_stack+26068,int_stack+25627, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+202671, 0.0, zero_stack, 1.0, int_stack+216671,21);
 /*--- compute (h0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+13734,int_stack+12411,int_stack+11466, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+272650, 0.0, zero_stack, 1.0, int_stack+311332,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+15624,int_stack+26656,int_stack+26068, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+203112, 0.0, zero_stack, 1.0, int_stack+217112,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+17388,int_stack+15624,int_stack+12411, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+273595, 0.0, zero_stack, 1.0, int_stack+312277,21);
 /*--- compute (h0|gf) ---*/
   d1hrr3_build_gf(Libderiv->CD,int_stack+20034,int_stack+17388,int_stack+13734, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+274918, 0.0, zero_stack, 1.0, int_stack+313600,21);
 /*--- compute (i0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+11466,int_stack+27832,int_stack+27412, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+86212, 0.0, zero_stack, 1.0, int_stack+99596,28);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+12726,int_stack+28420,int_stack+27832, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+87052, 0.0, zero_stack, 1.0, int_stack+100436,28);
 /*--- compute (i0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+14490,int_stack+12726,int_stack+11466, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+279832, 0.0, zero_stack, 1.0, int_stack+321412,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+17010,int_stack+29204,int_stack+28420, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+88228, 0.0, zero_stack, 1.0, int_stack+101612,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+23184,int_stack+17010,int_stack+12726, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+286888, 0.0, zero_stack, 1.0, int_stack+0,28);
 /*--- compute (i0|gf) ---*/
   d1hrr3_build_gf(Libderiv->CD,int_stack+461776,int_stack+23184,int_stack+14490, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+288652, 0.0, zero_stack, 1.0, int_stack+327208,28);
 /*--- compute (h0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+23184,int_stack+30527,int_stack+30212, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+209356, 1.0, int_stack+216356, 0.0, zero_stack,21);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+24129,int_stack+30968,int_stack+30527, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+209671, 1.0, int_stack+216671, 0.0, zero_stack,21);
 /*--- compute (h0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+25452,int_stack+24129,int_stack+23184, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+291172, 1.0, int_stack+311332, 0.0, zero_stack,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+27342,int_stack+31556,int_stack+30968, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+210112, 1.0, int_stack+217112, 0.0, zero_stack,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+29106,int_stack+27342,int_stack+24129, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+292117, 1.0, int_stack+312277, 0.0, zero_stack,21);
 /*--- compute (h0|gf) ---*/
   d1hrr3_build_gf(Libderiv->CD,int_stack+11466,int_stack+29106,int_stack+25452, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+293440, 1.0, int_stack+313600, 0.0, zero_stack,21);
 /*--- compute (i0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+23184,int_stack+32732,int_stack+32312, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+92904, 1.0, int_stack+99596, 0.0, zero_stack,28);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+24444,int_stack+33320,int_stack+32732, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+93744, 1.0, int_stack+100436, 0.0, zero_stack,28);
 /*--- compute (i0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+26208,int_stack+24444,int_stack+23184, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+301252, 1.0, int_stack+321412, 0.0, zero_stack,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+28728,int_stack+34104,int_stack+33320, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+94920, 1.0, int_stack+101612, 0.0, zero_stack,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+31080,int_stack+28728,int_stack+24444, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+302512, 1.0, int_stack+0, 0.0, zero_stack,28);
 /*--- compute (i0|gf) ---*/
   d1hrr3_build_gf(Libderiv->CD,int_stack+14616,int_stack+31080,int_stack+26208, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+308812, 1.0, int_stack+327208, 0.0, zero_stack,28);
 /*--- compute (h0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+23184,int_stack+35427,int_stack+35112, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+216356, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+24129,int_stack+35868,int_stack+35427, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+216671, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+25452,int_stack+24129,int_stack+23184, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+311332, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+27342,int_stack+36456,int_stack+35868, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+217112, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+29106,int_stack+27342,int_stack+24129, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+312277, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|gf) ---*/
   d1hrr3_build_gf(Libderiv->CD,int_stack+31752,int_stack+29106,int_stack+25452, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+313600, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (i0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+23184,int_stack+37632,int_stack+37212, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+99596, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+24444,int_stack+38220,int_stack+37632, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+100436, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+26208,int_stack+24444,int_stack+23184, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+321412, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+28728,int_stack+39004,int_stack+38220, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+101612, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+34902,int_stack+28728,int_stack+24444, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+0, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|gf) ---*/
   d1hrr3_build_gf(Libderiv->CD,int_stack+465976,int_stack+34902,int_stack+26208, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+327208, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (h0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+34902,int_stack+40327,int_stack+40012, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+202356, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+223356,21);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+35847,int_stack+40768,int_stack+40327, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+202671, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+223671,21);
 /*--- compute (h0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+37170,int_stack+35847,int_stack+34902, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+272650, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+329728,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+23184,int_stack+41356,int_stack+40768, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+203112, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+224112,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+39060,int_stack+23184,int_stack+35847, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+273595, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+330673,21);
 /*--- compute (h0|gf) ---*/
   d1hrr3_build_gf(Libderiv->CD,int_stack+23184,int_stack+39060,int_stack+37170, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+274918, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+331996,21);
 /*--- compute (i0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+26334,int_stack+42532,int_stack+42112, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+86212, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+106288,28);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+27594,int_stack+43120,int_stack+42532, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+87052, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+107128,28);
 /*--- compute (i0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+34902,int_stack+27594,int_stack+26334, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+279832, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1764,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+29358,int_stack+43904,int_stack+43120, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+88228, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+108304,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+37422,int_stack+29358,int_stack+27594, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+286888, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+339808,28);
 /*--- compute (i0|gf) ---*/
   d1hrr3_build_gf(Libderiv->CD,int_stack+26334,int_stack+37422,int_stack+34902, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+288652, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+341572,28);
 /*--- compute (h0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+34902,int_stack+45227,int_stack+44912, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+209356, 0.0, zero_stack, 1.0, int_stack+223356, 0.0, zero_stack,21);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+35847,int_stack+45668,int_stack+45227, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+209671, 0.0, zero_stack, 1.0, int_stack+223671, 0.0, zero_stack,21);
 /*--- compute (h0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+37170,int_stack+35847,int_stack+34902, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+291172, 0.0, zero_stack, 1.0, int_stack+329728, 0.0, zero_stack,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+39060,int_stack+46256,int_stack+45668, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+210112, 0.0, zero_stack, 1.0, int_stack+224112, 0.0, zero_stack,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+40824,int_stack+39060,int_stack+35847, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+292117, 0.0, zero_stack, 1.0, int_stack+330673, 0.0, zero_stack,21);
 /*--- compute (h0|gf) ---*/
   d1hrr3_build_gf(Libderiv->CD,int_stack+43470,int_stack+40824,int_stack+37170, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+293440, 0.0, zero_stack, 1.0, int_stack+331996, 0.0, zero_stack,21);
 /*--- compute (i0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+34902,int_stack+47432,int_stack+47012, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+92904, 0.0, zero_stack, 1.0, int_stack+106288, 0.0, zero_stack,28);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+36162,int_stack+48020,int_stack+47432, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+93744, 0.0, zero_stack, 1.0, int_stack+107128, 0.0, zero_stack,28);
 /*--- compute (i0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+37926,int_stack+36162,int_stack+34902, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+301252, 0.0, zero_stack, 1.0, int_stack+1764, 0.0, zero_stack,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+40446,int_stack+48804,int_stack+48020, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+94920, 0.0, zero_stack, 1.0, int_stack+108304, 0.0, zero_stack,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+470176,int_stack+40446,int_stack+36162, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+302512, 0.0, zero_stack, 1.0, int_stack+339808, 0.0, zero_stack,28);
 /*--- compute (i0|gf) ---*/
   d1hrr3_build_gf(Libderiv->CD,int_stack+473704,int_stack+470176,int_stack+37926, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+308812, 0.0, zero_stack, 1.0, int_stack+341572, 0.0, zero_stack,28);
 /*--- compute (h0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+470176,int_stack+50127,int_stack+49812, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+216356, 1.0, int_stack+223356, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+471121,int_stack+50568,int_stack+50127, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+216671, 1.0, int_stack+223671, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+34902,int_stack+471121,int_stack+470176, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+311332, 1.0, int_stack+329728, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+36792,int_stack+51156,int_stack+50568, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+217112, 1.0, int_stack+224112, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+38556,int_stack+36792,int_stack+471121, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+312277, 1.0, int_stack+330673, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|gf) ---*/
   d1hrr3_build_gf(Libderiv->CD,int_stack+470176,int_stack+38556,int_stack+34902, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+313600, 1.0, int_stack+331996, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (i0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+34902,int_stack+52332,int_stack+51912, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+99596, 1.0, int_stack+106288, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+36162,int_stack+52920,int_stack+52332, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+100436, 1.0, int_stack+107128, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+37926,int_stack+36162,int_stack+34902, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+321412, 1.0, int_stack+1764, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+40446,int_stack+53704,int_stack+52920, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+101612, 1.0, int_stack+108304, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+46620,int_stack+40446,int_stack+36162, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+0, 1.0, int_stack+339808, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|gf) ---*/
   d1hrr3_build_gf(Libderiv->CD,int_stack+50148,int_stack+46620,int_stack+37926, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+327208, 1.0, int_stack+341572, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (h0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+46620,int_stack+55027,int_stack+54712, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+223356, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+47565,int_stack+55468,int_stack+55027, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+223671, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+34902,int_stack+47565,int_stack+46620, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+329728, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+36792,int_stack+56056,int_stack+55468, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+224112, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+38556,int_stack+36792,int_stack+47565, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+330673, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|gf) ---*/
   d1hrr3_build_gf(Libderiv->CD,int_stack+46620,int_stack+38556,int_stack+34902, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+331996, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (i0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+34902,int_stack+57232,int_stack+56812, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+106288, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+36162,int_stack+57820,int_stack+57232, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+107128, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+37926,int_stack+36162,int_stack+34902, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+1764, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+40446,int_stack+58604,int_stack+57820, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+108304, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+54348,int_stack+40446,int_stack+36162, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+339808, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|gf) ---*/
   d1hrr3_build_gf(Libderiv->CD,int_stack+477904,int_stack+54348,int_stack+37926, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+341572, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (h0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+54348,int_stack+59927,int_stack+59612, 0.0, zero_stack, 1.0, int_stack+202356, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+230356,21);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+55293,int_stack+60368,int_stack+59927, 0.0, zero_stack, 1.0, int_stack+202671, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+230671,21);
 /*--- compute (h0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+56616,int_stack+55293,int_stack+54348, 0.0, zero_stack, 1.0, int_stack+272650, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+347368,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+58506,int_stack+60956,int_stack+60368, 0.0, zero_stack, 1.0, int_stack+203112, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+231112,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+34902,int_stack+58506,int_stack+55293, 0.0, zero_stack, 1.0, int_stack+273595, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+348313,21);
 /*--- compute (h0|gf) ---*/
   d1hrr3_build_gf(Libderiv->CD,int_stack+58506,int_stack+34902,int_stack+56616, 0.0, zero_stack, 1.0, int_stack+274918, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+349636,21);
 /*--- compute (i0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+34902,int_stack+62132,int_stack+61712, 0.0, zero_stack, 1.0, int_stack+86212, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+112980,28);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+36162,int_stack+62720,int_stack+62132, 0.0, zero_stack, 1.0, int_stack+87052, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+113820,28);
 /*--- compute (i0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+37926,int_stack+36162,int_stack+34902, 0.0, zero_stack, 1.0, int_stack+279832, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+357448,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+40446,int_stack+63504,int_stack+62720, 0.0, zero_stack, 1.0, int_stack+88228, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+114996,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+54348,int_stack+40446,int_stack+36162, 0.0, zero_stack, 1.0, int_stack+286888, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+358708,28);
 /*--- compute (i0|gf) ---*/
   d1hrr3_build_gf(Libderiv->CD,int_stack+482104,int_stack+54348,int_stack+37926, 0.0, zero_stack, 1.0, int_stack+288652, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+365008,28);
 /*--- compute (h0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+54348,int_stack+64827,int_stack+64512, 0.0, zero_stack, 1.0, int_stack+209356, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+230356, 0.0, zero_stack,21);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+55293,int_stack+65268,int_stack+64827, 0.0, zero_stack, 1.0, int_stack+209671, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+230671, 0.0, zero_stack,21);
 /*--- compute (h0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+56616,int_stack+55293,int_stack+54348, 0.0, zero_stack, 1.0, int_stack+291172, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+347368, 0.0, zero_stack,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+34902,int_stack+65856,int_stack+65268, 0.0, zero_stack, 1.0, int_stack+210112, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+231112, 0.0, zero_stack,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+36666,int_stack+34902,int_stack+55293, 0.0, zero_stack, 1.0, int_stack+292117, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+348313, 0.0, zero_stack,21);
 /*--- compute (h0|gf) ---*/
   d1hrr3_build_gf(Libderiv->CD,int_stack+39312,int_stack+36666,int_stack+56616, 0.0, zero_stack, 1.0, int_stack+293440, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+349636, 0.0, zero_stack,21);
 /*--- compute (i0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+34902,int_stack+67032,int_stack+66612, 0.0, zero_stack, 1.0, int_stack+92904, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+112980, 0.0, zero_stack,28);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+36162,int_stack+67620,int_stack+67032, 0.0, zero_stack, 1.0, int_stack+93744, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+113820, 0.0, zero_stack,28);
 /*--- compute (i0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+54348,int_stack+36162,int_stack+34902, 0.0, zero_stack, 1.0, int_stack+301252, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+357448, 0.0, zero_stack,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+61656,int_stack+68404,int_stack+67620, 0.0, zero_stack, 1.0, int_stack+94920, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+114996, 0.0, zero_stack,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+64008,int_stack+61656,int_stack+36162, 0.0, zero_stack, 1.0, int_stack+302512, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+358708, 0.0, zero_stack,28);
 /*--- compute (i0|gf) ---*/
   d1hrr3_build_gf(Libderiv->CD,int_stack+34902,int_stack+64008,int_stack+54348, 0.0, zero_stack, 1.0, int_stack+308812, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+365008, 0.0, zero_stack,28);
 /*--- compute (h0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+54348,int_stack+69727,int_stack+69412, 0.0, zero_stack, 1.0, int_stack+216356, 0.0, zero_stack, 1.0, int_stack+230356, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+55293,int_stack+70168,int_stack+69727, 0.0, zero_stack, 1.0, int_stack+216671, 0.0, zero_stack, 1.0, int_stack+230671, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+56616,int_stack+55293,int_stack+54348, 0.0, zero_stack, 1.0, int_stack+311332, 0.0, zero_stack, 1.0, int_stack+347368, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+61656,int_stack+70756,int_stack+70168, 0.0, zero_stack, 1.0, int_stack+217112, 0.0, zero_stack, 1.0, int_stack+231112, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+63420,int_stack+61656,int_stack+55293, 0.0, zero_stack, 1.0, int_stack+312277, 0.0, zero_stack, 1.0, int_stack+348313, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|gf) ---*/
   d1hrr3_build_gf(Libderiv->CD,int_stack+66066,int_stack+63420,int_stack+56616, 0.0, zero_stack, 1.0, int_stack+313600, 0.0, zero_stack, 1.0, int_stack+349636, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (i0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+61656,int_stack+71932,int_stack+71512, 0.0, zero_stack, 1.0, int_stack+99596, 0.0, zero_stack, 1.0, int_stack+112980, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+62916,int_stack+72520,int_stack+71932, 0.0, zero_stack, 1.0, int_stack+100436, 0.0, zero_stack, 1.0, int_stack+113820, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+54348,int_stack+62916,int_stack+61656, 0.0, zero_stack, 1.0, int_stack+321412, 0.0, zero_stack, 1.0, int_stack+357448, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+69216,int_stack+73304,int_stack+72520, 0.0, zero_stack, 1.0, int_stack+101612, 0.0, zero_stack, 1.0, int_stack+114996, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+486304,int_stack+69216,int_stack+62916, 0.0, zero_stack, 1.0, int_stack+0, 0.0, zero_stack, 1.0, int_stack+358708, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|gf) ---*/
   d1hrr3_build_gf(Libderiv->CD,int_stack+69216,int_stack+486304,int_stack+54348, 0.0, zero_stack, 1.0, int_stack+327208, 0.0, zero_stack, 1.0, int_stack+365008, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (h0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+54348,int_stack+74627,int_stack+74312, 0.0, zero_stack, 1.0, int_stack+223356, 1.0, int_stack+230356, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+55293,int_stack+75068,int_stack+74627, 0.0, zero_stack, 1.0, int_stack+223671, 1.0, int_stack+230671, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+56616,int_stack+55293,int_stack+54348, 0.0, zero_stack, 1.0, int_stack+329728, 1.0, int_stack+347368, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+486304,int_stack+75656,int_stack+75068, 0.0, zero_stack, 1.0, int_stack+224112, 1.0, int_stack+231112, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+73416,int_stack+486304,int_stack+55293, 0.0, zero_stack, 1.0, int_stack+330673, 1.0, int_stack+348313, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|gf) ---*/
   d1hrr3_build_gf(Libderiv->CD,int_stack+486304,int_stack+73416,int_stack+56616, 0.0, zero_stack, 1.0, int_stack+331996, 1.0, int_stack+349636, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (i0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+73416,int_stack+76832,int_stack+76412, 0.0, zero_stack, 1.0, int_stack+106288, 1.0, int_stack+112980, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+74676,int_stack+77420,int_stack+76832, 0.0, zero_stack, 1.0, int_stack+107128, 1.0, int_stack+113820, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+54348,int_stack+74676,int_stack+73416, 0.0, zero_stack, 1.0, int_stack+1764, 1.0, int_stack+357448, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+61656,int_stack+78204,int_stack+77420, 0.0, zero_stack, 1.0, int_stack+108304, 1.0, int_stack+114996, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+489454,int_stack+61656,int_stack+74676, 0.0, zero_stack, 1.0, int_stack+339808, 1.0, int_stack+358708, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|gf) ---*/
   d1hrr3_build_gf(Libderiv->CD,int_stack+61656,int_stack+489454,int_stack+54348, 0.0, zero_stack, 1.0, int_stack+341572, 1.0, int_stack+365008, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (h0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+54348,int_stack+79527,int_stack+79212, 0.0, zero_stack, 2.0, int_stack+230356, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+55293,int_stack+79968,int_stack+79527, 0.0, zero_stack, 2.0, int_stack+230671, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+56616,int_stack+55293,int_stack+54348, 0.0, zero_stack, 2.0, int_stack+347368, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+489454,int_stack+80556,int_stack+79968, 0.0, zero_stack, 2.0, int_stack+231112, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+73416,int_stack+489454,int_stack+55293, 0.0, zero_stack, 2.0, int_stack+348313, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|gf) ---*/
   d1hrr3_build_gf(Libderiv->CD,int_stack+489454,int_stack+73416,int_stack+56616, 0.0, zero_stack, 2.0, int_stack+349636, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (i0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+73416,int_stack+81732,int_stack+81312, 0.0, zero_stack, 2.0, int_stack+112980, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+74676,int_stack+82320,int_stack+81732, 0.0, zero_stack, 2.0, int_stack+113820, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+76440,int_stack+74676,int_stack+73416, 0.0, zero_stack, 2.0, int_stack+357448, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+78960,int_stack+83104,int_stack+82320, 0.0, zero_stack, 2.0, int_stack+114996, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+54348,int_stack+78960,int_stack+74676, 0.0, zero_stack, 2.0, int_stack+358708, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|gf) ---*/
   d1hrr3_build_gf(Libderiv->CD,int_stack+78960,int_stack+54348,int_stack+76440, 0.0, zero_stack, 2.0, int_stack+365008, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (h0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+54348,int_stack+84427,int_stack+84112, 1.0, int_stack+202356, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+237671,21);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+55293,int_stack+84868,int_stack+84427, 1.0, int_stack+202671, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+238427,21);
 /*--- compute (h0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+56616,int_stack+55293,int_stack+54348, 1.0, int_stack+272650, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+367528,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+73416,int_stack+85456,int_stack+84868, 1.0, int_stack+203112, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+239456,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+83160,int_stack+73416,int_stack+55293, 1.0, int_stack+273595, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+368473,21);
 /*--- compute (h0|gf) ---*/
   d1hrr3_build_gf(Libderiv->CD,int_stack+73416,int_stack+83160,int_stack+56616, 1.0, int_stack+274918, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+369796,21);
 /*--- compute (i0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+83160,int_stack+87640,int_stack+86632, 1.0, int_stack+86212, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+120092,28);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+84420,int_stack+89012,int_stack+87640, 1.0, int_stack+87052, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+121520,28);
 /*--- compute (i0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+54348,int_stack+84420,int_stack+83160, 1.0, int_stack+279832, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+377608,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+76566,int_stack+89796,int_stack+89012, 1.0, int_stack+88228, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+122696,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+86184,int_stack+76566,int_stack+84420, 1.0, int_stack+286888, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3024,28);
 /*--- compute (i0|gf) ---*/
   d1hrr3_build_gf(Libderiv->CD,int_stack+271516,int_stack+86184,int_stack+54348, 1.0, int_stack+288652, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+383404,28);
 /*--- compute (h0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+54348,int_stack+91119,int_stack+90804, 1.0, int_stack+209356, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+237671, 0.0, zero_stack,21);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+55293,int_stack+91560,int_stack+91119, 1.0, int_stack+209671, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+238427, 0.0, zero_stack,21);
 /*--- compute (h0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+56616,int_stack+55293,int_stack+54348, 1.0, int_stack+291172, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+367528, 0.0, zero_stack,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+76566,int_stack+92148,int_stack+91560, 1.0, int_stack+210112, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+239456, 0.0, zero_stack,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+83160,int_stack+76566,int_stack+55293, 1.0, int_stack+292117, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+368473, 0.0, zero_stack,21);
 /*--- compute (h0|gf) ---*/
   d1hrr3_build_gf(Libderiv->CD,int_stack+85806,int_stack+83160,int_stack+56616, 1.0, int_stack+293440, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+369796, 0.0, zero_stack,21);
 /*--- compute (i0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+83160,int_stack+94332,int_stack+93324, 1.0, int_stack+92904, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+120092, 0.0, zero_stack,28);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+76566,int_stack+95704,int_stack+94332, 1.0, int_stack+93744, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+121520, 0.0, zero_stack,28);
 /*--- compute (i0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+54348,int_stack+76566,int_stack+83160, 1.0, int_stack+301252, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+377608, 0.0, zero_stack,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+83160,int_stack+96488,int_stack+95704, 1.0, int_stack+94920, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+122696, 0.0, zero_stack,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+88956,int_stack+83160,int_stack+76566, 1.0, int_stack+302512, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3024, 0.0, zero_stack,28);
 /*--- compute (i0|gf) ---*/
   d1hrr3_build_gf(Libderiv->CD,int_stack+301252,int_stack+88956,int_stack+54348, 1.0, int_stack+308812, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+383404, 0.0, zero_stack,28);
 /*--- compute (h0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+308812,int_stack+97811,int_stack+97496, 1.0, int_stack+216356, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+237671, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+309757,int_stack+98252,int_stack+97811, 1.0, int_stack+216671, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+238427, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+279328,int_stack+309757,int_stack+308812, 1.0, int_stack+311332, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+367528, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+54348,int_stack+98840,int_stack+98252, 1.0, int_stack+217112, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+239456, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+83160,int_stack+54348,int_stack+309757, 1.0, int_stack+312277, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+368473, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|gf) ---*/
   d1hrr3_build_gf(Libderiv->CD,int_stack+54348,int_stack+83160,int_stack+279328, 1.0, int_stack+313600, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+369796, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (i0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+279328,int_stack+101024,int_stack+100016, 1.0, int_stack+99596, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+120092, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+83160,int_stack+102396,int_stack+101024, 1.0, int_stack+100436, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+121520, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+308812,int_stack+83160,int_stack+279328, 1.0, int_stack+321412, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+377608, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+321412,int_stack+103180,int_stack+102396, 1.0, int_stack+101612, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+122696, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+311332,int_stack+321412,int_stack+83160, 1.0, int_stack+0, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3024, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|gf) ---*/
   d1hrr3_build_gf(Libderiv->CD,int_stack+88956,int_stack+311332,int_stack+308812, 1.0, int_stack+327208, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+383404, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (h0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+327208,int_stack+104503,int_stack+104188, 1.0, int_stack+223356, 0.0, zero_stack, 1.0, int_stack+237671, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+328153,int_stack+104944,int_stack+104503, 1.0, int_stack+223671, 0.0, zero_stack, 1.0, int_stack+238427, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+279328,int_stack+328153,int_stack+327208, 1.0, int_stack+329728, 0.0, zero_stack, 1.0, int_stack+367528, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+0,int_stack+105532,int_stack+104944, 1.0, int_stack+224112, 0.0, zero_stack, 1.0, int_stack+239456, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+83160,int_stack+0,int_stack+328153, 1.0, int_stack+330673, 0.0, zero_stack, 1.0, int_stack+368473, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|gf) ---*/
   d1hrr3_build_gf(Libderiv->CD,int_stack+327208,int_stack+83160,int_stack+279328, 1.0, int_stack+331996, 0.0, zero_stack, 1.0, int_stack+369796, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (i0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+279328,int_stack+107716,int_stack+106708, 1.0, int_stack+106288, 0.0, zero_stack, 1.0, int_stack+120092, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+0,int_stack+109088,int_stack+107716, 1.0, int_stack+107128, 0.0, zero_stack, 1.0, int_stack+121520, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+83160,int_stack+0,int_stack+279328, 1.0, int_stack+1764, 0.0, zero_stack, 1.0, int_stack+377608, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+330358,int_stack+109872,int_stack+109088, 1.0, int_stack+108304, 0.0, zero_stack, 1.0, int_stack+122696, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+308812,int_stack+330358,int_stack+0, 1.0, int_stack+339808, 0.0, zero_stack, 1.0, int_stack+3024, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|gf) ---*/
   d1hrr3_build_gf(Libderiv->CD,int_stack+330358,int_stack+308812,int_stack+83160, 1.0, int_stack+341572, 0.0, zero_stack, 1.0, int_stack+383404, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (h0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+83160,int_stack+111195,int_stack+110880, 1.0, int_stack+230356, 1.0, int_stack+237671, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+84105,int_stack+111636,int_stack+111195, 1.0, int_stack+230671, 1.0, int_stack+238427, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+279328,int_stack+84105,int_stack+83160, 1.0, int_stack+347368, 1.0, int_stack+367528, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+308812,int_stack+112224,int_stack+111636, 1.0, int_stack+231112, 1.0, int_stack+239456, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+321412,int_stack+308812,int_stack+84105, 1.0, int_stack+348313, 1.0, int_stack+368473, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|gf) ---*/
   d1hrr3_build_gf(Libderiv->CD,int_stack+308812,int_stack+321412,int_stack+279328, 1.0, int_stack+349636, 1.0, int_stack+369796, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (i0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+279328,int_stack+114408,int_stack+113400, 1.0, int_stack+112980, 1.0, int_stack+120092, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+321412,int_stack+115780,int_stack+114408, 1.0, int_stack+113820, 1.0, int_stack+121520, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+311962,int_stack+321412,int_stack+279328, 1.0, int_stack+357448, 1.0, int_stack+377608, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+314482,int_stack+116564,int_stack+115780, 1.0, int_stack+114996, 1.0, int_stack+122696, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+347368,int_stack+314482,int_stack+321412, 1.0, int_stack+358708, 1.0, int_stack+3024, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|gf) ---*/
   d1hrr3_build_gf(Libderiv->CD,int_stack+357448,int_stack+347368,int_stack+311962, 1.0, int_stack+365008, 1.0, int_stack+383404, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (h0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+365008,int_stack+117887,int_stack+117572, 2.0, int_stack+237671, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+365953,int_stack+118328,int_stack+117887, 2.0, int_stack+238427, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+279328,int_stack+365953,int_stack+365008, 2.0, int_stack+367528, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+311962,int_stack+118916,int_stack+118328, 2.0, int_stack+239456, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+321412,int_stack+311962,int_stack+365953, 2.0, int_stack+368473, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|gf) ---*/
   d1hrr3_build_gf(Libderiv->CD,int_stack+311962,int_stack+321412,int_stack+279328, 2.0, int_stack+369796, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (i0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+279328,int_stack+122108,int_stack+120512, 2.0, int_stack+120092, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+321412,int_stack+123480,int_stack+122108, 2.0, int_stack+121520, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+365008,int_stack+321412,int_stack+279328, 2.0, int_stack+377608, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+377608,int_stack+124264,int_stack+123480, 2.0, int_stack+122696, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+367528,int_stack+377608,int_stack+321412, 2.0, int_stack+3024, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|gf) ---*/
   d1hrr3_build_gf(Libderiv->CD,int_stack+347368,int_stack+367528,int_stack+365008, 2.0, int_stack+383404, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (h0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+383404,int_stack+125587,int_stack+125272, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+247492,21);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+384349,int_stack+126028,int_stack+125587, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+247807,21);
 /*--- compute (h0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+279328,int_stack+384349,int_stack+383404, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+385924,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+365008,int_stack+126616,int_stack+126028, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+248248,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+321412,int_stack+365008,int_stack+384349, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+386869,21);
 /*--- compute (h0|gf) ---*/
   d1hrr3_build_gf(Libderiv->CD,int_stack+365008,int_stack+321412,int_stack+279328, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+284368,21);
 /*--- compute (i0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+279328,int_stack+127792,int_stack+127372, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+151872,28);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+321412,int_stack+128380,int_stack+127792, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+152712,28);
 /*--- compute (i0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+383404,int_stack+321412,int_stack+279328, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+268492,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+368158,int_stack+129164,int_stack+128380, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+153888,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+339808,int_stack+368158,int_stack+321412, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+269752,28);
 /*--- compute (i0|gf) ---*/
   d1hrr3_build_gf(Libderiv->CD,int_stack+368158,int_stack+339808,int_stack+383404, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+276808,28);
 /*--- compute (h0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+383404,int_stack+130487,int_stack+130172, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+247492, 0.0, zero_stack,21);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+384349,int_stack+130928,int_stack+130487, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+247807, 0.0, zero_stack,21);
 /*--- compute (h0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+279328,int_stack+384349,int_stack+383404, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+385924, 0.0, zero_stack,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+339808,int_stack+131516,int_stack+130928, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+248248, 0.0, zero_stack,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+341572,int_stack+339808,int_stack+384349, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+386869, 0.0, zero_stack,21);
 /*--- compute (h0|gf) ---*/
   d1hrr3_build_gf(Libderiv->CD,int_stack+0,int_stack+341572,int_stack+279328, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+284368, 0.0, zero_stack,21);
 /*--- compute (i0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+279328,int_stack+132692,int_stack+132272, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+151872, 0.0, zero_stack,28);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+339808,int_stack+133280,int_stack+132692, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+152712, 0.0, zero_stack,28);
 /*--- compute (i0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+383404,int_stack+339808,int_stack+279328, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+268492, 0.0, zero_stack,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+341572,int_stack+134064,int_stack+133280, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+153888, 0.0, zero_stack,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+93156,int_stack+341572,int_stack+339808, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+269752, 0.0, zero_stack,28);
 /*--- compute (i0|gf) ---*/
   d1hrr3_build_gf(Libderiv->CD,int_stack+339808,int_stack+93156,int_stack+383404, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+276808, 0.0, zero_stack,28);
 /*--- compute (h0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+383404,int_stack+135387,int_stack+135072, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+247492, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+384349,int_stack+135828,int_stack+135387, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+247807, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+279328,int_stack+384349,int_stack+383404, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+385924, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+93156,int_stack+136416,int_stack+135828, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+248248, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+321412,int_stack+93156,int_stack+384349, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+386869, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|gf) ---*/
   d1hrr3_build_gf(Libderiv->CD,int_stack+93156,int_stack+321412,int_stack+279328, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+284368, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (i0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+279328,int_stack+137592,int_stack+137172, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+151872, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+321412,int_stack+138180,int_stack+137592, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+152712, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+383404,int_stack+321412,int_stack+279328, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+268492, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+96306,int_stack+138964,int_stack+138180, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+153888, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+98658,int_stack+96306,int_stack+321412, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+269752, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|gf) ---*/
   d1hrr3_build_gf(Libderiv->CD,int_stack+102186,int_stack+98658,int_stack+383404, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+276808, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (h0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+383404,int_stack+140287,int_stack+139972, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+247492, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+384349,int_stack+140728,int_stack+140287, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+247807, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+279328,int_stack+384349,int_stack+383404, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+385924, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+321412,int_stack+141316,int_stack+140728, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+248248, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+377608,int_stack+321412,int_stack+384349, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+386869, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|gf) ---*/
   d1hrr3_build_gf(Libderiv->CD,int_stack+96306,int_stack+377608,int_stack+279328, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+284368, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (i0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+279328,int_stack+142492,int_stack+142072, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+151872, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+377608,int_stack+143080,int_stack+142492, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+152712, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+383404,int_stack+377608,int_stack+279328, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+268492, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+321412,int_stack+143864,int_stack+143080, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+153888, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+106386,int_stack+321412,int_stack+377608, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+269752, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|gf) ---*/
   d1hrr3_build_gf(Libderiv->CD,int_stack+109914,int_stack+106386,int_stack+383404, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+276808, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (h0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+383404,int_stack+145187,int_stack+144872, 0.0, zero_stack, 1.0, int_stack+247492, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+384349,int_stack+145628,int_stack+145187, 0.0, zero_stack, 1.0, int_stack+247807, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+279328,int_stack+384349,int_stack+383404, 0.0, zero_stack, 1.0, int_stack+385924, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+106386,int_stack+146216,int_stack+145628, 0.0, zero_stack, 1.0, int_stack+248248, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+377608,int_stack+106386,int_stack+384349, 0.0, zero_stack, 1.0, int_stack+386869, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|gf) ---*/
   d1hrr3_build_gf(Libderiv->CD,int_stack+106386,int_stack+377608,int_stack+279328, 0.0, zero_stack, 1.0, int_stack+284368, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (i0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+279328,int_stack+147392,int_stack+146972, 0.0, zero_stack, 1.0, int_stack+151872, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+377608,int_stack+147980,int_stack+147392, 0.0, zero_stack, 1.0, int_stack+152712, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+383404,int_stack+377608,int_stack+279328, 0.0, zero_stack, 1.0, int_stack+268492, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+321412,int_stack+148764,int_stack+147980, 0.0, zero_stack, 1.0, int_stack+153888, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+114114,int_stack+321412,int_stack+377608, 0.0, zero_stack, 1.0, int_stack+269752, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|gf) ---*/
   d1hrr3_build_gf(Libderiv->CD,int_stack+117642,int_stack+114114,int_stack+383404, 0.0, zero_stack, 1.0, int_stack+276808, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (h0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+383404,int_stack+150087,int_stack+149772, 1.0, int_stack+247492, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+384349,int_stack+150528,int_stack+150087, 1.0, int_stack+247807, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+279328,int_stack+384349,int_stack+383404, 1.0, int_stack+385924, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+114114,int_stack+151116,int_stack+150528, 1.0, int_stack+248248, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+377608,int_stack+114114,int_stack+384349, 1.0, int_stack+386869, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|gf) ---*/
   d1hrr3_build_gf(Libderiv->CD,int_stack+114114,int_stack+377608,int_stack+279328, 1.0, int_stack+284368, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (i0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+284368,int_stack+153300,int_stack+152292, 1.0, int_stack+151872, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+285628,int_stack+154672,int_stack+153300, 1.0, int_stack+152712, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+287392,int_stack+285628,int_stack+284368, 1.0, int_stack+268492, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+289912,int_stack+155456,int_stack+154672, 1.0, int_stack+153888, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+292264,int_stack+289912,int_stack+285628, 1.0, int_stack+269752, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|gf) ---*/
   d1hrr3_build_gf(Libderiv->CD,int_stack+383404,int_stack+292264,int_stack+287392, 1.0, int_stack+276808, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (h0|gp) ---*/
   hrr3_build_gp(Libderiv->CD,int_stack+268492,int_stack+156779,int_stack+156464,21);
 /*--- compute (h0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+269437,int_stack+157220,int_stack+156779,21);
 /*--- compute (h0|gd) ---*/
   hrr3_build_gd(Libderiv->CD,int_stack+284368,int_stack+269437,int_stack+268492,21);
 /*--- compute (h0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+286258,int_stack+157808,int_stack+157220,21);
 /*--- compute (h0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+377608,int_stack+286258,int_stack+269437,21);
 /*--- compute (h0|gf) ---*/
   hrr3_build_gf(Libderiv->CD,int_stack+286258,int_stack+377608,int_stack+284368,21);
 /*--- compute (i0|gp) ---*/
   hrr3_build_gp(Libderiv->CD,int_stack+284368,int_stack+158984,int_stack+158564,28);
 /*--- compute (i0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+377608,int_stack+159572,int_stack+158984,28);
 /*--- compute (i0|gd) ---*/
   hrr3_build_gd(Libderiv->CD,int_stack+289408,int_stack+377608,int_stack+284368,28);
 /*--- compute (i0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+291928,int_stack+160356,int_stack+159572,28);
 /*--- compute (i0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+121842,int_stack+291928,int_stack+377608,28);
 /*--- compute (i0|gf) ---*/
   hrr3_build_gf(Libderiv->CD,int_stack+291928,int_stack+121842,int_stack+289408,28);
 /*--- compute (h0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+289408,int_stack+161679,int_stack+161364, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+254492,21);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+290353,int_stack+162120,int_stack+161679, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+254807,21);
 /*--- compute (h0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+284368,int_stack+290353,int_stack+289408, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+399154,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+121842,int_stack+162708,int_stack+162120, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+255248,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+377608,int_stack+121842,int_stack+290353, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+400099,21);
 /*--- compute (h0|gf) ---*/
   d1hrr3_build_gf(Libderiv->CD,int_stack+121842,int_stack+377608,int_stack+284368, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+401422,21);
 /*--- compute (i0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+284368,int_stack+163884,int_stack+163464, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+187964,28);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+377608,int_stack+164472,int_stack+163884, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+188804,28);
 /*--- compute (i0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+289408,int_stack+377608,int_stack+284368, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+409234,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+124992,int_stack+165256,int_stack+164472, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+189980,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+127344,int_stack+124992,int_stack+377608, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+4788,28);
 /*--- compute (i0|gf) ---*/
   d1hrr3_build_gf(Libderiv->CD,int_stack+130872,int_stack+127344,int_stack+289408, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+415030,28);
 /*--- compute (h0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+289408,int_stack+166579,int_stack+166264, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+254492, 0.0, zero_stack,21);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+290353,int_stack+167020,int_stack+166579, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+254807, 0.0, zero_stack,21);
 /*--- compute (h0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+284368,int_stack+290353,int_stack+289408, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+399154, 0.0, zero_stack,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+377608,int_stack+167608,int_stack+167020, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+255248, 0.0, zero_stack,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+321412,int_stack+377608,int_stack+290353, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+400099, 0.0, zero_stack,21);
 /*--- compute (h0|gf) ---*/
   d1hrr3_build_gf(Libderiv->CD,int_stack+124992,int_stack+321412,int_stack+284368, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+401422, 0.0, zero_stack,21);
 /*--- compute (i0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+284368,int_stack+168784,int_stack+168364, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+187964, 0.0, zero_stack,28);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+321412,int_stack+169372,int_stack+168784, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+188804, 0.0, zero_stack,28);
 /*--- compute (i0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+289408,int_stack+321412,int_stack+284368, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+409234, 0.0, zero_stack,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+377608,int_stack+170156,int_stack+169372, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+189980, 0.0, zero_stack,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+135072,int_stack+377608,int_stack+321412, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+4788, 0.0, zero_stack,28);
 /*--- compute (i0|gf) ---*/
   d1hrr3_build_gf(Libderiv->CD,int_stack+138600,int_stack+135072,int_stack+289408, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+415030, 0.0, zero_stack,28);
 /*--- compute (h0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+289408,int_stack+171479,int_stack+171164, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+254492, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+290353,int_stack+171920,int_stack+171479, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+254807, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+284368,int_stack+290353,int_stack+289408, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+399154, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+135072,int_stack+172508,int_stack+171920, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+255248, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+321412,int_stack+135072,int_stack+290353, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+400099, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|gf) ---*/
   d1hrr3_build_gf(Libderiv->CD,int_stack+135072,int_stack+321412,int_stack+284368, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+401422, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (i0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+284368,int_stack+173684,int_stack+173264, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+187964, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+321412,int_stack+174272,int_stack+173684, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+188804, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+289408,int_stack+321412,int_stack+284368, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+409234, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+377608,int_stack+175056,int_stack+174272, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+189980, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+142800,int_stack+377608,int_stack+321412, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+4788, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|gf) ---*/
   d1hrr3_build_gf(Libderiv->CD,int_stack+146328,int_stack+142800,int_stack+289408, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+415030, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (h0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+289408,int_stack+176379,int_stack+176064, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+254492, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+290353,int_stack+176820,int_stack+176379, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+254807, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+284368,int_stack+290353,int_stack+289408, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+399154, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+142800,int_stack+177408,int_stack+176820, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+255248, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+321412,int_stack+142800,int_stack+290353, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+400099, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|gf) ---*/
   d1hrr3_build_gf(Libderiv->CD,int_stack+142800,int_stack+321412,int_stack+284368, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+401422, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (i0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+284368,int_stack+178584,int_stack+178164, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+187964, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+321412,int_stack+179172,int_stack+178584, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+188804, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+289408,int_stack+321412,int_stack+284368, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+409234, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+377608,int_stack+179956,int_stack+179172, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+189980, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+150528,int_stack+377608,int_stack+321412, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+4788, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|gf) ---*/
   d1hrr3_build_gf(Libderiv->CD,int_stack+154056,int_stack+150528,int_stack+289408, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+415030, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (h0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+289408,int_stack+181279,int_stack+180964, 0.0, zero_stack, 1.0, int_stack+254492, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+290353,int_stack+181720,int_stack+181279, 0.0, zero_stack, 1.0, int_stack+254807, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+284368,int_stack+290353,int_stack+289408, 0.0, zero_stack, 1.0, int_stack+399154, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+150528,int_stack+182308,int_stack+181720, 0.0, zero_stack, 1.0, int_stack+255248, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+321412,int_stack+150528,int_stack+290353, 0.0, zero_stack, 1.0, int_stack+400099, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|gf) ---*/
   d1hrr3_build_gf(Libderiv->CD,int_stack+150528,int_stack+321412,int_stack+284368, 0.0, zero_stack, 1.0, int_stack+401422, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (i0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+284368,int_stack+183484,int_stack+183064, 0.0, zero_stack, 1.0, int_stack+187964, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+321412,int_stack+184072,int_stack+183484, 0.0, zero_stack, 1.0, int_stack+188804, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+289408,int_stack+321412,int_stack+284368, 0.0, zero_stack, 1.0, int_stack+409234, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+377608,int_stack+184856,int_stack+184072, 0.0, zero_stack, 1.0, int_stack+189980, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+158256,int_stack+377608,int_stack+321412, 0.0, zero_stack, 1.0, int_stack+4788, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|gf) ---*/
   d1hrr3_build_gf(Libderiv->CD,int_stack+161784,int_stack+158256,int_stack+289408, 0.0, zero_stack, 1.0, int_stack+415030, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (h0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+289408,int_stack+186179,int_stack+185864, 1.0, int_stack+254492, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+290353,int_stack+186620,int_stack+186179, 1.0, int_stack+254807, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+284368,int_stack+290353,int_stack+289408, 1.0, int_stack+399154, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+158256,int_stack+187208,int_stack+186620, 1.0, int_stack+255248, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+321412,int_stack+158256,int_stack+290353, 1.0, int_stack+400099, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|gf) ---*/
   d1hrr3_build_gf(Libderiv->CD,int_stack+158256,int_stack+321412,int_stack+284368, 1.0, int_stack+401422, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (i0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+284368,int_stack+189392,int_stack+188384, 1.0, int_stack+187964, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+321412,int_stack+190764,int_stack+189392, 1.0, int_stack+188804, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+289408,int_stack+321412,int_stack+284368, 1.0, int_stack+409234, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+409234,int_stack+191548,int_stack+190764, 1.0, int_stack+189980, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+399154,int_stack+409234,int_stack+321412, 1.0, int_stack+4788, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|gf) ---*/
   d1hrr3_build_gf(Libderiv->CD,int_stack+165984,int_stack+399154,int_stack+289408, 1.0, int_stack+415030, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (h0|gp) ---*/
   hrr3_build_gp(Libderiv->CD,int_stack+415030,int_stack+192871,int_stack+192556,21);
 /*--- compute (h0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+415975,int_stack+193312,int_stack+192871,21);
 /*--- compute (h0|gd) ---*/
   hrr3_build_gd(Libderiv->CD,int_stack+284368,int_stack+415975,int_stack+415030,21);
 /*--- compute (h0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+289408,int_stack+193900,int_stack+193312,21);
 /*--- compute (h0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+321412,int_stack+289408,int_stack+415975,21);
 /*--- compute (h0|gf) ---*/
   hrr3_build_gf(Libderiv->CD,int_stack+399154,int_stack+321412,int_stack+284368,21);
 /*--- compute (i0|gp) ---*/
   hrr3_build_gp(Libderiv->CD,int_stack+284368,int_stack+195076,int_stack+194656,28);
 /*--- compute (i0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+321412,int_stack+195664,int_stack+195076,28);
 /*--- compute (i0|gd) ---*/
   hrr3_build_gd(Libderiv->CD,int_stack+289408,int_stack+321412,int_stack+284368,28);
 /*--- compute (i0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+415030,int_stack+196448,int_stack+195664,28);
 /*--- compute (i0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+170184,int_stack+415030,int_stack+321412,28);
 /*--- compute (i0|gf) ---*/
   hrr3_build_gf(Libderiv->CD,int_stack+173712,int_stack+170184,int_stack+289408,28);
 /*--- compute (h0|gp) ---*/
   hrr3_build_gp(Libderiv->CD,int_stack+289408,int_stack+197771,int_stack+197456,21);
 /*--- compute (h0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+290353,int_stack+198212,int_stack+197771,21);
 /*--- compute (h0|gd) ---*/
   hrr3_build_gd(Libderiv->CD,int_stack+284368,int_stack+290353,int_stack+289408,21);
 /*--- compute (h0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+170184,int_stack+198800,int_stack+198212,21);
 /*--- compute (h0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+321412,int_stack+170184,int_stack+290353,21);
 /*--- compute (h0|gf) ---*/
   hrr3_build_gf(Libderiv->CD,int_stack+170184,int_stack+321412,int_stack+284368,21);
 /*--- compute (i0|gp) ---*/
   hrr3_build_gp(Libderiv->CD,int_stack+284368,int_stack+199976,int_stack+199556,28);
 /*--- compute (i0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+321412,int_stack+200564,int_stack+199976,28);
 /*--- compute (i0|gd) ---*/
   hrr3_build_gd(Libderiv->CD,int_stack+289408,int_stack+321412,int_stack+284368,28);
 /*--- compute (i0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+415030,int_stack+201348,int_stack+200564,28);
 /*--- compute (i0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+177912,int_stack+415030,int_stack+321412,28);
 /*--- compute (i0|gf) ---*/
   hrr3_build_gf(Libderiv->CD,int_stack+181440,int_stack+177912,int_stack+289408,28);
 /*--- compute (h0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+289408,int_stack+204771,int_stack+204456, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+261492,21);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+290353,int_stack+205212,int_stack+204771, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+261807,21);
 /*--- compute (h0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+284368,int_stack+290353,int_stack+289408, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+417550,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+177912,int_stack+205800,int_stack+205212, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+262248,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+321412,int_stack+177912,int_stack+290353, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+418495,21);
 /*--- compute (h0|gf) ---*/
   d1hrr3_build_gf(Libderiv->CD,int_stack+177912,int_stack+321412,int_stack+284368, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+419818,21);
 /*--- compute (i0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+284368,int_stack+206976,int_stack+206556, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+242900,28);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+321412,int_stack+207564,int_stack+206976, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+243740,28);
 /*--- compute (i0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+289408,int_stack+321412,int_stack+284368, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+427630,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+415030,int_stack+208348,int_stack+207564, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+244916,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+185640,int_stack+415030,int_stack+321412, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+6552,28);
 /*--- compute (i0|gf) ---*/
   d1hrr3_build_gf(Libderiv->CD,int_stack+189168,int_stack+185640,int_stack+289408, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+433426,28);
 /*--- compute (h0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+289408,int_stack+211771,int_stack+211456, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+261492, 0.0, zero_stack,21);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+290353,int_stack+212212,int_stack+211771, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+261807, 0.0, zero_stack,21);
 /*--- compute (h0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+284368,int_stack+290353,int_stack+289408, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+417550, 0.0, zero_stack,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+185640,int_stack+212800,int_stack+212212, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+262248, 0.0, zero_stack,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+321412,int_stack+185640,int_stack+290353, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+418495, 0.0, zero_stack,21);
 /*--- compute (h0|gf) ---*/
   d1hrr3_build_gf(Libderiv->CD,int_stack+185640,int_stack+321412,int_stack+284368, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+419818, 0.0, zero_stack,21);
 /*--- compute (i0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+284368,int_stack+213976,int_stack+213556, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+242900, 0.0, zero_stack,28);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+321412,int_stack+214564,int_stack+213976, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+243740, 0.0, zero_stack,28);
 /*--- compute (i0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+289408,int_stack+321412,int_stack+284368, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+427630, 0.0, zero_stack,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+415030,int_stack+215348,int_stack+214564, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+244916, 0.0, zero_stack,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+193368,int_stack+415030,int_stack+321412, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+6552, 0.0, zero_stack,28);
 /*--- compute (i0|gf) ---*/
   d1hrr3_build_gf(Libderiv->CD,int_stack+196896,int_stack+193368,int_stack+289408, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+433426, 0.0, zero_stack,28);
 /*--- compute (h0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+289408,int_stack+218771,int_stack+218456, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+261492, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+290353,int_stack+219212,int_stack+218771, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+261807, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+284368,int_stack+290353,int_stack+289408, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+417550, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+193368,int_stack+219800,int_stack+219212, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+262248, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+321412,int_stack+193368,int_stack+290353, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+418495, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|gf) ---*/
   d1hrr3_build_gf(Libderiv->CD,int_stack+193368,int_stack+321412,int_stack+284368, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+419818, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (i0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+284368,int_stack+220976,int_stack+220556, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+242900, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+321412,int_stack+221564,int_stack+220976, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+243740, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+289408,int_stack+321412,int_stack+284368, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+427630, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+415030,int_stack+222348,int_stack+221564, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+244916, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+201096,int_stack+415030,int_stack+321412, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+6552, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|gf) ---*/
   d1hrr3_build_gf(Libderiv->CD,int_stack+204624,int_stack+201096,int_stack+289408, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+433426, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (h0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+289408,int_stack+225771,int_stack+225456, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+261492, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+290353,int_stack+226212,int_stack+225771, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+261807, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+284368,int_stack+290353,int_stack+289408, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+417550, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+201096,int_stack+226800,int_stack+226212, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+262248, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+321412,int_stack+201096,int_stack+290353, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+418495, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|gf) ---*/
   d1hrr3_build_gf(Libderiv->CD,int_stack+201096,int_stack+321412,int_stack+284368, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+419818, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (i0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+284368,int_stack+227976,int_stack+227556, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+242900, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+321412,int_stack+228564,int_stack+227976, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+243740, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+289408,int_stack+321412,int_stack+284368, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+427630, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+415030,int_stack+229348,int_stack+228564, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+244916, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+208824,int_stack+415030,int_stack+321412, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+6552, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|gf) ---*/
   d1hrr3_build_gf(Libderiv->CD,int_stack+212352,int_stack+208824,int_stack+289408, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+433426, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (h0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+289408,int_stack+232771,int_stack+232456, 0.0, zero_stack, 1.0, int_stack+261492, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+290353,int_stack+233212,int_stack+232771, 0.0, zero_stack, 1.0, int_stack+261807, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+284368,int_stack+290353,int_stack+289408, 0.0, zero_stack, 1.0, int_stack+417550, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+208824,int_stack+233800,int_stack+233212, 0.0, zero_stack, 1.0, int_stack+262248, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+321412,int_stack+208824,int_stack+290353, 0.0, zero_stack, 1.0, int_stack+418495, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|gf) ---*/
   d1hrr3_build_gf(Libderiv->CD,int_stack+208824,int_stack+321412,int_stack+284368, 0.0, zero_stack, 1.0, int_stack+419818, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (i0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+284368,int_stack+234976,int_stack+234556, 0.0, zero_stack, 1.0, int_stack+242900, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+321412,int_stack+235564,int_stack+234976, 0.0, zero_stack, 1.0, int_stack+243740, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+289408,int_stack+321412,int_stack+284368, 0.0, zero_stack, 1.0, int_stack+427630, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+415030,int_stack+236348,int_stack+235564, 0.0, zero_stack, 1.0, int_stack+244916, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+216552,int_stack+415030,int_stack+321412, 0.0, zero_stack, 1.0, int_stack+6552, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|gf) ---*/
   d1hrr3_build_gf(Libderiv->CD,int_stack+220080,int_stack+216552,int_stack+289408, 0.0, zero_stack, 1.0, int_stack+433426, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (h0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+289408,int_stack+241115,int_stack+240800, 1.0, int_stack+261492, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+290353,int_stack+241556,int_stack+241115, 1.0, int_stack+261807, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+284368,int_stack+290353,int_stack+289408, 1.0, int_stack+417550, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+216552,int_stack+242144,int_stack+241556, 1.0, int_stack+262248, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+321412,int_stack+216552,int_stack+290353, 1.0, int_stack+418495, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|gf) ---*/
   d1hrr3_build_gf(Libderiv->CD,int_stack+216552,int_stack+321412,int_stack+284368, 1.0, int_stack+419818, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (i0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+284368,int_stack+244328,int_stack+243320, 1.0, int_stack+242900, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+321412,int_stack+245700,int_stack+244328, 1.0, int_stack+243740, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+289408,int_stack+321412,int_stack+284368, 1.0, int_stack+427630, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+427630,int_stack+246484,int_stack+245700, 1.0, int_stack+244916, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+415030,int_stack+427630,int_stack+321412, 1.0, int_stack+6552, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|gf) ---*/
   d1hrr3_build_gf(Libderiv->CD,int_stack+418558,int_stack+415030,int_stack+289408, 1.0, int_stack+433426, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (h0|gp) ---*/
   hrr3_build_gp(Libderiv->CD,int_stack+433426,int_stack+249907,int_stack+249592,21);
 /*--- compute (h0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+434371,int_stack+250348,int_stack+249907,21);
 /*--- compute (h0|gd) ---*/
   hrr3_build_gd(Libderiv->CD,int_stack+284368,int_stack+434371,int_stack+433426,21);
 /*--- compute (h0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+289408,int_stack+250936,int_stack+250348,21);
 /*--- compute (h0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+321412,int_stack+289408,int_stack+434371,21);
 /*--- compute (h0|gf) ---*/
   hrr3_build_gf(Libderiv->CD,int_stack+415030,int_stack+321412,int_stack+284368,21);
 /*--- compute (i0|gp) ---*/
   hrr3_build_gp(Libderiv->CD,int_stack+284368,int_stack+252112,int_stack+251692,28);
 /*--- compute (i0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+321412,int_stack+252700,int_stack+252112,28);
 /*--- compute (i0|gd) ---*/
   hrr3_build_gd(Libderiv->CD,int_stack+289408,int_stack+321412,int_stack+284368,28);
 /*--- compute (i0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+433426,int_stack+253484,int_stack+252700,28);
 /*--- compute (i0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+224280,int_stack+433426,int_stack+321412,28);
 /*--- compute (i0|gf) ---*/
   hrr3_build_gf(Libderiv->CD,int_stack+227808,int_stack+224280,int_stack+289408,28);
 /*--- compute (h0|gp) ---*/
   hrr3_build_gp(Libderiv->CD,int_stack+289408,int_stack+256907,int_stack+256592,21);
 /*--- compute (h0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+290353,int_stack+257348,int_stack+256907,21);
 /*--- compute (h0|gd) ---*/
   hrr3_build_gd(Libderiv->CD,int_stack+284368,int_stack+290353,int_stack+289408,21);
 /*--- compute (h0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+224280,int_stack+257936,int_stack+257348,21);
 /*--- compute (h0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+321412,int_stack+224280,int_stack+290353,21);
 /*--- compute (h0|gf) ---*/
   hrr3_build_gf(Libderiv->CD,int_stack+224280,int_stack+321412,int_stack+284368,21);
 /*--- compute (i0|gp) ---*/
   hrr3_build_gp(Libderiv->CD,int_stack+284368,int_stack+259112,int_stack+258692,28);
 /*--- compute (i0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+321412,int_stack+259700,int_stack+259112,28);
 /*--- compute (i0|gd) ---*/
   hrr3_build_gd(Libderiv->CD,int_stack+289408,int_stack+321412,int_stack+284368,28);
 /*--- compute (i0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+433426,int_stack+260484,int_stack+259700,28);
 /*--- compute (i0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+232008,int_stack+433426,int_stack+321412,28);
 /*--- compute (i0|gf) ---*/
   hrr3_build_gf(Libderiv->CD,int_stack+235536,int_stack+232008,int_stack+289408,28);
 /*--- compute (h0|gp) ---*/
   hrr3_build_gp(Libderiv->CD,int_stack+289408,int_stack+263907,int_stack+263592,21);
 /*--- compute (h0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+290353,int_stack+264348,int_stack+263907,21);
 /*--- compute (h0|gd) ---*/
   hrr3_build_gd(Libderiv->CD,int_stack+284368,int_stack+290353,int_stack+289408,21);
 /*--- compute (h0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+232008,int_stack+264936,int_stack+264348,21);
 /*--- compute (h0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+321412,int_stack+232008,int_stack+290353,21);
 /*--- compute (h0|gf) ---*/
   hrr3_build_gf(Libderiv->CD,int_stack+232008,int_stack+321412,int_stack+284368,21);
 /*--- compute (i0|gp) ---*/
   hrr3_build_gp(Libderiv->CD,int_stack+284368,int_stack+266112,int_stack+265692,28);
 /*--- compute (i0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+321412,int_stack+266700,int_stack+266112,28);
 /*--- compute (i0|gd) ---*/
   hrr3_build_gd(Libderiv->CD,int_stack+289408,int_stack+321412,int_stack+284368,28);
 /*--- compute (i0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+433426,int_stack+267484,int_stack+266700,28);
 /*--- compute (i0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+239736,int_stack+433426,int_stack+321412,28);
 /*--- compute (i0|gf) ---*/
   hrr3_build_gf(Libderiv->CD,int_stack+243264,int_stack+239736,int_stack+289408,28);
 /*--- compute (hp|gf) ---*/
   hrr1_build_hp(Libderiv->AB,int_stack+247464,int_stack+297052,int_stack+281218,150);
     Libderiv->ABCD[11] = int_stack + 247464;
 /*--- compute (hp|gf) ---*/
   hrr1_build_hp(Libderiv->AB,int_stack+256914,int_stack+317212,int_stack+305662,150);
     Libderiv->ABCD[10] = int_stack + 256914;
 /*--- compute (hp|gf) ---*/
   hrr1_build_hp(Libderiv->AB,int_stack+492604,int_stack+335608,int_stack+324058,150);
     Libderiv->ABCD[9] = int_stack + 492604;
 /*--- compute (hp|gf) ---*/
   hrr1_build_hp(Libderiv->AB,int_stack+502054,int_stack+353248,int_stack+344218,150);
     Libderiv->ABCD[8] = int_stack + 502054;
 /*--- compute (hp|gf) ---*/
   hrr1_build_hp(Libderiv->AB,int_stack+511504,int_stack+373408,int_stack+361858,150);
     Libderiv->ABCD[7] = int_stack + 511504;
 /*--- compute (hp|gf) ---*/
   hrr1_build_hp(Libderiv->AB,int_stack+520954,int_stack+391804,int_stack+380254,150);
     Libderiv->ABCD[6] = int_stack + 520954;
 /*--- compute (hp|gf) ---*/
   d1hrr1_build_hp(Libderiv->AB,int_stack+530404,int_stack+405034,int_stack+396004, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+388570, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,150);
     Libderiv->ABCD[2] = int_stack + 530404;
 /*--- compute (hp|gf) ---*/
   d1hrr1_build_hp(Libderiv->AB,int_stack+402304,int_stack+423430,int_stack+411880, 0.0, zero_stack, 1.0, int_stack+388570, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,150);
     Libderiv->ABCD[1] = int_stack + 402304;
 /*--- compute (hp|gf) ---*/
   d1hrr1_build_hp(Libderiv->AB,int_stack+539854,int_stack+441826,int_stack+430276, 1.0, int_stack+388570, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,150);
     Libderiv->ABCD[0] = int_stack + 539854;
 /*--- compute (hp|gf) ---*/
   hrr1_build_hp(Libderiv->AB,int_stack+549304,int_stack+446026,int_stack+8316,150);
     Libderiv->ABCD[155] = int_stack + 549304;
 /*--- compute (hp|gf) ---*/
   hrr1_build_hp(Libderiv->AB,int_stack+439096,int_stack+453376,int_stack+450226,150);
     Libderiv->ABCD[143] = int_stack + 439096;
 /*--- compute (hp|gf) ---*/
   hrr1_build_hp(Libderiv->AB,int_stack+558754,int_stack+457576,int_stack+435946,150);
     Libderiv->ABCD[142] = int_stack + 558754;
 /*--- compute (hp|gf) ---*/
   hrr1_build_hp(Libderiv->AB,int_stack+448546,int_stack+461776,int_stack+20034,150);
     Libderiv->ABCD[131] = int_stack + 448546;
 /*--- compute (hp|gf) ---*/
   hrr1_build_hp(Libderiv->AB,int_stack+568204,int_stack+14616,int_stack+11466,150);
     Libderiv->ABCD[130] = int_stack + 568204;
 /*--- compute (hp|gf) ---*/
   hrr1_build_hp(Libderiv->AB,int_stack+3150,int_stack+465976,int_stack+31752,150);
     Libderiv->ABCD[129] = int_stack + 3150;
 /*--- compute (hp|gf) ---*/
   hrr1_build_hp(Libderiv->AB,int_stack+12600,int_stack+26334,int_stack+23184,150);
     Libderiv->ABCD[119] = int_stack + 12600;
 /*--- compute (hp|gf) ---*/
   hrr1_build_hp(Libderiv->AB,int_stack+22050,int_stack+473704,int_stack+43470,150);
     Libderiv->ABCD[118] = int_stack + 22050;
 /*--- compute (hp|gf) ---*/
   hrr1_build_hp(Libderiv->AB,int_stack+457996,int_stack+50148,int_stack+470176,150);
     Libderiv->ABCD[117] = int_stack + 457996;
 /*--- compute (hp|gf) ---*/
   hrr1_build_hp(Libderiv->AB,int_stack+467446,int_stack+477904,int_stack+46620,150);
     Libderiv->ABCD[116] = int_stack + 467446;
 /*--- compute (hp|gf) ---*/
   hrr1_build_hp(Libderiv->AB,int_stack+42462,int_stack+482104,int_stack+58506,150);
     Libderiv->ABCD[107] = int_stack + 42462;
 /*--- compute (hp|gf) ---*/
   hrr1_build_hp(Libderiv->AB,int_stack+577654,int_stack+34902,int_stack+39312,150);
     Libderiv->ABCD[106] = int_stack + 577654;
 /*--- compute (hp|gf) ---*/
   hrr1_build_hp(Libderiv->AB,int_stack+31500,int_stack+69216,int_stack+66066,150);
     Libderiv->ABCD[105] = int_stack + 31500;
 /*--- compute (hp|gf) ---*/
   hrr1_build_hp(Libderiv->AB,int_stack+587104,int_stack+61656,int_stack+486304,150);
     Libderiv->ABCD[104] = int_stack + 587104;
 /*--- compute (hp|gf) ---*/
   hrr1_build_hp(Libderiv->AB,int_stack+57498,int_stack+78960,int_stack+489454,150);
     Libderiv->ABCD[103] = int_stack + 57498;
 /*--- compute (hp|gf) ---*/
   hrr1_build_hp(Libderiv->AB,int_stack+476896,int_stack+271516,int_stack+73416,150);
     Libderiv->ABCD[95] = int_stack + 476896;
 /*--- compute (hp|gf) ---*/
   hrr1_build_hp(Libderiv->AB,int_stack+266364,int_stack+301252,int_stack+85806,150);
     Libderiv->ABCD[94] = int_stack + 266364;
 /*--- compute (hp|gf) ---*/
   hrr1_build_hp(Libderiv->AB,int_stack+296128,int_stack+88956,int_stack+54348,150);
     Libderiv->ABCD[93] = int_stack + 296128;
 /*--- compute (hp|gf) ---*/
   hrr1_build_hp(Libderiv->AB,int_stack+66948,int_stack+330358,int_stack+327208,150);
     Libderiv->ABCD[92] = int_stack + 66948;
 /*--- compute (hp|gf) ---*/
   hrr1_build_hp(Libderiv->AB,int_stack+327208,int_stack+357448,int_stack+308812,150);
     Libderiv->ABCD[91] = int_stack + 327208;
 /*--- compute (hp|gf) ---*/
   hrr1_build_hp(Libderiv->AB,int_stack+351568,int_stack+347368,int_stack+311962,150);
     Libderiv->ABCD[90] = int_stack + 351568;
 /*--- compute (hp|gf) ---*/
   d1hrr1_build_hp(Libderiv->AB,int_stack+308812,int_stack+368158,int_stack+365008, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+281218, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,150);
     Libderiv->ABCD[47] = int_stack + 308812;
 /*--- compute (hp|gf) ---*/
   d1hrr1_build_hp(Libderiv->AB,int_stack+365008,int_stack+339808,int_stack+0, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+305662, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,150);
     Libderiv->ABCD[46] = int_stack + 365008;
 /*--- compute (hp|gf) ---*/
   d1hrr1_build_hp(Libderiv->AB,int_stack+76398,int_stack+102186,int_stack+93156, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+324058, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,150);
     Libderiv->ABCD[45] = int_stack + 76398;
 /*--- compute (hp|gf) ---*/
   d1hrr1_build_hp(Libderiv->AB,int_stack+85848,int_stack+109914,int_stack+96306, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+344218, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,150);
     Libderiv->ABCD[44] = int_stack + 85848;
 /*--- compute (hp|gf) ---*/
   d1hrr1_build_hp(Libderiv->AB,int_stack+95298,int_stack+117642,int_stack+106386, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+361858, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,150);
     Libderiv->ABCD[43] = int_stack + 95298;
 /*--- compute (hp|gf) ---*/
   d1hrr1_build_hp(Libderiv->AB,int_stack+596554,int_stack+383404,int_stack+114114, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+380254, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,150);
     Libderiv->ABCD[42] = int_stack + 596554;
 /*--- compute (hp|gf) ---*/
   d1hrr1_build_hp(Libderiv->AB,int_stack+383404,int_stack+291928,int_stack+286258, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+396004, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,150);
     Libderiv->ABCD[38] = int_stack + 383404;
 /*--- compute (hp|gf) ---*/
   d1hrr1_build_hp(Libderiv->AB,int_stack+284368,int_stack+130872,int_stack+121842, 0.0, zero_stack, 1.0, int_stack+281218, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,150);
     Libderiv->ABCD[35] = int_stack + 284368;
 /*--- compute (hp|gf) ---*/
   d1hrr1_build_hp(Libderiv->AB,int_stack+104748,int_stack+138600,int_stack+124992, 0.0, zero_stack, 1.0, int_stack+305662, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,150);
     Libderiv->ABCD[34] = int_stack + 104748;
 /*--- compute (hp|gf) ---*/
   d1hrr1_build_hp(Libderiv->AB,int_stack+114198,int_stack+146328,int_stack+135072, 0.0, zero_stack, 1.0, int_stack+324058, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,150);
     Libderiv->ABCD[33] = int_stack + 114198;
 /*--- compute (hp|gf) ---*/
   d1hrr1_build_hp(Libderiv->AB,int_stack+123648,int_stack+154056,int_stack+142800, 0.0, zero_stack, 1.0, int_stack+344218, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,150);
     Libderiv->ABCD[32] = int_stack + 123648;
 /*--- compute (hp|gf) ---*/
   d1hrr1_build_hp(Libderiv->AB,int_stack+133098,int_stack+161784,int_stack+150528, 0.0, zero_stack, 1.0, int_stack+361858, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,150);
     Libderiv->ABCD[31] = int_stack + 133098;
 /*--- compute (hp|gf) ---*/
   d1hrr1_build_hp(Libderiv->AB,int_stack+142548,int_stack+165984,int_stack+158256, 0.0, zero_stack, 1.0, int_stack+380254, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,150);
     Libderiv->ABCD[30] = int_stack + 142548;
 /*--- compute (hp|gf) ---*/
   d1hrr1_build_hp(Libderiv->AB,int_stack+151998,int_stack+173712,int_stack+399154, 0.0, zero_stack, 1.0, int_stack+396004, 1.0, int_stack+411880, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,150);
     Libderiv->ABCD[26] = int_stack + 151998;
 /*--- compute (hp|gf) ---*/
   d1hrr1_build_hp(Libderiv->AB,int_stack+606004,int_stack+181440,int_stack+170184, 0.0, zero_stack, 2.0, int_stack+411880, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,150);
     Libderiv->ABCD[25] = int_stack + 606004;
 /*--- compute (hp|gf) ---*/
   d1hrr1_build_hp(Libderiv->AB,int_stack+161448,int_stack+189168,int_stack+177912, 1.0, int_stack+281218, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,150);
     Libderiv->ABCD[23] = int_stack + 161448;
 /*--- compute (hp|gf) ---*/
   d1hrr1_build_hp(Libderiv->AB,int_stack+170898,int_stack+196896,int_stack+185640, 1.0, int_stack+305662, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,150);
     Libderiv->ABCD[22] = int_stack + 170898;
 /*--- compute (hp|gf) ---*/
   d1hrr1_build_hp(Libderiv->AB,int_stack+180348,int_stack+204624,int_stack+193368, 1.0, int_stack+324058, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,150);
     Libderiv->ABCD[21] = int_stack + 180348;
 /*--- compute (hp|gf) ---*/
   d1hrr1_build_hp(Libderiv->AB,int_stack+189798,int_stack+212352,int_stack+201096, 1.0, int_stack+344218, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,150);
     Libderiv->ABCD[20] = int_stack + 189798;
 /*--- compute (hp|gf) ---*/
   d1hrr1_build_hp(Libderiv->AB,int_stack+336658,int_stack+220080,int_stack+208824, 1.0, int_stack+361858, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,150);
     Libderiv->ABCD[19] = int_stack + 336658;
 /*--- compute (hp|gf) ---*/
   d1hrr1_build_hp(Libderiv->AB,int_stack+199248,int_stack+418558,int_stack+216552, 1.0, int_stack+380254, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,150);
     Libderiv->ABCD[18] = int_stack + 199248;
 /*--- compute (hp|gf) ---*/
   d1hrr1_build_hp(Libderiv->AB,int_stack+418180,int_stack+227808,int_stack+415030, 1.0, int_stack+396004, 0.0, zero_stack, 1.0, int_stack+430276, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,150);
     Libderiv->ABCD[14] = int_stack + 418180;
 /*--- compute (hp|gf) ---*/
   d1hrr1_build_hp(Libderiv->AB,int_stack+392854,int_stack+235536,int_stack+224280, 1.0, int_stack+411880, 1.0, int_stack+430276, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,150);
     Libderiv->ABCD[13] = int_stack + 392854;
 /*--- compute (hp|gf) ---*/
   d1hrr1_build_hp(Libderiv->AB,int_stack+208698,int_stack+243264,int_stack+232008, 2.0, int_stack+430276, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,150);
     Libderiv->ABCD[12] = int_stack + 208698;

}
