/*
 *  Copyright (C) 1996-2017 Edward F. Valeev and Justin T. Fermann
 *
 *  This file is part of Libint.
 *
 *  Libint is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU Lesser General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  Libint is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public License
 *  along with Libint.  If not, see <http://www.gnu.org/licenses/>.
 *
 */

#include <stdio.h>
#include <string.h>
#include <libint/libint.h>
#include "libderiv.h"
#include <libint/hrr_header.h>

#include "d1hrr_header.h"

extern void d1vrr_order_hgih(Libderiv_t *, prim_data *);

  /* Computes derivatives of (hg|ih) integrals */

void d1hrr_order_hgih(Libderiv_t *Libderiv, int num_prim_comb)
{
 prim_data *Data = Libderiv->PrimQuartet;
 double *int_stack = Libderiv->int_stack;
 double *zero_stack = Libderiv->zero_stack;
 int i,j;
 double tmp, *target;

 Libderiv->deriv_classes[5][6][11] = int_stack + 0;
 Libderiv->deriv_classes[5][7][11] = int_stack + 588;
 Libderiv->deriv_classes[5][8][11] = int_stack + 1344;
 Libderiv->deriv_classes[5][9][11] = int_stack + 2289;
 Libderiv->deriv_classes[5][10][11] = int_stack + 3444;
 Libderiv->deriv_classes[5][11][11] = int_stack + 4830;
 Libderiv->deriv_classes[6][6][11] = int_stack + 6468;
 Libderiv->deriv_classes[6][7][11] = int_stack + 7252;
 Libderiv->deriv_classes[6][8][11] = int_stack + 8260;
 Libderiv->deriv_classes[6][9][11] = int_stack + 9520;
 Libderiv->deriv_classes[6][10][11] = int_stack + 11060;
 Libderiv->deriv_classes[6][11][11] = int_stack + 12908;
 Libderiv->deriv_classes[7][6][11] = int_stack + 15092;
 Libderiv->deriv_classes[7][7][11] = int_stack + 16100;
 Libderiv->deriv_classes[7][8][11] = int_stack + 17396;
 Libderiv->deriv_classes[7][9][11] = int_stack + 19016;
 Libderiv->deriv_classes[7][10][11] = int_stack + 20996;
 Libderiv->deriv_classes[7][11][11] = int_stack + 23372;
 Libderiv->deriv_classes[8][6][11] = int_stack + 26180;
 Libderiv->deriv_classes[8][7][11] = int_stack + 27440;
 Libderiv->deriv_classes[8][8][11] = int_stack + 29060;
 Libderiv->deriv_classes[8][9][11] = int_stack + 31085;
 Libderiv->deriv_classes[8][10][11] = int_stack + 33560;
 Libderiv->deriv_classes[8][11][11] = int_stack + 36530;
 Libderiv->deriv_classes[9][6][11] = int_stack + 40040;
 Libderiv->deriv_classes[9][7][11] = int_stack + 41580;
 Libderiv->deriv_classes[9][8][11] = int_stack + 43560;
 Libderiv->deriv_classes[9][9][11] = int_stack + 46035;
 Libderiv->deriv_classes[9][10][11] = int_stack + 49060;
 Libderiv->deriv_classes[9][11][11] = int_stack + 52690;
 Libderiv->deriv_classes[5][6][10] = int_stack + 56980;
 Libderiv->deriv_classes[5][7][10] = int_stack + 57568;
 Libderiv->deriv_classes[5][8][10] = int_stack + 58324;
 Libderiv->deriv_classes[5][9][10] = int_stack + 59269;
 Libderiv->deriv_classes[5][10][10] = int_stack + 60424;
 Libderiv->deriv_classes[5][11][10] = int_stack + 61810;
 Libderiv->deriv_classes[6][6][10] = int_stack + 63448;
 Libderiv->deriv_classes[6][7][10] = int_stack + 64232;
 Libderiv->deriv_classes[6][8][10] = int_stack + 65240;
 Libderiv->deriv_classes[6][9][10] = int_stack + 66500;
 Libderiv->deriv_classes[6][10][10] = int_stack + 68040;
 Libderiv->deriv_classes[6][11][10] = int_stack + 69888;
 Libderiv->deriv_classes[7][6][10] = int_stack + 72072;
 Libderiv->deriv_classes[7][7][10] = int_stack + 73080;
 Libderiv->deriv_classes[7][8][10] = int_stack + 74376;
 Libderiv->deriv_classes[7][9][10] = int_stack + 75996;
 Libderiv->deriv_classes[7][10][10] = int_stack + 77976;
 Libderiv->deriv_classes[7][11][10] = int_stack + 80352;
 Libderiv->deriv_classes[8][6][10] = int_stack + 83160;
 Libderiv->deriv_classes[8][7][10] = int_stack + 84420;
 Libderiv->deriv_classes[8][8][10] = int_stack + 86040;
 Libderiv->deriv_classes[8][9][10] = int_stack + 88065;
 Libderiv->deriv_classes[8][10][10] = int_stack + 90540;
 Libderiv->deriv_classes[8][11][10] = int_stack + 93510;
 Libderiv->deriv_classes[9][6][10] = int_stack + 97020;
 Libderiv->deriv_classes[9][7][10] = int_stack + 98560;
 Libderiv->deriv_classes[9][8][10] = int_stack + 100540;
 Libderiv->deriv_classes[9][9][10] = int_stack + 103015;
 Libderiv->deriv_classes[9][10][10] = int_stack + 106040;
 Libderiv->deriv_classes[9][11][10] = int_stack + 109670;
 Libderiv->deriv_classes[5][6][9] = int_stack + 113960;
 Libderiv->deriv_classes[5][7][9] = int_stack + 114548;
 Libderiv->deriv_classes[5][8][9] = int_stack + 115304;
 Libderiv->deriv_classes[5][9][9] = int_stack + 116249;
 Libderiv->deriv_classes[5][10][9] = int_stack + 117404;
 Libderiv->deriv_classes[5][11][9] = int_stack + 118790;
 Libderiv->deriv_classes[6][6][9] = int_stack + 120428;
 Libderiv->deriv_classes[6][7][9] = int_stack + 121212;
 Libderiv->deriv_classes[6][8][9] = int_stack + 122220;
 Libderiv->deriv_classes[6][9][9] = int_stack + 123480;
 Libderiv->deriv_classes[6][10][9] = int_stack + 125020;
 Libderiv->deriv_classes[6][11][9] = int_stack + 126868;
 Libderiv->deriv_classes[7][6][9] = int_stack + 129052;
 Libderiv->deriv_classes[7][7][9] = int_stack + 130060;
 Libderiv->deriv_classes[7][8][9] = int_stack + 131356;
 Libderiv->deriv_classes[7][9][9] = int_stack + 132976;
 Libderiv->deriv_classes[7][10][9] = int_stack + 134956;
 Libderiv->deriv_classes[7][11][9] = int_stack + 137332;
 Libderiv->deriv_classes[8][6][9] = int_stack + 140140;
 Libderiv->deriv_classes[8][7][9] = int_stack + 141400;
 Libderiv->deriv_classes[8][8][9] = int_stack + 143020;
 Libderiv->deriv_classes[8][9][9] = int_stack + 145045;
 Libderiv->deriv_classes[8][10][9] = int_stack + 147520;
 Libderiv->deriv_classes[8][11][9] = int_stack + 150490;
 Libderiv->deriv_classes[9][6][9] = int_stack + 154000;
 Libderiv->deriv_classes[9][7][9] = int_stack + 155540;
 Libderiv->deriv_classes[9][8][9] = int_stack + 157520;
 Libderiv->deriv_classes[9][9][9] = int_stack + 159995;
 Libderiv->deriv_classes[9][10][9] = int_stack + 163020;
 Libderiv->deriv_classes[9][11][9] = int_stack + 166650;
 Libderiv->deriv_classes[5][6][8] = int_stack + 170940;
 Libderiv->deriv_classes[5][7][8] = int_stack + 171528;
 Libderiv->deriv_classes[5][8][8] = int_stack + 172284;
 Libderiv->deriv_classes[5][9][8] = int_stack + 173229;
 Libderiv->deriv_classes[5][10][8] = int_stack + 174384;
 Libderiv->deriv_classes[5][11][8] = int_stack + 175770;
 Libderiv->deriv_classes[6][6][8] = int_stack + 177408;
 Libderiv->deriv_classes[6][7][8] = int_stack + 178192;
 Libderiv->deriv_classes[6][8][8] = int_stack + 179200;
 Libderiv->deriv_classes[6][9][8] = int_stack + 180460;
 Libderiv->deriv_classes[6][10][8] = int_stack + 182000;
 Libderiv->deriv_classes[6][11][8] = int_stack + 183848;
 Libderiv->deriv_classes[7][6][8] = int_stack + 186032;
 Libderiv->deriv_classes[7][7][8] = int_stack + 187040;
 Libderiv->deriv_classes[7][8][8] = int_stack + 188336;
 Libderiv->deriv_classes[7][9][8] = int_stack + 189956;
 Libderiv->deriv_classes[7][10][8] = int_stack + 191936;
 Libderiv->deriv_classes[7][11][8] = int_stack + 194312;
 Libderiv->deriv_classes[8][6][8] = int_stack + 197120;
 Libderiv->deriv_classes[8][7][8] = int_stack + 198380;
 Libderiv->deriv_classes[8][8][8] = int_stack + 200000;
 Libderiv->deriv_classes[8][9][8] = int_stack + 202025;
 Libderiv->deriv_classes[8][10][8] = int_stack + 204500;
 Libderiv->deriv_classes[8][11][8] = int_stack + 207470;
 Libderiv->deriv_classes[9][6][8] = int_stack + 210980;
 Libderiv->deriv_classes[9][7][8] = int_stack + 212520;
 Libderiv->deriv_classes[9][8][8] = int_stack + 214500;
 Libderiv->deriv_classes[9][9][8] = int_stack + 216975;
 Libderiv->deriv_classes[9][10][8] = int_stack + 220000;
 Libderiv->deriv_classes[9][11][8] = int_stack + 223630;
 Libderiv->deriv_classes[5][6][7] = int_stack + 227920;
 Libderiv->deriv_classes[5][7][7] = int_stack + 228508;
 Libderiv->deriv_classes[5][8][7] = int_stack + 229264;
 Libderiv->deriv_classes[5][9][7] = int_stack + 230209;
 Libderiv->deriv_classes[5][10][7] = int_stack + 231364;
 Libderiv->deriv_classes[5][11][7] = int_stack + 232750;
 Libderiv->deriv_classes[6][6][7] = int_stack + 234388;
 Libderiv->deriv_classes[6][7][7] = int_stack + 235172;
 Libderiv->deriv_classes[6][8][7] = int_stack + 236180;
 Libderiv->deriv_classes[6][9][7] = int_stack + 237440;
 Libderiv->deriv_classes[6][10][7] = int_stack + 238980;
 Libderiv->deriv_classes[6][11][7] = int_stack + 240828;
 Libderiv->deriv_classes[7][6][7] = int_stack + 243012;
 Libderiv->deriv_classes[7][7][7] = int_stack + 244020;
 Libderiv->deriv_classes[7][8][7] = int_stack + 245316;
 Libderiv->deriv_classes[7][9][7] = int_stack + 246936;
 Libderiv->deriv_classes[7][10][7] = int_stack + 248916;
 Libderiv->deriv_classes[7][11][7] = int_stack + 251292;
 Libderiv->deriv_classes[8][6][7] = int_stack + 254100;
 Libderiv->deriv_classes[8][7][7] = int_stack + 255360;
 Libderiv->deriv_classes[8][8][7] = int_stack + 256980;
 Libderiv->deriv_classes[8][9][7] = int_stack + 259005;
 Libderiv->deriv_classes[8][10][7] = int_stack + 261480;
 Libderiv->deriv_classes[8][11][7] = int_stack + 264450;
 Libderiv->deriv_classes[9][6][7] = int_stack + 267960;
 Libderiv->deriv_classes[9][7][7] = int_stack + 269500;
 Libderiv->deriv_classes[9][8][7] = int_stack + 271480;
 Libderiv->deriv_classes[9][9][7] = int_stack + 273955;
 Libderiv->deriv_classes[9][10][7] = int_stack + 276980;
 Libderiv->deriv_classes[9][11][7] = int_stack + 280610;
 Libderiv->deriv_classes[5][6][6] = int_stack + 284900;
 Libderiv->deriv_classes[5][7][6] = int_stack + 285488;
 Libderiv->deriv_classes[5][8][6] = int_stack + 286244;
 Libderiv->deriv_classes[5][9][6] = int_stack + 287189;
 Libderiv->deriv_classes[5][10][6] = int_stack + 288344;
 Libderiv->deriv_classes[5][11][6] = int_stack + 289730;
 Libderiv->deriv_classes[6][6][6] = int_stack + 291368;
 Libderiv->deriv_classes[6][7][6] = int_stack + 292152;
 Libderiv->deriv_classes[6][8][6] = int_stack + 293160;
 Libderiv->deriv_classes[6][9][6] = int_stack + 294420;
 Libderiv->deriv_classes[6][10][6] = int_stack + 295960;
 Libderiv->deriv_classes[6][11][6] = int_stack + 297808;
 Libderiv->deriv_classes[7][6][6] = int_stack + 299992;
 Libderiv->deriv_classes[7][7][6] = int_stack + 301000;
 Libderiv->deriv_classes[7][8][6] = int_stack + 302296;
 Libderiv->deriv_classes[7][9][6] = int_stack + 303916;
 Libderiv->deriv_classes[7][10][6] = int_stack + 305896;
 Libderiv->deriv_classes[7][11][6] = int_stack + 308272;
 Libderiv->deriv_classes[8][6][6] = int_stack + 311080;
 Libderiv->deriv_classes[8][7][6] = int_stack + 312340;
 Libderiv->deriv_classes[8][8][6] = int_stack + 313960;
 Libderiv->deriv_classes[8][9][6] = int_stack + 315985;
 Libderiv->deriv_classes[8][10][6] = int_stack + 318460;
 Libderiv->deriv_classes[8][11][6] = int_stack + 321430;
 Libderiv->dvrr_classes[9][6] = int_stack + 324940;
 Libderiv->deriv_classes[9][6][6] = int_stack + 326480;
 Libderiv->dvrr_classes[9][7] = int_stack + 328020;
 Libderiv->deriv_classes[9][7][6] = int_stack + 330000;
 Libderiv->dvrr_classes[9][8] = int_stack + 331980;
 Libderiv->deriv_classes[9][8][6] = int_stack + 334455;
 Libderiv->dvrr_classes[9][9] = int_stack + 336930;
 Libderiv->deriv_classes[9][9][6] = int_stack + 339955;
 Libderiv->dvrr_classes[9][10] = int_stack + 342980;
 Libderiv->deriv_classes[9][10][6] = int_stack + 346610;
 Libderiv->deriv_classes[9][11][6] = int_stack + 350240;
 Libderiv->deriv_classes[5][6][2] = int_stack + 354530;
 Libderiv->deriv_classes[5][7][2] = int_stack + 355118;
 Libderiv->deriv_classes[5][8][2] = int_stack + 355874;
 Libderiv->deriv_classes[5][9][2] = int_stack + 356819;
 Libderiv->deriv_classes[5][10][2] = int_stack + 357974;
 Libderiv->deriv_classes[5][11][2] = int_stack + 359360;
 Libderiv->deriv_classes[6][6][2] = int_stack + 360998;
 Libderiv->deriv_classes[6][7][2] = int_stack + 361782;
 Libderiv->deriv_classes[6][8][2] = int_stack + 362790;
 Libderiv->deriv_classes[6][9][2] = int_stack + 364050;
 Libderiv->deriv_classes[6][10][2] = int_stack + 365590;
 Libderiv->deriv_classes[6][11][2] = int_stack + 367438;
 Libderiv->deriv_classes[7][6][2] = int_stack + 369622;
 Libderiv->deriv_classes[7][7][2] = int_stack + 370630;
 Libderiv->deriv_classes[7][8][2] = int_stack + 371926;
 Libderiv->deriv_classes[7][9][2] = int_stack + 373546;
 Libderiv->deriv_classes[7][10][2] = int_stack + 375526;
 Libderiv->deriv_classes[7][11][2] = int_stack + 377902;
 Libderiv->deriv_classes[8][6][2] = int_stack + 380710;
 Libderiv->deriv_classes[8][7][2] = int_stack + 381970;
 Libderiv->deriv_classes[8][8][2] = int_stack + 383590;
 Libderiv->deriv_classes[8][9][2] = int_stack + 385615;
 Libderiv->deriv_classes[8][10][2] = int_stack + 388090;
 Libderiv->deriv_classes[8][11][2] = int_stack + 391060;
 Libderiv->deriv_classes[9][6][2] = int_stack + 394570;
 Libderiv->deriv_classes[9][7][2] = int_stack + 396110;
 Libderiv->deriv_classes[9][8][2] = int_stack + 398090;
 Libderiv->deriv_classes[9][9][2] = int_stack + 400565;
 Libderiv->deriv_classes[9][10][2] = int_stack + 403590;
 Libderiv->deriv_classes[9][11][2] = int_stack + 407220;
 Libderiv->deriv_classes[5][6][1] = int_stack + 411510;
 Libderiv->deriv_classes[5][7][1] = int_stack + 412098;
 Libderiv->deriv_classes[5][8][1] = int_stack + 412854;
 Libderiv->deriv_classes[5][9][1] = int_stack + 413799;
 Libderiv->deriv_classes[5][10][1] = int_stack + 414954;
 Libderiv->deriv_classes[5][11][1] = int_stack + 416340;
 Libderiv->deriv_classes[6][6][1] = int_stack + 417978;
 Libderiv->deriv_classes[6][7][1] = int_stack + 418762;
 Libderiv->deriv_classes[6][8][1] = int_stack + 419770;
 Libderiv->deriv_classes[6][9][1] = int_stack + 421030;
 Libderiv->deriv_classes[6][10][1] = int_stack + 422570;
 Libderiv->deriv_classes[6][11][1] = int_stack + 424418;
 Libderiv->deriv_classes[7][6][1] = int_stack + 426602;
 Libderiv->deriv_classes[7][7][1] = int_stack + 427610;
 Libderiv->deriv_classes[7][8][1] = int_stack + 428906;
 Libderiv->deriv_classes[7][9][1] = int_stack + 430526;
 Libderiv->deriv_classes[7][10][1] = int_stack + 432506;
 Libderiv->deriv_classes[7][11][1] = int_stack + 434882;
 Libderiv->deriv_classes[8][6][1] = int_stack + 437690;
 Libderiv->deriv_classes[8][7][1] = int_stack + 438950;
 Libderiv->deriv_classes[8][8][1] = int_stack + 440570;
 Libderiv->deriv_classes[8][9][1] = int_stack + 442595;
 Libderiv->deriv_classes[8][10][1] = int_stack + 445070;
 Libderiv->deriv_classes[8][11][1] = int_stack + 448040;
 Libderiv->deriv_classes[9][6][1] = int_stack + 451550;
 Libderiv->deriv_classes[9][7][1] = int_stack + 453090;
 Libderiv->deriv_classes[9][8][1] = int_stack + 455070;
 Libderiv->deriv_classes[9][9][1] = int_stack + 457545;
 Libderiv->deriv_classes[9][10][1] = int_stack + 460570;
 Libderiv->deriv_classes[9][11][1] = int_stack + 464200;
 Libderiv->dvrr_classes[5][6] = int_stack + 468490;
 Libderiv->dvrr_classes[5][7] = int_stack + 469078;
 Libderiv->dvrr_classes[5][8] = int_stack + 469834;
 Libderiv->dvrr_classes[5][9] = int_stack + 470779;
 Libderiv->dvrr_classes[5][10] = int_stack + 471934;
 Libderiv->dvrr_classes[5][11] = int_stack + 473320;
 Libderiv->deriv_classes[5][6][0] = int_stack + 474958;
 Libderiv->deriv_classes[5][7][0] = int_stack + 475546;
 Libderiv->deriv_classes[5][8][0] = int_stack + 476302;
 Libderiv->deriv_classes[5][9][0] = int_stack + 477247;
 Libderiv->deriv_classes[5][10][0] = int_stack + 478402;
 Libderiv->deriv_classes[5][11][0] = int_stack + 479788;
 Libderiv->dvrr_classes[6][6] = int_stack + 481426;
 Libderiv->dvrr_classes[6][7] = int_stack + 482210;
 Libderiv->dvrr_classes[6][8] = int_stack + 483218;
 Libderiv->dvrr_classes[6][9] = int_stack + 484478;
 Libderiv->dvrr_classes[6][10] = int_stack + 486018;
 Libderiv->dvrr_classes[6][11] = int_stack + 487866;
 Libderiv->deriv_classes[6][6][0] = int_stack + 490050;
 Libderiv->deriv_classes[6][7][0] = int_stack + 490834;
 Libderiv->deriv_classes[6][8][0] = int_stack + 491842;
 Libderiv->deriv_classes[6][9][0] = int_stack + 493102;
 Libderiv->deriv_classes[6][10][0] = int_stack + 494642;
 Libderiv->deriv_classes[6][11][0] = int_stack + 496490;
 Libderiv->dvrr_classes[7][6] = int_stack + 498674;
 Libderiv->dvrr_classes[7][7] = int_stack + 499682;
 Libderiv->dvrr_classes[7][8] = int_stack + 500978;
 Libderiv->dvrr_classes[7][9] = int_stack + 502598;
 Libderiv->dvrr_classes[7][10] = int_stack + 504578;
 Libderiv->dvrr_classes[7][11] = int_stack + 506954;
 Libderiv->deriv_classes[7][6][0] = int_stack + 509762;
 Libderiv->deriv_classes[7][7][0] = int_stack + 510770;
 Libderiv->deriv_classes[7][8][0] = int_stack + 512066;
 Libderiv->deriv_classes[7][9][0] = int_stack + 513686;
 Libderiv->deriv_classes[7][10][0] = int_stack + 515666;
 Libderiv->deriv_classes[7][11][0] = int_stack + 518042;
 Libderiv->dvrr_classes[8][6] = int_stack + 520850;
 Libderiv->dvrr_classes[8][7] = int_stack + 522110;
 Libderiv->dvrr_classes[8][8] = int_stack + 523730;
 Libderiv->dvrr_classes[8][9] = int_stack + 525755;
 Libderiv->dvrr_classes[8][10] = int_stack + 528230;
 Libderiv->dvrr_classes[8][11] = int_stack + 531200;
 Libderiv->deriv_classes[8][6][0] = int_stack + 534710;
 Libderiv->deriv_classes[8][7][0] = int_stack + 535970;
 Libderiv->deriv_classes[8][8][0] = int_stack + 537590;
 Libderiv->deriv_classes[8][9][0] = int_stack + 539615;
 Libderiv->deriv_classes[8][10][0] = int_stack + 542090;
 Libderiv->deriv_classes[8][11][0] = int_stack + 545060;
 Libderiv->deriv_classes[9][6][0] = int_stack + 548570;
 Libderiv->deriv_classes[9][7][0] = int_stack + 550110;
 Libderiv->deriv_classes[9][8][0] = int_stack + 552090;
 Libderiv->deriv_classes[9][9][0] = int_stack + 554565;
 Libderiv->deriv_classes[9][10][0] = int_stack + 557590;
 Libderiv->deriv_classes[9][11][0] = int_stack + 561220;
 memset(int_stack,0,4524080);

 Libderiv->dvrr_stack = int_stack + 3868517;
 for(i=0;i<num_prim_comb;i++) {
   d1vrr_order_hgih(Libderiv, Data);
   Data++;
 }

 /*--- compute (h0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+565510,int_stack+469078,int_stack+468490,21);
 /*--- compute (h0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+567274,int_stack+469834,int_stack+469078,21);
 /*--- compute (h0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+569542,int_stack+567274,int_stack+565510,21);
 /*--- compute (h0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+573070,int_stack+470779,int_stack+469834,21);
 /*--- compute (h0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+575905,int_stack+573070,int_stack+567274,21);
 /*--- compute (h0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+580441,int_stack+575905,int_stack+569542,21);
 /*--- compute (h0|mp) ---*/
   hrr3_build_mp(Libderiv->CD,int_stack+586321,int_stack+471934,int_stack+470779,21);
 /*--- compute (h0|ld) ---*/
   hrr3_build_ld(Libderiv->CD,int_stack+589786,int_stack+586321,int_stack+573070,21);
 /*--- compute (h0|kf) ---*/
   hrr3_build_kf(Libderiv->CD,int_stack+595456,int_stack+589786,int_stack+575905,21);
 /*--- compute (h0|ig) ---*/
   hrr3_build_ig(Libderiv->CD,int_stack+603016,int_stack+595456,int_stack+580441,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+611836,int_stack+588,int_stack+0, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+468490,21);
 /*--- compute (h0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+613600,int_stack+1344,int_stack+588, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+469078,21);
 /*--- compute (h0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+615868,int_stack+613600,int_stack+611836, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+565510,21);
 /*--- compute (h0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+619396,int_stack+2289,int_stack+1344, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+469834,21);
 /*--- compute (h0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+622231,int_stack+619396,int_stack+613600, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+567274,21);
 /*--- compute (h0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+626767,int_stack+622231,int_stack+615868, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+569542,21);
 /*--- compute (h0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+611836,int_stack+3444,int_stack+2289, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+470779,21);
 /*--- compute (h0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+632647,int_stack+611836,int_stack+619396, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+573070,21);
 /*--- compute (h0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+638317,int_stack+632647,int_stack+622231, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+575905,21);
 /*--- compute (h0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+615301,int_stack+638317,int_stack+626767, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+580441,21);
 /*--- compute (h0|np) ---*/
   d1hrr3_build_np(Libderiv->CD,int_stack+624121,int_stack+4830,int_stack+3444, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+471934,21);
 /*--- compute (h0|md) ---*/
   d1hrr3_build_md(Libderiv->CD,int_stack+645877,int_stack+624121,int_stack+611836, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+586321,21);
 /*--- compute (h0|lf) ---*/
   d1hrr3_build_lf(Libderiv->CD,int_stack+652807,int_stack+645877,int_stack+632647, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+589786,21);
 /*--- compute (h0|kg) ---*/
   d1hrr3_build_kg(Libderiv->CD,int_stack+624121,int_stack+652807,int_stack+638317, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+595456,21);
 /*--- compute (h0|ih) ---*/
   d1hrr3_build_ih(Libderiv->CD,int_stack+635461,int_stack+624121,int_stack+615301, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+603016,21);
 /*--- compute (i0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+611836,int_stack+482210,int_stack+481426,28);
 /*--- compute (i0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+614188,int_stack+483218,int_stack+482210,28);
 /*--- compute (i0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+617212,int_stack+614188,int_stack+611836,28);
 /*--- compute (i0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+621916,int_stack+484478,int_stack+483218,28);
 /*--- compute (i0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+625696,int_stack+621916,int_stack+614188,28);
 /*--- compute (i0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+647809,int_stack+625696,int_stack+617212,28);
 /*--- compute (i0|mp) ---*/
   hrr3_build_mp(Libderiv->CD,int_stack+655649,int_stack+486018,int_stack+484478,28);
 /*--- compute (i0|ld) ---*/
   hrr3_build_ld(Libderiv->CD,int_stack+660269,int_stack+655649,int_stack+621916,28);
 /*--- compute (i0|kf) ---*/
   hrr3_build_kf(Libderiv->CD,int_stack+667829,int_stack+660269,int_stack+625696,28);
 /*--- compute (i0|ig) ---*/
   hrr3_build_ig(Libderiv->CD,int_stack+677909,int_stack+667829,int_stack+647809,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+631744,int_stack+7252,int_stack+6468, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+481426,28);
 /*--- compute (i0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+0,int_stack+8260,int_stack+7252, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+482210,28);
 /*--- compute (i0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+3024,int_stack+0,int_stack+631744, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+611836,28);
 /*--- compute (i0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+689669,int_stack+9520,int_stack+8260, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+483218,28);
 /*--- compute (i0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+693449,int_stack+689669,int_stack+0, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+614188,28);
 /*--- compute (i0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+699497,int_stack+693449,int_stack+3024, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+617212,28);
 /*--- compute (i0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+0,int_stack+11060,int_stack+9520, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+484478,28);
 /*--- compute (i0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+707337,int_stack+0,int_stack+689669, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+621916,28);
 /*--- compute (i0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+714897,int_stack+707337,int_stack+693449, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+625696,28);
 /*--- compute (i0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+724977,int_stack+714897,int_stack+699497, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+647809,28);
 /*--- compute (i0|np) ---*/
   d1hrr3_build_np(Libderiv->CD,int_stack+689669,int_stack+12908,int_stack+11060, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+486018,28);
 /*--- compute (i0|md) ---*/
   d1hrr3_build_md(Libderiv->CD,int_stack+695213,int_stack+689669,int_stack+0, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+655649,28);
 /*--- compute (i0|lf) ---*/
   d1hrr3_build_lf(Libderiv->CD,int_stack+0,int_stack+695213,int_stack+707337, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+660269,28);
 /*--- compute (i0|kg) ---*/
   d1hrr3_build_kg(Libderiv->CD,int_stack+689669,int_stack+0,int_stack+714897, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+667829,28);
 /*--- compute (i0|ih) ---*/
   d1hrr3_build_ih(Libderiv->CD,int_stack+704789,int_stack+689669,int_stack+724977, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+677909,28);
 /*--- compute (hp|ih) ---*/
   hrr1_build_hp(Libderiv->AB,int_stack+721253,int_stack+704789,int_stack+635461,588);
 /*--- compute (k0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+689669,int_stack+499682,int_stack+498674,36);
 /*--- compute (k0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+692693,int_stack+500978,int_stack+499682,36);
 /*--- compute (k0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+696581,int_stack+692693,int_stack+689669,36);
 /*--- compute (k0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+0,int_stack+502598,int_stack+500978,36);
 /*--- compute (k0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+4860,int_stack+0,int_stack+692693,36);
 /*--- compute (k0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+631744,int_stack+4860,int_stack+696581,36);
 /*--- compute (k0|mp) ---*/
   hrr3_build_mp(Libderiv->CD,int_stack+641824,int_stack+504578,int_stack+502598,36);
 /*--- compute (k0|ld) ---*/
   hrr3_build_ld(Libderiv->CD,int_stack+758297,int_stack+641824,int_stack+0,36);
 /*--- compute (k0|kf) ---*/
   hrr3_build_kf(Libderiv->CD,int_stack+768017,int_stack+758297,int_stack+4860,36);
 /*--- compute (k0|ig) ---*/
   hrr3_build_ig(Libderiv->CD,int_stack+780977,int_stack+768017,int_stack+631744,36);
 /*--- compute (k0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+796097,int_stack+16100,int_stack+15092, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+498674,36);
 /*--- compute (k0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+799121,int_stack+17396,int_stack+16100, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+499682,36);
 /*--- compute (k0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+803009,int_stack+799121,int_stack+796097, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+689669,36);
 /*--- compute (k0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+809057,int_stack+19016,int_stack+17396, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+500978,36);
 /*--- compute (k0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+813917,int_stack+809057,int_stack+799121, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+692693,36);
 /*--- compute (k0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+821693,int_stack+813917,int_stack+803009, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+696581,36);
 /*--- compute (k0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+796097,int_stack+20996,int_stack+19016, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+502598,36);
 /*--- compute (k0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+831773,int_stack+796097,int_stack+809057, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+0,36);
 /*--- compute (k0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+841493,int_stack+831773,int_stack+813917, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+4860,36);
 /*--- compute (k0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+802037,int_stack+841493,int_stack+821693, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+631744,36);
 /*--- compute (k0|np) ---*/
   d1hrr3_build_np(Libderiv->CD,int_stack+817157,int_stack+23372,int_stack+20996, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+504578,36);
 /*--- compute (k0|md) ---*/
   d1hrr3_build_md(Libderiv->CD,int_stack+12636,int_stack+817157,int_stack+796097, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+641824,36);
 /*--- compute (k0|lf) ---*/
   d1hrr3_build_lf(Libderiv->CD,int_stack+854453,int_stack+12636,int_stack+831773, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+758297,36);
 /*--- compute (k0|kg) ---*/
   d1hrr3_build_kg(Libderiv->CD,int_stack+817157,int_stack+854453,int_stack+841493, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+768017,36);
 /*--- compute (k0|ih) ---*/
   d1hrr3_build_ih(Libderiv->CD,int_stack+836597,int_stack+817157,int_stack+802037, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+780977,36);
 /*--- compute (ip|ih) ---*/
   hrr1_build_ip(Libderiv->AB,int_stack+857765,int_stack+836597,int_stack+704789,588);
 /*--- compute (hd|ih) ---*/
   hrr1_build_hd(Libderiv->AB,int_stack+907157,int_stack+857765,int_stack+721253,588);
 /*--- compute (l0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+12636,int_stack+522110,int_stack+520850,45);
 /*--- compute (l0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+16416,int_stack+523730,int_stack+522110,45);
 /*--- compute (l0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+796097,int_stack+16416,int_stack+12636,45);
 /*--- compute (l0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+803657,int_stack+525755,int_stack+523730,45);
 /*--- compute (l0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+809732,int_stack+803657,int_stack+16416,45);
 /*--- compute (l0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+819452,int_stack+809732,int_stack+796097,45);
 /*--- compute (l0|mp) ---*/
   hrr3_build_mp(Libderiv->CD,int_stack+702629,int_stack+528230,int_stack+525755,45);
 /*--- compute (l0|ld) ---*/
   hrr3_build_ld(Libderiv->CD,int_stack+710054,int_stack+702629,int_stack+803657,45);
 /*--- compute (l0|kf) ---*/
   hrr3_build_kf(Libderiv->CD,int_stack+722204,int_stack+710054,int_stack+809732,45);
 /*--- compute (l0|ig) ---*/
   hrr3_build_ig(Libderiv->CD,int_stack+738404,int_stack+722204,int_stack+819452,45);
 /*--- compute (l0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+21276,int_stack+27440,int_stack+26180, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+520850,45);
 /*--- compute (l0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+981245,int_stack+29060,int_stack+27440, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+522110,45);
 /*--- compute (l0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+986105,int_stack+981245,int_stack+21276, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+12636,45);
 /*--- compute (l0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+21276,int_stack+31085,int_stack+29060, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+523730,45);
 /*--- compute (l0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+993665,int_stack+21276,int_stack+981245, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+16416,45);
 /*--- compute (l0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+1003385,int_stack+993665,int_stack+986105, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+796097,45);
 /*--- compute (l0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+981245,int_stack+33560,int_stack+31085, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+525755,45);
 /*--- compute (l0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+1015985,int_stack+981245,int_stack+21276, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+803657,45);
 /*--- compute (l0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+1028135,int_stack+1015985,int_stack+993665, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+809732,45);
 /*--- compute (l0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+1044335,int_stack+1028135,int_stack+1003385, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+819452,45);
 /*--- compute (l0|np) ---*/
   d1hrr3_build_np(Libderiv->CD,int_stack+21276,int_stack+36530,int_stack+33560, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+528230,45);
 /*--- compute (l0|md) ---*/
   d1hrr3_build_md(Libderiv->CD,int_stack+988670,int_stack+21276,int_stack+981245, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+702629,45);
 /*--- compute (l0|lf) ---*/
   d1hrr3_build_lf(Libderiv->CD,int_stack+1063235,int_stack+988670,int_stack+1015985, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+710054,45);
 /*--- compute (l0|kg) ---*/
   d1hrr3_build_kg(Libderiv->CD,int_stack+981245,int_stack+1063235,int_stack+1028135, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+722204,45);
 /*--- compute (l0|ih) ---*/
   d1hrr3_build_ih(Libderiv->CD,int_stack+1005545,int_stack+981245,int_stack+1044335, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+738404,45);
 /*--- compute (kp|ih) ---*/
   hrr1_build_kp(Libderiv->AB,int_stack+1032005,int_stack+1005545,int_stack+836597,588);
 /*--- compute (id|ih) ---*/
   hrr1_build_id(Libderiv->AB,int_stack+1095509,int_stack+1032005,int_stack+857765,588);
 /*--- compute (hf|ih) ---*/
   hrr1_build_hf(Libderiv->AB,int_stack+1194293,int_stack+1095509,int_stack+907157,588);
 /*--- compute (m0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+21276,int_stack+328020,int_stack+324940,55);
 /*--- compute (m0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+25896,int_stack+331980,int_stack+328020,55);
 /*--- compute (m0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+832052,int_stack+25896,int_stack+21276,55);
 /*--- compute (m0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+31836,int_stack+336930,int_stack+331980,55);
 /*--- compute (m0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+841292,int_stack+31836,int_stack+25896,55);
 /*--- compute (m0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+853172,int_stack+841292,int_stack+832052,55);
 /*--- compute (m0|mp) ---*/
   hrr3_build_mp(Libderiv->CD,int_stack+868572,int_stack+342980,int_stack+336930,55);
 /*--- compute (m0|ld) ---*/
   hrr3_build_ld(Libderiv->CD,int_stack+877647,int_stack+868572,int_stack+31836,55);
 /*--- compute (m0|kf) ---*/
   hrr3_build_kf(Libderiv->CD,int_stack+892497,int_stack+877647,int_stack+841292,55);
 /*--- compute (m0|ig) ---*/
   hrr3_build_ig(Libderiv->CD,int_stack+912297,int_stack+892497,int_stack+853172,55);
 /*--- compute (m0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+935397,int_stack+41580,int_stack+40040, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+324940,55);
 /*--- compute (m0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+940017,int_stack+43560,int_stack+41580, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+328020,55);
 /*--- compute (m0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+945957,int_stack+940017,int_stack+935397, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+21276,55);
 /*--- compute (m0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+955197,int_stack+46035,int_stack+43560, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+331980,55);
 /*--- compute (m0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+962622,int_stack+955197,int_stack+940017, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+25896,55);
 /*--- compute (m0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+974502,int_stack+962622,int_stack+945957, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+832052,55);
 /*--- compute (m0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+935397,int_stack+49060,int_stack+46035, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+336930,55);
 /*--- compute (m0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+989902,int_stack+935397,int_stack+955197, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+31836,55);
 /*--- compute (m0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+1317773,int_stack+989902,int_stack+962622, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+841292,55);
 /*--- compute (m0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+944472,int_stack+1317773,int_stack+974502, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+853172,55);
 /*--- compute (m0|np) ---*/
   d1hrr3_build_np(Libderiv->CD,int_stack+967572,int_stack+52690,int_stack+49060, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+342980,55);
 /*--- compute (m0|md) ---*/
   d1hrr3_build_md(Libderiv->CD,int_stack+1337573,int_stack+967572,int_stack+935397, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+868572,55);
 /*--- compute (m0|lf) ---*/
   d1hrr3_build_lf(Libderiv->CD,int_stack+1355723,int_stack+1337573,int_stack+989902, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+877647,55);
 /*--- compute (m0|kg) ---*/
   d1hrr3_build_kg(Libderiv->CD,int_stack+967572,int_stack+1355723,int_stack+1317773, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+892497,55);
 /*--- compute (m0|ih) ---*/
   d1hrr3_build_ih(Libderiv->CD,int_stack+1317773,int_stack+967572,int_stack+944472, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+912297,55);
 /*--- compute (lp|ih) ---*/
   hrr1_build_lp(Libderiv->AB,int_stack+1350113,int_stack+1317773,int_stack+1005545,588);
 /*--- compute (kd|ih) ---*/
   hrr1_build_kd(Libderiv->AB,int_stack+1429493,int_stack+1350113,int_stack+1032005,588);
 /*--- compute (if|ih) ---*/
   hrr1_build_if(Libderiv->AB,int_stack+1556501,int_stack+1429493,int_stack+1095509,588);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+1317773,int_stack+57568,int_stack+56980, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+468490, 0.0, zero_stack,21);
 /*--- compute (h0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+1319537,int_stack+58324,int_stack+57568, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+469078, 0.0, zero_stack,21);
 /*--- compute (h0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+1321805,int_stack+1319537,int_stack+1317773, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+565510, 0.0, zero_stack,21);
 /*--- compute (h0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+1325333,int_stack+59269,int_stack+58324, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+469834, 0.0, zero_stack,21);
 /*--- compute (h0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+1328168,int_stack+1325333,int_stack+1319537, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+567274, 0.0, zero_stack,21);
 /*--- compute (h0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+1332704,int_stack+1328168,int_stack+1321805, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+569542, 0.0, zero_stack,21);
 /*--- compute (h0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+1317773,int_stack+60424,int_stack+59269, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+470779, 0.0, zero_stack,21);
 /*--- compute (h0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+1338584,int_stack+1317773,int_stack+1325333, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+573070, 0.0, zero_stack,21);
 /*--- compute (h0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+1344254,int_stack+1338584,int_stack+1328168, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+575905, 0.0, zero_stack,21);
 /*--- compute (h0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+1321238,int_stack+1344254,int_stack+1332704, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+580441, 0.0, zero_stack,21);
 /*--- compute (h0|np) ---*/
   d1hrr3_build_np(Libderiv->CD,int_stack+1330058,int_stack+61810,int_stack+60424, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+471934, 0.0, zero_stack,21);
 /*--- compute (h0|md) ---*/
   d1hrr3_build_md(Libderiv->CD,int_stack+1351814,int_stack+1330058,int_stack+1317773, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+586321, 0.0, zero_stack,21);
 /*--- compute (h0|lf) ---*/
   d1hrr3_build_lf(Libderiv->CD,int_stack+1358744,int_stack+1351814,int_stack+1338584, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+589786, 0.0, zero_stack,21);
 /*--- compute (h0|kg) ---*/
   d1hrr3_build_kg(Libderiv->CD,int_stack+1330058,int_stack+1358744,int_stack+1344254, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+595456, 0.0, zero_stack,21);
 /*--- compute (h0|ih) ---*/
   d1hrr3_build_ih(Libderiv->CD,int_stack+1341398,int_stack+1330058,int_stack+1321238, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+603016, 0.0, zero_stack,21);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+1317773,int_stack+64232,int_stack+63448, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+481426, 0.0, zero_stack,28);
 /*--- compute (i0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+1320125,int_stack+65240,int_stack+64232, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+482210, 0.0, zero_stack,28);
 /*--- compute (i0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+1323149,int_stack+1320125,int_stack+1317773, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+611836, 0.0, zero_stack,28);
 /*--- compute (i0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+1327853,int_stack+66500,int_stack+65240, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+483218, 0.0, zero_stack,28);
 /*--- compute (i0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+1331633,int_stack+1327853,int_stack+1320125, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+614188, 0.0, zero_stack,28);
 /*--- compute (i0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+1353746,int_stack+1331633,int_stack+1323149, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+617212, 0.0, zero_stack,28);
 /*--- compute (i0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+1317773,int_stack+68040,int_stack+66500, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+484478, 0.0, zero_stack,28);
 /*--- compute (i0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+1361586,int_stack+1317773,int_stack+1327853, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+621916, 0.0, zero_stack,28);
 /*--- compute (i0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+1369146,int_stack+1361586,int_stack+1331633, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+625696, 0.0, zero_stack,28);
 /*--- compute (i0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+1322393,int_stack+1369146,int_stack+1353746, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+647809, 0.0, zero_stack,28);
 /*--- compute (i0|np) ---*/
   d1hrr3_build_np(Libderiv->CD,int_stack+1353746,int_stack+69888,int_stack+68040, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+486018, 0.0, zero_stack,28);
 /*--- compute (i0|md) ---*/
   d1hrr3_build_md(Libderiv->CD,int_stack+1379226,int_stack+1353746,int_stack+1317773, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+655649, 0.0, zero_stack,28);
 /*--- compute (i0|lf) ---*/
   d1hrr3_build_lf(Libderiv->CD,int_stack+1388466,int_stack+1379226,int_stack+1361586, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+660269, 0.0, zero_stack,28);
 /*--- compute (i0|kg) ---*/
   d1hrr3_build_kg(Libderiv->CD,int_stack+1353746,int_stack+1388466,int_stack+1369146, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+667829, 0.0, zero_stack,28);
 /*--- compute (i0|ih) ---*/
   d1hrr3_build_ih(Libderiv->CD,int_stack+1368866,int_stack+1353746,int_stack+1322393, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+677909, 0.0, zero_stack,28);
 /*--- compute (hp|ih) ---*/
   hrr1_build_hp(Libderiv->AB,int_stack+1385330,int_stack+1368866,int_stack+1341398,588);
 /*--- compute (k0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+1317773,int_stack+73080,int_stack+72072, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+498674, 0.0, zero_stack,36);
 /*--- compute (k0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+1320797,int_stack+74376,int_stack+73080, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+499682, 0.0, zero_stack,36);
 /*--- compute (k0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+1324685,int_stack+1320797,int_stack+1317773, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+689669, 0.0, zero_stack,36);
 /*--- compute (k0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+1330733,int_stack+75996,int_stack+74376, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+500978, 0.0, zero_stack,36);
 /*--- compute (k0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+1335593,int_stack+1330733,int_stack+1320797, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+692693, 0.0, zero_stack,36);
 /*--- compute (k0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+1343369,int_stack+1335593,int_stack+1324685, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+696581, 0.0, zero_stack,36);
 /*--- compute (k0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+1317773,int_stack+77976,int_stack+75996, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+502598, 0.0, zero_stack,36);
 /*--- compute (k0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+1353449,int_stack+1317773,int_stack+1330733, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+0, 0.0, zero_stack,36);
 /*--- compute (k0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+1422374,int_stack+1353449,int_stack+1335593, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+4860, 0.0, zero_stack,36);
 /*--- compute (k0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+1323713,int_stack+1422374,int_stack+1343369, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+631744, 0.0, zero_stack,36);
 /*--- compute (k0|np) ---*/
   d1hrr3_build_np(Libderiv->CD,int_stack+1338833,int_stack+80352,int_stack+77976, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+504578, 0.0, zero_stack,36);
 /*--- compute (k0|md) ---*/
   d1hrr3_build_md(Libderiv->CD,int_stack+1435334,int_stack+1338833,int_stack+1317773, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+641824, 0.0, zero_stack,36);
 /*--- compute (k0|lf) ---*/
   d1hrr3_build_lf(Libderiv->CD,int_stack+1447214,int_stack+1435334,int_stack+1353449, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+758297, 0.0, zero_stack,36);
 /*--- compute (k0|kg) ---*/
   d1hrr3_build_kg(Libderiv->CD,int_stack+1338833,int_stack+1447214,int_stack+1422374, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+768017, 0.0, zero_stack,36);
 /*--- compute (k0|ih) ---*/
   d1hrr3_build_ih(Libderiv->CD,int_stack+1422374,int_stack+1338833,int_stack+1323713, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+780977, 0.0, zero_stack,36);
 /*--- compute (ip|ih) ---*/
   hrr1_build_ip(Libderiv->AB,int_stack+1443542,int_stack+1422374,int_stack+1368866,588);
 /*--- compute (hd|ih) ---*/
   hrr1_build_hd(Libderiv->AB,int_stack+935397,int_stack+1443542,int_stack+1385330,588);
 /*--- compute (l0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+1492934,int_stack+84420,int_stack+83160, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+520850, 0.0, zero_stack,45);
 /*--- compute (l0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+1496714,int_stack+86040,int_stack+84420, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+522110, 0.0, zero_stack,45);
 /*--- compute (l0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+1501574,int_stack+1496714,int_stack+1492934, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+12636, 0.0, zero_stack,45);
 /*--- compute (l0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+1509134,int_stack+88065,int_stack+86040, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+523730, 0.0, zero_stack,45);
 /*--- compute (l0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+1515209,int_stack+1509134,int_stack+1496714, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+16416, 0.0, zero_stack,45);
 /*--- compute (l0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+1524929,int_stack+1515209,int_stack+1501574, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+796097, 0.0, zero_stack,45);
 /*--- compute (l0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+1492934,int_stack+90540,int_stack+88065, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+525755, 0.0, zero_stack,45);
 /*--- compute (l0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+1537529,int_stack+1492934,int_stack+1509134, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+803657, 0.0, zero_stack,45);
 /*--- compute (l0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+1317773,int_stack+1537529,int_stack+1515209, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+809732, 0.0, zero_stack,45);
 /*--- compute (l0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+1500359,int_stack+1317773,int_stack+1524929, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+819452, 0.0, zero_stack,45);
 /*--- compute (l0|np) ---*/
   d1hrr3_build_np(Libderiv->CD,int_stack+1519259,int_stack+93510,int_stack+90540, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+528230, 0.0, zero_stack,45);
 /*--- compute (l0|md) ---*/
   d1hrr3_build_md(Libderiv->CD,int_stack+1333973,int_stack+1519259,int_stack+1492934, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+702629, 0.0, zero_stack,45);
 /*--- compute (l0|lf) ---*/
   d1hrr3_build_lf(Libderiv->CD,int_stack+1348823,int_stack+1333973,int_stack+1537529, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+710054, 0.0, zero_stack,45);
 /*--- compute (l0|kg) ---*/
   d1hrr3_build_kg(Libderiv->CD,int_stack+1519259,int_stack+1348823,int_stack+1317773, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+722204, 0.0, zero_stack,45);
 /*--- compute (l0|ih) ---*/
   d1hrr3_build_ih(Libderiv->CD,int_stack+1317773,int_stack+1519259,int_stack+1500359, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+738404, 0.0, zero_stack,45);
 /*--- compute (kp|ih) ---*/
   hrr1_build_kp(Libderiv->AB,int_stack+1344233,int_stack+1317773,int_stack+1422374,588);
 /*--- compute (id|ih) ---*/
   hrr1_build_id(Libderiv->AB,int_stack+1009485,int_stack+1344233,int_stack+1443542,588);
 /*--- compute (hf|ih) ---*/
   hrr1_build_hf(Libderiv->AB,int_stack+1407737,int_stack+1009485,int_stack+935397,588);
 /*--- compute (m0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+935397,int_stack+98560,int_stack+97020, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+324940, 0.0, zero_stack,55);
 /*--- compute (m0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+940017,int_stack+100540,int_stack+98560, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+328020, 0.0, zero_stack,55);
 /*--- compute (m0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+945957,int_stack+940017,int_stack+935397, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+21276, 0.0, zero_stack,55);
 /*--- compute (m0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+955197,int_stack+103015,int_stack+100540, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+331980, 0.0, zero_stack,55);
 /*--- compute (m0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+962622,int_stack+955197,int_stack+940017, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+25896, 0.0, zero_stack,55);
 /*--- compute (m0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+974502,int_stack+962622,int_stack+945957, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+832052, 0.0, zero_stack,55);
 /*--- compute (m0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+935397,int_stack+106040,int_stack+103015, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+336930, 0.0, zero_stack,55);
 /*--- compute (m0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+989902,int_stack+935397,int_stack+955197, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+31836, 0.0, zero_stack,55);
 /*--- compute (m0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+1531217,int_stack+989902,int_stack+962622, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+841292, 0.0, zero_stack,55);
 /*--- compute (m0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+944472,int_stack+1531217,int_stack+974502, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+853172, 0.0, zero_stack,55);
 /*--- compute (m0|np) ---*/
   d1hrr3_build_np(Libderiv->CD,int_stack+967572,int_stack+109670,int_stack+106040, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+342980, 0.0, zero_stack,55);
 /*--- compute (m0|md) ---*/
   d1hrr3_build_md(Libderiv->CD,int_stack+1108269,int_stack+967572,int_stack+935397, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+868572, 0.0, zero_stack,55);
 /*--- compute (m0|lf) ---*/
   d1hrr3_build_lf(Libderiv->CD,int_stack+1126419,int_stack+1108269,int_stack+989902, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+877647, 0.0, zero_stack,55);
 /*--- compute (m0|kg) ---*/
   d1hrr3_build_kg(Libderiv->CD,int_stack+967572,int_stack+1126419,int_stack+1531217, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+892497, 0.0, zero_stack,55);
 /*--- compute (m0|ih) ---*/
   d1hrr3_build_ih(Libderiv->CD,int_stack+1108269,int_stack+967572,int_stack+944472, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+912297, 0.0, zero_stack,55);
 /*--- compute (lp|ih) ---*/
   hrr1_build_lp(Libderiv->AB,int_stack+1721141,int_stack+1108269,int_stack+1317773,588);
 /*--- compute (kd|ih) ---*/
   hrr1_build_kd(Libderiv->AB,int_stack+1800521,int_stack+1721141,int_stack+1344233,588);
 /*--- compute (if|ih) ---*/
   hrr1_build_if(Libderiv->AB,int_stack+1927529,int_stack+1800521,int_stack+1009485,588);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+1721141,int_stack+114548,int_stack+113960, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+468490, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+1722905,int_stack+115304,int_stack+114548, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+469078, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+1725173,int_stack+1722905,int_stack+1721141, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+565510, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+1728701,int_stack+116249,int_stack+115304, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+469834, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+1731536,int_stack+1728701,int_stack+1722905, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+567274, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+1736072,int_stack+1731536,int_stack+1725173, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+569542, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+1721141,int_stack+117404,int_stack+116249, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+470779, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+1741952,int_stack+1721141,int_stack+1728701, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+573070, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+1747622,int_stack+1741952,int_stack+1731536, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+575905, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+1724606,int_stack+1747622,int_stack+1736072, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+580441, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|np) ---*/
   d1hrr3_build_np(Libderiv->CD,int_stack+1733426,int_stack+118790,int_stack+117404, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+471934, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|md) ---*/
   d1hrr3_build_md(Libderiv->CD,int_stack+1755182,int_stack+1733426,int_stack+1721141, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+586321, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|lf) ---*/
   d1hrr3_build_lf(Libderiv->CD,int_stack+1762112,int_stack+1755182,int_stack+1741952, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+589786, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kg) ---*/
   d1hrr3_build_kg(Libderiv->CD,int_stack+1733426,int_stack+1762112,int_stack+1747622, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+595456, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ih) ---*/
   d1hrr3_build_ih(Libderiv->CD,int_stack+1744766,int_stack+1733426,int_stack+1724606, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+603016, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+1721141,int_stack+121212,int_stack+120428, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+481426, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+1723493,int_stack+122220,int_stack+121212, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+482210, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+1726517,int_stack+1723493,int_stack+1721141, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+611836, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+1731221,int_stack+123480,int_stack+122220, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+483218, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+1735001,int_stack+1731221,int_stack+1723493, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+614188, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+1757114,int_stack+1735001,int_stack+1726517, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+617212, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+1721141,int_stack+125020,int_stack+123480, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+484478, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+1764954,int_stack+1721141,int_stack+1731221, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+621916, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+1772514,int_stack+1764954,int_stack+1735001, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+625696, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+1725761,int_stack+1772514,int_stack+1757114, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+647809, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|np) ---*/
   d1hrr3_build_np(Libderiv->CD,int_stack+1757114,int_stack+126868,int_stack+125020, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+486018, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|md) ---*/
   d1hrr3_build_md(Libderiv->CD,int_stack+1782594,int_stack+1757114,int_stack+1721141, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+655649, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|lf) ---*/
   d1hrr3_build_lf(Libderiv->CD,int_stack+1791834,int_stack+1782594,int_stack+1764954, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+660269, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kg) ---*/
   d1hrr3_build_kg(Libderiv->CD,int_stack+1757114,int_stack+1791834,int_stack+1772514, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+667829, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ih) ---*/
   d1hrr3_build_ih(Libderiv->CD,int_stack+1772234,int_stack+1757114,int_stack+1725761, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+677909, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (hp|ih) ---*/
   hrr1_build_hp(Libderiv->AB,int_stack+1788698,int_stack+1772234,int_stack+1744766,588);
 /*--- compute (k0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+1721141,int_stack+130060,int_stack+129052, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+498674, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+1724165,int_stack+131356,int_stack+130060, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+499682, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+1728053,int_stack+1724165,int_stack+1721141, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+689669, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+1734101,int_stack+132976,int_stack+131356, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+500978, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+1738961,int_stack+1734101,int_stack+1724165, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+692693, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+1746737,int_stack+1738961,int_stack+1728053, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+696581, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+1721141,int_stack+134956,int_stack+132976, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+502598, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+1756817,int_stack+1721141,int_stack+1734101, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+0, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+1825742,int_stack+1756817,int_stack+1738961, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+4860, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+1727081,int_stack+1825742,int_stack+1746737, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+631744, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|np) ---*/
   d1hrr3_build_np(Libderiv->CD,int_stack+1742201,int_stack+137332,int_stack+134956, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+504578, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|md) ---*/
   d1hrr3_build_md(Libderiv->CD,int_stack+1838702,int_stack+1742201,int_stack+1721141, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+641824, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|lf) ---*/
   d1hrr3_build_lf(Libderiv->CD,int_stack+1850582,int_stack+1838702,int_stack+1756817, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+758297, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|kg) ---*/
   d1hrr3_build_kg(Libderiv->CD,int_stack+1742201,int_stack+1850582,int_stack+1825742, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+768017, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|ih) ---*/
   d1hrr3_build_ih(Libderiv->CD,int_stack+1825742,int_stack+1742201,int_stack+1727081, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+780977, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (ip|ih) ---*/
   hrr1_build_ip(Libderiv->AB,int_stack+1846910,int_stack+1825742,int_stack+1772234,588);
 /*--- compute (hd|ih) ---*/
   hrr1_build_hd(Libderiv->AB,int_stack+1317773,int_stack+1846910,int_stack+1788698,588);
 /*--- compute (l0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+1896302,int_stack+141400,int_stack+140140, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+520850, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+1900082,int_stack+143020,int_stack+141400, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+522110, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+1904942,int_stack+1900082,int_stack+1896302, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+12636, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+1912502,int_stack+145045,int_stack+143020, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+523730, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+1721141,int_stack+1912502,int_stack+1900082, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+16416, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+1730861,int_stack+1721141,int_stack+1904942, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+796097, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+1896302,int_stack+147520,int_stack+145045, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+525755, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+1743461,int_stack+1896302,int_stack+1912502, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+803657, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+1903727,int_stack+1743461,int_stack+1721141, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+809732, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+1755611,int_stack+1903727,int_stack+1730861, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+819452, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|np) ---*/
   d1hrr3_build_np(Libderiv->CD,int_stack+1721141,int_stack+150490,int_stack+147520, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+528230, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|md) ---*/
   d1hrr3_build_md(Libderiv->CD,int_stack+1774511,int_stack+1721141,int_stack+1896302, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+702629, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|lf) ---*/
   d1hrr3_build_lf(Libderiv->CD,int_stack+1721141,int_stack+1774511,int_stack+1743461, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+710054, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|kg) ---*/
   d1hrr3_build_kg(Libderiv->CD,int_stack+1774511,int_stack+1721141,int_stack+1903727, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+722204, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|ih) ---*/
   d1hrr3_build_ih(Libderiv->CD,int_stack+1721141,int_stack+1774511,int_stack+1755611, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+738404, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (kp|ih) ---*/
   hrr1_build_kp(Libderiv->AB,int_stack+1747601,int_stack+1721141,int_stack+1825742,588);
 /*--- compute (id|ih) ---*/
   hrr1_build_id(Libderiv->AB,int_stack+935397,int_stack+1747601,int_stack+1846910,588);
 /*--- compute (hf|ih) ---*/
   hrr1_build_hf(Libderiv->AB,int_stack+1034181,int_stack+935397,int_stack+1317773,588);
 /*--- compute (m0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+1317773,int_stack+155540,int_stack+154000, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+324940, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+1322393,int_stack+157520,int_stack+155540, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+328020, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+1328333,int_stack+1322393,int_stack+1317773, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+21276, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+1337573,int_stack+159995,int_stack+157520, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+331980, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+1344998,int_stack+1337573,int_stack+1322393, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+25896, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+1356878,int_stack+1344998,int_stack+1328333, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+832052, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+1317773,int_stack+163020,int_stack+159995, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+336930, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+1372278,int_stack+1317773,int_stack+1337573, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+31836, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+1387128,int_stack+1372278,int_stack+1344998, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+841292, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+1326848,int_stack+1387128,int_stack+1356878, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+853172, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|np) ---*/
   d1hrr3_build_np(Libderiv->CD,int_stack+1349948,int_stack+166650,int_stack+163020, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+342980, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|md) ---*/
   d1hrr3_build_md(Libderiv->CD,int_stack+1811105,int_stack+1349948,int_stack+1317773, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+868572, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|lf) ---*/
   d1hrr3_build_lf(Libderiv->CD,int_stack+1829255,int_stack+1811105,int_stack+1372278, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+877647, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|kg) ---*/
   d1hrr3_build_kg(Libderiv->CD,int_stack+1349948,int_stack+1829255,int_stack+1387128, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+892497, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|ih) ---*/
   d1hrr3_build_ih(Libderiv->CD,int_stack+1811105,int_stack+1349948,int_stack+1326848, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+912297, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (lp|ih) ---*/
   hrr1_build_lp(Libderiv->AB,int_stack+1843445,int_stack+1811105,int_stack+1721141,588);
 /*--- compute (kd|ih) ---*/
   hrr1_build_kd(Libderiv->AB,int_stack+39261,int_stack+1843445,int_stack+1747601,588);
 /*--- compute (if|ih) ---*/
   hrr1_build_if(Libderiv->AB,int_stack+1721141,int_stack+39261,int_stack+935397,588);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+935397,int_stack+171528,int_stack+170940, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+468490, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+937161,int_stack+172284,int_stack+171528, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+469078, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+939429,int_stack+937161,int_stack+935397, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+565510, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+942957,int_stack+173229,int_stack+172284, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+469834, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+945792,int_stack+942957,int_stack+937161, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+567274, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+950328,int_stack+945792,int_stack+939429, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+569542, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+935397,int_stack+174384,int_stack+173229, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+470779, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+956208,int_stack+935397,int_stack+942957, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+573070, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+961878,int_stack+956208,int_stack+945792, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+575905, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+938862,int_stack+961878,int_stack+950328, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+580441, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|np) ---*/
   d1hrr3_build_np(Libderiv->CD,int_stack+947682,int_stack+175770,int_stack+174384, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+471934, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|md) ---*/
   d1hrr3_build_md(Libderiv->CD,int_stack+969438,int_stack+947682,int_stack+935397, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+586321, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|lf) ---*/
   d1hrr3_build_lf(Libderiv->CD,int_stack+976368,int_stack+969438,int_stack+956208, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+589786, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kg) ---*/
   d1hrr3_build_kg(Libderiv->CD,int_stack+947682,int_stack+976368,int_stack+961878, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+595456, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ih) ---*/
   d1hrr3_build_ih(Libderiv->CD,int_stack+959022,int_stack+947682,int_stack+938862, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+603016, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+935397,int_stack+178192,int_stack+177408, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+481426, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+937749,int_stack+179200,int_stack+178192, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+482210, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+940773,int_stack+937749,int_stack+935397, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+611836, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+945477,int_stack+180460,int_stack+179200, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+483218, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+949257,int_stack+945477,int_stack+937749, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+614188, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+971370,int_stack+949257,int_stack+940773, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+617212, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+935397,int_stack+182000,int_stack+180460, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+484478, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+979210,int_stack+935397,int_stack+945477, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+621916, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+986770,int_stack+979210,int_stack+949257, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+625696, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+940017,int_stack+986770,int_stack+971370, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+647809, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|np) ---*/
   d1hrr3_build_np(Libderiv->CD,int_stack+971370,int_stack+183848,int_stack+182000, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+486018, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|md) ---*/
   d1hrr3_build_md(Libderiv->CD,int_stack+996850,int_stack+971370,int_stack+935397, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+655649, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|lf) ---*/
   d1hrr3_build_lf(Libderiv->CD,int_stack+1006090,int_stack+996850,int_stack+979210, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+660269, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kg) ---*/
   d1hrr3_build_kg(Libderiv->CD,int_stack+971370,int_stack+1006090,int_stack+986770, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+667829, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ih) ---*/
   d1hrr3_build_ih(Libderiv->CD,int_stack+986490,int_stack+971370,int_stack+940017, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+677909, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (hp|ih) ---*/
   hrr1_build_hp(Libderiv->AB,int_stack+39261,int_stack+986490,int_stack+959022,588);
 /*--- compute (k0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+935397,int_stack+187040,int_stack+186032, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+498674, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+938421,int_stack+188336,int_stack+187040, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+499682, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+942309,int_stack+938421,int_stack+935397, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+689669, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+948357,int_stack+189956,int_stack+188336, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+500978, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+953217,int_stack+948357,int_stack+938421, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+692693, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+960993,int_stack+953217,int_stack+942309, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+696581, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+935397,int_stack+191936,int_stack+189956, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+502598, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+971073,int_stack+935397,int_stack+948357, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+0, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+1002954,int_stack+971073,int_stack+953217, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+4860, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+941337,int_stack+1002954,int_stack+960993, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+631744, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|np) ---*/
   d1hrr3_build_np(Libderiv->CD,int_stack+956457,int_stack+194312,int_stack+191936, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+504578, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|md) ---*/
   d1hrr3_build_md(Libderiv->CD,int_stack+1015914,int_stack+956457,int_stack+935397, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+641824, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|lf) ---*/
   d1hrr3_build_lf(Libderiv->CD,int_stack+76305,int_stack+1015914,int_stack+971073, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+758297, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|kg) ---*/
   d1hrr3_build_kg(Libderiv->CD,int_stack+956457,int_stack+76305,int_stack+1002954, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+768017, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|ih) ---*/
   d1hrr3_build_ih(Libderiv->CD,int_stack+1002954,int_stack+956457,int_stack+941337, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+780977, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (ip|ih) ---*/
   hrr1_build_ip(Libderiv->AB,int_stack+76305,int_stack+1002954,int_stack+986490,588);
 /*--- compute (hd|ih) ---*/
   hrr1_build_hd(Libderiv->AB,int_stack+1317773,int_stack+76305,int_stack+39261,588);
 /*--- compute (l0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+39261,int_stack+198380,int_stack+197120, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+520850, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+43041,int_stack+200000,int_stack+198380, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+522110, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+47901,int_stack+43041,int_stack+39261, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+12636, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+55461,int_stack+202025,int_stack+200000, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+523730, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+61536,int_stack+55461,int_stack+43041, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+16416, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+125697,int_stack+61536,int_stack+47901, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+796097, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+39261,int_stack+204500,int_stack+202025, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+525755, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+138297,int_stack+39261,int_stack+55461, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+803657, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+150447,int_stack+138297,int_stack+61536, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+809732, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+46686,int_stack+150447,int_stack+125697, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+819452, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|np) ---*/
   d1hrr3_build_np(Libderiv->CD,int_stack+125697,int_stack+207470,int_stack+204500, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+528230, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|md) ---*/
   d1hrr3_build_md(Libderiv->CD,int_stack+166647,int_stack+125697,int_stack+39261, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+702629, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|lf) ---*/
   d1hrr3_build_lf(Libderiv->CD,int_stack+181497,int_stack+166647,int_stack+138297, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+710054, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|kg) ---*/
   d1hrr3_build_kg(Libderiv->CD,int_stack+125697,int_stack+181497,int_stack+150447, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+722204, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|ih) ---*/
   d1hrr3_build_ih(Libderiv->CD,int_stack+149997,int_stack+125697,int_stack+46686, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+738404, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (kp|ih) ---*/
   hrr1_build_kp(Libderiv->AB,int_stack+935397,int_stack+149997,int_stack+1002954,588);
 /*--- compute (id|ih) ---*/
   hrr1_build_id(Libderiv->AB,int_stack+2092169,int_stack+935397,int_stack+76305,588);
 /*--- compute (hf|ih) ---*/
   hrr1_build_hf(Libderiv->AB,int_stack+2190953,int_stack+2092169,int_stack+1317773,588);
 /*--- compute (m0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+1317773,int_stack+212520,int_stack+210980, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+324940, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+1322393,int_stack+214500,int_stack+212520, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+328020, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+1328333,int_stack+1322393,int_stack+1317773, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+21276, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+1337573,int_stack+216975,int_stack+214500, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+331980, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+1344998,int_stack+1337573,int_stack+1322393, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+25896, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+1356878,int_stack+1344998,int_stack+1328333, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+832052, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+1317773,int_stack+220000,int_stack+216975, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+336930, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+1372278,int_stack+1317773,int_stack+1337573, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+31836, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+1387128,int_stack+1372278,int_stack+1344998, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+841292, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+1326848,int_stack+1387128,int_stack+1356878, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+853172, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|np) ---*/
   d1hrr3_build_np(Libderiv->CD,int_stack+1349948,int_stack+223630,int_stack+220000, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+342980, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|md) ---*/
   d1hrr3_build_md(Libderiv->CD,int_stack+39261,int_stack+1349948,int_stack+1317773, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+868572, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|lf) ---*/
   d1hrr3_build_lf(Libderiv->CD,int_stack+57411,int_stack+39261,int_stack+1372278, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+877647, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|kg) ---*/
   d1hrr3_build_kg(Libderiv->CD,int_stack+1349948,int_stack+57411,int_stack+1387128, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+892497, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|ih) ---*/
   d1hrr3_build_ih(Libderiv->CD,int_stack+39261,int_stack+1349948,int_stack+1326848, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+912297, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (lp|ih) ---*/
   hrr1_build_lp(Libderiv->AB,int_stack+1317773,int_stack+39261,int_stack+149997,588);
 /*--- compute (kd|ih) ---*/
   hrr1_build_kd(Libderiv->AB,int_stack+39261,int_stack+1317773,int_stack+935397,588);
 /*--- compute (if|ih) ---*/
   hrr1_build_if(Libderiv->AB,int_stack+2314433,int_stack+39261,int_stack+2092169,588);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+2092169,int_stack+228508,int_stack+227920, 0.0, zero_stack, 1.0, int_stack+468490, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+2093933,int_stack+229264,int_stack+228508, 0.0, zero_stack, 1.0, int_stack+469078, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+2096201,int_stack+2093933,int_stack+2092169, 0.0, zero_stack, 1.0, int_stack+565510, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+2099729,int_stack+230209,int_stack+229264, 0.0, zero_stack, 1.0, int_stack+469834, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+2102564,int_stack+2099729,int_stack+2093933, 0.0, zero_stack, 1.0, int_stack+567274, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+2107100,int_stack+2102564,int_stack+2096201, 0.0, zero_stack, 1.0, int_stack+569542, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+2092169,int_stack+231364,int_stack+230209, 0.0, zero_stack, 1.0, int_stack+470779, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+2112980,int_stack+2092169,int_stack+2099729, 0.0, zero_stack, 1.0, int_stack+573070, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+2118650,int_stack+2112980,int_stack+2102564, 0.0, zero_stack, 1.0, int_stack+575905, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+2095634,int_stack+2118650,int_stack+2107100, 0.0, zero_stack, 1.0, int_stack+580441, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|np) ---*/
   d1hrr3_build_np(Libderiv->CD,int_stack+2104454,int_stack+232750,int_stack+231364, 0.0, zero_stack, 1.0, int_stack+471934, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|md) ---*/
   d1hrr3_build_md(Libderiv->CD,int_stack+2126210,int_stack+2104454,int_stack+2092169, 0.0, zero_stack, 1.0, int_stack+586321, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|lf) ---*/
   d1hrr3_build_lf(Libderiv->CD,int_stack+2133140,int_stack+2126210,int_stack+2112980, 0.0, zero_stack, 1.0, int_stack+589786, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kg) ---*/
   d1hrr3_build_kg(Libderiv->CD,int_stack+2104454,int_stack+2133140,int_stack+2118650, 0.0, zero_stack, 1.0, int_stack+595456, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ih) ---*/
   d1hrr3_build_ih(Libderiv->CD,int_stack+2115794,int_stack+2104454,int_stack+2095634, 0.0, zero_stack, 1.0, int_stack+603016, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+2092169,int_stack+235172,int_stack+234388, 0.0, zero_stack, 1.0, int_stack+481426, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+2094521,int_stack+236180,int_stack+235172, 0.0, zero_stack, 1.0, int_stack+482210, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+2097545,int_stack+2094521,int_stack+2092169, 0.0, zero_stack, 1.0, int_stack+611836, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+2102249,int_stack+237440,int_stack+236180, 0.0, zero_stack, 1.0, int_stack+483218, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+2106029,int_stack+2102249,int_stack+2094521, 0.0, zero_stack, 1.0, int_stack+614188, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+2128142,int_stack+2106029,int_stack+2097545, 0.0, zero_stack, 1.0, int_stack+617212, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+2092169,int_stack+238980,int_stack+237440, 0.0, zero_stack, 1.0, int_stack+484478, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+2135982,int_stack+2092169,int_stack+2102249, 0.0, zero_stack, 1.0, int_stack+621916, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+2143542,int_stack+2135982,int_stack+2106029, 0.0, zero_stack, 1.0, int_stack+625696, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+2096789,int_stack+2143542,int_stack+2128142, 0.0, zero_stack, 1.0, int_stack+647809, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|np) ---*/
   d1hrr3_build_np(Libderiv->CD,int_stack+2128142,int_stack+240828,int_stack+238980, 0.0, zero_stack, 1.0, int_stack+486018, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|md) ---*/
   d1hrr3_build_md(Libderiv->CD,int_stack+2153622,int_stack+2128142,int_stack+2092169, 0.0, zero_stack, 1.0, int_stack+655649, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|lf) ---*/
   d1hrr3_build_lf(Libderiv->CD,int_stack+2162862,int_stack+2153622,int_stack+2135982, 0.0, zero_stack, 1.0, int_stack+660269, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kg) ---*/
   d1hrr3_build_kg(Libderiv->CD,int_stack+2128142,int_stack+2162862,int_stack+2143542, 0.0, zero_stack, 1.0, int_stack+667829, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ih) ---*/
   d1hrr3_build_ih(Libderiv->CD,int_stack+2143262,int_stack+2128142,int_stack+2096789, 0.0, zero_stack, 1.0, int_stack+677909, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (hp|ih) ---*/
   hrr1_build_hp(Libderiv->AB,int_stack+39261,int_stack+2143262,int_stack+2115794,588);
 /*--- compute (k0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+2092169,int_stack+244020,int_stack+243012, 0.0, zero_stack, 1.0, int_stack+498674, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+2095193,int_stack+245316,int_stack+244020, 0.0, zero_stack, 1.0, int_stack+499682, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+2099081,int_stack+2095193,int_stack+2092169, 0.0, zero_stack, 1.0, int_stack+689669, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+2105129,int_stack+246936,int_stack+245316, 0.0, zero_stack, 1.0, int_stack+500978, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+2109989,int_stack+2105129,int_stack+2095193, 0.0, zero_stack, 1.0, int_stack+692693, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+2117765,int_stack+2109989,int_stack+2099081, 0.0, zero_stack, 1.0, int_stack+696581, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+2092169,int_stack+248916,int_stack+246936, 0.0, zero_stack, 1.0, int_stack+502598, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+2127845,int_stack+2092169,int_stack+2105129, 0.0, zero_stack, 1.0, int_stack+0, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+2159726,int_stack+2127845,int_stack+2109989, 0.0, zero_stack, 1.0, int_stack+4860, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+2098109,int_stack+2159726,int_stack+2117765, 0.0, zero_stack, 1.0, int_stack+631744, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|np) ---*/
   d1hrr3_build_np(Libderiv->CD,int_stack+2113229,int_stack+251292,int_stack+248916, 0.0, zero_stack, 1.0, int_stack+504578, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|md) ---*/
   d1hrr3_build_md(Libderiv->CD,int_stack+2172686,int_stack+2113229,int_stack+2092169, 0.0, zero_stack, 1.0, int_stack+641824, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|lf) ---*/
   d1hrr3_build_lf(Libderiv->CD,int_stack+76305,int_stack+2172686,int_stack+2127845, 0.0, zero_stack, 1.0, int_stack+758297, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|kg) ---*/
   d1hrr3_build_kg(Libderiv->CD,int_stack+2113229,int_stack+76305,int_stack+2159726, 0.0, zero_stack, 1.0, int_stack+768017, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|ih) ---*/
   d1hrr3_build_ih(Libderiv->CD,int_stack+2159726,int_stack+2113229,int_stack+2098109, 0.0, zero_stack, 1.0, int_stack+780977, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (ip|ih) ---*/
   hrr1_build_ip(Libderiv->AB,int_stack+76305,int_stack+2159726,int_stack+2143262,588);
 /*--- compute (hd|ih) ---*/
   hrr1_build_hd(Libderiv->AB,int_stack+125697,int_stack+76305,int_stack+39261,588);
 /*--- compute (l0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+39261,int_stack+255360,int_stack+254100, 0.0, zero_stack, 1.0, int_stack+520850, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+43041,int_stack+256980,int_stack+255360, 0.0, zero_stack, 1.0, int_stack+522110, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+47901,int_stack+43041,int_stack+39261, 0.0, zero_stack, 1.0, int_stack+12636, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+55461,int_stack+259005,int_stack+256980, 0.0, zero_stack, 1.0, int_stack+523730, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+61536,int_stack+55461,int_stack+43041, 0.0, zero_stack, 1.0, int_stack+16416, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+199785,int_stack+61536,int_stack+47901, 0.0, zero_stack, 1.0, int_stack+796097, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+39261,int_stack+261480,int_stack+259005, 0.0, zero_stack, 1.0, int_stack+525755, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+212385,int_stack+39261,int_stack+55461, 0.0, zero_stack, 1.0, int_stack+803657, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+224535,int_stack+212385,int_stack+61536, 0.0, zero_stack, 1.0, int_stack+809732, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+46686,int_stack+224535,int_stack+199785, 0.0, zero_stack, 1.0, int_stack+819452, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|np) ---*/
   d1hrr3_build_np(Libderiv->CD,int_stack+199785,int_stack+264450,int_stack+261480, 0.0, zero_stack, 1.0, int_stack+528230, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|md) ---*/
   d1hrr3_build_md(Libderiv->CD,int_stack+240735,int_stack+199785,int_stack+39261, 0.0, zero_stack, 1.0, int_stack+702629, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|lf) ---*/
   d1hrr3_build_lf(Libderiv->CD,int_stack+2092169,int_stack+240735,int_stack+212385, 0.0, zero_stack, 1.0, int_stack+710054, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|kg) ---*/
   d1hrr3_build_kg(Libderiv->CD,int_stack+240735,int_stack+2092169,int_stack+224535, 0.0, zero_stack, 1.0, int_stack+722204, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|ih) ---*/
   d1hrr3_build_ih(Libderiv->CD,int_stack+2092169,int_stack+240735,int_stack+46686, 0.0, zero_stack, 1.0, int_stack+738404, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (kp|ih) ---*/
   hrr1_build_kp(Libderiv->AB,int_stack+199785,int_stack+2092169,int_stack+2159726,588);
 /*--- compute (id|ih) ---*/
   hrr1_build_id(Libderiv->AB,int_stack+935397,int_stack+199785,int_stack+76305,588);
 /*--- compute (hf|ih) ---*/
   hrr1_build_hf(Libderiv->AB,int_stack+2479073,int_stack+935397,int_stack+125697,588);
 /*--- compute (m0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+2118629,int_stack+269500,int_stack+267960, 0.0, zero_stack, 1.0, int_stack+324940, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+2123249,int_stack+271480,int_stack+269500, 0.0, zero_stack, 1.0, int_stack+328020, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+2129189,int_stack+2123249,int_stack+2118629, 0.0, zero_stack, 1.0, int_stack+21276, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+2138429,int_stack+273955,int_stack+271480, 0.0, zero_stack, 1.0, int_stack+331980, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+2145854,int_stack+2138429,int_stack+2123249, 0.0, zero_stack, 1.0, int_stack+25896, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+2157734,int_stack+2145854,int_stack+2129189, 0.0, zero_stack, 1.0, int_stack+832052, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+2118629,int_stack+276980,int_stack+273955, 0.0, zero_stack, 1.0, int_stack+336930, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+2173134,int_stack+2118629,int_stack+2138429, 0.0, zero_stack, 1.0, int_stack+31836, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+39261,int_stack+2173134,int_stack+2145854, 0.0, zero_stack, 1.0, int_stack+841292, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+2127704,int_stack+39261,int_stack+2157734, 0.0, zero_stack, 1.0, int_stack+853172, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|np) ---*/
   d1hrr3_build_np(Libderiv->CD,int_stack+2150804,int_stack+280610,int_stack+276980, 0.0, zero_stack, 1.0, int_stack+342980, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|md) ---*/
   d1hrr3_build_md(Libderiv->CD,int_stack+59061,int_stack+2150804,int_stack+2118629, 0.0, zero_stack, 1.0, int_stack+868572, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|lf) ---*/
   d1hrr3_build_lf(Libderiv->CD,int_stack+77211,int_stack+59061,int_stack+2173134, 0.0, zero_stack, 1.0, int_stack+877647, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|kg) ---*/
   d1hrr3_build_kg(Libderiv->CD,int_stack+2150804,int_stack+77211,int_stack+39261, 0.0, zero_stack, 1.0, int_stack+892497, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|ih) ---*/
   d1hrr3_build_ih(Libderiv->CD,int_stack+39261,int_stack+2150804,int_stack+2127704, 0.0, zero_stack, 1.0, int_stack+912297, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (lp|ih) ---*/
   hrr1_build_lp(Libderiv->AB,int_stack+71601,int_stack+39261,int_stack+2092169,588);
 /*--- compute (kd|ih) ---*/
   hrr1_build_kd(Libderiv->AB,int_stack+2602553,int_stack+71601,int_stack+199785,588);
 /*--- compute (if|ih) ---*/
   hrr1_build_if(Libderiv->AB,int_stack+39261,int_stack+2602553,int_stack+935397,588);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+935397,int_stack+285488,int_stack+284900, 1.0, int_stack+468490, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+937161,int_stack+286244,int_stack+285488, 1.0, int_stack+469078, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+939429,int_stack+937161,int_stack+935397, 1.0, int_stack+565510, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+942957,int_stack+287189,int_stack+286244, 1.0, int_stack+469834, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+945792,int_stack+942957,int_stack+937161, 1.0, int_stack+567274, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+950328,int_stack+945792,int_stack+939429, 1.0, int_stack+569542, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+565510,int_stack+288344,int_stack+287189, 1.0, int_stack+470779, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+935397,int_stack+565510,int_stack+942957, 1.0, int_stack+573070, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+956208,int_stack+935397,int_stack+945792, 1.0, int_stack+575905, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+568975,int_stack+956208,int_stack+950328, 1.0, int_stack+580441, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|np) ---*/
   d1hrr3_build_np(Libderiv->CD,int_stack+577795,int_stack+289730,int_stack+288344, 1.0, int_stack+471934, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|md) ---*/
   d1hrr3_build_md(Libderiv->CD,int_stack+941067,int_stack+577795,int_stack+565510, 1.0, int_stack+586321, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|lf) ---*/
   d1hrr3_build_lf(Libderiv->CD,int_stack+963768,int_stack+941067,int_stack+935397, 1.0, int_stack+589786, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kg) ---*/
   d1hrr3_build_kg(Libderiv->CD,int_stack+935397,int_stack+963768,int_stack+956208, 1.0, int_stack+595456, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ih) ---*/
   d1hrr3_build_ih(Libderiv->CD,int_stack+946737,int_stack+935397,int_stack+568975, 1.0, int_stack+603016, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+935397,int_stack+292152,int_stack+291368, 1.0, int_stack+481426, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+937749,int_stack+293160,int_stack+292152, 1.0, int_stack+482210, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+940773,int_stack+937749,int_stack+935397, 1.0, int_stack+611836, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+959085,int_stack+294420,int_stack+293160, 1.0, int_stack+483218, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+962865,int_stack+959085,int_stack+937749, 1.0, int_stack+614188, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+968913,int_stack+962865,int_stack+940773, 1.0, int_stack+617212, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+611836,int_stack+295960,int_stack+294420, 1.0, int_stack+484478, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+935397,int_stack+611836,int_stack+959085, 1.0, int_stack+621916, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+976753,int_stack+935397,int_stack+962865, 1.0, int_stack+625696, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+616456,int_stack+976753,int_stack+968913, 1.0, int_stack+647809, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|np) ---*/
   d1hrr3_build_np(Libderiv->CD,int_stack+959085,int_stack+297808,int_stack+295960, 1.0, int_stack+486018, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|md) ---*/
   d1hrr3_build_md(Libderiv->CD,int_stack+964629,int_stack+959085,int_stack+611836, 1.0, int_stack+655649, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|lf) ---*/
   d1hrr3_build_lf(Libderiv->CD,int_stack+986833,int_stack+964629,int_stack+935397, 1.0, int_stack+660269, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kg) ---*/
   d1hrr3_build_kg(Libderiv->CD,int_stack+959085,int_stack+986833,int_stack+976753, 1.0, int_stack+667829, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ih) ---*/
   d1hrr3_build_ih(Libderiv->CD,int_stack+974205,int_stack+959085,int_stack+616456, 1.0, int_stack+677909, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (hp|ih) ---*/
   hrr1_build_hp(Libderiv->AB,int_stack+990669,int_stack+974205,int_stack+946737,588);
 /*--- compute (k0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+935397,int_stack+301000,int_stack+299992, 1.0, int_stack+498674, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+938421,int_stack+302296,int_stack+301000, 1.0, int_stack+499682, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+942309,int_stack+938421,int_stack+935397, 1.0, int_stack+689669, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+948357,int_stack+303916,int_stack+302296, 1.0, int_stack+500978, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+953217,int_stack+948357,int_stack+938421, 1.0, int_stack+692693, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+960993,int_stack+953217,int_stack+942309, 1.0, int_stack+696581, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+689669,int_stack+305896,int_stack+303916, 1.0, int_stack+502598, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+935397,int_stack+689669,int_stack+948357, 1.0, int_stack+0, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+611836,int_stack+935397,int_stack+953217, 1.0, int_stack+4860, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+945117,int_stack+611836,int_stack+960993, 1.0, int_stack+631744, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|np) ---*/
   d1hrr3_build_np(Libderiv->CD,int_stack+0,int_stack+308272,int_stack+305896, 1.0, int_stack+504578, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|md) ---*/
   d1hrr3_build_md(Libderiv->CD,int_stack+960237,int_stack+0,int_stack+689669, 1.0, int_stack+641824, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|lf) ---*/
   d1hrr3_build_lf(Libderiv->CD,int_stack+624796,int_stack+960237,int_stack+935397, 1.0, int_stack+758297, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|kg) ---*/
   d1hrr3_build_kg(Libderiv->CD,int_stack+565510,int_stack+624796,int_stack+611836, 1.0, int_stack+768017, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|ih) ---*/
   d1hrr3_build_ih(Libderiv->CD,int_stack+611836,int_stack+565510,int_stack+945117, 1.0, int_stack+780977, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (ip|ih) ---*/
   hrr1_build_ip(Libderiv->AB,int_stack+2602553,int_stack+611836,int_stack+974205,588);
 /*--- compute (hd|ih) ---*/
   hrr1_build_hd(Libderiv->AB,int_stack+2651945,int_stack+2602553,int_stack+990669,588);
 /*--- compute (l0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+565510,int_stack+312340,int_stack+311080, 1.0, int_stack+520850, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+569290,int_stack+313960,int_stack+312340, 1.0, int_stack+522110, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+574150,int_stack+569290,int_stack+565510, 1.0, int_stack+12636, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+633004,int_stack+315985,int_stack+313960, 1.0, int_stack+523730, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+935397,int_stack+633004,int_stack+569290, 1.0, int_stack+16416, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+945117,int_stack+935397,int_stack+574150, 1.0, int_stack+796097, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+796097,int_stack+318460,int_stack+315985, 1.0, int_stack+525755, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+565510,int_stack+796097,int_stack+633004, 1.0, int_stack+803657, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+957717,int_stack+565510,int_stack+935397, 1.0, int_stack+809732, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+973917,int_stack+957717,int_stack+945117, 1.0, int_stack+819452, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|np) ---*/
   d1hrr3_build_np(Libderiv->CD,int_stack+935397,int_stack+321430,int_stack+318460, 1.0, int_stack+528230, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|md) ---*/
   d1hrr3_build_md(Libderiv->CD,int_stack+803522,int_stack+935397,int_stack+796097, 1.0, int_stack+702629, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|lf) ---*/
   d1hrr3_build_lf(Libderiv->CD,int_stack+935397,int_stack+803522,int_stack+565510, 1.0, int_stack+710054, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|kg) ---*/
   d1hrr3_build_kg(Libderiv->CD,int_stack+796097,int_stack+935397,int_stack+957717, 1.0, int_stack+722204, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|ih) ---*/
   d1hrr3_build_ih(Libderiv->CD,int_stack+935397,int_stack+796097,int_stack+973917, 1.0, int_stack+738404, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (kp|ih) ---*/
   hrr1_build_kp(Libderiv->AB,int_stack+961857,int_stack+935397,int_stack+611836,588);
 /*--- compute (id|ih) ---*/
   hrr1_build_id(Libderiv->AB,int_stack+2092169,int_stack+961857,int_stack+2602553,588);
 /*--- compute (hf|ih) ---*/
   hrr1_build_hf(Libderiv->AB,int_stack+2726033,int_stack+2092169,int_stack+2651945,588);
 /*--- compute (m0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+2602553,int_stack+330000,int_stack+326480, 1.0, int_stack+324940, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+2607173,int_stack+334455,int_stack+330000, 1.0, int_stack+328020, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+2613113,int_stack+2607173,int_stack+2602553, 1.0, int_stack+21276, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+2622353,int_stack+339955,int_stack+334455, 1.0, int_stack+331980, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+2629778,int_stack+2622353,int_stack+2607173, 1.0, int_stack+25896, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+2641658,int_stack+2629778,int_stack+2613113, 1.0, int_stack+832052, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+2602553,int_stack+346610,int_stack+339955, 1.0, int_stack+336930, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+2657058,int_stack+2602553,int_stack+2622353, 1.0, int_stack+31836, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+2671908,int_stack+2657058,int_stack+2629778, 1.0, int_stack+841292, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+2611628,int_stack+2671908,int_stack+2641658, 1.0, int_stack+853172, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|np) ---*/
   d1hrr3_build_np(Libderiv->CD,int_stack+2634728,int_stack+350240,int_stack+346610, 1.0, int_stack+342980, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|md) ---*/
   d1hrr3_build_md(Libderiv->CD,int_stack+2691708,int_stack+2634728,int_stack+2602553, 1.0, int_stack+868572, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|lf) ---*/
   d1hrr3_build_lf(Libderiv->CD,int_stack+611836,int_stack+2691708,int_stack+2657058, 1.0, int_stack+877647, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|kg) ---*/
   d1hrr3_build_kg(Libderiv->CD,int_stack+2691708,int_stack+611836,int_stack+2671908, 1.0, int_stack+892497, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|ih) ---*/
   d1hrr3_build_ih(Libderiv->CD,int_stack+2634728,int_stack+2691708,int_stack+2611628, 1.0, int_stack+912297, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (lp|ih) ---*/
   hrr1_build_lp(Libderiv->AB,int_stack+796097,int_stack+2634728,int_stack+935397,588);
 /*--- compute (kd|ih) ---*/
   hrr1_build_kd(Libderiv->AB,int_stack+203901,int_stack+796097,int_stack+961857,588);
 /*--- compute (if|ih) ---*/
   hrr1_build_if(Libderiv->AB,int_stack+796097,int_stack+203901,int_stack+2092169,588);
 /*--- compute (h0|np) ---*/
   hrr3_build_np(Libderiv->CD,int_stack+2092169,int_stack+473320,int_stack+471934,21);
 /*--- compute (h0|md) ---*/
   hrr3_build_md(Libderiv->CD,int_stack+2096327,int_stack+2092169,int_stack+586321,21);
 /*--- compute (h0|lf) ---*/
   hrr3_build_lf(Libderiv->CD,int_stack+2103257,int_stack+2096327,int_stack+589786,21);
 /*--- compute (h0|kg) ---*/
   hrr3_build_kg(Libderiv->CD,int_stack+2112707,int_stack+2103257,int_stack+595456,21);
 /*--- compute (h0|ih) ---*/
   hrr3_build_ih(Libderiv->CD,int_stack+2092169,int_stack+2112707,int_stack+603016,21);
 /*--- compute (i0|np) ---*/
   hrr3_build_np(Libderiv->CD,int_stack+2104517,int_stack+487866,int_stack+486018,28);
 /*--- compute (i0|md) ---*/
   hrr3_build_md(Libderiv->CD,int_stack+2110061,int_stack+2104517,int_stack+655649,28);
 /*--- compute (i0|lf) ---*/
   hrr3_build_lf(Libderiv->CD,int_stack+2119301,int_stack+2110061,int_stack+660269,28);
 /*--- compute (i0|kg) ---*/
   hrr3_build_kg(Libderiv->CD,int_stack+2131901,int_stack+2119301,int_stack+667829,28);
 /*--- compute (i0|ih) ---*/
   hrr3_build_ih(Libderiv->CD,int_stack+2104517,int_stack+2131901,int_stack+677909,28);
 /*--- compute (hp|ih) ---*/
   hrr1_build_hp(Libderiv->AB,int_stack+2120981,int_stack+2104517,int_stack+2092169,588);
 /*--- compute (k0|np) ---*/
   hrr3_build_np(Libderiv->CD,int_stack+2158025,int_stack+506954,int_stack+504578,36);
 /*--- compute (k0|md) ---*/
   hrr3_build_md(Libderiv->CD,int_stack+2165153,int_stack+2158025,int_stack+641824,36);
 /*--- compute (k0|lf) ---*/
   hrr3_build_lf(Libderiv->CD,int_stack+203901,int_stack+2165153,int_stack+758297,36);
 /*--- compute (k0|kg) ---*/
   hrr3_build_kg(Libderiv->CD,int_stack+2158025,int_stack+203901,int_stack+768017,36);
 /*--- compute (k0|ih) ---*/
   hrr3_build_ih(Libderiv->CD,int_stack+203901,int_stack+2158025,int_stack+780977,36);
 /*--- compute (ip|ih) ---*/
   hrr1_build_ip(Libderiv->AB,int_stack+225069,int_stack+203901,int_stack+2104517,588);
 /*--- compute (hd|ih) ---*/
   hrr1_build_hd(Libderiv->AB,int_stack+274461,int_stack+225069,int_stack+2120981,588);
 /*--- compute (l0|np) ---*/
   hrr3_build_np(Libderiv->CD,int_stack+2158025,int_stack+531200,int_stack+528230,45);
 /*--- compute (l0|md) ---*/
   hrr3_build_md(Libderiv->CD,int_stack+2166935,int_stack+2158025,int_stack+702629,45);
 /*--- compute (l0|lf) ---*/
   hrr3_build_lf(Libderiv->CD,int_stack+960737,int_stack+2166935,int_stack+710054,45);
 /*--- compute (l0|kg) ---*/
   hrr3_build_kg(Libderiv->CD,int_stack+2158025,int_stack+960737,int_stack+722204,45);
 /*--- compute (l0|ih) ---*/
   hrr3_build_ih(Libderiv->CD,int_stack+960737,int_stack+2158025,int_stack+738404,45);
 /*--- compute (kp|ih) ---*/
   hrr1_build_kp(Libderiv->AB,int_stack+2602553,int_stack+960737,int_stack+203901,588);
 /*--- compute (id|ih) ---*/
   hrr1_build_id(Libderiv->AB,int_stack+565510,int_stack+2602553,int_stack+225069,588);
 /*--- compute (hf|ih) ---*/
   hrr1_build_hf(Libderiv->AB,int_stack+664294,int_stack+565510,int_stack+274461,588);
 /*--- compute (h0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+2158025,int_stack+355118,int_stack+354530,21);
 /*--- compute (h0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+2159789,int_stack+355874,int_stack+355118,21);
 /*--- compute (h0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+2162057,int_stack+2159789,int_stack+2158025,21);
 /*--- compute (h0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+2165585,int_stack+356819,int_stack+355874,21);
 /*--- compute (h0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+2168420,int_stack+2165585,int_stack+2159789,21);
 /*--- compute (h0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+2172956,int_stack+2168420,int_stack+2162057,21);
 /*--- compute (h0|mp) ---*/
   hrr3_build_mp(Libderiv->CD,int_stack+2158025,int_stack+357974,int_stack+356819,21);
 /*--- compute (h0|ld) ---*/
   hrr3_build_ld(Libderiv->CD,int_stack+2178836,int_stack+2158025,int_stack+2165585,21);
 /*--- compute (h0|kf) ---*/
   hrr3_build_kf(Libderiv->CD,int_stack+987197,int_stack+2178836,int_stack+2168420,21);
 /*--- compute (h0|ig) ---*/
   hrr3_build_ig(Libderiv->CD,int_stack+2161490,int_stack+987197,int_stack+2172956,21);
 /*--- compute (h0|np) ---*/
   hrr3_build_np(Libderiv->CD,int_stack+2170310,int_stack+359360,int_stack+357974,21);
 /*--- compute (h0|md) ---*/
   hrr3_build_md(Libderiv->CD,int_stack+994757,int_stack+2170310,int_stack+2158025,21);
 /*--- compute (h0|lf) ---*/
   hrr3_build_lf(Libderiv->CD,int_stack+1001687,int_stack+994757,int_stack+2178836,21);
 /*--- compute (h0|kg) ---*/
   hrr3_build_kg(Libderiv->CD,int_stack+2170310,int_stack+1001687,int_stack+987197,21);
 /*--- compute (h0|ih) ---*/
   hrr3_build_ih(Libderiv->CD,int_stack+987197,int_stack+2170310,int_stack+2161490,21);
 /*--- compute (i0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+999545,int_stack+361782,int_stack+360998,28);
 /*--- compute (i0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+1001897,int_stack+362790,int_stack+361782,28);
 /*--- compute (i0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+1004921,int_stack+1001897,int_stack+999545,28);
 /*--- compute (i0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+1009625,int_stack+364050,int_stack+362790,28);
 /*--- compute (i0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+1013405,int_stack+1009625,int_stack+1001897,28);
 /*--- compute (i0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+1019453,int_stack+1013405,int_stack+1004921,28);
 /*--- compute (i0|mp) ---*/
   hrr3_build_mp(Libderiv->CD,int_stack+999545,int_stack+365590,int_stack+364050,28);
 /*--- compute (i0|ld) ---*/
   hrr3_build_ld(Libderiv->CD,int_stack+2158025,int_stack+999545,int_stack+1009625,28);
 /*--- compute (i0|kf) ---*/
   hrr3_build_kf(Libderiv->CD,int_stack+2165585,int_stack+2158025,int_stack+1013405,28);
 /*--- compute (i0|ig) ---*/
   hrr3_build_ig(Libderiv->CD,int_stack+1004165,int_stack+2165585,int_stack+1019453,28);
 /*--- compute (i0|np) ---*/
   hrr3_build_np(Libderiv->CD,int_stack+1015925,int_stack+367438,int_stack+365590,28);
 /*--- compute (i0|md) ---*/
   hrr3_build_md(Libderiv->CD,int_stack+1021469,int_stack+1015925,int_stack+999545,28);
 /*--- compute (i0|lf) ---*/
   hrr3_build_lf(Libderiv->CD,int_stack+2175665,int_stack+1021469,int_stack+2158025,28);
 /*--- compute (i0|kg) ---*/
   hrr3_build_kg(Libderiv->CD,int_stack+1015925,int_stack+2175665,int_stack+2165585,28);
 /*--- compute (i0|ih) ---*/
   hrr3_build_ih(Libderiv->CD,int_stack+2158025,int_stack+1015925,int_stack+1004165,28);
 /*--- compute (hp|ih) ---*/
   d1hrr1_build_hp(Libderiv->AB,int_stack+2666057,int_stack+2158025,int_stack+987197, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2092169, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,588);
 /*--- compute (k0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+987197,int_stack+370630,int_stack+369622,36);
 /*--- compute (k0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+990221,int_stack+371926,int_stack+370630,36);
 /*--- compute (k0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+994109,int_stack+990221,int_stack+987197,36);
 /*--- compute (k0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+1000157,int_stack+373546,int_stack+371926,36);
 /*--- compute (k0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+1005017,int_stack+1000157,int_stack+990221,36);
 /*--- compute (k0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+1012793,int_stack+1005017,int_stack+994109,36);
 /*--- compute (k0|mp) ---*/
   hrr3_build_mp(Libderiv->CD,int_stack+987197,int_stack+375526,int_stack+373546,36);
 /*--- compute (k0|ld) ---*/
   hrr3_build_ld(Libderiv->CD,int_stack+1022873,int_stack+987197,int_stack+1000157,36);
 /*--- compute (k0|kf) ---*/
   hrr3_build_kf(Libderiv->CD,int_stack+2174489,int_stack+1022873,int_stack+1005017,36);
 /*--- compute (k0|ig) ---*/
   hrr3_build_ig(Libderiv->CD,int_stack+993137,int_stack+2174489,int_stack+1012793,36);
 /*--- compute (k0|np) ---*/
   hrr3_build_np(Libderiv->CD,int_stack+1008257,int_stack+377902,int_stack+375526,36);
 /*--- compute (k0|md) ---*/
   hrr3_build_md(Libderiv->CD,int_stack+348549,int_stack+1008257,int_stack+987197,36);
 /*--- compute (k0|lf) ---*/
   hrr3_build_lf(Libderiv->CD,int_stack+360429,int_stack+348549,int_stack+1022873,36);
 /*--- compute (k0|kg) ---*/
   hrr3_build_kg(Libderiv->CD,int_stack+1008257,int_stack+360429,int_stack+2174489,36);
 /*--- compute (k0|ih) ---*/
   hrr3_build_ih(Libderiv->CD,int_stack+348549,int_stack+1008257,int_stack+993137,36);
 /*--- compute (ip|ih) ---*/
   d1hrr1_build_ip(Libderiv->AB,int_stack+1317773,int_stack+348549,int_stack+2158025, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2104517, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,588);
 /*--- compute (hd|ih) ---*/
   d1hrr1_build_hd(Libderiv->AB,int_stack+2849513,int_stack+1317773,int_stack+2666057, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2120981, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,588);
 /*--- compute (l0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+2666057,int_stack+381970,int_stack+380710,45);
 /*--- compute (l0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+2669837,int_stack+383590,int_stack+381970,45);
 /*--- compute (l0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+2674697,int_stack+2669837,int_stack+2666057,45);
 /*--- compute (l0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+2682257,int_stack+385615,int_stack+383590,45);
 /*--- compute (l0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+2688332,int_stack+2682257,int_stack+2669837,45);
 /*--- compute (l0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+2698052,int_stack+2688332,int_stack+2674697,45);
 /*--- compute (l0|mp) ---*/
   hrr3_build_mp(Libderiv->CD,int_stack+2666057,int_stack+388090,int_stack+385615,45);
 /*--- compute (l0|ld) ---*/
   hrr3_build_ld(Libderiv->CD,int_stack+2710652,int_stack+2666057,int_stack+2682257,45);
 /*--- compute (l0|kf) ---*/
   hrr3_build_kf(Libderiv->CD,int_stack+2158025,int_stack+2710652,int_stack+2688332,45);
 /*--- compute (l0|ig) ---*/
   hrr3_build_ig(Libderiv->CD,int_stack+2673482,int_stack+2158025,int_stack+2698052,45);
 /*--- compute (l0|np) ---*/
   hrr3_build_np(Libderiv->CD,int_stack+2692382,int_stack+391060,int_stack+388090,45);
 /*--- compute (l0|md) ---*/
   hrr3_build_md(Libderiv->CD,int_stack+2174225,int_stack+2692382,int_stack+2666057,45);
 /*--- compute (l0|lf) ---*/
   hrr3_build_lf(Libderiv->CD,int_stack+369717,int_stack+2174225,int_stack+2710652,45);
 /*--- compute (l0|kg) ---*/
   hrr3_build_kg(Libderiv->CD,int_stack+2692382,int_stack+369717,int_stack+2158025,45);
 /*--- compute (l0|ih) ---*/
   hrr3_build_ih(Libderiv->CD,int_stack+2158025,int_stack+2692382,int_stack+2673482,45);
 /*--- compute (kp|ih) ---*/
   d1hrr1_build_kp(Libderiv->AB,int_stack+2923601,int_stack+2158025,int_stack+348549, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+203901, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,588);
 /*--- compute (id|ih) ---*/
   d1hrr1_build_id(Libderiv->AB,int_stack+2987105,int_stack+2923601,int_stack+1317773, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+225069, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,588);
 /*--- compute (hf|ih) ---*/
   d1hrr1_build_hf(Libderiv->AB,int_stack+3085889,int_stack+2987105,int_stack+2849513, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+274461, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,588);
 /*--- compute (m0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+2849513,int_stack+396110,int_stack+394570,55);
 /*--- compute (m0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+2854133,int_stack+398090,int_stack+396110,55);
 /*--- compute (m0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+2860073,int_stack+2854133,int_stack+2849513,55);
 /*--- compute (m0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+2869313,int_stack+400565,int_stack+398090,55);
 /*--- compute (m0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+2876738,int_stack+2869313,int_stack+2854133,55);
 /*--- compute (m0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+2888618,int_stack+2876738,int_stack+2860073,55);
 /*--- compute (m0|mp) ---*/
   hrr3_build_mp(Libderiv->CD,int_stack+2849513,int_stack+403590,int_stack+400565,55);
 /*--- compute (m0|ld) ---*/
   hrr3_build_ld(Libderiv->CD,int_stack+2904018,int_stack+2849513,int_stack+2869313,55);
 /*--- compute (m0|kf) ---*/
   hrr3_build_kf(Libderiv->CD,int_stack+1317773,int_stack+2904018,int_stack+2876738,55);
 /*--- compute (m0|ig) ---*/
   hrr3_build_ig(Libderiv->CD,int_stack+2858588,int_stack+1317773,int_stack+2888618,55);
 /*--- compute (m0|np) ---*/
   hrr3_build_np(Libderiv->CD,int_stack+2881688,int_stack+407220,int_stack+403590,55);
 /*--- compute (m0|md) ---*/
   hrr3_build_md(Libderiv->CD,int_stack+1337573,int_stack+2881688,int_stack+2849513,55);
 /*--- compute (m0|lf) ---*/
   hrr3_build_lf(Libderiv->CD,int_stack+1355723,int_stack+1337573,int_stack+2904018,55);
 /*--- compute (m0|kg) ---*/
   hrr3_build_kg(Libderiv->CD,int_stack+2881688,int_stack+1355723,int_stack+1317773,55);
 /*--- compute (m0|ih) ---*/
   hrr3_build_ih(Libderiv->CD,int_stack+1317773,int_stack+2881688,int_stack+2858588,55);
 /*--- compute (lp|ih) ---*/
   d1hrr1_build_lp(Libderiv->AB,int_stack+3209369,int_stack+1317773,int_stack+2158025, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+960737, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,588);
 /*--- compute (kd|ih) ---*/
   d1hrr1_build_kd(Libderiv->AB,int_stack+3288749,int_stack+3209369,int_stack+2923601, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2602553, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,588);
 /*--- compute (if|ih) ---*/
   d1hrr1_build_if(Libderiv->AB,int_stack+3415757,int_stack+3288749,int_stack+2987105, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+565510, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,588);
 /*--- compute (h0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+3209369,int_stack+412098,int_stack+411510,21);
 /*--- compute (h0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+3211133,int_stack+412854,int_stack+412098,21);
 /*--- compute (h0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+3213401,int_stack+3211133,int_stack+3209369,21);
 /*--- compute (h0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+3216929,int_stack+413799,int_stack+412854,21);
 /*--- compute (h0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+3219764,int_stack+3216929,int_stack+3211133,21);
 /*--- compute (h0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+3224300,int_stack+3219764,int_stack+3213401,21);
 /*--- compute (h0|mp) ---*/
   hrr3_build_mp(Libderiv->CD,int_stack+3209369,int_stack+414954,int_stack+413799,21);
 /*--- compute (h0|ld) ---*/
   hrr3_build_ld(Libderiv->CD,int_stack+3230180,int_stack+3209369,int_stack+3216929,21);
 /*--- compute (h0|kf) ---*/
   hrr3_build_kf(Libderiv->CD,int_stack+3235850,int_stack+3230180,int_stack+3219764,21);
 /*--- compute (h0|ig) ---*/
   hrr3_build_ig(Libderiv->CD,int_stack+3212834,int_stack+3235850,int_stack+3224300,21);
 /*--- compute (h0|np) ---*/
   hrr3_build_np(Libderiv->CD,int_stack+3221654,int_stack+416340,int_stack+414954,21);
 /*--- compute (h0|md) ---*/
   hrr3_build_md(Libderiv->CD,int_stack+3243410,int_stack+3221654,int_stack+3209369,21);
 /*--- compute (h0|lf) ---*/
   hrr3_build_lf(Libderiv->CD,int_stack+3250340,int_stack+3243410,int_stack+3230180,21);
 /*--- compute (h0|kg) ---*/
   hrr3_build_kg(Libderiv->CD,int_stack+3221654,int_stack+3250340,int_stack+3235850,21);
 /*--- compute (h0|ih) ---*/
   hrr3_build_ih(Libderiv->CD,int_stack+3232994,int_stack+3221654,int_stack+3212834,21);
 /*--- compute (i0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+3209369,int_stack+418762,int_stack+417978,28);
 /*--- compute (i0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+3211721,int_stack+419770,int_stack+418762,28);
 /*--- compute (i0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+3214745,int_stack+3211721,int_stack+3209369,28);
 /*--- compute (i0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+3219449,int_stack+421030,int_stack+419770,28);
 /*--- compute (i0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+3223229,int_stack+3219449,int_stack+3211721,28);
 /*--- compute (i0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+3245342,int_stack+3223229,int_stack+3214745,28);
 /*--- compute (i0|mp) ---*/
   hrr3_build_mp(Libderiv->CD,int_stack+3209369,int_stack+422570,int_stack+421030,28);
 /*--- compute (i0|ld) ---*/
   hrr3_build_ld(Libderiv->CD,int_stack+3253182,int_stack+3209369,int_stack+3219449,28);
 /*--- compute (i0|kf) ---*/
   hrr3_build_kf(Libderiv->CD,int_stack+3260742,int_stack+3253182,int_stack+3223229,28);
 /*--- compute (i0|ig) ---*/
   hrr3_build_ig(Libderiv->CD,int_stack+3213989,int_stack+3260742,int_stack+3245342,28);
 /*--- compute (i0|np) ---*/
   hrr3_build_np(Libderiv->CD,int_stack+3245342,int_stack+424418,int_stack+422570,28);
 /*--- compute (i0|md) ---*/
   hrr3_build_md(Libderiv->CD,int_stack+3270822,int_stack+3245342,int_stack+3209369,28);
 /*--- compute (i0|lf) ---*/
   hrr3_build_lf(Libderiv->CD,int_stack+3280062,int_stack+3270822,int_stack+3253182,28);
 /*--- compute (i0|kg) ---*/
   hrr3_build_kg(Libderiv->CD,int_stack+3245342,int_stack+3280062,int_stack+3260742,28);
 /*--- compute (i0|ih) ---*/
   hrr3_build_ih(Libderiv->CD,int_stack+3260462,int_stack+3245342,int_stack+3213989,28);
 /*--- compute (hp|ih) ---*/
   d1hrr1_build_hp(Libderiv->AB,int_stack+3276926,int_stack+3260462,int_stack+3232994, 0.0, zero_stack, 1.0, int_stack+2092169, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,588);
 /*--- compute (k0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+3209369,int_stack+427610,int_stack+426602,36);
 /*--- compute (k0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+3212393,int_stack+428906,int_stack+427610,36);
 /*--- compute (k0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+3216281,int_stack+3212393,int_stack+3209369,36);
 /*--- compute (k0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+3222329,int_stack+430526,int_stack+428906,36);
 /*--- compute (k0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+3227189,int_stack+3222329,int_stack+3212393,36);
 /*--- compute (k0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+3234965,int_stack+3227189,int_stack+3216281,36);
 /*--- compute (k0|mp) ---*/
   hrr3_build_mp(Libderiv->CD,int_stack+3209369,int_stack+432506,int_stack+430526,36);
 /*--- compute (k0|ld) ---*/
   hrr3_build_ld(Libderiv->CD,int_stack+3245045,int_stack+3209369,int_stack+3222329,36);
 /*--- compute (k0|kf) ---*/
   hrr3_build_kf(Libderiv->CD,int_stack+3313970,int_stack+3245045,int_stack+3227189,36);
 /*--- compute (k0|ig) ---*/
   hrr3_build_ig(Libderiv->CD,int_stack+3215309,int_stack+3313970,int_stack+3234965,36);
 /*--- compute (k0|np) ---*/
   hrr3_build_np(Libderiv->CD,int_stack+3230429,int_stack+434882,int_stack+432506,36);
 /*--- compute (k0|md) ---*/
   hrr3_build_md(Libderiv->CD,int_stack+3326930,int_stack+3230429,int_stack+3209369,36);
 /*--- compute (k0|lf) ---*/
   hrr3_build_lf(Libderiv->CD,int_stack+3338810,int_stack+3326930,int_stack+3245045,36);
 /*--- compute (k0|kg) ---*/
   hrr3_build_kg(Libderiv->CD,int_stack+3230429,int_stack+3338810,int_stack+3313970,36);
 /*--- compute (k0|ih) ---*/
   hrr3_build_ih(Libderiv->CD,int_stack+3313970,int_stack+3230429,int_stack+3215309,36);
 /*--- compute (ip|ih) ---*/
   d1hrr1_build_ip(Libderiv->AB,int_stack+3335138,int_stack+3313970,int_stack+3260462, 0.0, zero_stack, 1.0, int_stack+2104517, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,588);
 /*--- compute (hd|ih) ---*/
   d1hrr1_build_hd(Libderiv->AB,int_stack+1317773,int_stack+3335138,int_stack+3276926, 0.0, zero_stack, 1.0, int_stack+2120981, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,588);
 /*--- compute (l0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+3384530,int_stack+438950,int_stack+437690,45);
 /*--- compute (l0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+3388310,int_stack+440570,int_stack+438950,45);
 /*--- compute (l0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+3393170,int_stack+3388310,int_stack+3384530,45);
 /*--- compute (l0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+3400730,int_stack+442595,int_stack+440570,45);
 /*--- compute (l0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+3209369,int_stack+3400730,int_stack+3388310,45);
 /*--- compute (l0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+3219089,int_stack+3209369,int_stack+3393170,45);
 /*--- compute (l0|mp) ---*/
   hrr3_build_mp(Libderiv->CD,int_stack+3384530,int_stack+445070,int_stack+442595,45);
 /*--- compute (l0|ld) ---*/
   hrr3_build_ld(Libderiv->CD,int_stack+3231689,int_stack+3384530,int_stack+3400730,45);
 /*--- compute (l0|kf) ---*/
   hrr3_build_kf(Libderiv->CD,int_stack+3391955,int_stack+3231689,int_stack+3209369,45);
 /*--- compute (l0|ig) ---*/
   hrr3_build_ig(Libderiv->CD,int_stack+3243839,int_stack+3391955,int_stack+3219089,45);
 /*--- compute (l0|np) ---*/
   hrr3_build_np(Libderiv->CD,int_stack+3209369,int_stack+448040,int_stack+445070,45);
 /*--- compute (l0|md) ---*/
   hrr3_build_md(Libderiv->CD,int_stack+3262739,int_stack+3209369,int_stack+3384530,45);
 /*--- compute (l0|lf) ---*/
   hrr3_build_lf(Libderiv->CD,int_stack+3209369,int_stack+3262739,int_stack+3231689,45);
 /*--- compute (l0|kg) ---*/
   hrr3_build_kg(Libderiv->CD,int_stack+3262739,int_stack+3209369,int_stack+3391955,45);
 /*--- compute (l0|ih) ---*/
   hrr3_build_ih(Libderiv->CD,int_stack+3209369,int_stack+3262739,int_stack+3243839,45);
 /*--- compute (kp|ih) ---*/
   d1hrr1_build_kp(Libderiv->AB,int_stack+3235829,int_stack+3209369,int_stack+3313970, 0.0, zero_stack, 1.0, int_stack+203901, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,588);
 /*--- compute (id|ih) ---*/
   d1hrr1_build_id(Libderiv->AB,int_stack+2849513,int_stack+3235829,int_stack+3335138, 0.0, zero_stack, 1.0, int_stack+225069, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,588);
 /*--- compute (hf|ih) ---*/
   d1hrr1_build_hf(Libderiv->AB,int_stack+2948297,int_stack+2849513,int_stack+1317773, 0.0, zero_stack, 1.0, int_stack+274461, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,588);
 /*--- compute (m0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+1317773,int_stack+453090,int_stack+451550,55);
 /*--- compute (m0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+1322393,int_stack+455070,int_stack+453090,55);
 /*--- compute (m0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+1328333,int_stack+1322393,int_stack+1317773,55);
 /*--- compute (m0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+1337573,int_stack+457545,int_stack+455070,55);
 /*--- compute (m0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+1344998,int_stack+1337573,int_stack+1322393,55);
 /*--- compute (m0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+1356878,int_stack+1344998,int_stack+1328333,55);
 /*--- compute (m0|mp) ---*/
   hrr3_build_mp(Libderiv->CD,int_stack+1317773,int_stack+460570,int_stack+457545,55);
 /*--- compute (m0|ld) ---*/
   hrr3_build_ld(Libderiv->CD,int_stack+1372278,int_stack+1317773,int_stack+1337573,55);
 /*--- compute (m0|kf) ---*/
   hrr3_build_kf(Libderiv->CD,int_stack+1387128,int_stack+1372278,int_stack+1344998,55);
 /*--- compute (m0|ig) ---*/
   hrr3_build_ig(Libderiv->CD,int_stack+1326848,int_stack+1387128,int_stack+1356878,55);
 /*--- compute (m0|np) ---*/
   hrr3_build_np(Libderiv->CD,int_stack+1349948,int_stack+464200,int_stack+460570,55);
 /*--- compute (m0|md) ---*/
   hrr3_build_md(Libderiv->CD,int_stack+3299333,int_stack+1349948,int_stack+1317773,55);
 /*--- compute (m0|lf) ---*/
   hrr3_build_lf(Libderiv->CD,int_stack+3317483,int_stack+3299333,int_stack+1372278,55);
 /*--- compute (m0|kg) ---*/
   hrr3_build_kg(Libderiv->CD,int_stack+1349948,int_stack+3317483,int_stack+1387128,55);
 /*--- compute (m0|ih) ---*/
   hrr3_build_ih(Libderiv->CD,int_stack+3299333,int_stack+1349948,int_stack+1326848,55);
 /*--- compute (lp|ih) ---*/
   d1hrr1_build_lp(Libderiv->AB,int_stack+3331673,int_stack+3299333,int_stack+3209369, 0.0, zero_stack, 1.0, int_stack+960737, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,588);
 /*--- compute (kd|ih) ---*/
   d1hrr1_build_kd(Libderiv->AB,int_stack+3580397,int_stack+3331673,int_stack+3235829, 0.0, zero_stack, 1.0, int_stack+2602553, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,588);
 /*--- compute (if|ih) ---*/
   d1hrr1_build_if(Libderiv->AB,int_stack+3209369,int_stack+3580397,int_stack+2849513, 0.0, zero_stack, 1.0, int_stack+565510, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,588);
 /*--- compute (h0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+2849513,int_stack+475546,int_stack+474958,21);
 /*--- compute (h0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+2851277,int_stack+476302,int_stack+475546,21);
 /*--- compute (h0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+2853545,int_stack+2851277,int_stack+2849513,21);
 /*--- compute (h0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+2857073,int_stack+477247,int_stack+476302,21);
 /*--- compute (h0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+2859908,int_stack+2857073,int_stack+2851277,21);
 /*--- compute (h0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+2864444,int_stack+2859908,int_stack+2853545,21);
 /*--- compute (h0|mp) ---*/
   hrr3_build_mp(Libderiv->CD,int_stack+2849513,int_stack+478402,int_stack+477247,21);
 /*--- compute (h0|ld) ---*/
   hrr3_build_ld(Libderiv->CD,int_stack+2870324,int_stack+2849513,int_stack+2857073,21);
 /*--- compute (h0|kf) ---*/
   hrr3_build_kf(Libderiv->CD,int_stack+2875994,int_stack+2870324,int_stack+2859908,21);
 /*--- compute (h0|ig) ---*/
   hrr3_build_ig(Libderiv->CD,int_stack+2852978,int_stack+2875994,int_stack+2864444,21);
 /*--- compute (h0|np) ---*/
   hrr3_build_np(Libderiv->CD,int_stack+2861798,int_stack+479788,int_stack+478402,21);
 /*--- compute (h0|md) ---*/
   hrr3_build_md(Libderiv->CD,int_stack+2883554,int_stack+2861798,int_stack+2849513,21);
 /*--- compute (h0|lf) ---*/
   hrr3_build_lf(Libderiv->CD,int_stack+2890484,int_stack+2883554,int_stack+2870324,21);
 /*--- compute (h0|kg) ---*/
   hrr3_build_kg(Libderiv->CD,int_stack+2861798,int_stack+2890484,int_stack+2875994,21);
 /*--- compute (h0|ih) ---*/
   hrr3_build_ih(Libderiv->CD,int_stack+2873138,int_stack+2861798,int_stack+2852978,21);
 /*--- compute (i0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+2849513,int_stack+490834,int_stack+490050,28);
 /*--- compute (i0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+2851865,int_stack+491842,int_stack+490834,28);
 /*--- compute (i0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+2854889,int_stack+2851865,int_stack+2849513,28);
 /*--- compute (i0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+2859593,int_stack+493102,int_stack+491842,28);
 /*--- compute (i0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+2863373,int_stack+2859593,int_stack+2851865,28);
 /*--- compute (i0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+2885486,int_stack+2863373,int_stack+2854889,28);
 /*--- compute (i0|mp) ---*/
   hrr3_build_mp(Libderiv->CD,int_stack+2849513,int_stack+494642,int_stack+493102,28);
 /*--- compute (i0|ld) ---*/
   hrr3_build_ld(Libderiv->CD,int_stack+2893326,int_stack+2849513,int_stack+2859593,28);
 /*--- compute (i0|kf) ---*/
   hrr3_build_kf(Libderiv->CD,int_stack+2900886,int_stack+2893326,int_stack+2863373,28);
 /*--- compute (i0|ig) ---*/
   hrr3_build_ig(Libderiv->CD,int_stack+2854133,int_stack+2900886,int_stack+2885486,28);
 /*--- compute (i0|np) ---*/
   hrr3_build_np(Libderiv->CD,int_stack+2885486,int_stack+496490,int_stack+494642,28);
 /*--- compute (i0|md) ---*/
   hrr3_build_md(Libderiv->CD,int_stack+2910966,int_stack+2885486,int_stack+2849513,28);
 /*--- compute (i0|lf) ---*/
   hrr3_build_lf(Libderiv->CD,int_stack+2920206,int_stack+2910966,int_stack+2893326,28);
 /*--- compute (i0|kg) ---*/
   hrr3_build_kg(Libderiv->CD,int_stack+2885486,int_stack+2920206,int_stack+2900886,28);
 /*--- compute (i0|ih) ---*/
   hrr3_build_ih(Libderiv->CD,int_stack+2900606,int_stack+2885486,int_stack+2854133,28);
 /*--- compute (hp|ih) ---*/
   d1hrr1_build_hp(Libderiv->AB,int_stack+3580397,int_stack+2900606,int_stack+2873138, 1.0, int_stack+2092169, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,588);
 /*--- compute (k0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+2092169,int_stack+510770,int_stack+509762,36);
 /*--- compute (k0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+2095193,int_stack+512066,int_stack+510770,36);
 /*--- compute (k0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+2849513,int_stack+2095193,int_stack+2092169,36);
 /*--- compute (k0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+2099081,int_stack+513686,int_stack+512066,36);
 /*--- compute (k0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+2855561,int_stack+2099081,int_stack+2095193,36);
 /*--- compute (k0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+2863337,int_stack+2855561,int_stack+2849513,36);
 /*--- compute (k0|mp) ---*/
   hrr3_build_mp(Libderiv->CD,int_stack+2849513,int_stack+515666,int_stack+513686,36);
 /*--- compute (k0|ld) ---*/
   hrr3_build_ld(Libderiv->CD,int_stack+2873417,int_stack+2849513,int_stack+2099081,36);
 /*--- compute (k0|kf) ---*/
   hrr3_build_kf(Libderiv->CD,int_stack+2883137,int_stack+2873417,int_stack+2855561,36);
 /*--- compute (k0|ig) ---*/
   hrr3_build_ig(Libderiv->CD,int_stack+2917070,int_stack+2883137,int_stack+2863337,36);
 /*--- compute (k0|np) ---*/
   hrr3_build_np(Libderiv->CD,int_stack+2855453,int_stack+518042,int_stack+515666,36);
 /*--- compute (k0|md) ---*/
   hrr3_build_md(Libderiv->CD,int_stack+2092169,int_stack+2855453,int_stack+2849513,36);
 /*--- compute (k0|lf) ---*/
   hrr3_build_lf(Libderiv->CD,int_stack+2849513,int_stack+2092169,int_stack+2873417,36);
 /*--- compute (k0|kg) ---*/
   hrr3_build_kg(Libderiv->CD,int_stack+3617441,int_stack+2849513,int_stack+2883137,36);
 /*--- compute (k0|ih) ---*/
   hrr3_build_ih(Libderiv->CD,int_stack+2849513,int_stack+3617441,int_stack+2917070,36);
 /*--- compute (ip|ih) ---*/
   d1hrr1_build_ip(Libderiv->AB,int_stack+3617441,int_stack+2849513,int_stack+2900606, 1.0, int_stack+2104517, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,588);
 /*--- compute (hd|ih) ---*/
   d1hrr1_build_hd(Libderiv->AB,int_stack+2870681,int_stack+3617441,int_stack+3580397, 1.0, int_stack+2120981, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,588);
 /*--- compute (l0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+3580397,int_stack+535970,int_stack+534710,45);
 /*--- compute (l0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+3584177,int_stack+537590,int_stack+535970,45);
 /*--- compute (l0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+3589037,int_stack+3584177,int_stack+3580397,45);
 /*--- compute (l0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+3596597,int_stack+539615,int_stack+537590,45);
 /*--- compute (l0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+3602672,int_stack+3596597,int_stack+3584177,45);
 /*--- compute (l0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+3666833,int_stack+3602672,int_stack+3589037,45);
 /*--- compute (l0|mp) ---*/
   hrr3_build_mp(Libderiv->CD,int_stack+3580397,int_stack+542090,int_stack+539615,45);
 /*--- compute (l0|ld) ---*/
   hrr3_build_ld(Libderiv->CD,int_stack+3679433,int_stack+3580397,int_stack+3596597,45);
 /*--- compute (l0|kf) ---*/
   hrr3_build_kf(Libderiv->CD,int_stack+3691583,int_stack+3679433,int_stack+3602672,45);
 /*--- compute (l0|ig) ---*/
   hrr3_build_ig(Libderiv->CD,int_stack+3587822,int_stack+3691583,int_stack+3666833,45);
 /*--- compute (l0|np) ---*/
   hrr3_build_np(Libderiv->CD,int_stack+3666833,int_stack+545060,int_stack+542090,45);
 /*--- compute (l0|md) ---*/
   hrr3_build_md(Libderiv->CD,int_stack+2092169,int_stack+3666833,int_stack+3580397,45);
 /*--- compute (l0|lf) ---*/
   hrr3_build_lf(Libderiv->CD,int_stack+2107019,int_stack+2092169,int_stack+3679433,45);
 /*--- compute (l0|kg) ---*/
   hrr3_build_kg(Libderiv->CD,int_stack+3666833,int_stack+2107019,int_stack+3691583,45);
 /*--- compute (l0|ih) ---*/
   hrr3_build_ih(Libderiv->CD,int_stack+2092169,int_stack+3666833,int_stack+3587822,45);
 /*--- compute (kp|ih) ---*/
   d1hrr1_build_kp(Libderiv->AB,int_stack+2118629,int_stack+2092169,int_stack+2849513, 1.0, int_stack+203901, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,588);
 /*--- compute (id|ih) ---*/
   d1hrr1_build_id(Libderiv->AB,int_stack+348549,int_stack+2118629,int_stack+3617441, 1.0, int_stack+225069, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,588);
 /*--- compute (hf|ih) ---*/
   d1hrr1_build_hf(Libderiv->AB,int_stack+3580397,int_stack+348549,int_stack+2870681, 1.0, int_stack+274461, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,588);
 /*--- compute (m0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+203901,int_stack+550110,int_stack+548570,55);
 /*--- compute (m0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+208521,int_stack+552090,int_stack+550110,55);
 /*--- compute (m0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+214461,int_stack+208521,int_stack+203901,55);
 /*--- compute (m0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+223701,int_stack+554565,int_stack+552090,55);
 /*--- compute (m0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+231126,int_stack+223701,int_stack+208521,55);
 /*--- compute (m0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+243006,int_stack+231126,int_stack+214461,55);
 /*--- compute (m0|mp) ---*/
   hrr3_build_mp(Libderiv->CD,int_stack+203901,int_stack+557590,int_stack+554565,55);
 /*--- compute (m0|ld) ---*/
   hrr3_build_ld(Libderiv->CD,int_stack+258406,int_stack+203901,int_stack+223701,55);
 /*--- compute (m0|kf) ---*/
   hrr3_build_kf(Libderiv->CD,int_stack+273256,int_stack+258406,int_stack+231126,55);
 /*--- compute (m0|ig) ---*/
   hrr3_build_ig(Libderiv->CD,int_stack+212976,int_stack+273256,int_stack+243006,55);
 /*--- compute (m0|np) ---*/
   hrr3_build_np(Libderiv->CD,int_stack+236076,int_stack+561220,int_stack+557590,55);
 /*--- compute (m0|md) ---*/
   hrr3_build_md(Libderiv->CD,int_stack+293056,int_stack+236076,int_stack+203901,55);
 /*--- compute (m0|lf) ---*/
   hrr3_build_lf(Libderiv->CD,int_stack+311206,int_stack+293056,int_stack+258406,55);
 /*--- compute (m0|kg) ---*/
   hrr3_build_kg(Libderiv->CD,int_stack+236076,int_stack+311206,int_stack+273256,55);
 /*--- compute (m0|ih) ---*/
   hrr3_build_ih(Libderiv->CD,int_stack+265776,int_stack+236076,int_stack+212976,55);
 /*--- compute (lp|ih) ---*/
   d1hrr1_build_lp(Libderiv->AB,int_stack+2849513,int_stack+265776,int_stack+2092169, 1.0, int_stack+960737, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,588);
 /*--- compute (kd|ih) ---*/
   d1hrr1_build_kd(Libderiv->AB,int_stack+203901,int_stack+2849513,int_stack+2118629, 1.0, int_stack+2602553, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,588);
 /*--- compute (if|ih) ---*/
   d1hrr1_build_if(Libderiv->AB,int_stack+3703877,int_stack+203901,int_stack+348549, 1.0, int_stack+565510, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,588);
 /*--- compute (hg|ih) ---*/
   hrr1_build_hg(Libderiv->AB,int_stack+203901,int_stack+1556501,int_stack+1194293,588);
     Libderiv->ABCD[11] = int_stack + 203901;
 /*--- compute (hg|ih) ---*/
   hrr1_build_hg(Libderiv->AB,int_stack+389121,int_stack+1927529,int_stack+1407737,588);
     Libderiv->ABCD[10] = int_stack + 389121;
 /*--- compute (hg|ih) ---*/
   hrr1_build_hg(Libderiv->AB,int_stack+1885781,int_stack+1721141,int_stack+1034181,588);
     Libderiv->ABCD[9] = int_stack + 1885781;
 /*--- compute (hg|ih) ---*/
   hrr1_build_hg(Libderiv->AB,int_stack+960737,int_stack+2314433,int_stack+2190953,588);
     Libderiv->ABCD[8] = int_stack + 960737;
 /*--- compute (hg|ih) ---*/
   hrr1_build_hg(Libderiv->AB,int_stack+1145957,int_stack+39261,int_stack+2479073,588);
     Libderiv->ABCD[7] = int_stack + 1145957;
 /*--- compute (hg|ih) ---*/
   hrr1_build_hg(Libderiv->AB,int_stack+1331177,int_stack+796097,int_stack+2726033,588);
     Libderiv->ABCD[6] = int_stack + 1331177;
 /*--- compute (hg|ih) ---*/
   d1hrr1_build_hg(Libderiv->AB,int_stack+1516397,int_stack+3415757,int_stack+3085889, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+664294, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,588);
     Libderiv->ABCD[2] = int_stack + 1516397;
 /*--- compute (hg|ih) ---*/
   d1hrr1_build_hg(Libderiv->AB,int_stack+3374009,int_stack+3209369,int_stack+2948297, 0.0, zero_stack, 1.0, int_stack+664294, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,588);
     Libderiv->ABCD[1] = int_stack + 3374009;
 /*--- compute (hg|ih) ---*/
   d1hrr1_build_hg(Libderiv->AB,int_stack+0,int_stack+3703877,int_stack+3580397, 1.0, int_stack+664294, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,588);
     Libderiv->ABCD[0] = int_stack + 0;

}
