/*
 *  Copyright (C) 1996-2017 Edward F. Valeev and Justin T. Fermann
 *
 *  This file is part of Libint.
 *
 *  Libint is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU Lesser General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  Libint is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public License
 *  along with Libint.  If not, see <http://www.gnu.org/licenses/>.
 *
 */

#include <stdio.h>
#include <string.h>
#include <libint/libint.h>
#include "libderiv.h"
#include <libint/hrr_header.h>

#include "d1hrr_header.h"

extern void d1vrr_order_hhih(Libderiv_t *, prim_data *);

  /* Computes derivatives of (hh|ih) integrals */

void d1hrr_order_hhih(Libderiv_t *Libderiv, int num_prim_comb)
{
 prim_data *Data = Libderiv->PrimQuartet;
 double *int_stack = Libderiv->int_stack;
 double *zero_stack = Libderiv->zero_stack;
 int i,j;
 double tmp, *target;

 Libderiv->deriv_classes[5][6][11] = int_stack + 0;
 Libderiv->deriv_classes[5][7][11] = int_stack + 588;
 Libderiv->deriv_classes[5][8][11] = int_stack + 1344;
 Libderiv->deriv_classes[5][9][11] = int_stack + 2289;
 Libderiv->deriv_classes[5][10][11] = int_stack + 3444;
 Libderiv->deriv_classes[5][11][11] = int_stack + 4830;
 Libderiv->deriv_classes[6][6][11] = int_stack + 6468;
 Libderiv->deriv_classes[6][7][11] = int_stack + 7252;
 Libderiv->deriv_classes[6][8][11] = int_stack + 8260;
 Libderiv->deriv_classes[6][9][11] = int_stack + 9520;
 Libderiv->deriv_classes[6][10][11] = int_stack + 11060;
 Libderiv->deriv_classes[6][11][11] = int_stack + 12908;
 Libderiv->deriv_classes[7][6][11] = int_stack + 15092;
 Libderiv->deriv_classes[7][7][11] = int_stack + 16100;
 Libderiv->deriv_classes[7][8][11] = int_stack + 17396;
 Libderiv->deriv_classes[7][9][11] = int_stack + 19016;
 Libderiv->deriv_classes[7][10][11] = int_stack + 20996;
 Libderiv->deriv_classes[7][11][11] = int_stack + 23372;
 Libderiv->deriv_classes[8][6][11] = int_stack + 26180;
 Libderiv->deriv_classes[8][7][11] = int_stack + 27440;
 Libderiv->deriv_classes[8][8][11] = int_stack + 29060;
 Libderiv->deriv_classes[8][9][11] = int_stack + 31085;
 Libderiv->deriv_classes[8][10][11] = int_stack + 33560;
 Libderiv->deriv_classes[8][11][11] = int_stack + 36530;
 Libderiv->deriv_classes[9][6][11] = int_stack + 40040;
 Libderiv->deriv_classes[9][7][11] = int_stack + 41580;
 Libderiv->deriv_classes[9][8][11] = int_stack + 43560;
 Libderiv->deriv_classes[9][9][11] = int_stack + 46035;
 Libderiv->deriv_classes[9][10][11] = int_stack + 49060;
 Libderiv->deriv_classes[9][11][11] = int_stack + 52690;
 Libderiv->deriv_classes[10][6][11] = int_stack + 56980;
 Libderiv->deriv_classes[10][7][11] = int_stack + 58828;
 Libderiv->deriv_classes[10][8][11] = int_stack + 61204;
 Libderiv->deriv_classes[10][9][11] = int_stack + 64174;
 Libderiv->deriv_classes[10][10][11] = int_stack + 67804;
 Libderiv->deriv_classes[10][11][11] = int_stack + 72160;
 Libderiv->deriv_classes[5][6][10] = int_stack + 77308;
 Libderiv->deriv_classes[5][7][10] = int_stack + 77896;
 Libderiv->deriv_classes[5][8][10] = int_stack + 78652;
 Libderiv->deriv_classes[5][9][10] = int_stack + 79597;
 Libderiv->deriv_classes[5][10][10] = int_stack + 80752;
 Libderiv->deriv_classes[5][11][10] = int_stack + 82138;
 Libderiv->deriv_classes[6][6][10] = int_stack + 83776;
 Libderiv->deriv_classes[6][7][10] = int_stack + 84560;
 Libderiv->deriv_classes[6][8][10] = int_stack + 85568;
 Libderiv->deriv_classes[6][9][10] = int_stack + 86828;
 Libderiv->deriv_classes[6][10][10] = int_stack + 88368;
 Libderiv->deriv_classes[6][11][10] = int_stack + 90216;
 Libderiv->deriv_classes[7][6][10] = int_stack + 92400;
 Libderiv->deriv_classes[7][7][10] = int_stack + 93408;
 Libderiv->deriv_classes[7][8][10] = int_stack + 94704;
 Libderiv->deriv_classes[7][9][10] = int_stack + 96324;
 Libderiv->deriv_classes[7][10][10] = int_stack + 98304;
 Libderiv->deriv_classes[7][11][10] = int_stack + 100680;
 Libderiv->deriv_classes[8][6][10] = int_stack + 103488;
 Libderiv->deriv_classes[8][7][10] = int_stack + 104748;
 Libderiv->deriv_classes[8][8][10] = int_stack + 106368;
 Libderiv->deriv_classes[8][9][10] = int_stack + 108393;
 Libderiv->deriv_classes[8][10][10] = int_stack + 110868;
 Libderiv->deriv_classes[8][11][10] = int_stack + 113838;
 Libderiv->deriv_classes[9][6][10] = int_stack + 117348;
 Libderiv->deriv_classes[9][7][10] = int_stack + 118888;
 Libderiv->deriv_classes[9][8][10] = int_stack + 120868;
 Libderiv->deriv_classes[9][9][10] = int_stack + 123343;
 Libderiv->deriv_classes[9][10][10] = int_stack + 126368;
 Libderiv->deriv_classes[9][11][10] = int_stack + 129998;
 Libderiv->deriv_classes[10][6][10] = int_stack + 134288;
 Libderiv->deriv_classes[10][7][10] = int_stack + 136136;
 Libderiv->deriv_classes[10][8][10] = int_stack + 138512;
 Libderiv->deriv_classes[10][9][10] = int_stack + 141482;
 Libderiv->deriv_classes[10][10][10] = int_stack + 145112;
 Libderiv->deriv_classes[10][11][10] = int_stack + 149468;
 Libderiv->deriv_classes[5][6][9] = int_stack + 154616;
 Libderiv->deriv_classes[5][7][9] = int_stack + 155204;
 Libderiv->deriv_classes[5][8][9] = int_stack + 155960;
 Libderiv->deriv_classes[5][9][9] = int_stack + 156905;
 Libderiv->deriv_classes[5][10][9] = int_stack + 158060;
 Libderiv->deriv_classes[5][11][9] = int_stack + 159446;
 Libderiv->deriv_classes[6][6][9] = int_stack + 161084;
 Libderiv->deriv_classes[6][7][9] = int_stack + 161868;
 Libderiv->deriv_classes[6][8][9] = int_stack + 162876;
 Libderiv->deriv_classes[6][9][9] = int_stack + 164136;
 Libderiv->deriv_classes[6][10][9] = int_stack + 165676;
 Libderiv->deriv_classes[6][11][9] = int_stack + 167524;
 Libderiv->deriv_classes[7][6][9] = int_stack + 169708;
 Libderiv->deriv_classes[7][7][9] = int_stack + 170716;
 Libderiv->deriv_classes[7][8][9] = int_stack + 172012;
 Libderiv->deriv_classes[7][9][9] = int_stack + 173632;
 Libderiv->deriv_classes[7][10][9] = int_stack + 175612;
 Libderiv->deriv_classes[7][11][9] = int_stack + 177988;
 Libderiv->deriv_classes[8][6][9] = int_stack + 180796;
 Libderiv->deriv_classes[8][7][9] = int_stack + 182056;
 Libderiv->deriv_classes[8][8][9] = int_stack + 183676;
 Libderiv->deriv_classes[8][9][9] = int_stack + 185701;
 Libderiv->deriv_classes[8][10][9] = int_stack + 188176;
 Libderiv->deriv_classes[8][11][9] = int_stack + 191146;
 Libderiv->deriv_classes[9][6][9] = int_stack + 194656;
 Libderiv->deriv_classes[9][7][9] = int_stack + 196196;
 Libderiv->deriv_classes[9][8][9] = int_stack + 198176;
 Libderiv->deriv_classes[9][9][9] = int_stack + 200651;
 Libderiv->deriv_classes[9][10][9] = int_stack + 203676;
 Libderiv->deriv_classes[9][11][9] = int_stack + 207306;
 Libderiv->deriv_classes[10][6][9] = int_stack + 211596;
 Libderiv->deriv_classes[10][7][9] = int_stack + 213444;
 Libderiv->deriv_classes[10][8][9] = int_stack + 215820;
 Libderiv->deriv_classes[10][9][9] = int_stack + 218790;
 Libderiv->deriv_classes[10][10][9] = int_stack + 222420;
 Libderiv->deriv_classes[10][11][9] = int_stack + 226776;
 Libderiv->deriv_classes[5][6][8] = int_stack + 231924;
 Libderiv->deriv_classes[5][7][8] = int_stack + 232512;
 Libderiv->deriv_classes[5][8][8] = int_stack + 233268;
 Libderiv->deriv_classes[5][9][8] = int_stack + 234213;
 Libderiv->deriv_classes[5][10][8] = int_stack + 235368;
 Libderiv->deriv_classes[5][11][8] = int_stack + 236754;
 Libderiv->deriv_classes[6][6][8] = int_stack + 238392;
 Libderiv->deriv_classes[6][7][8] = int_stack + 239176;
 Libderiv->deriv_classes[6][8][8] = int_stack + 240184;
 Libderiv->deriv_classes[6][9][8] = int_stack + 241444;
 Libderiv->deriv_classes[6][10][8] = int_stack + 242984;
 Libderiv->deriv_classes[6][11][8] = int_stack + 244832;
 Libderiv->deriv_classes[7][6][8] = int_stack + 247016;
 Libderiv->deriv_classes[7][7][8] = int_stack + 248024;
 Libderiv->deriv_classes[7][8][8] = int_stack + 249320;
 Libderiv->deriv_classes[7][9][8] = int_stack + 250940;
 Libderiv->deriv_classes[7][10][8] = int_stack + 252920;
 Libderiv->deriv_classes[7][11][8] = int_stack + 255296;
 Libderiv->deriv_classes[8][6][8] = int_stack + 258104;
 Libderiv->deriv_classes[8][7][8] = int_stack + 259364;
 Libderiv->deriv_classes[8][8][8] = int_stack + 260984;
 Libderiv->deriv_classes[8][9][8] = int_stack + 263009;
 Libderiv->deriv_classes[8][10][8] = int_stack + 265484;
 Libderiv->deriv_classes[8][11][8] = int_stack + 268454;
 Libderiv->deriv_classes[9][6][8] = int_stack + 271964;
 Libderiv->deriv_classes[9][7][8] = int_stack + 273504;
 Libderiv->deriv_classes[9][8][8] = int_stack + 275484;
 Libderiv->deriv_classes[9][9][8] = int_stack + 277959;
 Libderiv->deriv_classes[9][10][8] = int_stack + 280984;
 Libderiv->deriv_classes[9][11][8] = int_stack + 284614;
 Libderiv->deriv_classes[10][6][8] = int_stack + 288904;
 Libderiv->deriv_classes[10][7][8] = int_stack + 290752;
 Libderiv->deriv_classes[10][8][8] = int_stack + 293128;
 Libderiv->deriv_classes[10][9][8] = int_stack + 296098;
 Libderiv->deriv_classes[10][10][8] = int_stack + 299728;
 Libderiv->deriv_classes[10][11][8] = int_stack + 304084;
 Libderiv->deriv_classes[5][6][7] = int_stack + 309232;
 Libderiv->deriv_classes[5][7][7] = int_stack + 309820;
 Libderiv->deriv_classes[5][8][7] = int_stack + 310576;
 Libderiv->deriv_classes[5][9][7] = int_stack + 311521;
 Libderiv->deriv_classes[5][10][7] = int_stack + 312676;
 Libderiv->deriv_classes[5][11][7] = int_stack + 314062;
 Libderiv->deriv_classes[6][6][7] = int_stack + 315700;
 Libderiv->deriv_classes[6][7][7] = int_stack + 316484;
 Libderiv->deriv_classes[6][8][7] = int_stack + 317492;
 Libderiv->deriv_classes[6][9][7] = int_stack + 318752;
 Libderiv->deriv_classes[6][10][7] = int_stack + 320292;
 Libderiv->deriv_classes[6][11][7] = int_stack + 322140;
 Libderiv->deriv_classes[7][6][7] = int_stack + 324324;
 Libderiv->deriv_classes[7][7][7] = int_stack + 325332;
 Libderiv->deriv_classes[7][8][7] = int_stack + 326628;
 Libderiv->deriv_classes[7][9][7] = int_stack + 328248;
 Libderiv->deriv_classes[7][10][7] = int_stack + 330228;
 Libderiv->deriv_classes[7][11][7] = int_stack + 332604;
 Libderiv->deriv_classes[8][6][7] = int_stack + 335412;
 Libderiv->deriv_classes[8][7][7] = int_stack + 336672;
 Libderiv->deriv_classes[8][8][7] = int_stack + 338292;
 Libderiv->deriv_classes[8][9][7] = int_stack + 340317;
 Libderiv->deriv_classes[8][10][7] = int_stack + 342792;
 Libderiv->deriv_classes[8][11][7] = int_stack + 345762;
 Libderiv->deriv_classes[9][6][7] = int_stack + 349272;
 Libderiv->deriv_classes[9][7][7] = int_stack + 350812;
 Libderiv->deriv_classes[9][8][7] = int_stack + 352792;
 Libderiv->deriv_classes[9][9][7] = int_stack + 355267;
 Libderiv->deriv_classes[9][10][7] = int_stack + 358292;
 Libderiv->deriv_classes[9][11][7] = int_stack + 361922;
 Libderiv->deriv_classes[10][6][7] = int_stack + 366212;
 Libderiv->deriv_classes[10][7][7] = int_stack + 368060;
 Libderiv->deriv_classes[10][8][7] = int_stack + 370436;
 Libderiv->deriv_classes[10][9][7] = int_stack + 373406;
 Libderiv->deriv_classes[10][10][7] = int_stack + 377036;
 Libderiv->deriv_classes[10][11][7] = int_stack + 381392;
 Libderiv->deriv_classes[5][6][6] = int_stack + 386540;
 Libderiv->deriv_classes[5][7][6] = int_stack + 387128;
 Libderiv->deriv_classes[5][8][6] = int_stack + 387884;
 Libderiv->deriv_classes[5][9][6] = int_stack + 388829;
 Libderiv->deriv_classes[5][10][6] = int_stack + 389984;
 Libderiv->deriv_classes[5][11][6] = int_stack + 391370;
 Libderiv->deriv_classes[6][6][6] = int_stack + 393008;
 Libderiv->deriv_classes[6][7][6] = int_stack + 393792;
 Libderiv->deriv_classes[6][8][6] = int_stack + 394800;
 Libderiv->deriv_classes[6][9][6] = int_stack + 396060;
 Libderiv->deriv_classes[6][10][6] = int_stack + 397600;
 Libderiv->deriv_classes[6][11][6] = int_stack + 399448;
 Libderiv->deriv_classes[7][6][6] = int_stack + 401632;
 Libderiv->deriv_classes[7][7][6] = int_stack + 402640;
 Libderiv->deriv_classes[7][8][6] = int_stack + 403936;
 Libderiv->deriv_classes[7][9][6] = int_stack + 405556;
 Libderiv->deriv_classes[7][10][6] = int_stack + 407536;
 Libderiv->deriv_classes[7][11][6] = int_stack + 409912;
 Libderiv->deriv_classes[8][6][6] = int_stack + 412720;
 Libderiv->deriv_classes[8][7][6] = int_stack + 413980;
 Libderiv->deriv_classes[8][8][6] = int_stack + 415600;
 Libderiv->deriv_classes[8][9][6] = int_stack + 417625;
 Libderiv->deriv_classes[8][10][6] = int_stack + 420100;
 Libderiv->deriv_classes[8][11][6] = int_stack + 423070;
 Libderiv->deriv_classes[9][6][6] = int_stack + 426580;
 Libderiv->deriv_classes[9][7][6] = int_stack + 428120;
 Libderiv->deriv_classes[9][8][6] = int_stack + 430100;
 Libderiv->deriv_classes[9][9][6] = int_stack + 432575;
 Libderiv->deriv_classes[9][10][6] = int_stack + 435600;
 Libderiv->deriv_classes[9][11][6] = int_stack + 439230;
 Libderiv->dvrr_classes[10][6] = int_stack + 443520;
 Libderiv->deriv_classes[10][6][6] = int_stack + 445368;
 Libderiv->dvrr_classes[10][7] = int_stack + 447216;
 Libderiv->deriv_classes[10][7][6] = int_stack + 449592;
 Libderiv->dvrr_classes[10][8] = int_stack + 451968;
 Libderiv->deriv_classes[10][8][6] = int_stack + 454938;
 Libderiv->dvrr_classes[10][9] = int_stack + 457908;
 Libderiv->deriv_classes[10][9][6] = int_stack + 461538;
 Libderiv->dvrr_classes[10][10] = int_stack + 465168;
 Libderiv->deriv_classes[10][10][6] = int_stack + 469524;
 Libderiv->deriv_classes[10][11][6] = int_stack + 473880;
 Libderiv->deriv_classes[5][6][2] = int_stack + 479028;
 Libderiv->deriv_classes[5][7][2] = int_stack + 479616;
 Libderiv->deriv_classes[5][8][2] = int_stack + 480372;
 Libderiv->deriv_classes[5][9][2] = int_stack + 481317;
 Libderiv->deriv_classes[5][10][2] = int_stack + 482472;
 Libderiv->deriv_classes[5][11][2] = int_stack + 483858;
 Libderiv->deriv_classes[6][6][2] = int_stack + 485496;
 Libderiv->deriv_classes[6][7][2] = int_stack + 486280;
 Libderiv->deriv_classes[6][8][2] = int_stack + 487288;
 Libderiv->deriv_classes[6][9][2] = int_stack + 488548;
 Libderiv->deriv_classes[6][10][2] = int_stack + 490088;
 Libderiv->deriv_classes[6][11][2] = int_stack + 491936;
 Libderiv->deriv_classes[7][6][2] = int_stack + 494120;
 Libderiv->deriv_classes[7][7][2] = int_stack + 495128;
 Libderiv->deriv_classes[7][8][2] = int_stack + 496424;
 Libderiv->deriv_classes[7][9][2] = int_stack + 498044;
 Libderiv->deriv_classes[7][10][2] = int_stack + 500024;
 Libderiv->deriv_classes[7][11][2] = int_stack + 502400;
 Libderiv->deriv_classes[8][6][2] = int_stack + 505208;
 Libderiv->deriv_classes[8][7][2] = int_stack + 506468;
 Libderiv->deriv_classes[8][8][2] = int_stack + 508088;
 Libderiv->deriv_classes[8][9][2] = int_stack + 510113;
 Libderiv->deriv_classes[8][10][2] = int_stack + 512588;
 Libderiv->deriv_classes[8][11][2] = int_stack + 515558;
 Libderiv->deriv_classes[9][6][2] = int_stack + 519068;
 Libderiv->deriv_classes[9][7][2] = int_stack + 520608;
 Libderiv->deriv_classes[9][8][2] = int_stack + 522588;
 Libderiv->deriv_classes[9][9][2] = int_stack + 525063;
 Libderiv->deriv_classes[9][10][2] = int_stack + 528088;
 Libderiv->deriv_classes[9][11][2] = int_stack + 531718;
 Libderiv->deriv_classes[10][6][2] = int_stack + 536008;
 Libderiv->deriv_classes[10][7][2] = int_stack + 537856;
 Libderiv->deriv_classes[10][8][2] = int_stack + 540232;
 Libderiv->deriv_classes[10][9][2] = int_stack + 543202;
 Libderiv->deriv_classes[10][10][2] = int_stack + 546832;
 Libderiv->deriv_classes[10][11][2] = int_stack + 551188;
 Libderiv->deriv_classes[5][6][1] = int_stack + 556336;
 Libderiv->deriv_classes[5][7][1] = int_stack + 556924;
 Libderiv->deriv_classes[5][8][1] = int_stack + 557680;
 Libderiv->deriv_classes[5][9][1] = int_stack + 558625;
 Libderiv->deriv_classes[5][10][1] = int_stack + 559780;
 Libderiv->deriv_classes[5][11][1] = int_stack + 561166;
 Libderiv->deriv_classes[6][6][1] = int_stack + 562804;
 Libderiv->deriv_classes[6][7][1] = int_stack + 563588;
 Libderiv->deriv_classes[6][8][1] = int_stack + 564596;
 Libderiv->deriv_classes[6][9][1] = int_stack + 565856;
 Libderiv->deriv_classes[6][10][1] = int_stack + 567396;
 Libderiv->deriv_classes[6][11][1] = int_stack + 569244;
 Libderiv->deriv_classes[7][6][1] = int_stack + 571428;
 Libderiv->deriv_classes[7][7][1] = int_stack + 572436;
 Libderiv->deriv_classes[7][8][1] = int_stack + 573732;
 Libderiv->deriv_classes[7][9][1] = int_stack + 575352;
 Libderiv->deriv_classes[7][10][1] = int_stack + 577332;
 Libderiv->deriv_classes[7][11][1] = int_stack + 579708;
 Libderiv->deriv_classes[8][6][1] = int_stack + 582516;
 Libderiv->deriv_classes[8][7][1] = int_stack + 583776;
 Libderiv->deriv_classes[8][8][1] = int_stack + 585396;
 Libderiv->deriv_classes[8][9][1] = int_stack + 587421;
 Libderiv->deriv_classes[8][10][1] = int_stack + 589896;
 Libderiv->deriv_classes[8][11][1] = int_stack + 592866;
 Libderiv->deriv_classes[9][6][1] = int_stack + 596376;
 Libderiv->deriv_classes[9][7][1] = int_stack + 597916;
 Libderiv->deriv_classes[9][8][1] = int_stack + 599896;
 Libderiv->deriv_classes[9][9][1] = int_stack + 602371;
 Libderiv->deriv_classes[9][10][1] = int_stack + 605396;
 Libderiv->deriv_classes[9][11][1] = int_stack + 609026;
 Libderiv->deriv_classes[10][6][1] = int_stack + 613316;
 Libderiv->deriv_classes[10][7][1] = int_stack + 615164;
 Libderiv->deriv_classes[10][8][1] = int_stack + 617540;
 Libderiv->deriv_classes[10][9][1] = int_stack + 620510;
 Libderiv->deriv_classes[10][10][1] = int_stack + 624140;
 Libderiv->deriv_classes[10][11][1] = int_stack + 628496;
 Libderiv->dvrr_classes[5][6] = int_stack + 633644;
 Libderiv->dvrr_classes[5][7] = int_stack + 634232;
 Libderiv->dvrr_classes[5][8] = int_stack + 634988;
 Libderiv->dvrr_classes[5][9] = int_stack + 635933;
 Libderiv->dvrr_classes[5][10] = int_stack + 637088;
 Libderiv->dvrr_classes[5][11] = int_stack + 638474;
 Libderiv->deriv_classes[5][6][0] = int_stack + 640112;
 Libderiv->deriv_classes[5][7][0] = int_stack + 640700;
 Libderiv->deriv_classes[5][8][0] = int_stack + 641456;
 Libderiv->deriv_classes[5][9][0] = int_stack + 642401;
 Libderiv->deriv_classes[5][10][0] = int_stack + 643556;
 Libderiv->deriv_classes[5][11][0] = int_stack + 644942;
 Libderiv->dvrr_classes[6][6] = int_stack + 646580;
 Libderiv->dvrr_classes[6][7] = int_stack + 647364;
 Libderiv->dvrr_classes[6][8] = int_stack + 648372;
 Libderiv->dvrr_classes[6][9] = int_stack + 649632;
 Libderiv->dvrr_classes[6][10] = int_stack + 651172;
 Libderiv->dvrr_classes[6][11] = int_stack + 653020;
 Libderiv->deriv_classes[6][6][0] = int_stack + 655204;
 Libderiv->deriv_classes[6][7][0] = int_stack + 655988;
 Libderiv->deriv_classes[6][8][0] = int_stack + 656996;
 Libderiv->deriv_classes[6][9][0] = int_stack + 658256;
 Libderiv->deriv_classes[6][10][0] = int_stack + 659796;
 Libderiv->deriv_classes[6][11][0] = int_stack + 661644;
 Libderiv->dvrr_classes[7][6] = int_stack + 663828;
 Libderiv->dvrr_classes[7][7] = int_stack + 664836;
 Libderiv->dvrr_classes[7][8] = int_stack + 666132;
 Libderiv->dvrr_classes[7][9] = int_stack + 667752;
 Libderiv->dvrr_classes[7][10] = int_stack + 669732;
 Libderiv->dvrr_classes[7][11] = int_stack + 672108;
 Libderiv->deriv_classes[7][6][0] = int_stack + 674916;
 Libderiv->deriv_classes[7][7][0] = int_stack + 675924;
 Libderiv->deriv_classes[7][8][0] = int_stack + 677220;
 Libderiv->deriv_classes[7][9][0] = int_stack + 678840;
 Libderiv->deriv_classes[7][10][0] = int_stack + 680820;
 Libderiv->deriv_classes[7][11][0] = int_stack + 683196;
 Libderiv->dvrr_classes[8][6] = int_stack + 686004;
 Libderiv->dvrr_classes[8][7] = int_stack + 687264;
 Libderiv->dvrr_classes[8][8] = int_stack + 688884;
 Libderiv->dvrr_classes[8][9] = int_stack + 690909;
 Libderiv->dvrr_classes[8][10] = int_stack + 693384;
 Libderiv->dvrr_classes[8][11] = int_stack + 696354;
 Libderiv->deriv_classes[8][6][0] = int_stack + 699864;
 Libderiv->deriv_classes[8][7][0] = int_stack + 701124;
 Libderiv->deriv_classes[8][8][0] = int_stack + 702744;
 Libderiv->deriv_classes[8][9][0] = int_stack + 704769;
 Libderiv->deriv_classes[8][10][0] = int_stack + 707244;
 Libderiv->deriv_classes[8][11][0] = int_stack + 710214;
 Libderiv->dvrr_classes[9][6] = int_stack + 713724;
 Libderiv->dvrr_classes[9][7] = int_stack + 715264;
 Libderiv->dvrr_classes[9][8] = int_stack + 717244;
 Libderiv->dvrr_classes[9][9] = int_stack + 719719;
 Libderiv->dvrr_classes[9][10] = int_stack + 722744;
 Libderiv->dvrr_classes[9][11] = int_stack + 726374;
 Libderiv->deriv_classes[9][6][0] = int_stack + 730664;
 Libderiv->deriv_classes[9][7][0] = int_stack + 732204;
 Libderiv->deriv_classes[9][8][0] = int_stack + 734184;
 Libderiv->deriv_classes[9][9][0] = int_stack + 736659;
 Libderiv->deriv_classes[9][10][0] = int_stack + 739684;
 Libderiv->deriv_classes[9][11][0] = int_stack + 743314;
 Libderiv->deriv_classes[10][6][0] = int_stack + 747604;
 Libderiv->deriv_classes[10][7][0] = int_stack + 749452;
 Libderiv->deriv_classes[10][8][0] = int_stack + 751828;
 Libderiv->deriv_classes[10][9][0] = int_stack + 754798;
 Libderiv->deriv_classes[10][10][0] = int_stack + 758428;
 Libderiv->deriv_classes[10][11][0] = int_stack + 762784;
 memset(int_stack,0,6143456);

 Libderiv->dvrr_stack = int_stack + 5789006;
 for(i=0;i<num_prim_comb;i++) {
   d1vrr_order_hhih(Libderiv, Data);
   Data++;
 }

 /*--- compute (h0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+767932,int_stack+634232,int_stack+633644,21);
 /*--- compute (h0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+769696,int_stack+634988,int_stack+634232,21);
 /*--- compute (h0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+771964,int_stack+769696,int_stack+767932,21);
 /*--- compute (h0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+775492,int_stack+635933,int_stack+634988,21);
 /*--- compute (h0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+778327,int_stack+775492,int_stack+769696,21);
 /*--- compute (h0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+782863,int_stack+778327,int_stack+771964,21);
 /*--- compute (h0|mp) ---*/
   hrr3_build_mp(Libderiv->CD,int_stack+788743,int_stack+637088,int_stack+635933,21);
 /*--- compute (h0|ld) ---*/
   hrr3_build_ld(Libderiv->CD,int_stack+792208,int_stack+788743,int_stack+775492,21);
 /*--- compute (h0|kf) ---*/
   hrr3_build_kf(Libderiv->CD,int_stack+797878,int_stack+792208,int_stack+778327,21);
 /*--- compute (h0|ig) ---*/
   hrr3_build_ig(Libderiv->CD,int_stack+805438,int_stack+797878,int_stack+782863,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+814258,int_stack+588,int_stack+0, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+633644,21);
 /*--- compute (h0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+816022,int_stack+1344,int_stack+588, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+634232,21);
 /*--- compute (h0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+818290,int_stack+816022,int_stack+814258, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+767932,21);
 /*--- compute (h0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+821818,int_stack+2289,int_stack+1344, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+634988,21);
 /*--- compute (h0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+824653,int_stack+821818,int_stack+816022, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+769696,21);
 /*--- compute (h0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+829189,int_stack+824653,int_stack+818290, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+771964,21);
 /*--- compute (h0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+814258,int_stack+3444,int_stack+2289, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+635933,21);
 /*--- compute (h0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+835069,int_stack+814258,int_stack+821818, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+775492,21);
 /*--- compute (h0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+840739,int_stack+835069,int_stack+824653, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+778327,21);
 /*--- compute (h0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+817723,int_stack+840739,int_stack+829189, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+782863,21);
 /*--- compute (h0|np) ---*/
   d1hrr3_build_np(Libderiv->CD,int_stack+826543,int_stack+4830,int_stack+3444, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+637088,21);
 /*--- compute (h0|md) ---*/
   d1hrr3_build_md(Libderiv->CD,int_stack+848299,int_stack+826543,int_stack+814258, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+788743,21);
 /*--- compute (h0|lf) ---*/
   d1hrr3_build_lf(Libderiv->CD,int_stack+855229,int_stack+848299,int_stack+835069, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+792208,21);
 /*--- compute (h0|kg) ---*/
   d1hrr3_build_kg(Libderiv->CD,int_stack+826543,int_stack+855229,int_stack+840739, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+797878,21);
 /*--- compute (h0|ih) ---*/
   d1hrr3_build_ih(Libderiv->CD,int_stack+837883,int_stack+826543,int_stack+817723, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+805438,21);
 /*--- compute (i0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+814258,int_stack+647364,int_stack+646580,28);
 /*--- compute (i0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+816610,int_stack+648372,int_stack+647364,28);
 /*--- compute (i0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+819634,int_stack+816610,int_stack+814258,28);
 /*--- compute (i0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+824338,int_stack+649632,int_stack+648372,28);
 /*--- compute (i0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+828118,int_stack+824338,int_stack+816610,28);
 /*--- compute (i0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+850231,int_stack+828118,int_stack+819634,28);
 /*--- compute (i0|mp) ---*/
   hrr3_build_mp(Libderiv->CD,int_stack+858071,int_stack+651172,int_stack+649632,28);
 /*--- compute (i0|ld) ---*/
   hrr3_build_ld(Libderiv->CD,int_stack+862691,int_stack+858071,int_stack+824338,28);
 /*--- compute (i0|kf) ---*/
   hrr3_build_kf(Libderiv->CD,int_stack+870251,int_stack+862691,int_stack+828118,28);
 /*--- compute (i0|ig) ---*/
   hrr3_build_ig(Libderiv->CD,int_stack+880331,int_stack+870251,int_stack+850231,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+834166,int_stack+7252,int_stack+6468, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+646580,28);
 /*--- compute (i0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+0,int_stack+8260,int_stack+7252, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+647364,28);
 /*--- compute (i0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+3024,int_stack+0,int_stack+834166, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+814258,28);
 /*--- compute (i0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+892091,int_stack+9520,int_stack+8260, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+648372,28);
 /*--- compute (i0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+895871,int_stack+892091,int_stack+0, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+816610,28);
 /*--- compute (i0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+901919,int_stack+895871,int_stack+3024, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+819634,28);
 /*--- compute (i0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+0,int_stack+11060,int_stack+9520, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+649632,28);
 /*--- compute (i0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+909759,int_stack+0,int_stack+892091, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+824338,28);
 /*--- compute (i0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+917319,int_stack+909759,int_stack+895871, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+828118,28);
 /*--- compute (i0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+927399,int_stack+917319,int_stack+901919, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+850231,28);
 /*--- compute (i0|np) ---*/
   d1hrr3_build_np(Libderiv->CD,int_stack+892091,int_stack+12908,int_stack+11060, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+651172,28);
 /*--- compute (i0|md) ---*/
   d1hrr3_build_md(Libderiv->CD,int_stack+897635,int_stack+892091,int_stack+0, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+858071,28);
 /*--- compute (i0|lf) ---*/
   d1hrr3_build_lf(Libderiv->CD,int_stack+0,int_stack+897635,int_stack+909759, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+862691,28);
 /*--- compute (i0|kg) ---*/
   d1hrr3_build_kg(Libderiv->CD,int_stack+892091,int_stack+0,int_stack+917319, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+870251,28);
 /*--- compute (i0|ih) ---*/
   d1hrr3_build_ih(Libderiv->CD,int_stack+907211,int_stack+892091,int_stack+927399, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+880331,28);
 /*--- compute (hp|ih) ---*/
   hrr1_build_hp(Libderiv->AB,int_stack+923675,int_stack+907211,int_stack+837883,588);
 /*--- compute (k0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+892091,int_stack+664836,int_stack+663828,36);
 /*--- compute (k0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+895115,int_stack+666132,int_stack+664836,36);
 /*--- compute (k0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+899003,int_stack+895115,int_stack+892091,36);
 /*--- compute (k0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+0,int_stack+667752,int_stack+666132,36);
 /*--- compute (k0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+4860,int_stack+0,int_stack+895115,36);
 /*--- compute (k0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+834166,int_stack+4860,int_stack+899003,36);
 /*--- compute (k0|mp) ---*/
   hrr3_build_mp(Libderiv->CD,int_stack+844246,int_stack+669732,int_stack+667752,36);
 /*--- compute (k0|ld) ---*/
   hrr3_build_ld(Libderiv->CD,int_stack+960719,int_stack+844246,int_stack+0,36);
 /*--- compute (k0|kf) ---*/
   hrr3_build_kf(Libderiv->CD,int_stack+970439,int_stack+960719,int_stack+4860,36);
 /*--- compute (k0|ig) ---*/
   hrr3_build_ig(Libderiv->CD,int_stack+983399,int_stack+970439,int_stack+834166,36);
 /*--- compute (k0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+998519,int_stack+16100,int_stack+15092, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+663828,36);
 /*--- compute (k0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+1001543,int_stack+17396,int_stack+16100, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+664836,36);
 /*--- compute (k0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+1005431,int_stack+1001543,int_stack+998519, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+892091,36);
 /*--- compute (k0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+1011479,int_stack+19016,int_stack+17396, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+666132,36);
 /*--- compute (k0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+1016339,int_stack+1011479,int_stack+1001543, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+895115,36);
 /*--- compute (k0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+1024115,int_stack+1016339,int_stack+1005431, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+899003,36);
 /*--- compute (k0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+998519,int_stack+20996,int_stack+19016, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+667752,36);
 /*--- compute (k0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+1034195,int_stack+998519,int_stack+1011479, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+0,36);
 /*--- compute (k0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+1043915,int_stack+1034195,int_stack+1016339, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+4860,36);
 /*--- compute (k0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+1004459,int_stack+1043915,int_stack+1024115, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+834166,36);
 /*--- compute (k0|np) ---*/
   d1hrr3_build_np(Libderiv->CD,int_stack+1019579,int_stack+23372,int_stack+20996, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+669732,36);
 /*--- compute (k0|md) ---*/
   d1hrr3_build_md(Libderiv->CD,int_stack+12636,int_stack+1019579,int_stack+998519, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+844246,36);
 /*--- compute (k0|lf) ---*/
   d1hrr3_build_lf(Libderiv->CD,int_stack+1056875,int_stack+12636,int_stack+1034195, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+960719,36);
 /*--- compute (k0|kg) ---*/
   d1hrr3_build_kg(Libderiv->CD,int_stack+1019579,int_stack+1056875,int_stack+1043915, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+970439,36);
 /*--- compute (k0|ih) ---*/
   d1hrr3_build_ih(Libderiv->CD,int_stack+1039019,int_stack+1019579,int_stack+1004459, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+983399,36);
 /*--- compute (ip|ih) ---*/
   hrr1_build_ip(Libderiv->AB,int_stack+1060187,int_stack+1039019,int_stack+907211,588);
 /*--- compute (hd|ih) ---*/
   hrr1_build_hd(Libderiv->AB,int_stack+1109579,int_stack+1060187,int_stack+923675,588);
 /*--- compute (l0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+12636,int_stack+687264,int_stack+686004,45);
 /*--- compute (l0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+16416,int_stack+688884,int_stack+687264,45);
 /*--- compute (l0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+998519,int_stack+16416,int_stack+12636,45);
 /*--- compute (l0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+1006079,int_stack+690909,int_stack+688884,45);
 /*--- compute (l0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+1012154,int_stack+1006079,int_stack+16416,45);
 /*--- compute (l0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+1021874,int_stack+1012154,int_stack+998519,45);
 /*--- compute (l0|mp) ---*/
   hrr3_build_mp(Libderiv->CD,int_stack+905051,int_stack+693384,int_stack+690909,45);
 /*--- compute (l0|ld) ---*/
   hrr3_build_ld(Libderiv->CD,int_stack+912476,int_stack+905051,int_stack+1006079,45);
 /*--- compute (l0|kf) ---*/
   hrr3_build_kf(Libderiv->CD,int_stack+924626,int_stack+912476,int_stack+1012154,45);
 /*--- compute (l0|ig) ---*/
   hrr3_build_ig(Libderiv->CD,int_stack+940826,int_stack+924626,int_stack+1021874,45);
 /*--- compute (l0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+21276,int_stack+27440,int_stack+26180, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+686004,45);
 /*--- compute (l0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+1183667,int_stack+29060,int_stack+27440, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+687264,45);
 /*--- compute (l0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+1188527,int_stack+1183667,int_stack+21276, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+12636,45);
 /*--- compute (l0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+21276,int_stack+31085,int_stack+29060, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+688884,45);
 /*--- compute (l0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+1196087,int_stack+21276,int_stack+1183667, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+16416,45);
 /*--- compute (l0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+1205807,int_stack+1196087,int_stack+1188527, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+998519,45);
 /*--- compute (l0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+1183667,int_stack+33560,int_stack+31085, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+690909,45);
 /*--- compute (l0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+1218407,int_stack+1183667,int_stack+21276, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1006079,45);
 /*--- compute (l0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+1230557,int_stack+1218407,int_stack+1196087, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1012154,45);
 /*--- compute (l0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+1246757,int_stack+1230557,int_stack+1205807, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1021874,45);
 /*--- compute (l0|np) ---*/
   d1hrr3_build_np(Libderiv->CD,int_stack+21276,int_stack+36530,int_stack+33560, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+693384,45);
 /*--- compute (l0|md) ---*/
   d1hrr3_build_md(Libderiv->CD,int_stack+1191092,int_stack+21276,int_stack+1183667, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+905051,45);
 /*--- compute (l0|lf) ---*/
   d1hrr3_build_lf(Libderiv->CD,int_stack+1265657,int_stack+1191092,int_stack+1218407, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+912476,45);
 /*--- compute (l0|kg) ---*/
   d1hrr3_build_kg(Libderiv->CD,int_stack+1183667,int_stack+1265657,int_stack+1230557, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+924626,45);
 /*--- compute (l0|ih) ---*/
   d1hrr3_build_ih(Libderiv->CD,int_stack+1207967,int_stack+1183667,int_stack+1246757, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+940826,45);
 /*--- compute (kp|ih) ---*/
   hrr1_build_kp(Libderiv->AB,int_stack+1234427,int_stack+1207967,int_stack+1039019,588);
 /*--- compute (id|ih) ---*/
   hrr1_build_id(Libderiv->AB,int_stack+1297931,int_stack+1234427,int_stack+1060187,588);
 /*--- compute (hf|ih) ---*/
   hrr1_build_hf(Libderiv->AB,int_stack+1396715,int_stack+1297931,int_stack+1109579,588);
 /*--- compute (m0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+21276,int_stack+715264,int_stack+713724,55);
 /*--- compute (m0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+25896,int_stack+717244,int_stack+715264,55);
 /*--- compute (m0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+1034474,int_stack+25896,int_stack+21276,55);
 /*--- compute (m0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+31836,int_stack+719719,int_stack+717244,55);
 /*--- compute (m0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+1043714,int_stack+31836,int_stack+25896,55);
 /*--- compute (m0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+1055594,int_stack+1043714,int_stack+1034474,55);
 /*--- compute (m0|mp) ---*/
   hrr3_build_mp(Libderiv->CD,int_stack+1070994,int_stack+722744,int_stack+719719,55);
 /*--- compute (m0|ld) ---*/
   hrr3_build_ld(Libderiv->CD,int_stack+1080069,int_stack+1070994,int_stack+31836,55);
 /*--- compute (m0|kf) ---*/
   hrr3_build_kf(Libderiv->CD,int_stack+1094919,int_stack+1080069,int_stack+1043714,55);
 /*--- compute (m0|ig) ---*/
   hrr3_build_ig(Libderiv->CD,int_stack+1114719,int_stack+1094919,int_stack+1055594,55);
 /*--- compute (m0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+1137819,int_stack+41580,int_stack+40040, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+713724,55);
 /*--- compute (m0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+1142439,int_stack+43560,int_stack+41580, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+715264,55);
 /*--- compute (m0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+1148379,int_stack+1142439,int_stack+1137819, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+21276,55);
 /*--- compute (m0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+1157619,int_stack+46035,int_stack+43560, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+717244,55);
 /*--- compute (m0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+1165044,int_stack+1157619,int_stack+1142439, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+25896,55);
 /*--- compute (m0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+1176924,int_stack+1165044,int_stack+1148379, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1034474,55);
 /*--- compute (m0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+1137819,int_stack+49060,int_stack+46035, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+719719,55);
 /*--- compute (m0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+1192324,int_stack+1137819,int_stack+1157619, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+31836,55);
 /*--- compute (m0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+1520195,int_stack+1192324,int_stack+1165044, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1043714,55);
 /*--- compute (m0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+1146894,int_stack+1520195,int_stack+1176924, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1055594,55);
 /*--- compute (m0|np) ---*/
   d1hrr3_build_np(Libderiv->CD,int_stack+1169994,int_stack+52690,int_stack+49060, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+722744,55);
 /*--- compute (m0|md) ---*/
   d1hrr3_build_md(Libderiv->CD,int_stack+1539995,int_stack+1169994,int_stack+1137819, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1070994,55);
 /*--- compute (m0|lf) ---*/
   d1hrr3_build_lf(Libderiv->CD,int_stack+1558145,int_stack+1539995,int_stack+1192324, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1080069,55);
 /*--- compute (m0|kg) ---*/
   d1hrr3_build_kg(Libderiv->CD,int_stack+1169994,int_stack+1558145,int_stack+1520195, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1094919,55);
 /*--- compute (m0|ih) ---*/
   d1hrr3_build_ih(Libderiv->CD,int_stack+1520195,int_stack+1169994,int_stack+1146894, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1114719,55);
 /*--- compute (lp|ih) ---*/
   hrr1_build_lp(Libderiv->AB,int_stack+1552535,int_stack+1520195,int_stack+1207967,588);
 /*--- compute (kd|ih) ---*/
   hrr1_build_kd(Libderiv->AB,int_stack+1631915,int_stack+1552535,int_stack+1234427,588);
 /*--- compute (if|ih) ---*/
   hrr1_build_if(Libderiv->AB,int_stack+1758923,int_stack+1631915,int_stack+1297931,588);
 /*--- compute (hg|ih) ---*/
   hrr1_build_hg(Libderiv->AB,int_stack+1137819,int_stack+1758923,int_stack+1396715,588);
 /*--- compute (n0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+1323039,int_stack+447216,int_stack+443520,66);
 /*--- compute (n0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+1328583,int_stack+451968,int_stack+447216,66);
 /*--- compute (n0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+1335711,int_stack+1328583,int_stack+1323039,66);
 /*--- compute (n0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+1346799,int_stack+457908,int_stack+451968,66);
 /*--- compute (n0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+1355709,int_stack+1346799,int_stack+1328583,66);
 /*--- compute (n0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+1369965,int_stack+1355709,int_stack+1335711,66);
 /*--- compute (n0|mp) ---*/
   hrr3_build_mp(Libderiv->CD,int_stack+1388445,int_stack+465168,int_stack+457908,66);
 /*--- compute (n0|ld) ---*/
   hrr3_build_ld(Libderiv->CD,int_stack+1399335,int_stack+1388445,int_stack+1346799,66);
 /*--- compute (n0|kf) ---*/
   hrr3_build_kf(Libderiv->CD,int_stack+1417155,int_stack+1399335,int_stack+1355709,66);
 /*--- compute (n0|ig) ---*/
   hrr3_build_ig(Libderiv->CD,int_stack+1440915,int_stack+1417155,int_stack+1369965,66);
 /*--- compute (n0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+1468635,int_stack+58828,int_stack+56980, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+443520,66);
 /*--- compute (n0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+1474179,int_stack+61204,int_stack+58828, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+447216,66);
 /*--- compute (n0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+1481307,int_stack+1474179,int_stack+1468635, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1323039,66);
 /*--- compute (n0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+1492395,int_stack+64174,int_stack+61204, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+451968,66);
 /*--- compute (n0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+1501305,int_stack+1492395,int_stack+1474179, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1328583,66);
 /*--- compute (n0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+39261,int_stack+1501305,int_stack+1481307, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1335711,66);
 /*--- compute (n0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+1468635,int_stack+67804,int_stack+64174, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+457908,66);
 /*--- compute (n0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+1923563,int_stack+1468635,int_stack+1492395, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1346799,66);
 /*--- compute (n0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+1941383,int_stack+1923563,int_stack+1501305, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1355709,66);
 /*--- compute (n0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+1479525,int_stack+1941383,int_stack+39261, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1369965,66);
 /*--- compute (n0|np) ---*/
   d1hrr3_build_np(Libderiv->CD,int_stack+39261,int_stack+72160,int_stack+67804, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+465168,66);
 /*--- compute (n0|md) ---*/
   d1hrr3_build_md(Libderiv->CD,int_stack+52329,int_stack+39261,int_stack+1468635, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1388445,66);
 /*--- compute (n0|lf) ---*/
   d1hrr3_build_lf(Libderiv->CD,int_stack+1965143,int_stack+52329,int_stack+1923563, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1399335,66);
 /*--- compute (n0|kg) ---*/
   d1hrr3_build_kg(Libderiv->CD,int_stack+39261,int_stack+1965143,int_stack+1941383, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1417155,66);
 /*--- compute (n0|ih) ---*/
   d1hrr3_build_ih(Libderiv->CD,int_stack+1923563,int_stack+39261,int_stack+1479525, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1440915,66);
 /*--- compute (mp|ih) ---*/
   hrr1_build_mp(Libderiv->AB,int_stack+1962371,int_stack+1923563,int_stack+1520195,588);
 /*--- compute (ld|ih) ---*/
   hrr1_build_ld(Libderiv->AB,int_stack+2059391,int_stack+1962371,int_stack+1552535,588);
 /*--- compute (kf|ih) ---*/
   hrr1_build_kf(Libderiv->AB,int_stack+2218151,int_stack+2059391,int_stack+1631915,588);
 /*--- compute (ig|ih) ---*/
   hrr1_build_ig(Libderiv->AB,int_stack+1923563,int_stack+2218151,int_stack+1758923,588);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+2170523,int_stack+77896,int_stack+77308, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+633644, 0.0, zero_stack,21);
 /*--- compute (h0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+2172287,int_stack+78652,int_stack+77896, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+634232, 0.0, zero_stack,21);
 /*--- compute (h0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+2174555,int_stack+2172287,int_stack+2170523, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+767932, 0.0, zero_stack,21);
 /*--- compute (h0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+2178083,int_stack+79597,int_stack+78652, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+634988, 0.0, zero_stack,21);
 /*--- compute (h0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+2180918,int_stack+2178083,int_stack+2172287, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+769696, 0.0, zero_stack,21);
 /*--- compute (h0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+2185454,int_stack+2180918,int_stack+2174555, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+771964, 0.0, zero_stack,21);
 /*--- compute (h0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+2170523,int_stack+80752,int_stack+79597, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+635933, 0.0, zero_stack,21);
 /*--- compute (h0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+2191334,int_stack+2170523,int_stack+2178083, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+775492, 0.0, zero_stack,21);
 /*--- compute (h0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+2197004,int_stack+2191334,int_stack+2180918, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+778327, 0.0, zero_stack,21);
 /*--- compute (h0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+2173988,int_stack+2197004,int_stack+2185454, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+782863, 0.0, zero_stack,21);
 /*--- compute (h0|np) ---*/
   d1hrr3_build_np(Libderiv->CD,int_stack+2182808,int_stack+82138,int_stack+80752, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+637088, 0.0, zero_stack,21);
 /*--- compute (h0|md) ---*/
   d1hrr3_build_md(Libderiv->CD,int_stack+2204564,int_stack+2182808,int_stack+2170523, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+788743, 0.0, zero_stack,21);
 /*--- compute (h0|lf) ---*/
   d1hrr3_build_lf(Libderiv->CD,int_stack+2211494,int_stack+2204564,int_stack+2191334, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+792208, 0.0, zero_stack,21);
 /*--- compute (h0|kg) ---*/
   d1hrr3_build_kg(Libderiv->CD,int_stack+2182808,int_stack+2211494,int_stack+2197004, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+797878, 0.0, zero_stack,21);
 /*--- compute (h0|ih) ---*/
   d1hrr3_build_ih(Libderiv->CD,int_stack+2194148,int_stack+2182808,int_stack+2173988, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+805438, 0.0, zero_stack,21);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+2170523,int_stack+84560,int_stack+83776, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+646580, 0.0, zero_stack,28);
 /*--- compute (i0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+2172875,int_stack+85568,int_stack+84560, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+647364, 0.0, zero_stack,28);
 /*--- compute (i0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+2175899,int_stack+2172875,int_stack+2170523, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+814258, 0.0, zero_stack,28);
 /*--- compute (i0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+2180603,int_stack+86828,int_stack+85568, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+648372, 0.0, zero_stack,28);
 /*--- compute (i0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+2184383,int_stack+2180603,int_stack+2172875, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+816610, 0.0, zero_stack,28);
 /*--- compute (i0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+2206496,int_stack+2184383,int_stack+2175899, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+819634, 0.0, zero_stack,28);
 /*--- compute (i0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+2170523,int_stack+88368,int_stack+86828, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+649632, 0.0, zero_stack,28);
 /*--- compute (i0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+2214336,int_stack+2170523,int_stack+2180603, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+824338, 0.0, zero_stack,28);
 /*--- compute (i0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+2221896,int_stack+2214336,int_stack+2184383, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+828118, 0.0, zero_stack,28);
 /*--- compute (i0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+2175143,int_stack+2221896,int_stack+2206496, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+850231, 0.0, zero_stack,28);
 /*--- compute (i0|np) ---*/
   d1hrr3_build_np(Libderiv->CD,int_stack+2206496,int_stack+90216,int_stack+88368, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+651172, 0.0, zero_stack,28);
 /*--- compute (i0|md) ---*/
   d1hrr3_build_md(Libderiv->CD,int_stack+2231976,int_stack+2206496,int_stack+2170523, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+858071, 0.0, zero_stack,28);
 /*--- compute (i0|lf) ---*/
   d1hrr3_build_lf(Libderiv->CD,int_stack+2241216,int_stack+2231976,int_stack+2214336, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+862691, 0.0, zero_stack,28);
 /*--- compute (i0|kg) ---*/
   d1hrr3_build_kg(Libderiv->CD,int_stack+2206496,int_stack+2241216,int_stack+2221896, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+870251, 0.0, zero_stack,28);
 /*--- compute (i0|ih) ---*/
   d1hrr3_build_ih(Libderiv->CD,int_stack+2221616,int_stack+2206496,int_stack+2175143, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+880331, 0.0, zero_stack,28);
 /*--- compute (hp|ih) ---*/
   hrr1_build_hp(Libderiv->AB,int_stack+2238080,int_stack+2221616,int_stack+2194148,588);
 /*--- compute (k0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+2170523,int_stack+93408,int_stack+92400, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+663828, 0.0, zero_stack,36);
 /*--- compute (k0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+2173547,int_stack+94704,int_stack+93408, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+664836, 0.0, zero_stack,36);
 /*--- compute (k0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+2177435,int_stack+2173547,int_stack+2170523, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+892091, 0.0, zero_stack,36);
 /*--- compute (k0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+2183483,int_stack+96324,int_stack+94704, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+666132, 0.0, zero_stack,36);
 /*--- compute (k0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+2188343,int_stack+2183483,int_stack+2173547, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+895115, 0.0, zero_stack,36);
 /*--- compute (k0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+2196119,int_stack+2188343,int_stack+2177435, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+899003, 0.0, zero_stack,36);
 /*--- compute (k0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+2170523,int_stack+98304,int_stack+96324, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+667752, 0.0, zero_stack,36);
 /*--- compute (k0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+2206199,int_stack+2170523,int_stack+2183483, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+0, 0.0, zero_stack,36);
 /*--- compute (k0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+2275124,int_stack+2206199,int_stack+2188343, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+4860, 0.0, zero_stack,36);
 /*--- compute (k0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+2176463,int_stack+2275124,int_stack+2196119, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+834166, 0.0, zero_stack,36);
 /*--- compute (k0|np) ---*/
   d1hrr3_build_np(Libderiv->CD,int_stack+2191583,int_stack+100680,int_stack+98304, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+669732, 0.0, zero_stack,36);
 /*--- compute (k0|md) ---*/
   d1hrr3_build_md(Libderiv->CD,int_stack+2288084,int_stack+2191583,int_stack+2170523, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+844246, 0.0, zero_stack,36);
 /*--- compute (k0|lf) ---*/
   d1hrr3_build_lf(Libderiv->CD,int_stack+2299964,int_stack+2288084,int_stack+2206199, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+960719, 0.0, zero_stack,36);
 /*--- compute (k0|kg) ---*/
   d1hrr3_build_kg(Libderiv->CD,int_stack+2191583,int_stack+2299964,int_stack+2275124, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+970439, 0.0, zero_stack,36);
 /*--- compute (k0|ih) ---*/
   d1hrr3_build_ih(Libderiv->CD,int_stack+2275124,int_stack+2191583,int_stack+2176463, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+983399, 0.0, zero_stack,36);
 /*--- compute (ip|ih) ---*/
   hrr1_build_ip(Libderiv->AB,int_stack+2296292,int_stack+2275124,int_stack+2221616,588);
 /*--- compute (hd|ih) ---*/
   hrr1_build_hd(Libderiv->AB,int_stack+2345684,int_stack+2296292,int_stack+2238080,588);
 /*--- compute (l0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+2419772,int_stack+104748,int_stack+103488, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+686004, 0.0, zero_stack,45);
 /*--- compute (l0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+2423552,int_stack+106368,int_stack+104748, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+687264, 0.0, zero_stack,45);
 /*--- compute (l0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+2170523,int_stack+2423552,int_stack+2419772, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+12636, 0.0, zero_stack,45);
 /*--- compute (l0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+2178083,int_stack+108393,int_stack+106368, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+688884, 0.0, zero_stack,45);
 /*--- compute (l0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+2184158,int_stack+2178083,int_stack+2423552, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+16416, 0.0, zero_stack,45);
 /*--- compute (l0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+2193878,int_stack+2184158,int_stack+2170523, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+998519, 0.0, zero_stack,45);
 /*--- compute (l0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+2170523,int_stack+110868,int_stack+108393, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+690909, 0.0, zero_stack,45);
 /*--- compute (l0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+2206478,int_stack+2170523,int_stack+2178083, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1006079, 0.0, zero_stack,45);
 /*--- compute (l0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+2218628,int_stack+2206478,int_stack+2184158, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1012154, 0.0, zero_stack,45);
 /*--- compute (l0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+2234828,int_stack+2218628,int_stack+2193878, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1021874, 0.0, zero_stack,45);
 /*--- compute (l0|np) ---*/
   d1hrr3_build_np(Libderiv->CD,int_stack+2177948,int_stack+113838,int_stack+110868, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+693384, 0.0, zero_stack,45);
 /*--- compute (l0|md) ---*/
   d1hrr3_build_md(Libderiv->CD,int_stack+2186858,int_stack+2177948,int_stack+2170523, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+905051, 0.0, zero_stack,45);
 /*--- compute (l0|lf) ---*/
   d1hrr3_build_lf(Libderiv->CD,int_stack+2253728,int_stack+2186858,int_stack+2206478, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+912476, 0.0, zero_stack,45);
 /*--- compute (l0|kg) ---*/
   d1hrr3_build_kg(Libderiv->CD,int_stack+2170523,int_stack+2253728,int_stack+2218628, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+924626, 0.0, zero_stack,45);
 /*--- compute (l0|ih) ---*/
   d1hrr3_build_ih(Libderiv->CD,int_stack+2194823,int_stack+2170523,int_stack+2234828, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+940826, 0.0, zero_stack,45);
 /*--- compute (kp|ih) ---*/
   hrr1_build_kp(Libderiv->AB,int_stack+39261,int_stack+2194823,int_stack+2275124,588);
 /*--- compute (id|ih) ---*/
   hrr1_build_id(Libderiv->AB,int_stack+1468635,int_stack+39261,int_stack+2296292,588);
 /*--- compute (hf|ih) ---*/
   hrr1_build_hf(Libderiv->AB,int_stack+2221283,int_stack+1468635,int_stack+2345684,588);
 /*--- compute (m0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+2170523,int_stack+118888,int_stack+117348, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+713724, 0.0, zero_stack,55);
 /*--- compute (m0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+2175143,int_stack+120868,int_stack+118888, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+715264, 0.0, zero_stack,55);
 /*--- compute (m0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+2181083,int_stack+2175143,int_stack+2170523, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+21276, 0.0, zero_stack,55);
 /*--- compute (m0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+2344763,int_stack+123343,int_stack+120868, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+717244, 0.0, zero_stack,55);
 /*--- compute (m0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+2352188,int_stack+2344763,int_stack+2175143, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+25896, 0.0, zero_stack,55);
 /*--- compute (m0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+2364068,int_stack+2352188,int_stack+2181083, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1034474, 0.0, zero_stack,55);
 /*--- compute (m0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+2170523,int_stack+126368,int_stack+123343, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+719719, 0.0, zero_stack,55);
 /*--- compute (m0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+2179598,int_stack+2170523,int_stack+2344763, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+31836, 0.0, zero_stack,55);
 /*--- compute (m0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+2379468,int_stack+2179598,int_stack+2352188, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1043714, 0.0, zero_stack,55);
 /*--- compute (m0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+2399268,int_stack+2379468,int_stack+2364068, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1055594, 0.0, zero_stack,55);
 /*--- compute (m0|np) ---*/
   d1hrr3_build_np(Libderiv->CD,int_stack+2344763,int_stack+129998,int_stack+126368, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+722744, 0.0, zero_stack,55);
 /*--- compute (m0|md) ---*/
   d1hrr3_build_md(Libderiv->CD,int_stack+2355653,int_stack+2344763,int_stack+2170523, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1070994, 0.0, zero_stack,55);
 /*--- compute (m0|lf) ---*/
   d1hrr3_build_lf(Libderiv->CD,int_stack+102765,int_stack+2355653,int_stack+2179598, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1080069, 0.0, zero_stack,55);
 /*--- compute (m0|kg) ---*/
   d1hrr3_build_kg(Libderiv->CD,int_stack+2344763,int_stack+102765,int_stack+2379468, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1094919, 0.0, zero_stack,55);
 /*--- compute (m0|ih) ---*/
   d1hrr3_build_ih(Libderiv->CD,int_stack+1567419,int_stack+2344763,int_stack+2399268, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1114719, 0.0, zero_stack,55);
 /*--- compute (lp|ih) ---*/
   hrr1_build_lp(Libderiv->AB,int_stack+2344763,int_stack+1567419,int_stack+2194823,588);
 /*--- compute (kd|ih) ---*/
   hrr1_build_kd(Libderiv->AB,int_stack+1599759,int_stack+2344763,int_stack+39261,588);
 /*--- compute (if|ih) ---*/
   hrr1_build_if(Libderiv->AB,int_stack+1726767,int_stack+1599759,int_stack+1468635,588);
 /*--- compute (hg|ih) ---*/
   hrr1_build_hg(Libderiv->AB,int_stack+2424143,int_stack+1726767,int_stack+2221283,588);
 /*--- compute (n0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+1468635,int_stack+136136,int_stack+134288, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+443520, 0.0, zero_stack,66);
 /*--- compute (n0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+1474179,int_stack+138512,int_stack+136136, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+447216, 0.0, zero_stack,66);
 /*--- compute (n0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+1481307,int_stack+1474179,int_stack+1468635, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1323039, 0.0, zero_stack,66);
 /*--- compute (n0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+1492395,int_stack+141482,int_stack+138512, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+451968, 0.0, zero_stack,66);
 /*--- compute (n0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+1501305,int_stack+1492395,int_stack+1474179, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1328583, 0.0, zero_stack,66);
 /*--- compute (n0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+1515561,int_stack+1501305,int_stack+1481307, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1335711, 0.0, zero_stack,66);
 /*--- compute (n0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+1468635,int_stack+145112,int_stack+141482, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+457908, 0.0, zero_stack,66);
 /*--- compute (n0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+1534041,int_stack+1468635,int_stack+1492395, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1346799, 0.0, zero_stack,66);
 /*--- compute (n0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+39261,int_stack+1534041,int_stack+1501305, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1355709, 0.0, zero_stack,66);
 /*--- compute (n0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+1479525,int_stack+39261,int_stack+1515561, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1369965, 0.0, zero_stack,66);
 /*--- compute (n0|np) ---*/
   d1hrr3_build_np(Libderiv->CD,int_stack+1507245,int_stack+149468,int_stack+145112, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+465168, 0.0, zero_stack,66);
 /*--- compute (n0|md) ---*/
   d1hrr3_build_md(Libderiv->CD,int_stack+63021,int_stack+1507245,int_stack+1468635, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1388445, 0.0, zero_stack,66);
 /*--- compute (n0|lf) ---*/
   d1hrr3_build_lf(Libderiv->CD,int_stack+84801,int_stack+63021,int_stack+1534041, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1399335, 0.0, zero_stack,66);
 /*--- compute (n0|kg) ---*/
   d1hrr3_build_kg(Libderiv->CD,int_stack+1507245,int_stack+84801,int_stack+39261, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1417155, 0.0, zero_stack,66);
 /*--- compute (n0|ih) ---*/
   d1hrr3_build_ih(Libderiv->CD,int_stack+39261,int_stack+1507245,int_stack+1479525, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1440915, 0.0, zero_stack,66);
 /*--- compute (mp|ih) ---*/
   hrr1_build_mp(Libderiv->AB,int_stack+1468635,int_stack+39261,int_stack+1567419,588);
 /*--- compute (ld|ih) ---*/
   hrr1_build_ld(Libderiv->AB,int_stack+2170523,int_stack+1468635,int_stack+2344763,588);
 /*--- compute (kf|ih) ---*/
   hrr1_build_kf(Libderiv->AB,int_stack+2609363,int_stack+2170523,int_stack+1599759,588);
 /*--- compute (ig|ih) ---*/
   hrr1_build_ig(Libderiv->AB,int_stack+2170523,int_stack+2609363,int_stack+1726767,588);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+2609363,int_stack+155204,int_stack+154616, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+633644, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+2611127,int_stack+155960,int_stack+155204, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+634232, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+2613395,int_stack+2611127,int_stack+2609363, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+767932, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+2616923,int_stack+156905,int_stack+155960, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+634988, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+2619758,int_stack+2616923,int_stack+2611127, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+769696, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+2624294,int_stack+2619758,int_stack+2613395, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+771964, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+2609363,int_stack+158060,int_stack+156905, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+635933, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+2630174,int_stack+2609363,int_stack+2616923, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+775492, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+2635844,int_stack+2630174,int_stack+2619758, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+778327, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+2612828,int_stack+2635844,int_stack+2624294, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+782863, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|np) ---*/
   d1hrr3_build_np(Libderiv->CD,int_stack+2621648,int_stack+159446,int_stack+158060, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+637088, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|md) ---*/
   d1hrr3_build_md(Libderiv->CD,int_stack+2643404,int_stack+2621648,int_stack+2609363, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+788743, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|lf) ---*/
   d1hrr3_build_lf(Libderiv->CD,int_stack+2650334,int_stack+2643404,int_stack+2630174, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+792208, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kg) ---*/
   d1hrr3_build_kg(Libderiv->CD,int_stack+2621648,int_stack+2650334,int_stack+2635844, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+797878, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ih) ---*/
   d1hrr3_build_ih(Libderiv->CD,int_stack+2632988,int_stack+2621648,int_stack+2612828, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+805438, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+2609363,int_stack+161868,int_stack+161084, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+646580, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+2611715,int_stack+162876,int_stack+161868, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+647364, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+2614739,int_stack+2611715,int_stack+2609363, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+814258, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+2619443,int_stack+164136,int_stack+162876, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+648372, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+2623223,int_stack+2619443,int_stack+2611715, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+816610, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+2645336,int_stack+2623223,int_stack+2614739, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+819634, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+2609363,int_stack+165676,int_stack+164136, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+649632, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+2653176,int_stack+2609363,int_stack+2619443, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+824338, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+2660736,int_stack+2653176,int_stack+2623223, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+828118, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+2613983,int_stack+2660736,int_stack+2645336, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+850231, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|np) ---*/
   d1hrr3_build_np(Libderiv->CD,int_stack+2645336,int_stack+167524,int_stack+165676, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+651172, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|md) ---*/
   d1hrr3_build_md(Libderiv->CD,int_stack+2670816,int_stack+2645336,int_stack+2609363, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+858071, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|lf) ---*/
   d1hrr3_build_lf(Libderiv->CD,int_stack+2680056,int_stack+2670816,int_stack+2653176, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+862691, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kg) ---*/
   d1hrr3_build_kg(Libderiv->CD,int_stack+2645336,int_stack+2680056,int_stack+2660736, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+870251, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ih) ---*/
   d1hrr3_build_ih(Libderiv->CD,int_stack+2660456,int_stack+2645336,int_stack+2613983, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+880331, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (hp|ih) ---*/
   hrr1_build_hp(Libderiv->AB,int_stack+2676920,int_stack+2660456,int_stack+2632988,588);
 /*--- compute (k0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+2609363,int_stack+170716,int_stack+169708, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+663828, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+2612387,int_stack+172012,int_stack+170716, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+664836, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+2616275,int_stack+2612387,int_stack+2609363, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+892091, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+2622323,int_stack+173632,int_stack+172012, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+666132, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+2627183,int_stack+2622323,int_stack+2612387, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+895115, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+2634959,int_stack+2627183,int_stack+2616275, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+899003, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+2609363,int_stack+175612,int_stack+173632, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+667752, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+2645039,int_stack+2609363,int_stack+2622323, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+0, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+2713964,int_stack+2645039,int_stack+2627183, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+4860, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+2615303,int_stack+2713964,int_stack+2634959, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+834166, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|np) ---*/
   d1hrr3_build_np(Libderiv->CD,int_stack+2630423,int_stack+177988,int_stack+175612, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+669732, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|md) ---*/
   d1hrr3_build_md(Libderiv->CD,int_stack+2726924,int_stack+2630423,int_stack+2609363, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+844246, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|lf) ---*/
   d1hrr3_build_lf(Libderiv->CD,int_stack+2738804,int_stack+2726924,int_stack+2645039, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+960719, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|kg) ---*/
   d1hrr3_build_kg(Libderiv->CD,int_stack+2630423,int_stack+2738804,int_stack+2713964, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+970439, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|ih) ---*/
   d1hrr3_build_ih(Libderiv->CD,int_stack+2713964,int_stack+2630423,int_stack+2615303, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+983399, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (ip|ih) ---*/
   hrr1_build_ip(Libderiv->AB,int_stack+2735132,int_stack+2713964,int_stack+2660456,588);
 /*--- compute (hd|ih) ---*/
   hrr1_build_hd(Libderiv->AB,int_stack+1468635,int_stack+2735132,int_stack+2676920,588);
 /*--- compute (l0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+2784524,int_stack+182056,int_stack+180796, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+686004, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+2788304,int_stack+183676,int_stack+182056, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+687264, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+2793164,int_stack+2788304,int_stack+2784524, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+12636, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+2800724,int_stack+185701,int_stack+183676, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+688884, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+2806799,int_stack+2800724,int_stack+2788304, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+16416, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+2609363,int_stack+2806799,int_stack+2793164, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+998519, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+2784524,int_stack+188176,int_stack+185701, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+690909, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+2621963,int_stack+2784524,int_stack+2800724, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1006079, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+2634113,int_stack+2621963,int_stack+2806799, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1012154, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+2791949,int_stack+2634113,int_stack+2609363, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1021874, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|np) ---*/
   d1hrr3_build_np(Libderiv->CD,int_stack+2609363,int_stack+191146,int_stack+188176, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+693384, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|md) ---*/
   d1hrr3_build_md(Libderiv->CD,int_stack+2650313,int_stack+2609363,int_stack+2784524, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+905051, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|lf) ---*/
   d1hrr3_build_lf(Libderiv->CD,int_stack+2665163,int_stack+2650313,int_stack+2621963, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+912476, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|kg) ---*/
   d1hrr3_build_kg(Libderiv->CD,int_stack+2609363,int_stack+2665163,int_stack+2634113, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+924626, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|ih) ---*/
   d1hrr3_build_ih(Libderiv->CD,int_stack+2633663,int_stack+2609363,int_stack+2791949, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+940826, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (kp|ih) ---*/
   hrr1_build_kp(Libderiv->AB,int_stack+1542723,int_stack+2633663,int_stack+2713964,588);
 /*--- compute (id|ih) ---*/
   hrr1_build_id(Libderiv->AB,int_stack+1606227,int_stack+1542723,int_stack+2735132,588);
 /*--- compute (hf|ih) ---*/
   hrr1_build_hf(Libderiv->AB,int_stack+2660123,int_stack+1606227,int_stack+1468635,588);
 /*--- compute (m0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+1468635,int_stack+196196,int_stack+194656, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+713724, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+1473255,int_stack+198176,int_stack+196196, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+715264, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+1479195,int_stack+1473255,int_stack+1468635, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+21276, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+1488435,int_stack+200651,int_stack+198176, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+717244, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+1495860,int_stack+1488435,int_stack+1473255, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+25896, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+1507740,int_stack+1495860,int_stack+1479195, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1034474, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+1468635,int_stack+203676,int_stack+200651, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+719719, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+1523140,int_stack+1468635,int_stack+1488435, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+31836, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+2609363,int_stack+1523140,int_stack+1495860, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1043714, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+1477710,int_stack+2609363,int_stack+1507740, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1055594, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|np) ---*/
   d1hrr3_build_np(Libderiv->CD,int_stack+1500810,int_stack+207306,int_stack+203676, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+722744, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|md) ---*/
   d1hrr3_build_md(Libderiv->CD,int_stack+2783603,int_stack+1500810,int_stack+1468635, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1070994, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|lf) ---*/
   d1hrr3_build_lf(Libderiv->CD,int_stack+1705011,int_stack+2783603,int_stack+1523140, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1080069, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|kg) ---*/
   d1hrr3_build_kg(Libderiv->CD,int_stack+2783603,int_stack+1705011,int_stack+2609363, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1094919, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|ih) ---*/
   d1hrr3_build_ih(Libderiv->CD,int_stack+1705011,int_stack+2783603,int_stack+1477710, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1114719, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (lp|ih) ---*/
   hrr1_build_lp(Libderiv->AB,int_stack+1737351,int_stack+1705011,int_stack+2633663,588);
 /*--- compute (kd|ih) ---*/
   hrr1_build_kd(Libderiv->AB,int_stack+39261,int_stack+1737351,int_stack+1542723,588);
 /*--- compute (if|ih) ---*/
   hrr1_build_if(Libderiv->AB,int_stack+2783603,int_stack+39261,int_stack+1606227,588);
 /*--- compute (hg|ih) ---*/
   hrr1_build_hg(Libderiv->AB,int_stack+1468635,int_stack+2783603,int_stack+2660123,588);
 /*--- compute (n0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+2609363,int_stack+213444,int_stack+211596, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+443520, 0.0, zero_stack, 0.0, zero_stack,66);
 /*--- compute (n0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+2614907,int_stack+215820,int_stack+213444, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+447216, 0.0, zero_stack, 0.0, zero_stack,66);
 /*--- compute (n0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+2622035,int_stack+2614907,int_stack+2609363, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1323039, 0.0, zero_stack, 0.0, zero_stack,66);
 /*--- compute (n0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+2633123,int_stack+218790,int_stack+215820, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+451968, 0.0, zero_stack, 0.0, zero_stack,66);
 /*--- compute (n0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+2642033,int_stack+2633123,int_stack+2614907, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1328583, 0.0, zero_stack, 0.0, zero_stack,66);
 /*--- compute (n0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+2656289,int_stack+2642033,int_stack+2622035, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1335711, 0.0, zero_stack, 0.0, zero_stack,66);
 /*--- compute (n0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+2609363,int_stack+222420,int_stack+218790, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+457908, 0.0, zero_stack, 0.0, zero_stack,66);
 /*--- compute (n0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+2674769,int_stack+2609363,int_stack+2633123, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1346799, 0.0, zero_stack, 0.0, zero_stack,66);
 /*--- compute (n0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+2692589,int_stack+2674769,int_stack+2642033, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1355709, 0.0, zero_stack, 0.0, zero_stack,66);
 /*--- compute (n0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+2620253,int_stack+2692589,int_stack+2656289, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1369965, 0.0, zero_stack, 0.0, zero_stack,66);
 /*--- compute (n0|np) ---*/
   d1hrr3_build_np(Libderiv->CD,int_stack+2647973,int_stack+226776,int_stack+222420, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+465168, 0.0, zero_stack, 0.0, zero_stack,66);
 /*--- compute (n0|md) ---*/
   d1hrr3_build_md(Libderiv->CD,int_stack+2716349,int_stack+2647973,int_stack+2609363, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1388445, 0.0, zero_stack, 0.0, zero_stack,66);
 /*--- compute (n0|lf) ---*/
   d1hrr3_build_lf(Libderiv->CD,int_stack+2738129,int_stack+2716349,int_stack+2674769, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1399335, 0.0, zero_stack, 0.0, zero_stack,66);
 /*--- compute (n0|kg) ---*/
   d1hrr3_build_kg(Libderiv->CD,int_stack+2647973,int_stack+2738129,int_stack+2692589, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1417155, 0.0, zero_stack, 0.0, zero_stack,66);
 /*--- compute (n0|ih) ---*/
   d1hrr3_build_ih(Libderiv->CD,int_stack+2683613,int_stack+2647973,int_stack+2620253, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1440915, 0.0, zero_stack, 0.0, zero_stack,66);
 /*--- compute (mp|ih) ---*/
   hrr1_build_mp(Libderiv->AB,int_stack+1816731,int_stack+2683613,int_stack+1705011,588);
 /*--- compute (ld|ih) ---*/
   hrr1_build_ld(Libderiv->AB,int_stack+2609363,int_stack+1816731,int_stack+1737351,588);
 /*--- compute (kf|ih) ---*/
   hrr1_build_kf(Libderiv->AB,int_stack+1653855,int_stack+2609363,int_stack+39261,588);
 /*--- compute (ig|ih) ---*/
   hrr1_build_ig(Libderiv->AB,int_stack+2948243,int_stack+1653855,int_stack+2783603,588);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+1653855,int_stack+232512,int_stack+231924, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+633644, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+1655619,int_stack+233268,int_stack+232512, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+634232, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+1657887,int_stack+1655619,int_stack+1653855, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+767932, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+1661415,int_stack+234213,int_stack+233268, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+634988, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+1664250,int_stack+1661415,int_stack+1655619, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+769696, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+1668786,int_stack+1664250,int_stack+1657887, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+771964, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+1653855,int_stack+235368,int_stack+234213, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+635933, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+1674666,int_stack+1653855,int_stack+1661415, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+775492, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+1680336,int_stack+1674666,int_stack+1664250, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+778327, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+1657320,int_stack+1680336,int_stack+1668786, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+782863, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|np) ---*/
   d1hrr3_build_np(Libderiv->CD,int_stack+1666140,int_stack+236754,int_stack+235368, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+637088, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|md) ---*/
   d1hrr3_build_md(Libderiv->CD,int_stack+1687896,int_stack+1666140,int_stack+1653855, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+788743, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|lf) ---*/
   d1hrr3_build_lf(Libderiv->CD,int_stack+1694826,int_stack+1687896,int_stack+1674666, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+792208, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kg) ---*/
   d1hrr3_build_kg(Libderiv->CD,int_stack+1666140,int_stack+1694826,int_stack+1680336, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+797878, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ih) ---*/
   d1hrr3_build_ih(Libderiv->CD,int_stack+1677480,int_stack+1666140,int_stack+1657320, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+805438, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+1653855,int_stack+239176,int_stack+238392, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+646580, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+1656207,int_stack+240184,int_stack+239176, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+647364, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+1659231,int_stack+1656207,int_stack+1653855, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+814258, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+1663935,int_stack+241444,int_stack+240184, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+648372, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+1667715,int_stack+1663935,int_stack+1656207, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+816610, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+1689828,int_stack+1667715,int_stack+1659231, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+819634, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+1653855,int_stack+242984,int_stack+241444, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+649632, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+1697668,int_stack+1653855,int_stack+1663935, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+824338, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+1705228,int_stack+1697668,int_stack+1667715, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+828118, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+1658475,int_stack+1705228,int_stack+1689828, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+850231, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|np) ---*/
   d1hrr3_build_np(Libderiv->CD,int_stack+1689828,int_stack+244832,int_stack+242984, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+651172, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|md) ---*/
   d1hrr3_build_md(Libderiv->CD,int_stack+1715308,int_stack+1689828,int_stack+1653855, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+858071, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|lf) ---*/
   d1hrr3_build_lf(Libderiv->CD,int_stack+1724548,int_stack+1715308,int_stack+1697668, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+862691, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kg) ---*/
   d1hrr3_build_kg(Libderiv->CD,int_stack+1689828,int_stack+1724548,int_stack+1705228, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+870251, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ih) ---*/
   d1hrr3_build_ih(Libderiv->CD,int_stack+1704948,int_stack+1689828,int_stack+1658475, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+880331, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (hp|ih) ---*/
   hrr1_build_hp(Libderiv->AB,int_stack+1721412,int_stack+1704948,int_stack+1677480,588);
 /*--- compute (k0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+1653855,int_stack+248024,int_stack+247016, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+663828, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+1656879,int_stack+249320,int_stack+248024, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+664836, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+1660767,int_stack+1656879,int_stack+1653855, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+892091, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+1666815,int_stack+250940,int_stack+249320, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+666132, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+1671675,int_stack+1666815,int_stack+1656879, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+895115, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+1679451,int_stack+1671675,int_stack+1660767, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+899003, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+1653855,int_stack+252920,int_stack+250940, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+667752, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+1689531,int_stack+1653855,int_stack+1666815, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+0, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+1758456,int_stack+1689531,int_stack+1671675, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+4860, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+1659795,int_stack+1758456,int_stack+1679451, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+834166, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|np) ---*/
   d1hrr3_build_np(Libderiv->CD,int_stack+1674915,int_stack+255296,int_stack+252920, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+669732, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|md) ---*/
   d1hrr3_build_md(Libderiv->CD,int_stack+1771416,int_stack+1674915,int_stack+1653855, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+844246, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|lf) ---*/
   d1hrr3_build_lf(Libderiv->CD,int_stack+1783296,int_stack+1771416,int_stack+1689531, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+960719, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|kg) ---*/
   d1hrr3_build_kg(Libderiv->CD,int_stack+1674915,int_stack+1783296,int_stack+1758456, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+970439, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|ih) ---*/
   d1hrr3_build_ih(Libderiv->CD,int_stack+1758456,int_stack+1674915,int_stack+1659795, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+983399, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (ip|ih) ---*/
   hrr1_build_ip(Libderiv->AB,int_stack+1779624,int_stack+1758456,int_stack+1704948,588);
 /*--- compute (hd|ih) ---*/
   hrr1_build_hd(Libderiv->AB,int_stack+1829016,int_stack+1779624,int_stack+1721412,588);
 /*--- compute (l0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+1903104,int_stack+259364,int_stack+258104, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+686004, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+1906884,int_stack+260984,int_stack+259364, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+687264, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+1911744,int_stack+1906884,int_stack+1903104, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+12636, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+1653855,int_stack+263009,int_stack+260984, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+688884, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+1659930,int_stack+1653855,int_stack+1906884, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+16416, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+1669650,int_stack+1659930,int_stack+1911744, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+998519, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+1903104,int_stack+265484,int_stack+263009, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+690909, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+1910529,int_stack+1903104,int_stack+1653855, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1006079, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+1682250,int_stack+1910529,int_stack+1659930, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1012154, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+1698450,int_stack+1682250,int_stack+1669650, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1021874, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|np) ---*/
   d1hrr3_build_np(Libderiv->CD,int_stack+1653855,int_stack+268454,int_stack+265484, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+693384, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|md) ---*/
   d1hrr3_build_md(Libderiv->CD,int_stack+1662765,int_stack+1653855,int_stack+1903104, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+905051, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|lf) ---*/
   d1hrr3_build_lf(Libderiv->CD,int_stack+1717350,int_stack+1662765,int_stack+1910529, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+912476, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|kg) ---*/
   d1hrr3_build_kg(Libderiv->CD,int_stack+1653855,int_stack+1717350,int_stack+1682250, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+924626, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|ih) ---*/
   d1hrr3_build_ih(Libderiv->CD,int_stack+1717350,int_stack+1653855,int_stack+1698450, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+940826, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (kp|ih) ---*/
   hrr1_build_kp(Libderiv->AB,int_stack+39261,int_stack+1717350,int_stack+1758456,588);
 /*--- compute (id|ih) ---*/
   hrr1_build_id(Libderiv->AB,int_stack+102765,int_stack+39261,int_stack+1779624,588);
 /*--- compute (hf|ih) ---*/
   hrr1_build_hf(Libderiv->AB,int_stack+2609363,int_stack+102765,int_stack+1829016,588);
 /*--- compute (m0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+1653855,int_stack+273504,int_stack+271964, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+713724, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+1658475,int_stack+275484,int_stack+273504, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+715264, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+1664415,int_stack+1658475,int_stack+1653855, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+21276, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+1673655,int_stack+277959,int_stack+275484, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+717244, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+1681080,int_stack+1673655,int_stack+1658475, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+25896, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+1692960,int_stack+1681080,int_stack+1664415, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1034474, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+1653855,int_stack+280984,int_stack+277959, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+719719, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+1743810,int_stack+1653855,int_stack+1673655, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+31836, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+1758660,int_stack+1743810,int_stack+1681080, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1043714, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+1662930,int_stack+1758660,int_stack+1692960, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1055594, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|np) ---*/
   d1hrr3_build_np(Libderiv->CD,int_stack+1686030,int_stack+284614,int_stack+280984, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+722744, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|md) ---*/
   d1hrr3_build_md(Libderiv->CD,int_stack+1696920,int_stack+1686030,int_stack+1653855, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1070994, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|lf) ---*/
   d1hrr3_build_lf(Libderiv->CD,int_stack+1778460,int_stack+1696920,int_stack+1743810, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1080069, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|kg) ---*/
   d1hrr3_build_kg(Libderiv->CD,int_stack+1686030,int_stack+1778460,int_stack+1758660, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1094919, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|ih) ---*/
   d1hrr3_build_ih(Libderiv->CD,int_stack+1743810,int_stack+1686030,int_stack+1662930, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1114719, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (lp|ih) ---*/
   hrr1_build_lp(Libderiv->AB,int_stack+1776150,int_stack+1743810,int_stack+1717350,588);
 /*--- compute (kd|ih) ---*/
   hrr1_build_kd(Libderiv->AB,int_stack+2732843,int_stack+1776150,int_stack+39261,588);
 /*--- compute (if|ih) ---*/
   hrr1_build_if(Libderiv->AB,int_stack+3195203,int_stack+2732843,int_stack+102765,588);
 /*--- compute (hg|ih) ---*/
   hrr1_build_hg(Libderiv->AB,int_stack+39261,int_stack+3195203,int_stack+2609363,588);
 /*--- compute (n0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+2609363,int_stack+290752,int_stack+288904, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+443520, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,66);
 /*--- compute (n0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+2614907,int_stack+293128,int_stack+290752, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+447216, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,66);
 /*--- compute (n0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+2622035,int_stack+2614907,int_stack+2609363, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1323039, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,66);
 /*--- compute (n0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+2633123,int_stack+296098,int_stack+293128, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+451968, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,66);
 /*--- compute (n0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+2642033,int_stack+2633123,int_stack+2614907, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1328583, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,66);
 /*--- compute (n0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+2656289,int_stack+2642033,int_stack+2622035, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1335711, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,66);
 /*--- compute (n0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+2609363,int_stack+299728,int_stack+296098, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+457908, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,66);
 /*--- compute (n0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+2674769,int_stack+2609363,int_stack+2633123, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1346799, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,66);
 /*--- compute (n0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+2692589,int_stack+2674769,int_stack+2642033, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1355709, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,66);
 /*--- compute (n0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+2620253,int_stack+2692589,int_stack+2656289, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1369965, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,66);
 /*--- compute (n0|np) ---*/
   d1hrr3_build_np(Libderiv->CD,int_stack+2647973,int_stack+304084,int_stack+299728, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+465168, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,66);
 /*--- compute (n0|md) ---*/
   d1hrr3_build_md(Libderiv->CD,int_stack+224481,int_stack+2647973,int_stack+2609363, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1388445, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,66);
 /*--- compute (n0|lf) ---*/
   d1hrr3_build_lf(Libderiv->CD,int_stack+246261,int_stack+224481,int_stack+2674769, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1399335, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,66);
 /*--- compute (n0|kg) ---*/
   d1hrr3_build_kg(Libderiv->CD,int_stack+2647973,int_stack+246261,int_stack+2692589, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1417155, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,66);
 /*--- compute (n0|ih) ---*/
   d1hrr3_build_ih(Libderiv->CD,int_stack+224481,int_stack+2647973,int_stack+2620253, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1440915, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,66);
 /*--- compute (mp|ih) ---*/
   hrr1_build_mp(Libderiv->AB,int_stack+2609363,int_stack+224481,int_stack+1743810,588);
 /*--- compute (ld|ih) ---*/
   hrr1_build_ld(Libderiv->AB,int_stack+3359843,int_stack+2609363,int_stack+1776150,588);
 /*--- compute (kf|ih) ---*/
   hrr1_build_kf(Libderiv->AB,int_stack+1653855,int_stack+3359843,int_stack+2732843,588);
 /*--- compute (ig|ih) ---*/
   hrr1_build_ig(Libderiv->AB,int_stack+2609363,int_stack+1653855,int_stack+3195203,588);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+3195203,int_stack+309820,int_stack+309232, 0.0, zero_stack, 1.0, int_stack+633644, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+3196967,int_stack+310576,int_stack+309820, 0.0, zero_stack, 1.0, int_stack+634232, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+3199235,int_stack+3196967,int_stack+3195203, 0.0, zero_stack, 1.0, int_stack+767932, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+3202763,int_stack+311521,int_stack+310576, 0.0, zero_stack, 1.0, int_stack+634988, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+3205598,int_stack+3202763,int_stack+3196967, 0.0, zero_stack, 1.0, int_stack+769696, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+3210134,int_stack+3205598,int_stack+3199235, 0.0, zero_stack, 1.0, int_stack+771964, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+3195203,int_stack+312676,int_stack+311521, 0.0, zero_stack, 1.0, int_stack+635933, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+3216014,int_stack+3195203,int_stack+3202763, 0.0, zero_stack, 1.0, int_stack+775492, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+3221684,int_stack+3216014,int_stack+3205598, 0.0, zero_stack, 1.0, int_stack+778327, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+3198668,int_stack+3221684,int_stack+3210134, 0.0, zero_stack, 1.0, int_stack+782863, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|np) ---*/
   d1hrr3_build_np(Libderiv->CD,int_stack+3207488,int_stack+314062,int_stack+312676, 0.0, zero_stack, 1.0, int_stack+637088, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|md) ---*/
   d1hrr3_build_md(Libderiv->CD,int_stack+3229244,int_stack+3207488,int_stack+3195203, 0.0, zero_stack, 1.0, int_stack+788743, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|lf) ---*/
   d1hrr3_build_lf(Libderiv->CD,int_stack+3236174,int_stack+3229244,int_stack+3216014, 0.0, zero_stack, 1.0, int_stack+792208, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kg) ---*/
   d1hrr3_build_kg(Libderiv->CD,int_stack+3207488,int_stack+3236174,int_stack+3221684, 0.0, zero_stack, 1.0, int_stack+797878, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ih) ---*/
   d1hrr3_build_ih(Libderiv->CD,int_stack+3218828,int_stack+3207488,int_stack+3198668, 0.0, zero_stack, 1.0, int_stack+805438, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+3195203,int_stack+316484,int_stack+315700, 0.0, zero_stack, 1.0, int_stack+646580, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+3197555,int_stack+317492,int_stack+316484, 0.0, zero_stack, 1.0, int_stack+647364, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+3200579,int_stack+3197555,int_stack+3195203, 0.0, zero_stack, 1.0, int_stack+814258, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+3205283,int_stack+318752,int_stack+317492, 0.0, zero_stack, 1.0, int_stack+648372, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+3209063,int_stack+3205283,int_stack+3197555, 0.0, zero_stack, 1.0, int_stack+816610, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+3231176,int_stack+3209063,int_stack+3200579, 0.0, zero_stack, 1.0, int_stack+819634, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+3195203,int_stack+320292,int_stack+318752, 0.0, zero_stack, 1.0, int_stack+649632, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+3239016,int_stack+3195203,int_stack+3205283, 0.0, zero_stack, 1.0, int_stack+824338, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+3246576,int_stack+3239016,int_stack+3209063, 0.0, zero_stack, 1.0, int_stack+828118, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+3199823,int_stack+3246576,int_stack+3231176, 0.0, zero_stack, 1.0, int_stack+850231, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|np) ---*/
   d1hrr3_build_np(Libderiv->CD,int_stack+3231176,int_stack+322140,int_stack+320292, 0.0, zero_stack, 1.0, int_stack+651172, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|md) ---*/
   d1hrr3_build_md(Libderiv->CD,int_stack+3256656,int_stack+3231176,int_stack+3195203, 0.0, zero_stack, 1.0, int_stack+858071, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|lf) ---*/
   d1hrr3_build_lf(Libderiv->CD,int_stack+3265896,int_stack+3256656,int_stack+3239016, 0.0, zero_stack, 1.0, int_stack+862691, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kg) ---*/
   d1hrr3_build_kg(Libderiv->CD,int_stack+3231176,int_stack+3265896,int_stack+3246576, 0.0, zero_stack, 1.0, int_stack+870251, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ih) ---*/
   d1hrr3_build_ih(Libderiv->CD,int_stack+3246296,int_stack+3231176,int_stack+3199823, 0.0, zero_stack, 1.0, int_stack+880331, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (hp|ih) ---*/
   hrr1_build_hp(Libderiv->AB,int_stack+3262760,int_stack+3246296,int_stack+3218828,588);
 /*--- compute (k0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+3195203,int_stack+325332,int_stack+324324, 0.0, zero_stack, 1.0, int_stack+663828, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+3198227,int_stack+326628,int_stack+325332, 0.0, zero_stack, 1.0, int_stack+664836, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+3202115,int_stack+3198227,int_stack+3195203, 0.0, zero_stack, 1.0, int_stack+892091, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+3208163,int_stack+328248,int_stack+326628, 0.0, zero_stack, 1.0, int_stack+666132, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+3213023,int_stack+3208163,int_stack+3198227, 0.0, zero_stack, 1.0, int_stack+895115, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+3220799,int_stack+3213023,int_stack+3202115, 0.0, zero_stack, 1.0, int_stack+899003, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+3195203,int_stack+330228,int_stack+328248, 0.0, zero_stack, 1.0, int_stack+667752, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+3230879,int_stack+3195203,int_stack+3208163, 0.0, zero_stack, 1.0, int_stack+0, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+3299804,int_stack+3230879,int_stack+3213023, 0.0, zero_stack, 1.0, int_stack+4860, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+3201143,int_stack+3299804,int_stack+3220799, 0.0, zero_stack, 1.0, int_stack+834166, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|np) ---*/
   d1hrr3_build_np(Libderiv->CD,int_stack+3216263,int_stack+332604,int_stack+330228, 0.0, zero_stack, 1.0, int_stack+669732, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|md) ---*/
   d1hrr3_build_md(Libderiv->CD,int_stack+3312764,int_stack+3216263,int_stack+3195203, 0.0, zero_stack, 1.0, int_stack+844246, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|lf) ---*/
   d1hrr3_build_lf(Libderiv->CD,int_stack+3324644,int_stack+3312764,int_stack+3230879, 0.0, zero_stack, 1.0, int_stack+960719, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|kg) ---*/
   d1hrr3_build_kg(Libderiv->CD,int_stack+3216263,int_stack+3324644,int_stack+3299804, 0.0, zero_stack, 1.0, int_stack+970439, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|ih) ---*/
   d1hrr3_build_ih(Libderiv->CD,int_stack+3299804,int_stack+3216263,int_stack+3201143, 0.0, zero_stack, 1.0, int_stack+983399, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (ip|ih) ---*/
   hrr1_build_ip(Libderiv->AB,int_stack+3320972,int_stack+3299804,int_stack+3246296,588);
 /*--- compute (hd|ih) ---*/
   hrr1_build_hd(Libderiv->AB,int_stack+3370364,int_stack+3320972,int_stack+3262760,588);
 /*--- compute (l0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+3444452,int_stack+336672,int_stack+335412, 0.0, zero_stack, 1.0, int_stack+686004, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+3448232,int_stack+338292,int_stack+336672, 0.0, zero_stack, 1.0, int_stack+687264, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+3453092,int_stack+3448232,int_stack+3444452, 0.0, zero_stack, 1.0, int_stack+12636, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+3460652,int_stack+340317,int_stack+338292, 0.0, zero_stack, 1.0, int_stack+688884, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+3466727,int_stack+3460652,int_stack+3448232, 0.0, zero_stack, 1.0, int_stack+16416, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+3476447,int_stack+3466727,int_stack+3453092, 0.0, zero_stack, 1.0, int_stack+998519, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+3444452,int_stack+342792,int_stack+340317, 0.0, zero_stack, 1.0, int_stack+690909, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+3489047,int_stack+3444452,int_stack+3460652, 0.0, zero_stack, 1.0, int_stack+1006079, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+3501197,int_stack+3489047,int_stack+3466727, 0.0, zero_stack, 1.0, int_stack+1012154, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+3451877,int_stack+3501197,int_stack+3476447, 0.0, zero_stack, 1.0, int_stack+1021874, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|np) ---*/
   d1hrr3_build_np(Libderiv->CD,int_stack+3470777,int_stack+345762,int_stack+342792, 0.0, zero_stack, 1.0, int_stack+693384, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|md) ---*/
   d1hrr3_build_md(Libderiv->CD,int_stack+3195203,int_stack+3470777,int_stack+3444452, 0.0, zero_stack, 1.0, int_stack+905051, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|lf) ---*/
   d1hrr3_build_lf(Libderiv->CD,int_stack+3210053,int_stack+3195203,int_stack+3489047, 0.0, zero_stack, 1.0, int_stack+912476, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|kg) ---*/
   d1hrr3_build_kg(Libderiv->CD,int_stack+3470777,int_stack+3210053,int_stack+3501197, 0.0, zero_stack, 1.0, int_stack+924626, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|ih) ---*/
   d1hrr3_build_ih(Libderiv->CD,int_stack+3195203,int_stack+3470777,int_stack+3451877, 0.0, zero_stack, 1.0, int_stack+940826, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (kp|ih) ---*/
   hrr1_build_kp(Libderiv->AB,int_stack+3221663,int_stack+3195203,int_stack+3299804,588);
 /*--- compute (id|ih) ---*/
   hrr1_build_id(Libderiv->AB,int_stack+1653855,int_stack+3221663,int_stack+3320972,588);
 /*--- compute (hf|ih) ---*/
   hrr1_build_hf(Libderiv->AB,int_stack+1752639,int_stack+1653855,int_stack+3370364,588);
 /*--- compute (m0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+3285167,int_stack+350812,int_stack+349272, 0.0, zero_stack, 1.0, int_stack+713724, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+3289787,int_stack+352792,int_stack+350812, 0.0, zero_stack, 1.0, int_stack+715264, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+3295727,int_stack+3289787,int_stack+3285167, 0.0, zero_stack, 1.0, int_stack+21276, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+3304967,int_stack+355267,int_stack+352792, 0.0, zero_stack, 1.0, int_stack+717244, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+3312392,int_stack+3304967,int_stack+3289787, 0.0, zero_stack, 1.0, int_stack+25896, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+3324272,int_stack+3312392,int_stack+3295727, 0.0, zero_stack, 1.0, int_stack+1034474, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+3285167,int_stack+358292,int_stack+355267, 0.0, zero_stack, 1.0, int_stack+719719, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+3339672,int_stack+3285167,int_stack+3304967, 0.0, zero_stack, 1.0, int_stack+31836, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+3354522,int_stack+3339672,int_stack+3312392, 0.0, zero_stack, 1.0, int_stack+1043714, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+3294242,int_stack+3354522,int_stack+3324272, 0.0, zero_stack, 1.0, int_stack+1055594, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|np) ---*/
   d1hrr3_build_np(Libderiv->CD,int_stack+3317342,int_stack+361922,int_stack+358292, 0.0, zero_stack, 1.0, int_stack+722744, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|md) ---*/
   d1hrr3_build_md(Libderiv->CD,int_stack+3374322,int_stack+3317342,int_stack+3285167, 0.0, zero_stack, 1.0, int_stack+1070994, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|lf) ---*/
   d1hrr3_build_lf(Libderiv->CD,int_stack+3392472,int_stack+3374322,int_stack+3339672, 0.0, zero_stack, 1.0, int_stack+1080069, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|kg) ---*/
   d1hrr3_build_kg(Libderiv->CD,int_stack+3317342,int_stack+3392472,int_stack+3354522, 0.0, zero_stack, 1.0, int_stack+1094919, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|ih) ---*/
   d1hrr3_build_ih(Libderiv->CD,int_stack+3347042,int_stack+3317342,int_stack+3294242, 0.0, zero_stack, 1.0, int_stack+1114719, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (lp|ih) ---*/
   hrr1_build_lp(Libderiv->AB,int_stack+3379382,int_stack+3347042,int_stack+3195203,588);
 /*--- compute (kd|ih) ---*/
   hrr1_build_kd(Libderiv->AB,int_stack+224481,int_stack+3379382,int_stack+3221663,588);
 /*--- compute (if|ih) ---*/
   hrr1_build_if(Libderiv->AB,int_stack+3458762,int_stack+224481,int_stack+1653855,588);
 /*--- compute (hg|ih) ---*/
   hrr1_build_hg(Libderiv->AB,int_stack+3623402,int_stack+3458762,int_stack+1752639,588);
 /*--- compute (n0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+1653855,int_stack+368060,int_stack+366212, 0.0, zero_stack, 1.0, int_stack+443520, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,66);
 /*--- compute (n0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+1659399,int_stack+370436,int_stack+368060, 0.0, zero_stack, 1.0, int_stack+447216, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,66);
 /*--- compute (n0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+1666527,int_stack+1659399,int_stack+1653855, 0.0, zero_stack, 1.0, int_stack+1323039, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,66);
 /*--- compute (n0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+1677615,int_stack+373406,int_stack+370436, 0.0, zero_stack, 1.0, int_stack+451968, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,66);
 /*--- compute (n0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+1686525,int_stack+1677615,int_stack+1659399, 0.0, zero_stack, 1.0, int_stack+1328583, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,66);
 /*--- compute (n0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+1700781,int_stack+1686525,int_stack+1666527, 0.0, zero_stack, 1.0, int_stack+1335711, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,66);
 /*--- compute (n0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+1653855,int_stack+377036,int_stack+373406, 0.0, zero_stack, 1.0, int_stack+457908, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,66);
 /*--- compute (n0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+1719261,int_stack+1653855,int_stack+1677615, 0.0, zero_stack, 1.0, int_stack+1346799, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,66);
 /*--- compute (n0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+1737081,int_stack+1719261,int_stack+1686525, 0.0, zero_stack, 1.0, int_stack+1355709, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,66);
 /*--- compute (n0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+1664745,int_stack+1737081,int_stack+1700781, 0.0, zero_stack, 1.0, int_stack+1369965, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,66);
 /*--- compute (n0|np) ---*/
   d1hrr3_build_np(Libderiv->CD,int_stack+1692465,int_stack+381392,int_stack+377036, 0.0, zero_stack, 1.0, int_stack+465168, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,66);
 /*--- compute (n0|md) ---*/
   d1hrr3_build_md(Libderiv->CD,int_stack+1760841,int_stack+1692465,int_stack+1653855, 0.0, zero_stack, 1.0, int_stack+1388445, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,66);
 /*--- compute (n0|lf) ---*/
   d1hrr3_build_lf(Libderiv->CD,int_stack+1782621,int_stack+1760841,int_stack+1719261, 0.0, zero_stack, 1.0, int_stack+1399335, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,66);
 /*--- compute (n0|kg) ---*/
   d1hrr3_build_kg(Libderiv->CD,int_stack+1692465,int_stack+1782621,int_stack+1737081, 0.0, zero_stack, 1.0, int_stack+1417155, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,66);
 /*--- compute (n0|ih) ---*/
   d1hrr3_build_ih(Libderiv->CD,int_stack+1728105,int_stack+1692465,int_stack+1664745, 0.0, zero_stack, 1.0, int_stack+1440915, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,66);
 /*--- compute (mp|ih) ---*/
   hrr1_build_mp(Libderiv->AB,int_stack+1766913,int_stack+1728105,int_stack+3347042,588);
 /*--- compute (ld|ih) ---*/
   hrr1_build_ld(Libderiv->AB,int_stack+3195203,int_stack+1766913,int_stack+3379382,588);
 /*--- compute (kf|ih) ---*/
   hrr1_build_kf(Libderiv->AB,int_stack+1653855,int_stack+3195203,int_stack+224481,588);
 /*--- compute (ig|ih) ---*/
   hrr1_build_ig(Libderiv->AB,int_stack+3195203,int_stack+1653855,int_stack+3458762,588);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+1653855,int_stack+387128,int_stack+386540, 1.0, int_stack+633644, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+1655619,int_stack+387884,int_stack+387128, 1.0, int_stack+634232, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+1657887,int_stack+1655619,int_stack+1653855, 1.0, int_stack+767932, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+1661415,int_stack+388829,int_stack+387884, 1.0, int_stack+634988, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+1664250,int_stack+1661415,int_stack+1655619, 1.0, int_stack+769696, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+1668786,int_stack+1664250,int_stack+1657887, 1.0, int_stack+771964, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+767932,int_stack+389984,int_stack+388829, 1.0, int_stack+635933, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+1653855,int_stack+767932,int_stack+1661415, 1.0, int_stack+775492, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+1674666,int_stack+1653855,int_stack+1664250, 1.0, int_stack+778327, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+771397,int_stack+1674666,int_stack+1668786, 1.0, int_stack+782863, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|np) ---*/
   d1hrr3_build_np(Libderiv->CD,int_stack+780217,int_stack+391370,int_stack+389984, 1.0, int_stack+637088, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|md) ---*/
   d1hrr3_build_md(Libderiv->CD,int_stack+1659525,int_stack+780217,int_stack+767932, 1.0, int_stack+788743, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|lf) ---*/
   d1hrr3_build_lf(Libderiv->CD,int_stack+1682226,int_stack+1659525,int_stack+1653855, 1.0, int_stack+792208, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kg) ---*/
   d1hrr3_build_kg(Libderiv->CD,int_stack+1653855,int_stack+1682226,int_stack+1674666, 1.0, int_stack+797878, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ih) ---*/
   d1hrr3_build_ih(Libderiv->CD,int_stack+1665195,int_stack+1653855,int_stack+771397, 1.0, int_stack+805438, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+1653855,int_stack+393792,int_stack+393008, 1.0, int_stack+646580, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+1656207,int_stack+394800,int_stack+393792, 1.0, int_stack+647364, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+1659231,int_stack+1656207,int_stack+1653855, 1.0, int_stack+814258, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+1677543,int_stack+396060,int_stack+394800, 1.0, int_stack+648372, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+1681323,int_stack+1677543,int_stack+1656207, 1.0, int_stack+816610, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+1687371,int_stack+1681323,int_stack+1659231, 1.0, int_stack+819634, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+814258,int_stack+397600,int_stack+396060, 1.0, int_stack+649632, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+1653855,int_stack+814258,int_stack+1677543, 1.0, int_stack+824338, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+1695211,int_stack+1653855,int_stack+1681323, 1.0, int_stack+828118, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+818878,int_stack+1695211,int_stack+1687371, 1.0, int_stack+850231, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|np) ---*/
   d1hrr3_build_np(Libderiv->CD,int_stack+1677543,int_stack+399448,int_stack+397600, 1.0, int_stack+651172, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|md) ---*/
   d1hrr3_build_md(Libderiv->CD,int_stack+1683087,int_stack+1677543,int_stack+814258, 1.0, int_stack+858071, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|lf) ---*/
   d1hrr3_build_lf(Libderiv->CD,int_stack+1705291,int_stack+1683087,int_stack+1653855, 1.0, int_stack+862691, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kg) ---*/
   d1hrr3_build_kg(Libderiv->CD,int_stack+1677543,int_stack+1705291,int_stack+1695211, 1.0, int_stack+870251, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ih) ---*/
   d1hrr3_build_ih(Libderiv->CD,int_stack+1692663,int_stack+1677543,int_stack+818878, 1.0, int_stack+880331, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (hp|ih) ---*/
   hrr1_build_hp(Libderiv->AB,int_stack+1709127,int_stack+1692663,int_stack+1665195,588);
 /*--- compute (k0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+1653855,int_stack+402640,int_stack+401632, 1.0, int_stack+663828, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+1656879,int_stack+403936,int_stack+402640, 1.0, int_stack+664836, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+1660767,int_stack+1656879,int_stack+1653855, 1.0, int_stack+892091, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+1666815,int_stack+405556,int_stack+403936, 1.0, int_stack+666132, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+1671675,int_stack+1666815,int_stack+1656879, 1.0, int_stack+895115, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+1679451,int_stack+1671675,int_stack+1660767, 1.0, int_stack+899003, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+892091,int_stack+407536,int_stack+405556, 1.0, int_stack+667752, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+1653855,int_stack+892091,int_stack+1666815, 1.0, int_stack+0, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+814258,int_stack+1653855,int_stack+1671675, 1.0, int_stack+4860, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+1663575,int_stack+814258,int_stack+1679451, 1.0, int_stack+834166, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|np) ---*/
   d1hrr3_build_np(Libderiv->CD,int_stack+0,int_stack+409912,int_stack+407536, 1.0, int_stack+669732, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|md) ---*/
   d1hrr3_build_md(Libderiv->CD,int_stack+1678695,int_stack+0,int_stack+892091, 1.0, int_stack+844246, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|lf) ---*/
   d1hrr3_build_lf(Libderiv->CD,int_stack+827218,int_stack+1678695,int_stack+1653855, 1.0, int_stack+960719, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|kg) ---*/
   d1hrr3_build_kg(Libderiv->CD,int_stack+1746171,int_stack+827218,int_stack+814258, 1.0, int_stack+970439, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|ih) ---*/
   d1hrr3_build_ih(Libderiv->CD,int_stack+814258,int_stack+1746171,int_stack+1663575, 1.0, int_stack+983399, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (ip|ih) ---*/
   hrr1_build_ip(Libderiv->AB,int_stack+1746171,int_stack+814258,int_stack+1692663,588);
 /*--- compute (hd|ih) ---*/
   hrr1_build_hd(Libderiv->AB,int_stack+1795563,int_stack+1746171,int_stack+1709127,588);
 /*--- compute (l0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+1869651,int_stack+413980,int_stack+412720, 1.0, int_stack+686004, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+1873431,int_stack+415600,int_stack+413980, 1.0, int_stack+687264, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+1878291,int_stack+1873431,int_stack+1869651, 1.0, int_stack+12636, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+1885851,int_stack+417625,int_stack+415600, 1.0, int_stack+688884, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+1891926,int_stack+1885851,int_stack+1873431, 1.0, int_stack+16416, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+1901646,int_stack+1891926,int_stack+1878291, 1.0, int_stack+998519, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+998519,int_stack+420100,int_stack+417625, 1.0, int_stack+690909, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+1869651,int_stack+998519,int_stack+1885851, 1.0, int_stack+1006079, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+1653855,int_stack+1869651,int_stack+1891926, 1.0, int_stack+1012154, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+1881801,int_stack+1653855,int_stack+1901646, 1.0, int_stack+1021874, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|np) ---*/
   d1hrr3_build_np(Libderiv->CD,int_stack+1005944,int_stack+423070,int_stack+420100, 1.0, int_stack+693384, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|md) ---*/
   d1hrr3_build_md(Libderiv->CD,int_stack+1014854,int_stack+1005944,int_stack+998519, 1.0, int_stack+905051, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|lf) ---*/
   d1hrr3_build_lf(Libderiv->CD,int_stack+1900701,int_stack+1014854,int_stack+1869651, 1.0, int_stack+912476, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|kg) ---*/
   d1hrr3_build_kg(Libderiv->CD,int_stack+998519,int_stack+1900701,int_stack+1653855, 1.0, int_stack+924626, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|ih) ---*/
   d1hrr3_build_ih(Libderiv->CD,int_stack+1653855,int_stack+998519,int_stack+1881801, 1.0, int_stack+940826, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (kp|ih) ---*/
   hrr1_build_kp(Libderiv->AB,int_stack+1680315,int_stack+1653855,int_stack+814258,588);
 /*--- compute (id|ih) ---*/
   hrr1_build_id(Libderiv->AB,int_stack+224481,int_stack+1680315,int_stack+1746171,588);
 /*--- compute (hf|ih) ---*/
   hrr1_build_hf(Libderiv->AB,int_stack+3442163,int_stack+224481,int_stack+1795563,588);
 /*--- compute (m0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+814258,int_stack+428120,int_stack+426580, 1.0, int_stack+713724, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+818878,int_stack+430100,int_stack+428120, 1.0, int_stack+715264, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+824818,int_stack+818878,int_stack+814258, 1.0, int_stack+21276, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+834058,int_stack+432575,int_stack+430100, 1.0, int_stack+717244, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+998519,int_stack+834058,int_stack+818878, 1.0, int_stack+25896, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+1010399,int_stack+998519,int_stack+824818, 1.0, int_stack+1034474, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+814258,int_stack+435600,int_stack+432575, 1.0, int_stack+719719, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+1025799,int_stack+814258,int_stack+834058, 1.0, int_stack+31836, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+823333,int_stack+1025799,int_stack+998519, 1.0, int_stack+1043714, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+1743819,int_stack+823333,int_stack+1010399, 1.0, int_stack+1055594, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|np) ---*/
   d1hrr3_build_np(Libderiv->CD,int_stack+998519,int_stack+439230,int_stack+435600, 1.0, int_stack+722744, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|md) ---*/
   d1hrr3_build_md(Libderiv->CD,int_stack+1040649,int_stack+998519,int_stack+814258, 1.0, int_stack+1070994, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|lf) ---*/
   d1hrr3_build_lf(Libderiv->CD,int_stack+998519,int_stack+1040649,int_stack+1025799, 1.0, int_stack+1080069, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|kg) ---*/
   d1hrr3_build_kg(Libderiv->CD,int_stack+1023269,int_stack+998519,int_stack+823333, 1.0, int_stack+1094919, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (m0|ih) ---*/
   d1hrr3_build_ih(Libderiv->CD,int_stack+1766919,int_stack+1023269,int_stack+1743819, 1.0, int_stack+1114719, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,55);
 /*--- compute (lp|ih) ---*/
   hrr1_build_lp(Libderiv->AB,int_stack+1799259,int_stack+1766919,int_stack+1653855,588);
 /*--- compute (kd|ih) ---*/
   hrr1_build_kd(Libderiv->AB,int_stack+3808622,int_stack+1799259,int_stack+1680315,588);
 /*--- compute (if|ih) ---*/
   hrr1_build_if(Libderiv->AB,int_stack+3935630,int_stack+3808622,int_stack+224481,588);
 /*--- compute (hg|ih) ---*/
   hrr1_build_hg(Libderiv->AB,int_stack+224481,int_stack+3935630,int_stack+3442163,588);
 /*--- compute (n0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+3442163,int_stack+449592,int_stack+445368, 1.0, int_stack+443520, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,66);
 /*--- compute (n0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+3447707,int_stack+454938,int_stack+449592, 1.0, int_stack+447216, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,66);
 /*--- compute (n0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+3454835,int_stack+3447707,int_stack+3442163, 1.0, int_stack+1323039, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,66);
 /*--- compute (n0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+3465923,int_stack+461538,int_stack+454938, 1.0, int_stack+451968, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,66);
 /*--- compute (n0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+3474833,int_stack+3465923,int_stack+3447707, 1.0, int_stack+1328583, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,66);
 /*--- compute (n0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+3489089,int_stack+3474833,int_stack+3454835, 1.0, int_stack+1335711, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,66);
 /*--- compute (n0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+1323039,int_stack+469524,int_stack+461538, 1.0, int_stack+457908, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,66);
 /*--- compute (n0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+3442163,int_stack+1323039,int_stack+3465923, 1.0, int_stack+1346799, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,66);
 /*--- compute (n0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+3507569,int_stack+3442163,int_stack+3474833, 1.0, int_stack+1355709, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,66);
 /*--- compute (n0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+1333929,int_stack+3507569,int_stack+3489089, 1.0, int_stack+1369965, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,66);
 /*--- compute (n0|np) ---*/
   d1hrr3_build_np(Libderiv->CD,int_stack+1361649,int_stack+473880,int_stack+469524, 1.0, int_stack+465168, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,66);
 /*--- compute (n0|md) ---*/
   d1hrr3_build_md(Libderiv->CD,int_stack+3459983,int_stack+1361649,int_stack+1323039, 1.0, int_stack+1388445, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,66);
 /*--- compute (n0|lf) ---*/
   d1hrr3_build_lf(Libderiv->CD,int_stack+1361649,int_stack+3459983,int_stack+3442163, 1.0, int_stack+1399335, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,66);
 /*--- compute (n0|kg) ---*/
   d1hrr3_build_kg(Libderiv->CD,int_stack+3442163,int_stack+1361649,int_stack+3507569, 1.0, int_stack+1417155, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,66);
 /*--- compute (n0|ih) ---*/
   d1hrr3_build_ih(Libderiv->CD,int_stack+1361649,int_stack+3442163,int_stack+1333929, 1.0, int_stack+1440915, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,66);
 /*--- compute (mp|ih) ---*/
   hrr1_build_mp(Libderiv->AB,int_stack+3442163,int_stack+1361649,int_stack+1766919,588);
 /*--- compute (ld|ih) ---*/
   hrr1_build_ld(Libderiv->AB,int_stack+4100270,int_stack+3442163,int_stack+1799259,588);
 /*--- compute (kf|ih) ---*/
   hrr1_build_kf(Libderiv->AB,int_stack+1653855,int_stack+4100270,int_stack+3808622,588);
 /*--- compute (ig|ih) ---*/
   hrr1_build_ig(Libderiv->AB,int_stack+4100270,int_stack+1653855,int_stack+3935630,588);
 /*--- compute (h0|np) ---*/
   hrr3_build_np(Libderiv->CD,int_stack+1653855,int_stack+638474,int_stack+637088,21);
 /*--- compute (h0|md) ---*/
   hrr3_build_md(Libderiv->CD,int_stack+1658013,int_stack+1653855,int_stack+788743,21);
 /*--- compute (h0|lf) ---*/
   hrr3_build_lf(Libderiv->CD,int_stack+1664943,int_stack+1658013,int_stack+792208,21);
 /*--- compute (h0|kg) ---*/
   hrr3_build_kg(Libderiv->CD,int_stack+1674393,int_stack+1664943,int_stack+797878,21);
 /*--- compute (h0|ih) ---*/
   hrr3_build_ih(Libderiv->CD,int_stack+1653855,int_stack+1674393,int_stack+805438,21);
 /*--- compute (i0|np) ---*/
   hrr3_build_np(Libderiv->CD,int_stack+1666203,int_stack+653020,int_stack+651172,28);
 /*--- compute (i0|md) ---*/
   hrr3_build_md(Libderiv->CD,int_stack+1671747,int_stack+1666203,int_stack+858071,28);
 /*--- compute (i0|lf) ---*/
   hrr3_build_lf(Libderiv->CD,int_stack+1680987,int_stack+1671747,int_stack+862691,28);
 /*--- compute (i0|kg) ---*/
   hrr3_build_kg(Libderiv->CD,int_stack+1693587,int_stack+1680987,int_stack+870251,28);
 /*--- compute (i0|ih) ---*/
   hrr3_build_ih(Libderiv->CD,int_stack+1666203,int_stack+1693587,int_stack+880331,28);
 /*--- compute (hp|ih) ---*/
   hrr1_build_hp(Libderiv->AB,int_stack+1682667,int_stack+1666203,int_stack+1653855,588);
 /*--- compute (k0|np) ---*/
   hrr3_build_np(Libderiv->CD,int_stack+1719711,int_stack+672108,int_stack+669732,36);
 /*--- compute (k0|md) ---*/
   hrr3_build_md(Libderiv->CD,int_stack+1726839,int_stack+1719711,int_stack+844246,36);
 /*--- compute (k0|lf) ---*/
   hrr3_build_lf(Libderiv->CD,int_stack+1738719,int_stack+1726839,int_stack+960719,36);
 /*--- compute (k0|kg) ---*/
   hrr3_build_kg(Libderiv->CD,int_stack+1754919,int_stack+1738719,int_stack+970439,36);
 /*--- compute (k0|ih) ---*/
   hrr3_build_ih(Libderiv->CD,int_stack+1719711,int_stack+1754919,int_stack+983399,36);
 /*--- compute (ip|ih) ---*/
   hrr1_build_ip(Libderiv->AB,int_stack+1740879,int_stack+1719711,int_stack+1666203,588);
 /*--- compute (hd|ih) ---*/
   hrr1_build_hd(Libderiv->AB,int_stack+1790271,int_stack+1740879,int_stack+1682667,588);
 /*--- compute (l0|np) ---*/
   hrr3_build_np(Libderiv->CD,int_stack+1864359,int_stack+696354,int_stack+693384,45);
 /*--- compute (l0|md) ---*/
   hrr3_build_md(Libderiv->CD,int_stack+1873269,int_stack+1864359,int_stack+905051,45);
 /*--- compute (l0|lf) ---*/
   hrr3_build_lf(Libderiv->CD,int_stack+1888119,int_stack+1873269,int_stack+912476,45);
 /*--- compute (l0|kg) ---*/
   hrr3_build_kg(Libderiv->CD,int_stack+3808622,int_stack+1888119,int_stack+924626,45);
 /*--- compute (l0|ih) ---*/
   hrr3_build_ih(Libderiv->CD,int_stack+1864359,int_stack+3808622,int_stack+940826,45);
 /*--- compute (kp|ih) ---*/
   hrr1_build_kp(Libderiv->AB,int_stack+3808622,int_stack+1864359,int_stack+1719711,588);
 /*--- compute (id|ih) ---*/
   hrr1_build_id(Libderiv->AB,int_stack+3872126,int_stack+3808622,int_stack+1740879,588);
 /*--- compute (hf|ih) ---*/
   hrr1_build_hf(Libderiv->AB,int_stack+3970910,int_stack+3872126,int_stack+1790271,588);
 /*--- compute (m0|np) ---*/
   hrr3_build_np(Libderiv->CD,int_stack+1890819,int_stack+726374,int_stack+722744,55);
 /*--- compute (m0|md) ---*/
   hrr3_build_md(Libderiv->CD,int_stack+1901709,int_stack+1890819,int_stack+1070994,55);
 /*--- compute (m0|lf) ---*/
   hrr3_build_lf(Libderiv->CD,int_stack+3442163,int_stack+1901709,int_stack+1080069,55);
 /*--- compute (m0|kg) ---*/
   hrr3_build_kg(Libderiv->CD,int_stack+1890819,int_stack+3442163,int_stack+1094919,55);
 /*--- compute (m0|ih) ---*/
   hrr3_build_ih(Libderiv->CD,int_stack+3442163,int_stack+1890819,int_stack+1114719,55);
 /*--- compute (lp|ih) ---*/
   hrr1_build_lp(Libderiv->AB,int_stack+3474503,int_stack+3442163,int_stack+1864359,588);
 /*--- compute (kd|ih) ---*/
   hrr1_build_kd(Libderiv->AB,int_stack+1323039,int_stack+3474503,int_stack+3808622,588);
 /*--- compute (if|ih) ---*/
   hrr1_build_if(Libderiv->AB,int_stack+767932,int_stack+1323039,int_stack+3872126,588);
 /*--- compute (hg|ih) ---*/
   hrr1_build_hg(Libderiv->AB,int_stack+932572,int_stack+767932,int_stack+3970910,588);
 /*--- compute (h0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+1890819,int_stack+479616,int_stack+479028,21);
 /*--- compute (h0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+1892583,int_stack+480372,int_stack+479616,21);
 /*--- compute (h0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+1894851,int_stack+1892583,int_stack+1890819,21);
 /*--- compute (h0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+1898379,int_stack+481317,int_stack+480372,21);
 /*--- compute (h0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+1901214,int_stack+1898379,int_stack+1892583,21);
 /*--- compute (h0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+4094390,int_stack+1901214,int_stack+1894851,21);
 /*--- compute (h0|mp) ---*/
   hrr3_build_mp(Libderiv->CD,int_stack+1890819,int_stack+482472,int_stack+481317,21);
 /*--- compute (h0|ld) ---*/
   hrr3_build_ld(Libderiv->CD,int_stack+1905750,int_stack+1890819,int_stack+1898379,21);
 /*--- compute (h0|kf) ---*/
   hrr3_build_kf(Libderiv->CD,int_stack+1911420,int_stack+1905750,int_stack+1901214,21);
 /*--- compute (h0|ig) ---*/
   hrr3_build_ig(Libderiv->CD,int_stack+1894284,int_stack+1911420,int_stack+4094390,21);
 /*--- compute (h0|np) ---*/
   hrr3_build_np(Libderiv->CD,int_stack+4094390,int_stack+483858,int_stack+482472,21);
 /*--- compute (h0|md) ---*/
   hrr3_build_md(Libderiv->CD,int_stack+3553883,int_stack+4094390,int_stack+1890819,21);
 /*--- compute (h0|lf) ---*/
   hrr3_build_lf(Libderiv->CD,int_stack+3560813,int_stack+3553883,int_stack+1905750,21);
 /*--- compute (h0|kg) ---*/
   hrr3_build_kg(Libderiv->CD,int_stack+3570263,int_stack+3560813,int_stack+1911420,21);
 /*--- compute (h0|ih) ---*/
   hrr3_build_ih(Libderiv->CD,int_stack+3553883,int_stack+3570263,int_stack+1894284,21);
 /*--- compute (i0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+3566231,int_stack+486280,int_stack+485496,28);
 /*--- compute (i0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+3568583,int_stack+487288,int_stack+486280,28);
 /*--- compute (i0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+3571607,int_stack+3568583,int_stack+3566231,28);
 /*--- compute (i0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+3576311,int_stack+488548,int_stack+487288,28);
 /*--- compute (i0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+3580091,int_stack+3576311,int_stack+3568583,28);
 /*--- compute (i0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+3586139,int_stack+3580091,int_stack+3571607,28);
 /*--- compute (i0|mp) ---*/
   hrr3_build_mp(Libderiv->CD,int_stack+3566231,int_stack+490088,int_stack+488548,28);
 /*--- compute (i0|ld) ---*/
   hrr3_build_ld(Libderiv->CD,int_stack+3593979,int_stack+3566231,int_stack+3576311,28);
 /*--- compute (i0|kf) ---*/
   hrr3_build_kf(Libderiv->CD,int_stack+3601539,int_stack+3593979,int_stack+3580091,28);
 /*--- compute (i0|ig) ---*/
   hrr3_build_ig(Libderiv->CD,int_stack+3570851,int_stack+3601539,int_stack+3586139,28);
 /*--- compute (i0|np) ---*/
   hrr3_build_np(Libderiv->CD,int_stack+3582611,int_stack+491936,int_stack+490088,28);
 /*--- compute (i0|md) ---*/
   hrr3_build_md(Libderiv->CD,int_stack+3611619,int_stack+3582611,int_stack+3566231,28);
 /*--- compute (i0|lf) ---*/
   hrr3_build_lf(Libderiv->CD,int_stack+1890819,int_stack+3611619,int_stack+3593979,28);
 /*--- compute (i0|kg) ---*/
   hrr3_build_kg(Libderiv->CD,int_stack+3582611,int_stack+1890819,int_stack+3601539,28);
 /*--- compute (i0|ih) ---*/
   hrr3_build_ih(Libderiv->CD,int_stack+1890819,int_stack+3582611,int_stack+3570851,28);
 /*--- compute (hp|ih) ---*/
   d1hrr1_build_hp(Libderiv->AB,int_stack+3566231,int_stack+1890819,int_stack+3553883, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1653855, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,588);
 /*--- compute (k0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+3553883,int_stack+495128,int_stack+494120,36);
 /*--- compute (k0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+3556907,int_stack+496424,int_stack+495128,36);
 /*--- compute (k0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+1907283,int_stack+3556907,int_stack+3553883,36);
 /*--- compute (k0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+3560795,int_stack+498044,int_stack+496424,36);
 /*--- compute (k0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+1913331,int_stack+3560795,int_stack+3556907,36);
 /*--- compute (k0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+3603275,int_stack+1913331,int_stack+1907283,36);
 /*--- compute (k0|mp) ---*/
   hrr3_build_mp(Libderiv->CD,int_stack+1907283,int_stack+500024,int_stack+498044,36);
 /*--- compute (k0|ld) ---*/
   hrr3_build_ld(Libderiv->CD,int_stack+3613355,int_stack+1907283,int_stack+3560795,36);
 /*--- compute (k0|kf) ---*/
   hrr3_build_kf(Libderiv->CD,int_stack+1450047,int_stack+3613355,int_stack+1913331,36);
 /*--- compute (k0|ig) ---*/
   hrr3_build_ig(Libderiv->CD,int_stack+409701,int_stack+1450047,int_stack+3603275,36);
 /*--- compute (k0|np) ---*/
   hrr3_build_np(Libderiv->CD,int_stack+3603275,int_stack+502400,int_stack+500024,36);
 /*--- compute (k0|md) ---*/
   hrr3_build_md(Libderiv->CD,int_stack+3553883,int_stack+3603275,int_stack+1907283,36);
 /*--- compute (k0|lf) ---*/
   hrr3_build_lf(Libderiv->CD,int_stack+1907283,int_stack+3553883,int_stack+3613355,36);
 /*--- compute (k0|kg) ---*/
   hrr3_build_kg(Libderiv->CD,int_stack+3603275,int_stack+1907283,int_stack+1450047,36);
 /*--- compute (k0|ih) ---*/
   hrr3_build_ih(Libderiv->CD,int_stack+424821,int_stack+3603275,int_stack+409701,36);
 /*--- compute (ip|ih) ---*/
   d1hrr1_build_ip(Libderiv->AB,int_stack+445989,int_stack+424821,int_stack+1890819, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1666203, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,588);
 /*--- compute (hd|ih) ---*/
   d1hrr1_build_hd(Libderiv->AB,int_stack+2856323,int_stack+445989,int_stack+3566231, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1682667, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,588);
 /*--- compute (l0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+1890819,int_stack+506468,int_stack+505208,45);
 /*--- compute (l0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+1894599,int_stack+508088,int_stack+506468,45);
 /*--- compute (l0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+1899459,int_stack+1894599,int_stack+1890819,45);
 /*--- compute (l0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+1907019,int_stack+510113,int_stack+508088,45);
 /*--- compute (l0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+1913094,int_stack+1907019,int_stack+1894599,45);
 /*--- compute (l0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+409701,int_stack+1913094,int_stack+1899459,45);
 /*--- compute (l0|mp) ---*/
   hrr3_build_mp(Libderiv->CD,int_stack+1890819,int_stack+512588,int_stack+510113,45);
 /*--- compute (l0|ld) ---*/
   hrr3_build_ld(Libderiv->CD,int_stack+1450047,int_stack+1890819,int_stack+1907019,45);
 /*--- compute (l0|kf) ---*/
   hrr3_build_kf(Libderiv->CD,int_stack+3553883,int_stack+1450047,int_stack+1913094,45);
 /*--- compute (l0|ig) ---*/
   hrr3_build_ig(Libderiv->CD,int_stack+1898244,int_stack+3553883,int_stack+409701,45);
 /*--- compute (l0|np) ---*/
   hrr3_build_np(Libderiv->CD,int_stack+409701,int_stack+515558,int_stack+512588,45);
 /*--- compute (l0|md) ---*/
   hrr3_build_md(Libderiv->CD,int_stack+3570083,int_stack+409701,int_stack+1890819,45);
 /*--- compute (l0|lf) ---*/
   hrr3_build_lf(Libderiv->CD,int_stack+3584933,int_stack+3570083,int_stack+1450047,45);
 /*--- compute (l0|kg) ---*/
   hrr3_build_kg(Libderiv->CD,int_stack+0,int_stack+3584933,int_stack+3553883,45);
 /*--- compute (l0|ih) ---*/
   hrr3_build_ih(Libderiv->CD,int_stack+3553883,int_stack+0,int_stack+1898244,45);
 /*--- compute (kp|ih) ---*/
   d1hrr1_build_kp(Libderiv->AB,int_stack+4347230,int_stack+3553883,int_stack+424821, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1719711, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,588);
 /*--- compute (id|ih) ---*/
   d1hrr1_build_id(Libderiv->AB,int_stack+4410734,int_stack+4347230,int_stack+445989, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1740879, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,588);
 /*--- compute (hf|ih) ---*/
   d1hrr1_build_hf(Libderiv->AB,int_stack+4509518,int_stack+4410734,int_stack+2856323, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1790271, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,588);
 /*--- compute (m0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+2856323,int_stack+520608,int_stack+519068,55);
 /*--- compute (m0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+2860943,int_stack+522588,int_stack+520608,55);
 /*--- compute (m0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+2866883,int_stack+2860943,int_stack+2856323,55);
 /*--- compute (m0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+2876123,int_stack+525063,int_stack+522588,55);
 /*--- compute (m0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+2883548,int_stack+2876123,int_stack+2860943,55);
 /*--- compute (m0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+2895428,int_stack+2883548,int_stack+2866883,55);
 /*--- compute (m0|mp) ---*/
   hrr3_build_mp(Libderiv->CD,int_stack+2856323,int_stack+528088,int_stack+525063,55);
 /*--- compute (m0|ld) ---*/
   hrr3_build_ld(Libderiv->CD,int_stack+2910828,int_stack+2856323,int_stack+2876123,55);
 /*--- compute (m0|kf) ---*/
   hrr3_build_kf(Libderiv->CD,int_stack+2925678,int_stack+2910828,int_stack+2883548,55);
 /*--- compute (m0|ig) ---*/
   hrr3_build_ig(Libderiv->CD,int_stack+2865398,int_stack+2925678,int_stack+2895428,55);
 /*--- compute (m0|np) ---*/
   hrr3_build_np(Libderiv->CD,int_stack+2888498,int_stack+531718,int_stack+528088,55);
 /*--- compute (m0|md) ---*/
   hrr3_build_md(Libderiv->CD,int_stack+0,int_stack+2888498,int_stack+2856323,55);
 /*--- compute (m0|lf) ---*/
   hrr3_build_lf(Libderiv->CD,int_stack+3580343,int_stack+0,int_stack+2910828,55);
 /*--- compute (m0|kg) ---*/
   hrr3_build_kg(Libderiv->CD,int_stack+0,int_stack+3580343,int_stack+2925678,55);
 /*--- compute (m0|ih) ---*/
   hrr3_build_ih(Libderiv->CD,int_stack+3580343,int_stack+0,int_stack+2865398,55);
 /*--- compute (lp|ih) ---*/
   d1hrr1_build_lp(Libderiv->AB,int_stack+2856323,int_stack+3580343,int_stack+3553883, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1864359, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,588);
 /*--- compute (kd|ih) ---*/
   d1hrr1_build_kd(Libderiv->AB,int_stack+4632998,int_stack+2856323,int_stack+4347230, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3808622, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,588);
 /*--- compute (if|ih) ---*/
   d1hrr1_build_if(Libderiv->AB,int_stack+4760006,int_stack+4632998,int_stack+4410734, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3872126, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,588);
 /*--- compute (hg|ih) ---*/
   d1hrr1_build_hg(Libderiv->AB,int_stack+4924646,int_stack+4760006,int_stack+4509518, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3970910, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,588);
 /*--- compute (n0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+4347230,int_stack+537856,int_stack+536008,66);
 /*--- compute (n0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+4352774,int_stack+540232,int_stack+537856,66);
 /*--- compute (n0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+663828,int_stack+4352774,int_stack+4347230,66);
 /*--- compute (n0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+4359902,int_stack+543202,int_stack+540232,66);
 /*--- compute (n0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+4368812,int_stack+4359902,int_stack+4352774,66);
 /*--- compute (n0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+4383068,int_stack+4368812,int_stack+663828,66);
 /*--- compute (n0|mp) ---*/
   hrr3_build_mp(Libderiv->CD,int_stack+663828,int_stack+546832,int_stack+543202,66);
 /*--- compute (n0|ld) ---*/
   hrr3_build_ld(Libderiv->CD,int_stack+4401548,int_stack+663828,int_stack+4359902,66);
 /*--- compute (n0|kf) ---*/
   hrr3_build_kf(Libderiv->CD,int_stack+4419368,int_stack+4401548,int_stack+4368812,66);
 /*--- compute (n0|ig) ---*/
   hrr3_build_ig(Libderiv->CD,int_stack+4347230,int_stack+4419368,int_stack+4383068,66);
 /*--- compute (n0|np) ---*/
   hrr3_build_np(Libderiv->CD,int_stack+4374950,int_stack+551188,int_stack+546832,66);
 /*--- compute (n0|md) ---*/
   hrr3_build_md(Libderiv->CD,int_stack+4443128,int_stack+4374950,int_stack+663828,66);
 /*--- compute (n0|lf) ---*/
   hrr3_build_lf(Libderiv->CD,int_stack+4464908,int_stack+4443128,int_stack+4401548,66);
 /*--- compute (n0|kg) ---*/
   hrr3_build_kg(Libderiv->CD,int_stack+4374950,int_stack+4464908,int_stack+4419368,66);
 /*--- compute (n0|ih) ---*/
   hrr3_build_ih(Libderiv->CD,int_stack+4410590,int_stack+4374950,int_stack+4347230,66);
 /*--- compute (mp|ih) ---*/
   d1hrr1_build_mp(Libderiv->AB,int_stack+4449398,int_stack+4410590,int_stack+3580343, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3442163, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,588);
 /*--- compute (ld|ih) ---*/
   d1hrr1_build_ld(Libderiv->AB,int_stack+5109866,int_stack+4449398,int_stack+2856323, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3474503, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,588);
 /*--- compute (kf|ih) ---*/
   d1hrr1_build_kf(Libderiv->AB,int_stack+4347230,int_stack+5109866,int_stack+4632998, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1323039, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,588);
 /*--- compute (ig|ih) ---*/
   d1hrr1_build_ig(Libderiv->AB,int_stack+5109866,int_stack+4347230,int_stack+4760006, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+767932, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,588);
 /*--- compute (h0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+4347230,int_stack+556924,int_stack+556336,21);
 /*--- compute (h0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+4348994,int_stack+557680,int_stack+556924,21);
 /*--- compute (h0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+4351262,int_stack+4348994,int_stack+4347230,21);
 /*--- compute (h0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+4354790,int_stack+558625,int_stack+557680,21);
 /*--- compute (h0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+4357625,int_stack+4354790,int_stack+4348994,21);
 /*--- compute (h0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+4094390,int_stack+4357625,int_stack+4351262,21);
 /*--- compute (h0|mp) ---*/
   hrr3_build_mp(Libderiv->CD,int_stack+4347230,int_stack+559780,int_stack+558625,21);
 /*--- compute (h0|ld) ---*/
   hrr3_build_ld(Libderiv->CD,int_stack+4362161,int_stack+4347230,int_stack+4354790,21);
 /*--- compute (h0|kf) ---*/
   hrr3_build_kf(Libderiv->CD,int_stack+4367831,int_stack+4362161,int_stack+4357625,21);
 /*--- compute (h0|ig) ---*/
   hrr3_build_ig(Libderiv->CD,int_stack+4350695,int_stack+4367831,int_stack+4094390,21);
 /*--- compute (h0|np) ---*/
   hrr3_build_np(Libderiv->CD,int_stack+4094390,int_stack+561166,int_stack+559780,21);
 /*--- compute (h0|md) ---*/
   hrr3_build_md(Libderiv->CD,int_stack+4375391,int_stack+4094390,int_stack+4347230,21);
 /*--- compute (h0|lf) ---*/
   hrr3_build_lf(Libderiv->CD,int_stack+4382321,int_stack+4375391,int_stack+4362161,21);
 /*--- compute (h0|kg) ---*/
   hrr3_build_kg(Libderiv->CD,int_stack+4391771,int_stack+4382321,int_stack+4367831,21);
 /*--- compute (h0|ih) ---*/
   hrr3_build_ih(Libderiv->CD,int_stack+4359515,int_stack+4391771,int_stack+4350695,21);
 /*--- compute (i0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+4347230,int_stack+563588,int_stack+562804,28);
 /*--- compute (i0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+4349582,int_stack+564596,int_stack+563588,28);
 /*--- compute (i0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+4352606,int_stack+4349582,int_stack+4347230,28);
 /*--- compute (i0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+4094390,int_stack+565856,int_stack+564596,28);
 /*--- compute (i0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+4371863,int_stack+4094390,int_stack+4349582,28);
 /*--- compute (i0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+4377911,int_stack+4371863,int_stack+4352606,28);
 /*--- compute (i0|mp) ---*/
   hrr3_build_mp(Libderiv->CD,int_stack+4347230,int_stack+567396,int_stack+565856,28);
 /*--- compute (i0|ld) ---*/
   hrr3_build_ld(Libderiv->CD,int_stack+4351850,int_stack+4347230,int_stack+4094390,28);
 /*--- compute (i0|kf) ---*/
   hrr3_build_kf(Libderiv->CD,int_stack+4385751,int_stack+4351850,int_stack+4371863,28);
 /*--- compute (i0|ig) ---*/
   hrr3_build_ig(Libderiv->CD,int_stack+4395831,int_stack+4385751,int_stack+4377911,28);
 /*--- compute (i0|np) ---*/
   hrr3_build_np(Libderiv->CD,int_stack+4371863,int_stack+569244,int_stack+567396,28);
 /*--- compute (i0|md) ---*/
   hrr3_build_md(Libderiv->CD,int_stack+4407591,int_stack+4371863,int_stack+4347230,28);
 /*--- compute (i0|lf) ---*/
   hrr3_build_lf(Libderiv->CD,int_stack+4371863,int_stack+4407591,int_stack+4351850,28);
 /*--- compute (i0|kg) ---*/
   hrr3_build_kg(Libderiv->CD,int_stack+4407591,int_stack+4371863,int_stack+4385751,28);
 /*--- compute (i0|ih) ---*/
   hrr3_build_ih(Libderiv->CD,int_stack+4371863,int_stack+4407591,int_stack+4395831,28);
 /*--- compute (hp|ih) ---*/
   d1hrr1_build_hp(Libderiv->AB,int_stack+4388327,int_stack+4371863,int_stack+4359515, 0.0, zero_stack, 1.0, int_stack+1653855, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,588);
 /*--- compute (k0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+4425371,int_stack+572436,int_stack+571428,36);
 /*--- compute (k0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+4428395,int_stack+573732,int_stack+572436,36);
 /*--- compute (k0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+4432283,int_stack+4428395,int_stack+4425371,36);
 /*--- compute (k0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+4438331,int_stack+575352,int_stack+573732,36);
 /*--- compute (k0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+4443191,int_stack+4438331,int_stack+4428395,36);
 /*--- compute (k0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+4450967,int_stack+4443191,int_stack+4432283,36);
 /*--- compute (k0|mp) ---*/
   hrr3_build_mp(Libderiv->CD,int_stack+4425371,int_stack+577332,int_stack+575352,36);
 /*--- compute (k0|ld) ---*/
   hrr3_build_ld(Libderiv->CD,int_stack+4461047,int_stack+4425371,int_stack+4438331,36);
 /*--- compute (k0|kf) ---*/
   hrr3_build_kf(Libderiv->CD,int_stack+4470767,int_stack+4461047,int_stack+4443191,36);
 /*--- compute (k0|ig) ---*/
   hrr3_build_ig(Libderiv->CD,int_stack+4431311,int_stack+4470767,int_stack+4450967,36);
 /*--- compute (k0|np) ---*/
   hrr3_build_np(Libderiv->CD,int_stack+4446431,int_stack+579708,int_stack+577332,36);
 /*--- compute (k0|md) ---*/
   hrr3_build_md(Libderiv->CD,int_stack+4483727,int_stack+4446431,int_stack+4425371,36);
 /*--- compute (k0|lf) ---*/
   hrr3_build_lf(Libderiv->CD,int_stack+4495607,int_stack+4483727,int_stack+4461047,36);
 /*--- compute (k0|kg) ---*/
   hrr3_build_kg(Libderiv->CD,int_stack+4446431,int_stack+4495607,int_stack+4470767,36);
 /*--- compute (k0|ih) ---*/
   hrr3_build_ih(Libderiv->CD,int_stack+4465871,int_stack+4446431,int_stack+4431311,36);
 /*--- compute (ip|ih) ---*/
   d1hrr1_build_ip(Libderiv->AB,int_stack+4487039,int_stack+4465871,int_stack+4371863, 0.0, zero_stack, 1.0, int_stack+1666203, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,588);
 /*--- compute (hd|ih) ---*/
   d1hrr1_build_hd(Libderiv->AB,int_stack+4536431,int_stack+4487039,int_stack+4388327, 0.0, zero_stack, 1.0, int_stack+1682667, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,588);
 /*--- compute (l0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+4610519,int_stack+583776,int_stack+582516,45);
 /*--- compute (l0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+4614299,int_stack+585396,int_stack+583776,45);
 /*--- compute (l0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+4619159,int_stack+4614299,int_stack+4610519,45);
 /*--- compute (l0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+4626719,int_stack+587421,int_stack+585396,45);
 /*--- compute (l0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+4632794,int_stack+4626719,int_stack+4614299,45);
 /*--- compute (l0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+4642514,int_stack+4632794,int_stack+4619159,45);
 /*--- compute (l0|mp) ---*/
   hrr3_build_mp(Libderiv->CD,int_stack+4610519,int_stack+589896,int_stack+587421,45);
 /*--- compute (l0|ld) ---*/
   hrr3_build_ld(Libderiv->CD,int_stack+4655114,int_stack+4610519,int_stack+4626719,45);
 /*--- compute (l0|kf) ---*/
   hrr3_build_kf(Libderiv->CD,int_stack+4667264,int_stack+4655114,int_stack+4632794,45);
 /*--- compute (l0|ig) ---*/
   hrr3_build_ig(Libderiv->CD,int_stack+4617944,int_stack+4667264,int_stack+4642514,45);
 /*--- compute (l0|np) ---*/
   hrr3_build_np(Libderiv->CD,int_stack+4636844,int_stack+592866,int_stack+589896,45);
 /*--- compute (l0|md) ---*/
   hrr3_build_md(Libderiv->CD,int_stack+4683464,int_stack+4636844,int_stack+4610519,45);
 /*--- compute (l0|lf) ---*/
   hrr3_build_lf(Libderiv->CD,int_stack+4698314,int_stack+4683464,int_stack+4655114,45);
 /*--- compute (l0|kg) ---*/
   hrr3_build_kg(Libderiv->CD,int_stack+4636844,int_stack+4698314,int_stack+4667264,45);
 /*--- compute (l0|ih) ---*/
   hrr3_build_ih(Libderiv->CD,int_stack+4661144,int_stack+4636844,int_stack+4617944,45);
 /*--- compute (kp|ih) ---*/
   d1hrr1_build_kp(Libderiv->AB,int_stack+4687604,int_stack+4661144,int_stack+4465871, 0.0, zero_stack, 1.0, int_stack+1719711, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,588);
 /*--- compute (id|ih) ---*/
   d1hrr1_build_id(Libderiv->AB,int_stack+4751108,int_stack+4687604,int_stack+4487039, 0.0, zero_stack, 1.0, int_stack+1740879, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,588);
 /*--- compute (hf|ih) ---*/
   d1hrr1_build_hf(Libderiv->AB,int_stack+4347230,int_stack+4751108,int_stack+4536431, 0.0, zero_stack, 1.0, int_stack+1790271, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,588);
 /*--- compute (m0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+4849892,int_stack+597916,int_stack+596376,55);
 /*--- compute (m0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+4854512,int_stack+599896,int_stack+597916,55);
 /*--- compute (m0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+4860452,int_stack+4854512,int_stack+4849892,55);
 /*--- compute (m0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+4869692,int_stack+602371,int_stack+599896,55);
 /*--- compute (m0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+4877117,int_stack+4869692,int_stack+4854512,55);
 /*--- compute (m0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+4888997,int_stack+4877117,int_stack+4860452,55);
 /*--- compute (m0|mp) ---*/
   hrr3_build_mp(Libderiv->CD,int_stack+4849892,int_stack+605396,int_stack+602371,55);
 /*--- compute (m0|ld) ---*/
   hrr3_build_ld(Libderiv->CD,int_stack+4904397,int_stack+4849892,int_stack+4869692,55);
 /*--- compute (m0|kf) ---*/
   hrr3_build_kf(Libderiv->CD,int_stack+4470710,int_stack+4904397,int_stack+4877117,55);
 /*--- compute (m0|ig) ---*/
   hrr3_build_ig(Libderiv->CD,int_stack+4858967,int_stack+4470710,int_stack+4888997,55);
 /*--- compute (m0|np) ---*/
   hrr3_build_np(Libderiv->CD,int_stack+4882067,int_stack+609026,int_stack+605396,55);
 /*--- compute (m0|md) ---*/
   hrr3_build_md(Libderiv->CD,int_stack+4490510,int_stack+4882067,int_stack+4849892,55);
 /*--- compute (m0|lf) ---*/
   hrr3_build_lf(Libderiv->CD,int_stack+4508660,int_stack+4490510,int_stack+4904397,55);
 /*--- compute (m0|kg) ---*/
   hrr3_build_kg(Libderiv->CD,int_stack+4882067,int_stack+4508660,int_stack+4470710,55);
 /*--- compute (m0|ih) ---*/
   hrr3_build_ih(Libderiv->CD,int_stack+4470710,int_stack+4882067,int_stack+4858967,55);
 /*--- compute (lp|ih) ---*/
   d1hrr1_build_lp(Libderiv->AB,int_stack+4503050,int_stack+4470710,int_stack+4661144, 0.0, zero_stack, 1.0, int_stack+1864359, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,588);
 /*--- compute (kd|ih) ---*/
   d1hrr1_build_kd(Libderiv->AB,int_stack+409701,int_stack+4503050,int_stack+4687604, 0.0, zero_stack, 1.0, int_stack+3808622, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,588);
 /*--- compute (if|ih) ---*/
   d1hrr1_build_if(Libderiv->AB,int_stack+4582430,int_stack+409701,int_stack+4751108, 0.0, zero_stack, 1.0, int_stack+3872126, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,588);
 /*--- compute (hg|ih) ---*/
   d1hrr1_build_hg(Libderiv->AB,int_stack+5356826,int_stack+4582430,int_stack+4347230, 0.0, zero_stack, 1.0, int_stack+3970910, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,588);
 /*--- compute (n0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+4347230,int_stack+615164,int_stack+613316,66);
 /*--- compute (n0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+4352774,int_stack+617540,int_stack+615164,66);
 /*--- compute (n0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+663828,int_stack+4352774,int_stack+4347230,66);
 /*--- compute (n0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+4359902,int_stack+620510,int_stack+617540,66);
 /*--- compute (n0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+4368812,int_stack+4359902,int_stack+4352774,66);
 /*--- compute (n0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+4383068,int_stack+4368812,int_stack+663828,66);
 /*--- compute (n0|mp) ---*/
   hrr3_build_mp(Libderiv->CD,int_stack+663828,int_stack+624140,int_stack+620510,66);
 /*--- compute (n0|ld) ---*/
   hrr3_build_ld(Libderiv->CD,int_stack+4401548,int_stack+663828,int_stack+4359902,66);
 /*--- compute (n0|kf) ---*/
   hrr3_build_kf(Libderiv->CD,int_stack+4419368,int_stack+4401548,int_stack+4368812,66);
 /*--- compute (n0|ig) ---*/
   hrr3_build_ig(Libderiv->CD,int_stack+4347230,int_stack+4419368,int_stack+4383068,66);
 /*--- compute (n0|np) ---*/
   hrr3_build_np(Libderiv->CD,int_stack+4374950,int_stack+628496,int_stack+624140,66);
 /*--- compute (n0|md) ---*/
   hrr3_build_md(Libderiv->CD,int_stack+4443128,int_stack+4374950,int_stack+663828,66);
 /*--- compute (n0|lf) ---*/
   hrr3_build_lf(Libderiv->CD,int_stack+4747070,int_stack+4443128,int_stack+4401548,66);
 /*--- compute (n0|kg) ---*/
   hrr3_build_kg(Libderiv->CD,int_stack+4374950,int_stack+4747070,int_stack+4419368,66);
 /*--- compute (n0|ih) ---*/
   hrr3_build_ih(Libderiv->CD,int_stack+4747070,int_stack+4374950,int_stack+4347230,66);
 /*--- compute (mp|ih) ---*/
   d1hrr1_build_mp(Libderiv->AB,int_stack+4347230,int_stack+4747070,int_stack+4470710, 0.0, zero_stack, 1.0, int_stack+3442163, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,588);
 /*--- compute (ld|ih) ---*/
   d1hrr1_build_ld(Libderiv->AB,int_stack+4747070,int_stack+4347230,int_stack+4503050, 0.0, zero_stack, 1.0, int_stack+3474503, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,588);
 /*--- compute (kf|ih) ---*/
   d1hrr1_build_kf(Libderiv->AB,int_stack+4347230,int_stack+4747070,int_stack+409701, 0.0, zero_stack, 1.0, int_stack+1323039, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,588);
 /*--- compute (ig|ih) ---*/
   d1hrr1_build_ig(Libderiv->AB,int_stack+5542046,int_stack+4347230,int_stack+4582430, 0.0, zero_stack, 1.0, int_stack+767932, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,588);
 /*--- compute (h0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+4347230,int_stack+640700,int_stack+640112,21);
 /*--- compute (h0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+4348994,int_stack+641456,int_stack+640700,21);
 /*--- compute (h0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+4351262,int_stack+4348994,int_stack+4347230,21);
 /*--- compute (h0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+4354790,int_stack+642401,int_stack+641456,21);
 /*--- compute (h0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+4357625,int_stack+4354790,int_stack+4348994,21);
 /*--- compute (h0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+4094390,int_stack+4357625,int_stack+4351262,21);
 /*--- compute (h0|mp) ---*/
   hrr3_build_mp(Libderiv->CD,int_stack+4347230,int_stack+643556,int_stack+642401,21);
 /*--- compute (h0|ld) ---*/
   hrr3_build_ld(Libderiv->CD,int_stack+4362161,int_stack+4347230,int_stack+4354790,21);
 /*--- compute (h0|kf) ---*/
   hrr3_build_kf(Libderiv->CD,int_stack+4367831,int_stack+4362161,int_stack+4357625,21);
 /*--- compute (h0|ig) ---*/
   hrr3_build_ig(Libderiv->CD,int_stack+4350695,int_stack+4367831,int_stack+4094390,21);
 /*--- compute (h0|np) ---*/
   hrr3_build_np(Libderiv->CD,int_stack+4094390,int_stack+644942,int_stack+643556,21);
 /*--- compute (h0|md) ---*/
   hrr3_build_md(Libderiv->CD,int_stack+4375391,int_stack+4094390,int_stack+4347230,21);
 /*--- compute (h0|lf) ---*/
   hrr3_build_lf(Libderiv->CD,int_stack+4382321,int_stack+4375391,int_stack+4362161,21);
 /*--- compute (h0|kg) ---*/
   hrr3_build_kg(Libderiv->CD,int_stack+4391771,int_stack+4382321,int_stack+4367831,21);
 /*--- compute (h0|ih) ---*/
   hrr3_build_ih(Libderiv->CD,int_stack+4359515,int_stack+4391771,int_stack+4350695,21);
 /*--- compute (i0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+4347230,int_stack+655988,int_stack+655204,28);
 /*--- compute (i0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+4349582,int_stack+656996,int_stack+655988,28);
 /*--- compute (i0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+4352606,int_stack+4349582,int_stack+4347230,28);
 /*--- compute (i0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+4094390,int_stack+658256,int_stack+656996,28);
 /*--- compute (i0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+4371863,int_stack+4094390,int_stack+4349582,28);
 /*--- compute (i0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+4377911,int_stack+4371863,int_stack+4352606,28);
 /*--- compute (i0|mp) ---*/
   hrr3_build_mp(Libderiv->CD,int_stack+4347230,int_stack+659796,int_stack+658256,28);
 /*--- compute (i0|ld) ---*/
   hrr3_build_ld(Libderiv->CD,int_stack+4351850,int_stack+4347230,int_stack+4094390,28);
 /*--- compute (i0|kf) ---*/
   hrr3_build_kf(Libderiv->CD,int_stack+4385751,int_stack+4351850,int_stack+4371863,28);
 /*--- compute (i0|ig) ---*/
   hrr3_build_ig(Libderiv->CD,int_stack+4395831,int_stack+4385751,int_stack+4377911,28);
 /*--- compute (i0|np) ---*/
   hrr3_build_np(Libderiv->CD,int_stack+4371863,int_stack+661644,int_stack+659796,28);
 /*--- compute (i0|md) ---*/
   hrr3_build_md(Libderiv->CD,int_stack+4407591,int_stack+4371863,int_stack+4347230,28);
 /*--- compute (i0|lf) ---*/
   hrr3_build_lf(Libderiv->CD,int_stack+4371863,int_stack+4407591,int_stack+4351850,28);
 /*--- compute (i0|kg) ---*/
   hrr3_build_kg(Libderiv->CD,int_stack+4407591,int_stack+4371863,int_stack+4385751,28);
 /*--- compute (i0|ih) ---*/
   hrr3_build_ih(Libderiv->CD,int_stack+4371863,int_stack+4407591,int_stack+4395831,28);
 /*--- compute (hp|ih) ---*/
   d1hrr1_build_hp(Libderiv->AB,int_stack+4388327,int_stack+4371863,int_stack+4359515, 1.0, int_stack+1653855, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,588);
 /*--- compute (k0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+1653855,int_stack+675924,int_stack+674916,36);
 /*--- compute (k0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+1656879,int_stack+677220,int_stack+675924,36);
 /*--- compute (k0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+4425371,int_stack+1656879,int_stack+1653855,36);
 /*--- compute (k0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+1660767,int_stack+678840,int_stack+677220,36);
 /*--- compute (k0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+4431419,int_stack+1660767,int_stack+1656879,36);
 /*--- compute (k0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+4439195,int_stack+4431419,int_stack+4425371,36);
 /*--- compute (k0|mp) ---*/
   hrr3_build_mp(Libderiv->CD,int_stack+4425371,int_stack+680820,int_stack+678840,36);
 /*--- compute (k0|ld) ---*/
   hrr3_build_ld(Libderiv->CD,int_stack+4449275,int_stack+4425371,int_stack+1660767,36);
 /*--- compute (k0|kf) ---*/
   hrr3_build_kf(Libderiv->CD,int_stack+4458995,int_stack+4449275,int_stack+4431419,36);
 /*--- compute (k0|ig) ---*/
   hrr3_build_ig(Libderiv->CD,int_stack+4471955,int_stack+4458995,int_stack+4439195,36);
 /*--- compute (k0|np) ---*/
   hrr3_build_np(Libderiv->CD,int_stack+4431311,int_stack+683196,int_stack+680820,36);
 /*--- compute (k0|md) ---*/
   hrr3_build_md(Libderiv->CD,int_stack+1653855,int_stack+4431311,int_stack+4425371,36);
 /*--- compute (k0|lf) ---*/
   hrr3_build_lf(Libderiv->CD,int_stack+4425371,int_stack+1653855,int_stack+4449275,36);
 /*--- compute (k0|kg) ---*/
   hrr3_build_kg(Libderiv->CD,int_stack+4487075,int_stack+4425371,int_stack+4458995,36);
 /*--- compute (k0|ih) ---*/
   hrr3_build_ih(Libderiv->CD,int_stack+4425371,int_stack+4487075,int_stack+4471955,36);
 /*--- compute (ip|ih) ---*/
   d1hrr1_build_ip(Libderiv->AB,int_stack+4446539,int_stack+4425371,int_stack+4371863, 1.0, int_stack+1666203, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,588);
 /*--- compute (hd|ih) ---*/
   d1hrr1_build_hd(Libderiv->AB,int_stack+4495931,int_stack+4446539,int_stack+4388327, 1.0, int_stack+1682667, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,588);
 /*--- compute (l0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+4570019,int_stack+701124,int_stack+699864,45);
 /*--- compute (l0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+4573799,int_stack+702744,int_stack+701124,45);
 /*--- compute (l0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+4578659,int_stack+4573799,int_stack+4570019,45);
 /*--- compute (l0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+4586219,int_stack+704769,int_stack+702744,45);
 /*--- compute (l0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+4592294,int_stack+4586219,int_stack+4573799,45);
 /*--- compute (l0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+4602014,int_stack+4592294,int_stack+4578659,45);
 /*--- compute (l0|mp) ---*/
   hrr3_build_mp(Libderiv->CD,int_stack+4570019,int_stack+707244,int_stack+704769,45);
 /*--- compute (l0|ld) ---*/
   hrr3_build_ld(Libderiv->CD,int_stack+4614614,int_stack+4570019,int_stack+4586219,45);
 /*--- compute (l0|kf) ---*/
   hrr3_build_kf(Libderiv->CD,int_stack+4626764,int_stack+4614614,int_stack+4592294,45);
 /*--- compute (l0|ig) ---*/
   hrr3_build_ig(Libderiv->CD,int_stack+4577444,int_stack+4626764,int_stack+4602014,45);
 /*--- compute (l0|np) ---*/
   hrr3_build_np(Libderiv->CD,int_stack+4596344,int_stack+710214,int_stack+707244,45);
 /*--- compute (l0|md) ---*/
   hrr3_build_md(Libderiv->CD,int_stack+4642964,int_stack+4596344,int_stack+4570019,45);
 /*--- compute (l0|lf) ---*/
   hrr3_build_lf(Libderiv->CD,int_stack+4657814,int_stack+4642964,int_stack+4614614,45);
 /*--- compute (l0|kg) ---*/
   hrr3_build_kg(Libderiv->CD,int_stack+4596344,int_stack+4657814,int_stack+4626764,45);
 /*--- compute (l0|ih) ---*/
   hrr3_build_ih(Libderiv->CD,int_stack+4620644,int_stack+4596344,int_stack+4577444,45);
 /*--- compute (kp|ih) ---*/
   d1hrr1_build_kp(Libderiv->AB,int_stack+4647104,int_stack+4620644,int_stack+4425371, 1.0, int_stack+1719711, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,588);
 /*--- compute (id|ih) ---*/
   d1hrr1_build_id(Libderiv->AB,int_stack+4710608,int_stack+4647104,int_stack+4446539, 1.0, int_stack+1740879, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,588);
 /*--- compute (hf|ih) ---*/
   d1hrr1_build_hf(Libderiv->AB,int_stack+1653855,int_stack+4710608,int_stack+4495931, 1.0, int_stack+1790271, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,588);
 /*--- compute (m0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+4809392,int_stack+732204,int_stack+730664,55);
 /*--- compute (m0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+4814012,int_stack+734184,int_stack+732204,55);
 /*--- compute (m0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+4819952,int_stack+4814012,int_stack+4809392,55);
 /*--- compute (m0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+4829192,int_stack+736659,int_stack+734184,55);
 /*--- compute (m0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+4836617,int_stack+4829192,int_stack+4814012,55);
 /*--- compute (m0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+4848497,int_stack+4836617,int_stack+4819952,55);
 /*--- compute (m0|mp) ---*/
   hrr3_build_mp(Libderiv->CD,int_stack+4809392,int_stack+739684,int_stack+736659,55);
 /*--- compute (m0|ld) ---*/
   hrr3_build_ld(Libderiv->CD,int_stack+4863897,int_stack+4809392,int_stack+4829192,55);
 /*--- compute (m0|kf) ---*/
   hrr3_build_kf(Libderiv->CD,int_stack+4878747,int_stack+4863897,int_stack+4836617,55);
 /*--- compute (m0|ig) ---*/
   hrr3_build_ig(Libderiv->CD,int_stack+4818467,int_stack+4878747,int_stack+4848497,55);
 /*--- compute (m0|np) ---*/
   hrr3_build_np(Libderiv->CD,int_stack+4841567,int_stack+743314,int_stack+739684,55);
 /*--- compute (m0|md) ---*/
   hrr3_build_md(Libderiv->CD,int_stack+4898547,int_stack+4841567,int_stack+4809392,55);
 /*--- compute (m0|lf) ---*/
   hrr3_build_lf(Libderiv->CD,int_stack+1777335,int_stack+4898547,int_stack+4863897,55);
 /*--- compute (m0|kg) ---*/
   hrr3_build_kg(Libderiv->CD,int_stack+4841567,int_stack+1777335,int_stack+4878747,55);
 /*--- compute (m0|ih) ---*/
   hrr3_build_ih(Libderiv->CD,int_stack+1777335,int_stack+4841567,int_stack+4818467,55);
 /*--- compute (lp|ih) ---*/
   d1hrr1_build_lp(Libderiv->AB,int_stack+4809392,int_stack+1777335,int_stack+4620644, 1.0, int_stack+1864359, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,588);
 /*--- compute (kd|ih) ---*/
   d1hrr1_build_kd(Libderiv->AB,int_stack+4347230,int_stack+4809392,int_stack+4647104, 1.0, int_stack+3808622, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,588);
 /*--- compute (if|ih) ---*/
   d1hrr1_build_if(Libderiv->AB,int_stack+4474238,int_stack+4347230,int_stack+4710608, 1.0, int_stack+3872126, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,588);
 /*--- compute (hg|ih) ---*/
   d1hrr1_build_hg(Libderiv->AB,int_stack+409701,int_stack+4474238,int_stack+1653855, 1.0, int_stack+3970910, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,588);
 /*--- compute (n0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+1653855,int_stack+749452,int_stack+747604,66);
 /*--- compute (n0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+1659399,int_stack+751828,int_stack+749452,66);
 /*--- compute (n0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+1666527,int_stack+1659399,int_stack+1653855,66);
 /*--- compute (n0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+1677615,int_stack+754798,int_stack+751828,66);
 /*--- compute (n0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+1686525,int_stack+1677615,int_stack+1659399,66);
 /*--- compute (n0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+1700781,int_stack+1686525,int_stack+1666527,66);
 /*--- compute (n0|mp) ---*/
   hrr3_build_mp(Libderiv->CD,int_stack+1653855,int_stack+758428,int_stack+754798,66);
 /*--- compute (n0|ld) ---*/
   hrr3_build_ld(Libderiv->CD,int_stack+1719261,int_stack+1653855,int_stack+1677615,66);
 /*--- compute (n0|kf) ---*/
   hrr3_build_kf(Libderiv->CD,int_stack+1737081,int_stack+1719261,int_stack+1686525,66);
 /*--- compute (n0|ig) ---*/
   hrr3_build_ig(Libderiv->CD,int_stack+1664745,int_stack+1737081,int_stack+1700781,66);
 /*--- compute (n0|np) ---*/
   hrr3_build_np(Libderiv->CD,int_stack+1692465,int_stack+762784,int_stack+758428,66);
 /*--- compute (n0|md) ---*/
   hrr3_build_md(Libderiv->CD,int_stack+3808622,int_stack+1692465,int_stack+1653855,66);
 /*--- compute (n0|lf) ---*/
   hrr3_build_lf(Libderiv->CD,int_stack+3830402,int_stack+3808622,int_stack+1719261,66);
 /*--- compute (n0|kg) ---*/
   hrr3_build_kg(Libderiv->CD,int_stack+1692465,int_stack+3830402,int_stack+1737081,66);
 /*--- compute (n0|ih) ---*/
   hrr3_build_ih(Libderiv->CD,int_stack+3808622,int_stack+1692465,int_stack+1664745,66);
 /*--- compute (mp|ih) ---*/
   d1hrr1_build_mp(Libderiv->AB,int_stack+3847430,int_stack+3808622,int_stack+1777335, 1.0, int_stack+3442163, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,588);
 /*--- compute (ld|ih) ---*/
   d1hrr1_build_ld(Libderiv->AB,int_stack+1653855,int_stack+3847430,int_stack+4809392, 1.0, int_stack+3474503, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,588);
 /*--- compute (kf|ih) ---*/
   d1hrr1_build_kf(Libderiv->AB,int_stack+3808622,int_stack+1653855,int_stack+4347230, 1.0, int_stack+1323039, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,588);
 /*--- compute (ig|ih) ---*/
   d1hrr1_build_ig(Libderiv->AB,int_stack+1653855,int_stack+3808622,int_stack+4474238, 1.0, int_stack+767932, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,588);
 /*--- compute (hh|ih) ---*/
   hrr1_build_hh(Libderiv->AB,int_stack+3808622,int_stack+1923563,int_stack+1137819,588);
     Libderiv->ABCD[11] = int_stack + 3808622;
 /*--- compute (hh|ih) ---*/
   hrr1_build_hh(Libderiv->AB,int_stack+4347230,int_stack+2170523,int_stack+2424143,588);
     Libderiv->ABCD[10] = int_stack + 4347230;
 /*--- compute (hh|ih) ---*/
   hrr1_build_hh(Libderiv->AB,int_stack+4606538,int_stack+2948243,int_stack+1468635,588);
     Libderiv->ABCD[9] = int_stack + 4606538;
 /*--- compute (hh|ih) ---*/
   hrr1_build_hh(Libderiv->AB,int_stack+1900815,int_stack+2609363,int_stack+39261,588);
     Libderiv->ABCD[8] = int_stack + 1900815;
 /*--- compute (hh|ih) ---*/
   hrr1_build_hh(Libderiv->AB,int_stack+2160123,int_stack+3195203,int_stack+3623402,588);
     Libderiv->ABCD[7] = int_stack + 2160123;
 /*--- compute (hh|ih) ---*/
   hrr1_build_hh(Libderiv->AB,int_stack+2419431,int_stack+4100270,int_stack+224481,588);
     Libderiv->ABCD[6] = int_stack + 2419431;
 /*--- compute (hh|ih) ---*/
   d1hrr1_build_hh(Libderiv->AB,int_stack+4067930,int_stack+5109866,int_stack+4924646, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+932572, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,588);
     Libderiv->ABCD[2] = int_stack + 4067930;
 /*--- compute (hh|ih) ---*/
   d1hrr1_build_hh(Libderiv->AB,int_stack+4865846,int_stack+5542046,int_stack+5356826, 0.0, zero_stack, 1.0, int_stack+932572, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,588);
     Libderiv->ABCD[1] = int_stack + 4865846;
 /*--- compute (hh|ih) ---*/
   d1hrr1_build_hh(Libderiv->AB,int_stack+5125154,int_stack+1653855,int_stack+409701, 1.0, int_stack+932572, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,588);
     Libderiv->ABCD[0] = int_stack + 5125154;

}
